// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import type {protobuf as $protobuf} from "google-gax";
import Long = require("long");
/** Namespace google. */
export namespace google {

    /** Namespace cloud. */
    namespace cloud {

        /** Namespace compute. */
        namespace compute {

            /** Namespace v1. */
            namespace v1 {

                /** Properties of an AbandonInstancesInstanceGroupManagerRequest. */
                interface IAbandonInstancesInstanceGroupManagerRequest {

                    /** AbandonInstancesInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** AbandonInstancesInstanceGroupManagerRequest instanceGroupManagersAbandonInstancesRequestResource */
                    instanceGroupManagersAbandonInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersAbandonInstancesRequest|null);

                    /** AbandonInstancesInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** AbandonInstancesInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** AbandonInstancesInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AbandonInstancesInstanceGroupManagerRequest. */
                class AbandonInstancesInstanceGroupManagerRequest implements IAbandonInstancesInstanceGroupManagerRequest {

                    /**
                     * Constructs a new AbandonInstancesInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest);

                    /** AbandonInstancesInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** AbandonInstancesInstanceGroupManagerRequest instanceGroupManagersAbandonInstancesRequestResource. */
                    public instanceGroupManagersAbandonInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersAbandonInstancesRequest|null);

                    /** AbandonInstancesInstanceGroupManagerRequest project. */
                    public project: string;

                    /** AbandonInstancesInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** AbandonInstancesInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** AbandonInstancesInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AbandonInstancesInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AbandonInstancesInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest): google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified AbandonInstancesInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message AbandonInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AbandonInstancesInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message AbandonInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AbandonInstancesInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AbandonInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest;

                    /**
                     * Decodes an AbandonInstancesInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AbandonInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest;

                    /**
                     * Verifies an AbandonInstancesInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AbandonInstancesInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AbandonInstancesInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an AbandonInstancesInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message AbandonInstancesInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AbandonInstancesInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AbandonInstancesInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AbandonInstancesInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AbandonInstancesRegionInstanceGroupManagerRequest. */
                interface IAbandonInstancesRegionInstanceGroupManagerRequest {

                    /** AbandonInstancesRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersAbandonInstancesRequestResource */
                    regionInstanceGroupManagersAbandonInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersAbandonInstancesRequest|null);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AbandonInstancesRegionInstanceGroupManagerRequest. */
                class AbandonInstancesRegionInstanceGroupManagerRequest implements IAbandonInstancesRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new AbandonInstancesRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** AbandonInstancesRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** AbandonInstancesRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** AbandonInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersAbandonInstancesRequestResource. */
                    public regionInstanceGroupManagersAbandonInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersAbandonInstancesRequest|null);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** AbandonInstancesRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AbandonInstancesRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AbandonInstancesRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest): google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified AbandonInstancesRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message AbandonInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AbandonInstancesRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message AbandonInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AbandonInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AbandonInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes an AbandonInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AbandonInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies an AbandonInstancesRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AbandonInstancesRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AbandonInstancesRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an AbandonInstancesRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message AbandonInstancesRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AbandonInstancesRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AbandonInstancesRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AbandonInstancesRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AcceleratorConfig. */
                interface IAcceleratorConfig {

                    /** AcceleratorConfig acceleratorCount */
                    acceleratorCount?: (number|null);

                    /** AcceleratorConfig acceleratorType */
                    acceleratorType?: (string|null);
                }

                /** Represents an AcceleratorConfig. */
                class AcceleratorConfig implements IAcceleratorConfig {

                    /**
                     * Constructs a new AcceleratorConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAcceleratorConfig);

                    /** AcceleratorConfig acceleratorCount. */
                    public acceleratorCount?: (number|null);

                    /** AcceleratorConfig acceleratorType. */
                    public acceleratorType?: (string|null);

                    /** AcceleratorConfig _acceleratorCount. */
                    public _acceleratorCount?: "acceleratorCount";

                    /** AcceleratorConfig _acceleratorType. */
                    public _acceleratorType?: "acceleratorType";

                    /**
                     * Creates a new AcceleratorConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AcceleratorConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAcceleratorConfig): google.cloud.compute.v1.AcceleratorConfig;

                    /**
                     * Encodes the specified AcceleratorConfig message. Does not implicitly {@link google.cloud.compute.v1.AcceleratorConfig.verify|verify} messages.
                     * @param message AcceleratorConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAcceleratorConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AcceleratorConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AcceleratorConfig.verify|verify} messages.
                     * @param message AcceleratorConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAcceleratorConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AcceleratorConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AcceleratorConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AcceleratorConfig;

                    /**
                     * Decodes an AcceleratorConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AcceleratorConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AcceleratorConfig;

                    /**
                     * Verifies an AcceleratorConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AcceleratorConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AcceleratorConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AcceleratorConfig;

                    /**
                     * Creates a plain object from an AcceleratorConfig message. Also converts values to other types if specified.
                     * @param message AcceleratorConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AcceleratorConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AcceleratorConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AcceleratorConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AcceleratorType. */
                interface IAcceleratorType {

                    /** AcceleratorType creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** AcceleratorType deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** AcceleratorType description */
                    description?: (string|null);

                    /** AcceleratorType id */
                    id?: (number|Long|string|null);

                    /** AcceleratorType kind */
                    kind?: (string|null);

                    /** AcceleratorType maximumCardsPerInstance */
                    maximumCardsPerInstance?: (number|null);

                    /** AcceleratorType name */
                    name?: (string|null);

                    /** AcceleratorType selfLink */
                    selfLink?: (string|null);

                    /** AcceleratorType zone */
                    zone?: (string|null);
                }

                /** Represents an AcceleratorType. */
                class AcceleratorType implements IAcceleratorType {

                    /**
                     * Constructs a new AcceleratorType.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAcceleratorType);

                    /** AcceleratorType creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** AcceleratorType deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** AcceleratorType description. */
                    public description?: (string|null);

                    /** AcceleratorType id. */
                    public id?: (number|Long|string|null);

                    /** AcceleratorType kind. */
                    public kind?: (string|null);

                    /** AcceleratorType maximumCardsPerInstance. */
                    public maximumCardsPerInstance?: (number|null);

                    /** AcceleratorType name. */
                    public name?: (string|null);

                    /** AcceleratorType selfLink. */
                    public selfLink?: (string|null);

                    /** AcceleratorType zone. */
                    public zone?: (string|null);

                    /** AcceleratorType _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** AcceleratorType _deprecated. */
                    public _deprecated?: "deprecated";

                    /** AcceleratorType _description. */
                    public _description?: "description";

                    /** AcceleratorType _id. */
                    public _id?: "id";

                    /** AcceleratorType _kind. */
                    public _kind?: "kind";

                    /** AcceleratorType _maximumCardsPerInstance. */
                    public _maximumCardsPerInstance?: "maximumCardsPerInstance";

                    /** AcceleratorType _name. */
                    public _name?: "name";

                    /** AcceleratorType _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AcceleratorType _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new AcceleratorType instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AcceleratorType instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAcceleratorType): google.cloud.compute.v1.AcceleratorType;

                    /**
                     * Encodes the specified AcceleratorType message. Does not implicitly {@link google.cloud.compute.v1.AcceleratorType.verify|verify} messages.
                     * @param message AcceleratorType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAcceleratorType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AcceleratorType message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AcceleratorType.verify|verify} messages.
                     * @param message AcceleratorType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAcceleratorType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AcceleratorType message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AcceleratorType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AcceleratorType;

                    /**
                     * Decodes an AcceleratorType message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AcceleratorType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AcceleratorType;

                    /**
                     * Verifies an AcceleratorType message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AcceleratorType message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AcceleratorType
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AcceleratorType;

                    /**
                     * Creates a plain object from an AcceleratorType message. Also converts values to other types if specified.
                     * @param message AcceleratorType
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AcceleratorType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AcceleratorType to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AcceleratorType
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AcceleratorTypeAggregatedList. */
                interface IAcceleratorTypeAggregatedList {

                    /** AcceleratorTypeAggregatedList id */
                    id?: (string|null);

                    /** AcceleratorTypeAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IAcceleratorTypesScopedList }|null);

                    /** AcceleratorTypeAggregatedList kind */
                    kind?: (string|null);

                    /** AcceleratorTypeAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AcceleratorTypeAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** AcceleratorTypeAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** AcceleratorTypeAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AcceleratorTypeAggregatedList. */
                class AcceleratorTypeAggregatedList implements IAcceleratorTypeAggregatedList {

                    /**
                     * Constructs a new AcceleratorTypeAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAcceleratorTypeAggregatedList);

                    /** AcceleratorTypeAggregatedList id. */
                    public id?: (string|null);

                    /** AcceleratorTypeAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IAcceleratorTypesScopedList };

                    /** AcceleratorTypeAggregatedList kind. */
                    public kind?: (string|null);

                    /** AcceleratorTypeAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AcceleratorTypeAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** AcceleratorTypeAggregatedList unreachables. */
                    public unreachables: string[];

                    /** AcceleratorTypeAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AcceleratorTypeAggregatedList _id. */
                    public _id?: "id";

                    /** AcceleratorTypeAggregatedList _kind. */
                    public _kind?: "kind";

                    /** AcceleratorTypeAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AcceleratorTypeAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AcceleratorTypeAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AcceleratorTypeAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AcceleratorTypeAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAcceleratorTypeAggregatedList): google.cloud.compute.v1.AcceleratorTypeAggregatedList;

                    /**
                     * Encodes the specified AcceleratorTypeAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.AcceleratorTypeAggregatedList.verify|verify} messages.
                     * @param message AcceleratorTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAcceleratorTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AcceleratorTypeAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AcceleratorTypeAggregatedList.verify|verify} messages.
                     * @param message AcceleratorTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAcceleratorTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AcceleratorTypeAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AcceleratorTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AcceleratorTypeAggregatedList;

                    /**
                     * Decodes an AcceleratorTypeAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AcceleratorTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AcceleratorTypeAggregatedList;

                    /**
                     * Verifies an AcceleratorTypeAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AcceleratorTypeAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AcceleratorTypeAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AcceleratorTypeAggregatedList;

                    /**
                     * Creates a plain object from an AcceleratorTypeAggregatedList message. Also converts values to other types if specified.
                     * @param message AcceleratorTypeAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AcceleratorTypeAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AcceleratorTypeAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AcceleratorTypeAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AcceleratorTypeList. */
                interface IAcceleratorTypeList {

                    /** AcceleratorTypeList id */
                    id?: (string|null);

                    /** AcceleratorTypeList items */
                    items?: (google.cloud.compute.v1.IAcceleratorType[]|null);

                    /** AcceleratorTypeList kind */
                    kind?: (string|null);

                    /** AcceleratorTypeList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AcceleratorTypeList selfLink */
                    selfLink?: (string|null);

                    /** AcceleratorTypeList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AcceleratorTypeList. */
                class AcceleratorTypeList implements IAcceleratorTypeList {

                    /**
                     * Constructs a new AcceleratorTypeList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAcceleratorTypeList);

                    /** AcceleratorTypeList id. */
                    public id?: (string|null);

                    /** AcceleratorTypeList items. */
                    public items: google.cloud.compute.v1.IAcceleratorType[];

                    /** AcceleratorTypeList kind. */
                    public kind?: (string|null);

                    /** AcceleratorTypeList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AcceleratorTypeList selfLink. */
                    public selfLink?: (string|null);

                    /** AcceleratorTypeList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AcceleratorTypeList _id. */
                    public _id?: "id";

                    /** AcceleratorTypeList _kind. */
                    public _kind?: "kind";

                    /** AcceleratorTypeList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AcceleratorTypeList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AcceleratorTypeList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AcceleratorTypeList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AcceleratorTypeList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAcceleratorTypeList): google.cloud.compute.v1.AcceleratorTypeList;

                    /**
                     * Encodes the specified AcceleratorTypeList message. Does not implicitly {@link google.cloud.compute.v1.AcceleratorTypeList.verify|verify} messages.
                     * @param message AcceleratorTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAcceleratorTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AcceleratorTypeList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AcceleratorTypeList.verify|verify} messages.
                     * @param message AcceleratorTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAcceleratorTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AcceleratorTypeList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AcceleratorTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AcceleratorTypeList;

                    /**
                     * Decodes an AcceleratorTypeList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AcceleratorTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AcceleratorTypeList;

                    /**
                     * Verifies an AcceleratorTypeList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AcceleratorTypeList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AcceleratorTypeList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AcceleratorTypeList;

                    /**
                     * Creates a plain object from an AcceleratorTypeList message. Also converts values to other types if specified.
                     * @param message AcceleratorTypeList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AcceleratorTypeList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AcceleratorTypeList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AcceleratorTypeList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AcceleratorTypesScopedList. */
                interface IAcceleratorTypesScopedList {

                    /** AcceleratorTypesScopedList acceleratorTypes */
                    acceleratorTypes?: (google.cloud.compute.v1.IAcceleratorType[]|null);

                    /** AcceleratorTypesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AcceleratorTypesScopedList. */
                class AcceleratorTypesScopedList implements IAcceleratorTypesScopedList {

                    /**
                     * Constructs a new AcceleratorTypesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAcceleratorTypesScopedList);

                    /** AcceleratorTypesScopedList acceleratorTypes. */
                    public acceleratorTypes: google.cloud.compute.v1.IAcceleratorType[];

                    /** AcceleratorTypesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AcceleratorTypesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AcceleratorTypesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AcceleratorTypesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAcceleratorTypesScopedList): google.cloud.compute.v1.AcceleratorTypesScopedList;

                    /**
                     * Encodes the specified AcceleratorTypesScopedList message. Does not implicitly {@link google.cloud.compute.v1.AcceleratorTypesScopedList.verify|verify} messages.
                     * @param message AcceleratorTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAcceleratorTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AcceleratorTypesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AcceleratorTypesScopedList.verify|verify} messages.
                     * @param message AcceleratorTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAcceleratorTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AcceleratorTypesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AcceleratorTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AcceleratorTypesScopedList;

                    /**
                     * Decodes an AcceleratorTypesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AcceleratorTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AcceleratorTypesScopedList;

                    /**
                     * Verifies an AcceleratorTypesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AcceleratorTypesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AcceleratorTypesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AcceleratorTypesScopedList;

                    /**
                     * Creates a plain object from an AcceleratorTypesScopedList message. Also converts values to other types if specified.
                     * @param message AcceleratorTypesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AcceleratorTypesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AcceleratorTypesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AcceleratorTypesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Accelerators. */
                interface IAccelerators {

                    /** Accelerators guestAcceleratorCount */
                    guestAcceleratorCount?: (number|null);

                    /** Accelerators guestAcceleratorType */
                    guestAcceleratorType?: (string|null);
                }

                /** Represents an Accelerators. */
                class Accelerators implements IAccelerators {

                    /**
                     * Constructs a new Accelerators.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAccelerators);

                    /** Accelerators guestAcceleratorCount. */
                    public guestAcceleratorCount?: (number|null);

                    /** Accelerators guestAcceleratorType. */
                    public guestAcceleratorType?: (string|null);

                    /** Accelerators _guestAcceleratorCount. */
                    public _guestAcceleratorCount?: "guestAcceleratorCount";

                    /** Accelerators _guestAcceleratorType. */
                    public _guestAcceleratorType?: "guestAcceleratorType";

                    /**
                     * Creates a new Accelerators instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Accelerators instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAccelerators): google.cloud.compute.v1.Accelerators;

                    /**
                     * Encodes the specified Accelerators message. Does not implicitly {@link google.cloud.compute.v1.Accelerators.verify|verify} messages.
                     * @param message Accelerators message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAccelerators, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Accelerators message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Accelerators.verify|verify} messages.
                     * @param message Accelerators message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAccelerators, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Accelerators message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Accelerators
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Accelerators;

                    /**
                     * Decodes an Accelerators message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Accelerators
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Accelerators;

                    /**
                     * Verifies an Accelerators message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Accelerators message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Accelerators
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Accelerators;

                    /**
                     * Creates a plain object from an Accelerators message. Also converts values to other types if specified.
                     * @param message Accelerators
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Accelerators, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Accelerators to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Accelerators
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AccessConfig. */
                interface IAccessConfig {

                    /** AccessConfig externalIpv6 */
                    externalIpv6?: (string|null);

                    /** AccessConfig externalIpv6PrefixLength */
                    externalIpv6PrefixLength?: (number|null);

                    /** AccessConfig kind */
                    kind?: (string|null);

                    /** AccessConfig name */
                    name?: (string|null);

                    /** AccessConfig natIP */
                    natIP?: (string|null);

                    /** AccessConfig networkTier */
                    networkTier?: (string|null);

                    /** AccessConfig publicPtrDomainName */
                    publicPtrDomainName?: (string|null);

                    /** AccessConfig setPublicPtr */
                    setPublicPtr?: (boolean|null);

                    /** AccessConfig type */
                    type?: (string|null);
                }

                /** Represents an AccessConfig. */
                class AccessConfig implements IAccessConfig {

                    /**
                     * Constructs a new AccessConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAccessConfig);

                    /** AccessConfig externalIpv6. */
                    public externalIpv6?: (string|null);

                    /** AccessConfig externalIpv6PrefixLength. */
                    public externalIpv6PrefixLength?: (number|null);

                    /** AccessConfig kind. */
                    public kind?: (string|null);

                    /** AccessConfig name. */
                    public name?: (string|null);

                    /** AccessConfig natIP. */
                    public natIP?: (string|null);

                    /** AccessConfig networkTier. */
                    public networkTier?: (string|null);

                    /** AccessConfig publicPtrDomainName. */
                    public publicPtrDomainName?: (string|null);

                    /** AccessConfig setPublicPtr. */
                    public setPublicPtr?: (boolean|null);

                    /** AccessConfig type. */
                    public type?: (string|null);

                    /** AccessConfig _externalIpv6. */
                    public _externalIpv6?: "externalIpv6";

                    /** AccessConfig _externalIpv6PrefixLength. */
                    public _externalIpv6PrefixLength?: "externalIpv6PrefixLength";

                    /** AccessConfig _kind. */
                    public _kind?: "kind";

                    /** AccessConfig _name. */
                    public _name?: "name";

                    /** AccessConfig _natIP. */
                    public _natIP?: "natIP";

                    /** AccessConfig _networkTier. */
                    public _networkTier?: "networkTier";

                    /** AccessConfig _publicPtrDomainName. */
                    public _publicPtrDomainName?: "publicPtrDomainName";

                    /** AccessConfig _setPublicPtr. */
                    public _setPublicPtr?: "setPublicPtr";

                    /** AccessConfig _type. */
                    public _type?: "type";

                    /**
                     * Creates a new AccessConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AccessConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAccessConfig): google.cloud.compute.v1.AccessConfig;

                    /**
                     * Encodes the specified AccessConfig message. Does not implicitly {@link google.cloud.compute.v1.AccessConfig.verify|verify} messages.
                     * @param message AccessConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAccessConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AccessConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AccessConfig.verify|verify} messages.
                     * @param message AccessConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAccessConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AccessConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AccessConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AccessConfig;

                    /**
                     * Decodes an AccessConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AccessConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AccessConfig;

                    /**
                     * Verifies an AccessConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AccessConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AccessConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AccessConfig;

                    /**
                     * Creates a plain object from an AccessConfig message. Also converts values to other types if specified.
                     * @param message AccessConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AccessConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AccessConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AccessConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AccessConfig {

                    /** NetworkTier enum. */
                    enum NetworkTier {
                        UNDEFINED_NETWORK_TIER = 0,
                        FIXED_STANDARD = 310464328,
                        PREMIUM = 399530551,
                        STANDARD = 484642493,
                        STANDARD_OVERRIDES_FIXED_STANDARD = 465847234
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        DIRECT_IPV6 = 4397213,
                        ONE_TO_ONE_NAT = 84090205
                    }
                }

                /** Properties of an AddAccessConfigInstanceRequest. */
                interface IAddAccessConfigInstanceRequest {

                    /** AddAccessConfigInstanceRequest accessConfigResource */
                    accessConfigResource?: (google.cloud.compute.v1.IAccessConfig|null);

                    /** AddAccessConfigInstanceRequest instance */
                    instance?: (string|null);

                    /** AddAccessConfigInstanceRequest networkInterface */
                    networkInterface?: (string|null);

                    /** AddAccessConfigInstanceRequest project */
                    project?: (string|null);

                    /** AddAccessConfigInstanceRequest requestId */
                    requestId?: (string|null);

                    /** AddAccessConfigInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AddAccessConfigInstanceRequest. */
                class AddAccessConfigInstanceRequest implements IAddAccessConfigInstanceRequest {

                    /**
                     * Constructs a new AddAccessConfigInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddAccessConfigInstanceRequest);

                    /** AddAccessConfigInstanceRequest accessConfigResource. */
                    public accessConfigResource?: (google.cloud.compute.v1.IAccessConfig|null);

                    /** AddAccessConfigInstanceRequest instance. */
                    public instance: string;

                    /** AddAccessConfigInstanceRequest networkInterface. */
                    public networkInterface: string;

                    /** AddAccessConfigInstanceRequest project. */
                    public project: string;

                    /** AddAccessConfigInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** AddAccessConfigInstanceRequest zone. */
                    public zone: string;

                    /** AddAccessConfigInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddAccessConfigInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddAccessConfigInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddAccessConfigInstanceRequest): google.cloud.compute.v1.AddAccessConfigInstanceRequest;

                    /**
                     * Encodes the specified AddAccessConfigInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.AddAccessConfigInstanceRequest.verify|verify} messages.
                     * @param message AddAccessConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddAccessConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddAccessConfigInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddAccessConfigInstanceRequest.verify|verify} messages.
                     * @param message AddAccessConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddAccessConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddAccessConfigInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddAccessConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddAccessConfigInstanceRequest;

                    /**
                     * Decodes an AddAccessConfigInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddAccessConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddAccessConfigInstanceRequest;

                    /**
                     * Verifies an AddAccessConfigInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddAccessConfigInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddAccessConfigInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddAccessConfigInstanceRequest;

                    /**
                     * Creates a plain object from an AddAccessConfigInstanceRequest message. Also converts values to other types if specified.
                     * @param message AddAccessConfigInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddAccessConfigInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddAccessConfigInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddAccessConfigInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddAssociationFirewallPolicyRequest. */
                interface IAddAssociationFirewallPolicyRequest {

                    /** AddAssociationFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** AddAssociationFirewallPolicyRequest firewallPolicyAssociationResource */
                    firewallPolicyAssociationResource?: (google.cloud.compute.v1.IFirewallPolicyAssociation|null);

                    /** AddAssociationFirewallPolicyRequest replaceExistingAssociation */
                    replaceExistingAssociation?: (boolean|null);

                    /** AddAssociationFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddAssociationFirewallPolicyRequest. */
                class AddAssociationFirewallPolicyRequest implements IAddAssociationFirewallPolicyRequest {

                    /**
                     * Constructs a new AddAssociationFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddAssociationFirewallPolicyRequest);

                    /** AddAssociationFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** AddAssociationFirewallPolicyRequest firewallPolicyAssociationResource. */
                    public firewallPolicyAssociationResource?: (google.cloud.compute.v1.IFirewallPolicyAssociation|null);

                    /** AddAssociationFirewallPolicyRequest replaceExistingAssociation. */
                    public replaceExistingAssociation?: (boolean|null);

                    /** AddAssociationFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** AddAssociationFirewallPolicyRequest _replaceExistingAssociation. */
                    public _replaceExistingAssociation?: "replaceExistingAssociation";

                    /** AddAssociationFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddAssociationFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddAssociationFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddAssociationFirewallPolicyRequest): google.cloud.compute.v1.AddAssociationFirewallPolicyRequest;

                    /**
                     * Encodes the specified AddAssociationFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddAssociationFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddAssociationFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddAssociationFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddAssociationFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddAssociationFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddAssociationFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddAssociationFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddAssociationFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddAssociationFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddAssociationFirewallPolicyRequest;

                    /**
                     * Decodes an AddAssociationFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddAssociationFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddAssociationFirewallPolicyRequest;

                    /**
                     * Verifies an AddAssociationFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddAssociationFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddAssociationFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddAssociationFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an AddAssociationFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddAssociationFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddAssociationFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddAssociationFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddAssociationFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddAssociationNetworkFirewallPolicyRequest. */
                interface IAddAssociationNetworkFirewallPolicyRequest {

                    /** AddAssociationNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** AddAssociationNetworkFirewallPolicyRequest firewallPolicyAssociationResource */
                    firewallPolicyAssociationResource?: (google.cloud.compute.v1.IFirewallPolicyAssociation|null);

                    /** AddAssociationNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** AddAssociationNetworkFirewallPolicyRequest replaceExistingAssociation */
                    replaceExistingAssociation?: (boolean|null);

                    /** AddAssociationNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddAssociationNetworkFirewallPolicyRequest. */
                class AddAssociationNetworkFirewallPolicyRequest implements IAddAssociationNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new AddAssociationNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddAssociationNetworkFirewallPolicyRequest);

                    /** AddAssociationNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** AddAssociationNetworkFirewallPolicyRequest firewallPolicyAssociationResource. */
                    public firewallPolicyAssociationResource?: (google.cloud.compute.v1.IFirewallPolicyAssociation|null);

                    /** AddAssociationNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** AddAssociationNetworkFirewallPolicyRequest replaceExistingAssociation. */
                    public replaceExistingAssociation?: (boolean|null);

                    /** AddAssociationNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** AddAssociationNetworkFirewallPolicyRequest _replaceExistingAssociation. */
                    public _replaceExistingAssociation?: "replaceExistingAssociation";

                    /** AddAssociationNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddAssociationNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddAssociationNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddAssociationNetworkFirewallPolicyRequest): google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified AddAssociationNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddAssociationNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddAssociationNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddAssociationNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddAssociationNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddAssociationNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddAssociationNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddAssociationNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Decodes an AddAssociationNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddAssociationNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Verifies an AddAssociationNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddAssociationNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddAssociationNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an AddAssociationNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddAssociationNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddAssociationNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddAssociationNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddAssociationNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddAssociationRegionNetworkFirewallPolicyRequest. */
                interface IAddAssociationRegionNetworkFirewallPolicyRequest {

                    /** AddAssociationRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest firewallPolicyAssociationResource */
                    firewallPolicyAssociationResource?: (google.cloud.compute.v1.IFirewallPolicyAssociation|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest replaceExistingAssociation */
                    replaceExistingAssociation?: (boolean|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddAssociationRegionNetworkFirewallPolicyRequest. */
                class AddAssociationRegionNetworkFirewallPolicyRequest implements IAddAssociationRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new AddAssociationRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddAssociationRegionNetworkFirewallPolicyRequest);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** AddAssociationRegionNetworkFirewallPolicyRequest firewallPolicyAssociationResource. */
                    public firewallPolicyAssociationResource?: (google.cloud.compute.v1.IFirewallPolicyAssociation|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** AddAssociationRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** AddAssociationRegionNetworkFirewallPolicyRequest replaceExistingAssociation. */
                    public replaceExistingAssociation?: (boolean|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** AddAssociationRegionNetworkFirewallPolicyRequest _replaceExistingAssociation. */
                    public _replaceExistingAssociation?: "replaceExistingAssociation";

                    /** AddAssociationRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddAssociationRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddAssociationRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddAssociationRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified AddAssociationRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddAssociationRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddAssociationRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddAssociationRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddAssociationRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddAssociationRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddAssociationRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddAssociationRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes an AddAssociationRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddAssociationRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies an AddAssociationRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddAssociationRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddAssociationRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an AddAssociationRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddAssociationRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddAssociationRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddAssociationRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddAssociationRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddHealthCheckTargetPoolRequest. */
                interface IAddHealthCheckTargetPoolRequest {

                    /** AddHealthCheckTargetPoolRequest project */
                    project?: (string|null);

                    /** AddHealthCheckTargetPoolRequest region */
                    region?: (string|null);

                    /** AddHealthCheckTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** AddHealthCheckTargetPoolRequest targetPool */
                    targetPool?: (string|null);

                    /** AddHealthCheckTargetPoolRequest targetPoolsAddHealthCheckRequestResource */
                    targetPoolsAddHealthCheckRequestResource?: (google.cloud.compute.v1.ITargetPoolsAddHealthCheckRequest|null);
                }

                /** Represents an AddHealthCheckTargetPoolRequest. */
                class AddHealthCheckTargetPoolRequest implements IAddHealthCheckTargetPoolRequest {

                    /**
                     * Constructs a new AddHealthCheckTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddHealthCheckTargetPoolRequest);

                    /** AddHealthCheckTargetPoolRequest project. */
                    public project: string;

                    /** AddHealthCheckTargetPoolRequest region. */
                    public region: string;

                    /** AddHealthCheckTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** AddHealthCheckTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /** AddHealthCheckTargetPoolRequest targetPoolsAddHealthCheckRequestResource. */
                    public targetPoolsAddHealthCheckRequestResource?: (google.cloud.compute.v1.ITargetPoolsAddHealthCheckRequest|null);

                    /** AddHealthCheckTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddHealthCheckTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddHealthCheckTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddHealthCheckTargetPoolRequest): google.cloud.compute.v1.AddHealthCheckTargetPoolRequest;

                    /**
                     * Encodes the specified AddHealthCheckTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.AddHealthCheckTargetPoolRequest.verify|verify} messages.
                     * @param message AddHealthCheckTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddHealthCheckTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddHealthCheckTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddHealthCheckTargetPoolRequest.verify|verify} messages.
                     * @param message AddHealthCheckTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddHealthCheckTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddHealthCheckTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddHealthCheckTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddHealthCheckTargetPoolRequest;

                    /**
                     * Decodes an AddHealthCheckTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddHealthCheckTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddHealthCheckTargetPoolRequest;

                    /**
                     * Verifies an AddHealthCheckTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddHealthCheckTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddHealthCheckTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddHealthCheckTargetPoolRequest;

                    /**
                     * Creates a plain object from an AddHealthCheckTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message AddHealthCheckTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddHealthCheckTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddHealthCheckTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddHealthCheckTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddInstanceTargetPoolRequest. */
                interface IAddInstanceTargetPoolRequest {

                    /** AddInstanceTargetPoolRequest project */
                    project?: (string|null);

                    /** AddInstanceTargetPoolRequest region */
                    region?: (string|null);

                    /** AddInstanceTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** AddInstanceTargetPoolRequest targetPool */
                    targetPool?: (string|null);

                    /** AddInstanceTargetPoolRequest targetPoolsAddInstanceRequestResource */
                    targetPoolsAddInstanceRequestResource?: (google.cloud.compute.v1.ITargetPoolsAddInstanceRequest|null);
                }

                /** Represents an AddInstanceTargetPoolRequest. */
                class AddInstanceTargetPoolRequest implements IAddInstanceTargetPoolRequest {

                    /**
                     * Constructs a new AddInstanceTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddInstanceTargetPoolRequest);

                    /** AddInstanceTargetPoolRequest project. */
                    public project: string;

                    /** AddInstanceTargetPoolRequest region. */
                    public region: string;

                    /** AddInstanceTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** AddInstanceTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /** AddInstanceTargetPoolRequest targetPoolsAddInstanceRequestResource. */
                    public targetPoolsAddInstanceRequestResource?: (google.cloud.compute.v1.ITargetPoolsAddInstanceRequest|null);

                    /** AddInstanceTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddInstanceTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddInstanceTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddInstanceTargetPoolRequest): google.cloud.compute.v1.AddInstanceTargetPoolRequest;

                    /**
                     * Encodes the specified AddInstanceTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.AddInstanceTargetPoolRequest.verify|verify} messages.
                     * @param message AddInstanceTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddInstanceTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddInstanceTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddInstanceTargetPoolRequest.verify|verify} messages.
                     * @param message AddInstanceTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddInstanceTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddInstanceTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddInstanceTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddInstanceTargetPoolRequest;

                    /**
                     * Decodes an AddInstanceTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddInstanceTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddInstanceTargetPoolRequest;

                    /**
                     * Verifies an AddInstanceTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddInstanceTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddInstanceTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddInstanceTargetPoolRequest;

                    /**
                     * Creates a plain object from an AddInstanceTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message AddInstanceTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddInstanceTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddInstanceTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddInstanceTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddInstancesInstanceGroupRequest. */
                interface IAddInstancesInstanceGroupRequest {

                    /** AddInstancesInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** AddInstancesInstanceGroupRequest instanceGroupsAddInstancesRequestResource */
                    instanceGroupsAddInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupsAddInstancesRequest|null);

                    /** AddInstancesInstanceGroupRequest project */
                    project?: (string|null);

                    /** AddInstancesInstanceGroupRequest requestId */
                    requestId?: (string|null);

                    /** AddInstancesInstanceGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AddInstancesInstanceGroupRequest. */
                class AddInstancesInstanceGroupRequest implements IAddInstancesInstanceGroupRequest {

                    /**
                     * Constructs a new AddInstancesInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddInstancesInstanceGroupRequest);

                    /** AddInstancesInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** AddInstancesInstanceGroupRequest instanceGroupsAddInstancesRequestResource. */
                    public instanceGroupsAddInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupsAddInstancesRequest|null);

                    /** AddInstancesInstanceGroupRequest project. */
                    public project: string;

                    /** AddInstancesInstanceGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** AddInstancesInstanceGroupRequest zone. */
                    public zone: string;

                    /** AddInstancesInstanceGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddInstancesInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddInstancesInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddInstancesInstanceGroupRequest): google.cloud.compute.v1.AddInstancesInstanceGroupRequest;

                    /**
                     * Encodes the specified AddInstancesInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.AddInstancesInstanceGroupRequest.verify|verify} messages.
                     * @param message AddInstancesInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddInstancesInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddInstancesInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddInstancesInstanceGroupRequest.verify|verify} messages.
                     * @param message AddInstancesInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddInstancesInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddInstancesInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddInstancesInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddInstancesInstanceGroupRequest;

                    /**
                     * Decodes an AddInstancesInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddInstancesInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddInstancesInstanceGroupRequest;

                    /**
                     * Verifies an AddInstancesInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddInstancesInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddInstancesInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddInstancesInstanceGroupRequest;

                    /**
                     * Creates a plain object from an AddInstancesInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message AddInstancesInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddInstancesInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddInstancesInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddInstancesInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddNodesNodeGroupRequest. */
                interface IAddNodesNodeGroupRequest {

                    /** AddNodesNodeGroupRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** AddNodesNodeGroupRequest nodeGroupsAddNodesRequestResource */
                    nodeGroupsAddNodesRequestResource?: (google.cloud.compute.v1.INodeGroupsAddNodesRequest|null);

                    /** AddNodesNodeGroupRequest project */
                    project?: (string|null);

                    /** AddNodesNodeGroupRequest requestId */
                    requestId?: (string|null);

                    /** AddNodesNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AddNodesNodeGroupRequest. */
                class AddNodesNodeGroupRequest implements IAddNodesNodeGroupRequest {

                    /**
                     * Constructs a new AddNodesNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddNodesNodeGroupRequest);

                    /** AddNodesNodeGroupRequest nodeGroup. */
                    public nodeGroup: string;

                    /** AddNodesNodeGroupRequest nodeGroupsAddNodesRequestResource. */
                    public nodeGroupsAddNodesRequestResource?: (google.cloud.compute.v1.INodeGroupsAddNodesRequest|null);

                    /** AddNodesNodeGroupRequest project. */
                    public project: string;

                    /** AddNodesNodeGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** AddNodesNodeGroupRequest zone. */
                    public zone: string;

                    /** AddNodesNodeGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddNodesNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddNodesNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddNodesNodeGroupRequest): google.cloud.compute.v1.AddNodesNodeGroupRequest;

                    /**
                     * Encodes the specified AddNodesNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.AddNodesNodeGroupRequest.verify|verify} messages.
                     * @param message AddNodesNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddNodesNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddNodesNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddNodesNodeGroupRequest.verify|verify} messages.
                     * @param message AddNodesNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddNodesNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddNodesNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddNodesNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddNodesNodeGroupRequest;

                    /**
                     * Decodes an AddNodesNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddNodesNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddNodesNodeGroupRequest;

                    /**
                     * Verifies an AddNodesNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddNodesNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddNodesNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddNodesNodeGroupRequest;

                    /**
                     * Creates a plain object from an AddNodesNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message AddNodesNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddNodesNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddNodesNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddNodesNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddPeeringNetworkRequest. */
                interface IAddPeeringNetworkRequest {

                    /** AddPeeringNetworkRequest network */
                    network?: (string|null);

                    /** AddPeeringNetworkRequest networksAddPeeringRequestResource */
                    networksAddPeeringRequestResource?: (google.cloud.compute.v1.INetworksAddPeeringRequest|null);

                    /** AddPeeringNetworkRequest project */
                    project?: (string|null);

                    /** AddPeeringNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddPeeringNetworkRequest. */
                class AddPeeringNetworkRequest implements IAddPeeringNetworkRequest {

                    /**
                     * Constructs a new AddPeeringNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddPeeringNetworkRequest);

                    /** AddPeeringNetworkRequest network. */
                    public network: string;

                    /** AddPeeringNetworkRequest networksAddPeeringRequestResource. */
                    public networksAddPeeringRequestResource?: (google.cloud.compute.v1.INetworksAddPeeringRequest|null);

                    /** AddPeeringNetworkRequest project. */
                    public project: string;

                    /** AddPeeringNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** AddPeeringNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddPeeringNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddPeeringNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddPeeringNetworkRequest): google.cloud.compute.v1.AddPeeringNetworkRequest;

                    /**
                     * Encodes the specified AddPeeringNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.AddPeeringNetworkRequest.verify|verify} messages.
                     * @param message AddPeeringNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddPeeringNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddPeeringNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddPeeringNetworkRequest.verify|verify} messages.
                     * @param message AddPeeringNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddPeeringNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddPeeringNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddPeeringNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddPeeringNetworkRequest;

                    /**
                     * Decodes an AddPeeringNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddPeeringNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddPeeringNetworkRequest;

                    /**
                     * Verifies an AddPeeringNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddPeeringNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddPeeringNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddPeeringNetworkRequest;

                    /**
                     * Creates a plain object from an AddPeeringNetworkRequest message. Also converts values to other types if specified.
                     * @param message AddPeeringNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddPeeringNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddPeeringNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddPeeringNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddResourcePoliciesDiskRequest. */
                interface IAddResourcePoliciesDiskRequest {

                    /** AddResourcePoliciesDiskRequest disk */
                    disk?: (string|null);

                    /** AddResourcePoliciesDiskRequest disksAddResourcePoliciesRequestResource */
                    disksAddResourcePoliciesRequestResource?: (google.cloud.compute.v1.IDisksAddResourcePoliciesRequest|null);

                    /** AddResourcePoliciesDiskRequest project */
                    project?: (string|null);

                    /** AddResourcePoliciesDiskRequest requestId */
                    requestId?: (string|null);

                    /** AddResourcePoliciesDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AddResourcePoliciesDiskRequest. */
                class AddResourcePoliciesDiskRequest implements IAddResourcePoliciesDiskRequest {

                    /**
                     * Constructs a new AddResourcePoliciesDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddResourcePoliciesDiskRequest);

                    /** AddResourcePoliciesDiskRequest disk. */
                    public disk: string;

                    /** AddResourcePoliciesDiskRequest disksAddResourcePoliciesRequestResource. */
                    public disksAddResourcePoliciesRequestResource?: (google.cloud.compute.v1.IDisksAddResourcePoliciesRequest|null);

                    /** AddResourcePoliciesDiskRequest project. */
                    public project: string;

                    /** AddResourcePoliciesDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** AddResourcePoliciesDiskRequest zone. */
                    public zone: string;

                    /** AddResourcePoliciesDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddResourcePoliciesDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddResourcePoliciesDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddResourcePoliciesDiskRequest): google.cloud.compute.v1.AddResourcePoliciesDiskRequest;

                    /**
                     * Encodes the specified AddResourcePoliciesDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.AddResourcePoliciesDiskRequest.verify|verify} messages.
                     * @param message AddResourcePoliciesDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddResourcePoliciesDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddResourcePoliciesDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddResourcePoliciesDiskRequest.verify|verify} messages.
                     * @param message AddResourcePoliciesDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddResourcePoliciesDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddResourcePoliciesDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddResourcePoliciesDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddResourcePoliciesDiskRequest;

                    /**
                     * Decodes an AddResourcePoliciesDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddResourcePoliciesDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddResourcePoliciesDiskRequest;

                    /**
                     * Verifies an AddResourcePoliciesDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddResourcePoliciesDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddResourcePoliciesDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddResourcePoliciesDiskRequest;

                    /**
                     * Creates a plain object from an AddResourcePoliciesDiskRequest message. Also converts values to other types if specified.
                     * @param message AddResourcePoliciesDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddResourcePoliciesDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddResourcePoliciesDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddResourcePoliciesDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddResourcePoliciesInstanceRequest. */
                interface IAddResourcePoliciesInstanceRequest {

                    /** AddResourcePoliciesInstanceRequest instance */
                    instance?: (string|null);

                    /** AddResourcePoliciesInstanceRequest instancesAddResourcePoliciesRequestResource */
                    instancesAddResourcePoliciesRequestResource?: (google.cloud.compute.v1.IInstancesAddResourcePoliciesRequest|null);

                    /** AddResourcePoliciesInstanceRequest project */
                    project?: (string|null);

                    /** AddResourcePoliciesInstanceRequest requestId */
                    requestId?: (string|null);

                    /** AddResourcePoliciesInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AddResourcePoliciesInstanceRequest. */
                class AddResourcePoliciesInstanceRequest implements IAddResourcePoliciesInstanceRequest {

                    /**
                     * Constructs a new AddResourcePoliciesInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddResourcePoliciesInstanceRequest);

                    /** AddResourcePoliciesInstanceRequest instance. */
                    public instance: string;

                    /** AddResourcePoliciesInstanceRequest instancesAddResourcePoliciesRequestResource. */
                    public instancesAddResourcePoliciesRequestResource?: (google.cloud.compute.v1.IInstancesAddResourcePoliciesRequest|null);

                    /** AddResourcePoliciesInstanceRequest project. */
                    public project: string;

                    /** AddResourcePoliciesInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** AddResourcePoliciesInstanceRequest zone. */
                    public zone: string;

                    /** AddResourcePoliciesInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddResourcePoliciesInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddResourcePoliciesInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddResourcePoliciesInstanceRequest): google.cloud.compute.v1.AddResourcePoliciesInstanceRequest;

                    /**
                     * Encodes the specified AddResourcePoliciesInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.AddResourcePoliciesInstanceRequest.verify|verify} messages.
                     * @param message AddResourcePoliciesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddResourcePoliciesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddResourcePoliciesInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddResourcePoliciesInstanceRequest.verify|verify} messages.
                     * @param message AddResourcePoliciesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddResourcePoliciesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddResourcePoliciesInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddResourcePoliciesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddResourcePoliciesInstanceRequest;

                    /**
                     * Decodes an AddResourcePoliciesInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddResourcePoliciesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddResourcePoliciesInstanceRequest;

                    /**
                     * Verifies an AddResourcePoliciesInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddResourcePoliciesInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddResourcePoliciesInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddResourcePoliciesInstanceRequest;

                    /**
                     * Creates a plain object from an AddResourcePoliciesInstanceRequest message. Also converts values to other types if specified.
                     * @param message AddResourcePoliciesInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddResourcePoliciesInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddResourcePoliciesInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddResourcePoliciesInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddResourcePoliciesRegionDiskRequest. */
                interface IAddResourcePoliciesRegionDiskRequest {

                    /** AddResourcePoliciesRegionDiskRequest disk */
                    disk?: (string|null);

                    /** AddResourcePoliciesRegionDiskRequest project */
                    project?: (string|null);

                    /** AddResourcePoliciesRegionDiskRequest region */
                    region?: (string|null);

                    /** AddResourcePoliciesRegionDiskRequest regionDisksAddResourcePoliciesRequestResource */
                    regionDisksAddResourcePoliciesRequestResource?: (google.cloud.compute.v1.IRegionDisksAddResourcePoliciesRequest|null);

                    /** AddResourcePoliciesRegionDiskRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddResourcePoliciesRegionDiskRequest. */
                class AddResourcePoliciesRegionDiskRequest implements IAddResourcePoliciesRegionDiskRequest {

                    /**
                     * Constructs a new AddResourcePoliciesRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddResourcePoliciesRegionDiskRequest);

                    /** AddResourcePoliciesRegionDiskRequest disk. */
                    public disk: string;

                    /** AddResourcePoliciesRegionDiskRequest project. */
                    public project: string;

                    /** AddResourcePoliciesRegionDiskRequest region. */
                    public region: string;

                    /** AddResourcePoliciesRegionDiskRequest regionDisksAddResourcePoliciesRequestResource. */
                    public regionDisksAddResourcePoliciesRequestResource?: (google.cloud.compute.v1.IRegionDisksAddResourcePoliciesRequest|null);

                    /** AddResourcePoliciesRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** AddResourcePoliciesRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddResourcePoliciesRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddResourcePoliciesRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddResourcePoliciesRegionDiskRequest): google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest;

                    /**
                     * Encodes the specified AddResourcePoliciesRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest.verify|verify} messages.
                     * @param message AddResourcePoliciesRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddResourcePoliciesRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddResourcePoliciesRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest.verify|verify} messages.
                     * @param message AddResourcePoliciesRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddResourcePoliciesRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddResourcePoliciesRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddResourcePoliciesRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest;

                    /**
                     * Decodes an AddResourcePoliciesRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddResourcePoliciesRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest;

                    /**
                     * Verifies an AddResourcePoliciesRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddResourcePoliciesRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddResourcePoliciesRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest;

                    /**
                     * Creates a plain object from an AddResourcePoliciesRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message AddResourcePoliciesRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddResourcePoliciesRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddResourcePoliciesRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddResourcePoliciesRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddRuleFirewallPolicyRequest. */
                interface IAddRuleFirewallPolicyRequest {

                    /** AddRuleFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** AddRuleFirewallPolicyRequest firewallPolicyRuleResource */
                    firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** AddRuleFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddRuleFirewallPolicyRequest. */
                class AddRuleFirewallPolicyRequest implements IAddRuleFirewallPolicyRequest {

                    /**
                     * Constructs a new AddRuleFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddRuleFirewallPolicyRequest);

                    /** AddRuleFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** AddRuleFirewallPolicyRequest firewallPolicyRuleResource. */
                    public firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** AddRuleFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** AddRuleFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddRuleFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddRuleFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddRuleFirewallPolicyRequest): google.cloud.compute.v1.AddRuleFirewallPolicyRequest;

                    /**
                     * Encodes the specified AddRuleFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddRuleFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddRuleFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddRuleFirewallPolicyRequest;

                    /**
                     * Decodes an AddRuleFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddRuleFirewallPolicyRequest;

                    /**
                     * Verifies an AddRuleFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddRuleFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddRuleFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddRuleFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an AddRuleFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddRuleFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddRuleFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddRuleFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddRuleFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddRuleNetworkFirewallPolicyRequest. */
                interface IAddRuleNetworkFirewallPolicyRequest {

                    /** AddRuleNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** AddRuleNetworkFirewallPolicyRequest firewallPolicyRuleResource */
                    firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** AddRuleNetworkFirewallPolicyRequest maxPriority */
                    maxPriority?: (number|null);

                    /** AddRuleNetworkFirewallPolicyRequest minPriority */
                    minPriority?: (number|null);

                    /** AddRuleNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** AddRuleNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddRuleNetworkFirewallPolicyRequest. */
                class AddRuleNetworkFirewallPolicyRequest implements IAddRuleNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new AddRuleNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddRuleNetworkFirewallPolicyRequest);

                    /** AddRuleNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** AddRuleNetworkFirewallPolicyRequest firewallPolicyRuleResource. */
                    public firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** AddRuleNetworkFirewallPolicyRequest maxPriority. */
                    public maxPriority?: (number|null);

                    /** AddRuleNetworkFirewallPolicyRequest minPriority. */
                    public minPriority?: (number|null);

                    /** AddRuleNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** AddRuleNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** AddRuleNetworkFirewallPolicyRequest _maxPriority. */
                    public _maxPriority?: "maxPriority";

                    /** AddRuleNetworkFirewallPolicyRequest _minPriority. */
                    public _minPriority?: "minPriority";

                    /** AddRuleNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddRuleNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddRuleNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddRuleNetworkFirewallPolicyRequest): google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified AddRuleNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddRuleNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddRuleNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest;

                    /**
                     * Decodes an AddRuleNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest;

                    /**
                     * Verifies an AddRuleNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddRuleNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddRuleNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an AddRuleNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddRuleNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddRuleNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddRuleNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddRuleNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddRuleRegionNetworkFirewallPolicyRequest. */
                interface IAddRuleRegionNetworkFirewallPolicyRequest {

                    /** AddRuleRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest firewallPolicyRuleResource */
                    firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest maxPriority */
                    maxPriority?: (number|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest minPriority */
                    minPriority?: (number|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AddRuleRegionNetworkFirewallPolicyRequest. */
                class AddRuleRegionNetworkFirewallPolicyRequest implements IAddRuleRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new AddRuleRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddRuleRegionNetworkFirewallPolicyRequest);

                    /** AddRuleRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** AddRuleRegionNetworkFirewallPolicyRequest firewallPolicyRuleResource. */
                    public firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest maxPriority. */
                    public maxPriority?: (number|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest minPriority. */
                    public minPriority?: (number|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** AddRuleRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** AddRuleRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** AddRuleRegionNetworkFirewallPolicyRequest _maxPriority. */
                    public _maxPriority?: "maxPriority";

                    /** AddRuleRegionNetworkFirewallPolicyRequest _minPriority. */
                    public _minPriority?: "minPriority";

                    /** AddRuleRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddRuleRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddRuleRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddRuleRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified AddRuleRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddRuleRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message AddRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes an AddRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies an AddRuleRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddRuleRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddRuleRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an AddRuleRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddRuleRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddRuleRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddRuleRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddRuleRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddRuleSecurityPolicyRequest. */
                interface IAddRuleSecurityPolicyRequest {

                    /** AddRuleSecurityPolicyRequest project */
                    project?: (string|null);

                    /** AddRuleSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);

                    /** AddRuleSecurityPolicyRequest securityPolicyRuleResource */
                    securityPolicyRuleResource?: (google.cloud.compute.v1.ISecurityPolicyRule|null);

                    /** AddRuleSecurityPolicyRequest validateOnly */
                    validateOnly?: (boolean|null);
                }

                /** Represents an AddRuleSecurityPolicyRequest. */
                class AddRuleSecurityPolicyRequest implements IAddRuleSecurityPolicyRequest {

                    /**
                     * Constructs a new AddRuleSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddRuleSecurityPolicyRequest);

                    /** AddRuleSecurityPolicyRequest project. */
                    public project: string;

                    /** AddRuleSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** AddRuleSecurityPolicyRequest securityPolicyRuleResource. */
                    public securityPolicyRuleResource?: (google.cloud.compute.v1.ISecurityPolicyRule|null);

                    /** AddRuleSecurityPolicyRequest validateOnly. */
                    public validateOnly?: (boolean|null);

                    /** AddRuleSecurityPolicyRequest _validateOnly. */
                    public _validateOnly?: "validateOnly";

                    /**
                     * Creates a new AddRuleSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddRuleSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddRuleSecurityPolicyRequest): google.cloud.compute.v1.AddRuleSecurityPolicyRequest;

                    /**
                     * Encodes the specified AddRuleSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.AddRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message AddRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddRuleSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message AddRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddRuleSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddRuleSecurityPolicyRequest;

                    /**
                     * Decodes an AddRuleSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddRuleSecurityPolicyRequest;

                    /**
                     * Verifies an AddRuleSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddRuleSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddRuleSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddRuleSecurityPolicyRequest;

                    /**
                     * Creates a plain object from an AddRuleSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message AddRuleSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddRuleSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddRuleSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddRuleSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddSignedUrlKeyBackendBucketRequest. */
                interface IAddSignedUrlKeyBackendBucketRequest {

                    /** AddSignedUrlKeyBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** AddSignedUrlKeyBackendBucketRequest project */
                    project?: (string|null);

                    /** AddSignedUrlKeyBackendBucketRequest requestId */
                    requestId?: (string|null);

                    /** AddSignedUrlKeyBackendBucketRequest signedUrlKeyResource */
                    signedUrlKeyResource?: (google.cloud.compute.v1.ISignedUrlKey|null);
                }

                /** Represents an AddSignedUrlKeyBackendBucketRequest. */
                class AddSignedUrlKeyBackendBucketRequest implements IAddSignedUrlKeyBackendBucketRequest {

                    /**
                     * Constructs a new AddSignedUrlKeyBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddSignedUrlKeyBackendBucketRequest);

                    /** AddSignedUrlKeyBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** AddSignedUrlKeyBackendBucketRequest project. */
                    public project: string;

                    /** AddSignedUrlKeyBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** AddSignedUrlKeyBackendBucketRequest signedUrlKeyResource. */
                    public signedUrlKeyResource?: (google.cloud.compute.v1.ISignedUrlKey|null);

                    /** AddSignedUrlKeyBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddSignedUrlKeyBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddSignedUrlKeyBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddSignedUrlKeyBackendBucketRequest): google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest;

                    /**
                     * Encodes the specified AddSignedUrlKeyBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest.verify|verify} messages.
                     * @param message AddSignedUrlKeyBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddSignedUrlKeyBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddSignedUrlKeyBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest.verify|verify} messages.
                     * @param message AddSignedUrlKeyBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddSignedUrlKeyBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddSignedUrlKeyBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddSignedUrlKeyBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest;

                    /**
                     * Decodes an AddSignedUrlKeyBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddSignedUrlKeyBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest;

                    /**
                     * Verifies an AddSignedUrlKeyBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddSignedUrlKeyBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddSignedUrlKeyBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest;

                    /**
                     * Creates a plain object from an AddSignedUrlKeyBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message AddSignedUrlKeyBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddSignedUrlKeyBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddSignedUrlKeyBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddSignedUrlKeyBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddSignedUrlKeyBackendServiceRequest. */
                interface IAddSignedUrlKeyBackendServiceRequest {

                    /** AddSignedUrlKeyBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** AddSignedUrlKeyBackendServiceRequest project */
                    project?: (string|null);

                    /** AddSignedUrlKeyBackendServiceRequest requestId */
                    requestId?: (string|null);

                    /** AddSignedUrlKeyBackendServiceRequest signedUrlKeyResource */
                    signedUrlKeyResource?: (google.cloud.compute.v1.ISignedUrlKey|null);
                }

                /** Represents an AddSignedUrlKeyBackendServiceRequest. */
                class AddSignedUrlKeyBackendServiceRequest implements IAddSignedUrlKeyBackendServiceRequest {

                    /**
                     * Constructs a new AddSignedUrlKeyBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddSignedUrlKeyBackendServiceRequest);

                    /** AddSignedUrlKeyBackendServiceRequest backendService. */
                    public backendService: string;

                    /** AddSignedUrlKeyBackendServiceRequest project. */
                    public project: string;

                    /** AddSignedUrlKeyBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** AddSignedUrlKeyBackendServiceRequest signedUrlKeyResource. */
                    public signedUrlKeyResource?: (google.cloud.compute.v1.ISignedUrlKey|null);

                    /** AddSignedUrlKeyBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AddSignedUrlKeyBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddSignedUrlKeyBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddSignedUrlKeyBackendServiceRequest): google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest;

                    /**
                     * Encodes the specified AddSignedUrlKeyBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest.verify|verify} messages.
                     * @param message AddSignedUrlKeyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddSignedUrlKeyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddSignedUrlKeyBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest.verify|verify} messages.
                     * @param message AddSignedUrlKeyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddSignedUrlKeyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddSignedUrlKeyBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddSignedUrlKeyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest;

                    /**
                     * Decodes an AddSignedUrlKeyBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddSignedUrlKeyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest;

                    /**
                     * Verifies an AddSignedUrlKeyBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddSignedUrlKeyBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddSignedUrlKeyBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest;

                    /**
                     * Creates a plain object from an AddSignedUrlKeyBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message AddSignedUrlKeyBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddSignedUrlKeyBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddSignedUrlKeyBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddSignedUrlKeyBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Address. */
                interface IAddress {

                    /** Address address */
                    address?: (string|null);

                    /** Address addressType */
                    addressType?: (string|null);

                    /** Address creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Address description */
                    description?: (string|null);

                    /** Address id */
                    id?: (number|Long|string|null);

                    /** Address ipVersion */
                    ipVersion?: (string|null);

                    /** Address ipv6EndpointType */
                    ipv6EndpointType?: (string|null);

                    /** Address kind */
                    kind?: (string|null);

                    /** Address name */
                    name?: (string|null);

                    /** Address network */
                    network?: (string|null);

                    /** Address networkTier */
                    networkTier?: (string|null);

                    /** Address prefixLength */
                    prefixLength?: (number|null);

                    /** Address purpose */
                    purpose?: (string|null);

                    /** Address region */
                    region?: (string|null);

                    /** Address selfLink */
                    selfLink?: (string|null);

                    /** Address status */
                    status?: (string|null);

                    /** Address subnetwork */
                    subnetwork?: (string|null);

                    /** Address users */
                    users?: (string[]|null);
                }

                /** Represents an Address. */
                class Address implements IAddress {

                    /**
                     * Constructs a new Address.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddress);

                    /** Address address. */
                    public address?: (string|null);

                    /** Address addressType. */
                    public addressType?: (string|null);

                    /** Address creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Address description. */
                    public description?: (string|null);

                    /** Address id. */
                    public id?: (number|Long|string|null);

                    /** Address ipVersion. */
                    public ipVersion?: (string|null);

                    /** Address ipv6EndpointType. */
                    public ipv6EndpointType?: (string|null);

                    /** Address kind. */
                    public kind?: (string|null);

                    /** Address name. */
                    public name?: (string|null);

                    /** Address network. */
                    public network?: (string|null);

                    /** Address networkTier. */
                    public networkTier?: (string|null);

                    /** Address prefixLength. */
                    public prefixLength?: (number|null);

                    /** Address purpose. */
                    public purpose?: (string|null);

                    /** Address region. */
                    public region?: (string|null);

                    /** Address selfLink. */
                    public selfLink?: (string|null);

                    /** Address status. */
                    public status?: (string|null);

                    /** Address subnetwork. */
                    public subnetwork?: (string|null);

                    /** Address users. */
                    public users: string[];

                    /** Address _address. */
                    public _address?: "address";

                    /** Address _addressType. */
                    public _addressType?: "addressType";

                    /** Address _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Address _description. */
                    public _description?: "description";

                    /** Address _id. */
                    public _id?: "id";

                    /** Address _ipVersion. */
                    public _ipVersion?: "ipVersion";

                    /** Address _ipv6EndpointType. */
                    public _ipv6EndpointType?: "ipv6EndpointType";

                    /** Address _kind. */
                    public _kind?: "kind";

                    /** Address _name. */
                    public _name?: "name";

                    /** Address _network. */
                    public _network?: "network";

                    /** Address _networkTier. */
                    public _networkTier?: "networkTier";

                    /** Address _prefixLength. */
                    public _prefixLength?: "prefixLength";

                    /** Address _purpose. */
                    public _purpose?: "purpose";

                    /** Address _region. */
                    public _region?: "region";

                    /** Address _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Address _status. */
                    public _status?: "status";

                    /** Address _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /**
                     * Creates a new Address instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Address instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddress): google.cloud.compute.v1.Address;

                    /**
                     * Encodes the specified Address message. Does not implicitly {@link google.cloud.compute.v1.Address.verify|verify} messages.
                     * @param message Address message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddress, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Address message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Address.verify|verify} messages.
                     * @param message Address message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddress, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Address message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Address
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Address;

                    /**
                     * Decodes an Address message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Address
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Address;

                    /**
                     * Verifies an Address message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Address message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Address
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Address;

                    /**
                     * Creates a plain object from an Address message. Also converts values to other types if specified.
                     * @param message Address
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Address, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Address to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Address
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Address {

                    /** AddressType enum. */
                    enum AddressType {
                        UNDEFINED_ADDRESS_TYPE = 0,
                        EXTERNAL = 35607499,
                        INTERNAL = 279295677,
                        UNSPECIFIED_TYPE = 53933922
                    }

                    /** IpVersion enum. */
                    enum IpVersion {
                        UNDEFINED_IP_VERSION = 0,
                        IPV4 = 2254341,
                        IPV6 = 2254343,
                        UNSPECIFIED_VERSION = 21850000
                    }

                    /** Ipv6EndpointType enum. */
                    enum Ipv6EndpointType {
                        UNDEFINED_IPV6_ENDPOINT_TYPE = 0,
                        NETLB = 74173363,
                        VM = 2743
                    }

                    /** NetworkTier enum. */
                    enum NetworkTier {
                        UNDEFINED_NETWORK_TIER = 0,
                        FIXED_STANDARD = 310464328,
                        PREMIUM = 399530551,
                        STANDARD = 484642493,
                        STANDARD_OVERRIDES_FIXED_STANDARD = 465847234
                    }

                    /** Purpose enum. */
                    enum Purpose {
                        UNDEFINED_PURPOSE = 0,
                        DNS_RESOLVER = 476114556,
                        GCE_ENDPOINT = 230515243,
                        IPSEC_INTERCONNECT = 340437251,
                        NAT_AUTO = 163666477,
                        PRIVATE_SERVICE_CONNECT = 48134724,
                        SERVERLESS = 270492508,
                        SHARED_LOADBALANCER_VIP = 294447572,
                        VPC_PEERING = 400800170
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        IN_USE = 17393485,
                        RESERVED = 432241448,
                        RESERVING = 514587225
                    }
                }

                /** Properties of an AddressAggregatedList. */
                interface IAddressAggregatedList {

                    /** AddressAggregatedList id */
                    id?: (string|null);

                    /** AddressAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IAddressesScopedList }|null);

                    /** AddressAggregatedList kind */
                    kind?: (string|null);

                    /** AddressAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AddressAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** AddressAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** AddressAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AddressAggregatedList. */
                class AddressAggregatedList implements IAddressAggregatedList {

                    /**
                     * Constructs a new AddressAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddressAggregatedList);

                    /** AddressAggregatedList id. */
                    public id?: (string|null);

                    /** AddressAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IAddressesScopedList };

                    /** AddressAggregatedList kind. */
                    public kind?: (string|null);

                    /** AddressAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AddressAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** AddressAggregatedList unreachables. */
                    public unreachables: string[];

                    /** AddressAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AddressAggregatedList _id. */
                    public _id?: "id";

                    /** AddressAggregatedList _kind. */
                    public _kind?: "kind";

                    /** AddressAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AddressAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AddressAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AddressAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddressAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddressAggregatedList): google.cloud.compute.v1.AddressAggregatedList;

                    /**
                     * Encodes the specified AddressAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.AddressAggregatedList.verify|verify} messages.
                     * @param message AddressAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddressAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddressAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddressAggregatedList.verify|verify} messages.
                     * @param message AddressAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddressAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddressAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddressAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddressAggregatedList;

                    /**
                     * Decodes an AddressAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddressAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddressAggregatedList;

                    /**
                     * Verifies an AddressAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddressAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddressAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddressAggregatedList;

                    /**
                     * Creates a plain object from an AddressAggregatedList message. Also converts values to other types if specified.
                     * @param message AddressAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddressAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddressAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddressAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddressList. */
                interface IAddressList {

                    /** AddressList id */
                    id?: (string|null);

                    /** AddressList items */
                    items?: (google.cloud.compute.v1.IAddress[]|null);

                    /** AddressList kind */
                    kind?: (string|null);

                    /** AddressList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AddressList selfLink */
                    selfLink?: (string|null);

                    /** AddressList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AddressList. */
                class AddressList implements IAddressList {

                    /**
                     * Constructs a new AddressList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddressList);

                    /** AddressList id. */
                    public id?: (string|null);

                    /** AddressList items. */
                    public items: google.cloud.compute.v1.IAddress[];

                    /** AddressList kind. */
                    public kind?: (string|null);

                    /** AddressList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AddressList selfLink. */
                    public selfLink?: (string|null);

                    /** AddressList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AddressList _id. */
                    public _id?: "id";

                    /** AddressList _kind. */
                    public _kind?: "kind";

                    /** AddressList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AddressList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AddressList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AddressList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddressList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddressList): google.cloud.compute.v1.AddressList;

                    /**
                     * Encodes the specified AddressList message. Does not implicitly {@link google.cloud.compute.v1.AddressList.verify|verify} messages.
                     * @param message AddressList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddressList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddressList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddressList.verify|verify} messages.
                     * @param message AddressList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddressList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddressList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddressList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddressList;

                    /**
                     * Decodes an AddressList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddressList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddressList;

                    /**
                     * Verifies an AddressList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddressList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddressList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddressList;

                    /**
                     * Creates a plain object from an AddressList message. Also converts values to other types if specified.
                     * @param message AddressList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddressList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddressList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddressList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddressesScopedList. */
                interface IAddressesScopedList {

                    /** AddressesScopedList addresses */
                    addresses?: (google.cloud.compute.v1.IAddress[]|null);

                    /** AddressesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AddressesScopedList. */
                class AddressesScopedList implements IAddressesScopedList {

                    /**
                     * Constructs a new AddressesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAddressesScopedList);

                    /** AddressesScopedList addresses. */
                    public addresses: google.cloud.compute.v1.IAddress[];

                    /** AddressesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AddressesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AddressesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddressesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAddressesScopedList): google.cloud.compute.v1.AddressesScopedList;

                    /**
                     * Encodes the specified AddressesScopedList message. Does not implicitly {@link google.cloud.compute.v1.AddressesScopedList.verify|verify} messages.
                     * @param message AddressesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAddressesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddressesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AddressesScopedList.verify|verify} messages.
                     * @param message AddressesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAddressesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddressesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddressesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AddressesScopedList;

                    /**
                     * Decodes an AddressesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddressesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AddressesScopedList;

                    /**
                     * Verifies an AddressesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddressesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddressesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AddressesScopedList;

                    /**
                     * Creates a plain object from an AddressesScopedList message. Also converts values to other types if specified.
                     * @param message AddressesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AddressesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddressesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddressesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AdvancedMachineFeatures. */
                interface IAdvancedMachineFeatures {

                    /** AdvancedMachineFeatures enableNestedVirtualization */
                    enableNestedVirtualization?: (boolean|null);

                    /** AdvancedMachineFeatures enableUefiNetworking */
                    enableUefiNetworking?: (boolean|null);

                    /** AdvancedMachineFeatures threadsPerCore */
                    threadsPerCore?: (number|null);

                    /** AdvancedMachineFeatures visibleCoreCount */
                    visibleCoreCount?: (number|null);
                }

                /** Represents an AdvancedMachineFeatures. */
                class AdvancedMachineFeatures implements IAdvancedMachineFeatures {

                    /**
                     * Constructs a new AdvancedMachineFeatures.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAdvancedMachineFeatures);

                    /** AdvancedMachineFeatures enableNestedVirtualization. */
                    public enableNestedVirtualization?: (boolean|null);

                    /** AdvancedMachineFeatures enableUefiNetworking. */
                    public enableUefiNetworking?: (boolean|null);

                    /** AdvancedMachineFeatures threadsPerCore. */
                    public threadsPerCore?: (number|null);

                    /** AdvancedMachineFeatures visibleCoreCount. */
                    public visibleCoreCount?: (number|null);

                    /** AdvancedMachineFeatures _enableNestedVirtualization. */
                    public _enableNestedVirtualization?: "enableNestedVirtualization";

                    /** AdvancedMachineFeatures _enableUefiNetworking. */
                    public _enableUefiNetworking?: "enableUefiNetworking";

                    /** AdvancedMachineFeatures _threadsPerCore. */
                    public _threadsPerCore?: "threadsPerCore";

                    /** AdvancedMachineFeatures _visibleCoreCount. */
                    public _visibleCoreCount?: "visibleCoreCount";

                    /**
                     * Creates a new AdvancedMachineFeatures instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AdvancedMachineFeatures instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAdvancedMachineFeatures): google.cloud.compute.v1.AdvancedMachineFeatures;

                    /**
                     * Encodes the specified AdvancedMachineFeatures message. Does not implicitly {@link google.cloud.compute.v1.AdvancedMachineFeatures.verify|verify} messages.
                     * @param message AdvancedMachineFeatures message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAdvancedMachineFeatures, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AdvancedMachineFeatures message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AdvancedMachineFeatures.verify|verify} messages.
                     * @param message AdvancedMachineFeatures message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAdvancedMachineFeatures, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AdvancedMachineFeatures message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AdvancedMachineFeatures
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AdvancedMachineFeatures;

                    /**
                     * Decodes an AdvancedMachineFeatures message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AdvancedMachineFeatures
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AdvancedMachineFeatures;

                    /**
                     * Verifies an AdvancedMachineFeatures message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AdvancedMachineFeatures message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AdvancedMachineFeatures
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AdvancedMachineFeatures;

                    /**
                     * Creates a plain object from an AdvancedMachineFeatures message. Also converts values to other types if specified.
                     * @param message AdvancedMachineFeatures
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AdvancedMachineFeatures, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AdvancedMachineFeatures to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AdvancedMachineFeatures
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListAcceleratorTypesRequest. */
                interface IAggregatedListAcceleratorTypesRequest {

                    /** AggregatedListAcceleratorTypesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListAcceleratorTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListAcceleratorTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest project */
                    project?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListAcceleratorTypesRequest. */
                class AggregatedListAcceleratorTypesRequest implements IAggregatedListAcceleratorTypesRequest {

                    /**
                     * Constructs a new AggregatedListAcceleratorTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListAcceleratorTypesRequest);

                    /** AggregatedListAcceleratorTypesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListAcceleratorTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListAcceleratorTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListAcceleratorTypesRequest project. */
                    public project: string;

                    /** AggregatedListAcceleratorTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListAcceleratorTypesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListAcceleratorTypesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListAcceleratorTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListAcceleratorTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListAcceleratorTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListAcceleratorTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListAcceleratorTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListAcceleratorTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListAcceleratorTypesRequest): google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest;

                    /**
                     * Encodes the specified AggregatedListAcceleratorTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest.verify|verify} messages.
                     * @param message AggregatedListAcceleratorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListAcceleratorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListAcceleratorTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest.verify|verify} messages.
                     * @param message AggregatedListAcceleratorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListAcceleratorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListAcceleratorTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListAcceleratorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest;

                    /**
                     * Decodes an AggregatedListAcceleratorTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListAcceleratorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest;

                    /**
                     * Verifies an AggregatedListAcceleratorTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListAcceleratorTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListAcceleratorTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest;

                    /**
                     * Creates a plain object from an AggregatedListAcceleratorTypesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListAcceleratorTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListAcceleratorTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListAcceleratorTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListAcceleratorTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListAddressesRequest. */
                interface IAggregatedListAddressesRequest {

                    /** AggregatedListAddressesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListAddressesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListAddressesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListAddressesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListAddressesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListAddressesRequest project */
                    project?: (string|null);

                    /** AggregatedListAddressesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListAddressesRequest. */
                class AggregatedListAddressesRequest implements IAggregatedListAddressesRequest {

                    /**
                     * Constructs a new AggregatedListAddressesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListAddressesRequest);

                    /** AggregatedListAddressesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListAddressesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListAddressesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListAddressesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListAddressesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListAddressesRequest project. */
                    public project: string;

                    /** AggregatedListAddressesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListAddressesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListAddressesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListAddressesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListAddressesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListAddressesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListAddressesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListAddressesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListAddressesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListAddressesRequest): google.cloud.compute.v1.AggregatedListAddressesRequest;

                    /**
                     * Encodes the specified AggregatedListAddressesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListAddressesRequest.verify|verify} messages.
                     * @param message AggregatedListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListAddressesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListAddressesRequest.verify|verify} messages.
                     * @param message AggregatedListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListAddressesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListAddressesRequest;

                    /**
                     * Decodes an AggregatedListAddressesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListAddressesRequest;

                    /**
                     * Verifies an AggregatedListAddressesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListAddressesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListAddressesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListAddressesRequest;

                    /**
                     * Creates a plain object from an AggregatedListAddressesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListAddressesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListAddressesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListAddressesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListAddressesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListAutoscalersRequest. */
                interface IAggregatedListAutoscalersRequest {

                    /** AggregatedListAutoscalersRequest filter */
                    filter?: (string|null);

                    /** AggregatedListAutoscalersRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListAutoscalersRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListAutoscalersRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListAutoscalersRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListAutoscalersRequest project */
                    project?: (string|null);

                    /** AggregatedListAutoscalersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListAutoscalersRequest. */
                class AggregatedListAutoscalersRequest implements IAggregatedListAutoscalersRequest {

                    /**
                     * Constructs a new AggregatedListAutoscalersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListAutoscalersRequest);

                    /** AggregatedListAutoscalersRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListAutoscalersRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListAutoscalersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListAutoscalersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListAutoscalersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListAutoscalersRequest project. */
                    public project: string;

                    /** AggregatedListAutoscalersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListAutoscalersRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListAutoscalersRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListAutoscalersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListAutoscalersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListAutoscalersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListAutoscalersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListAutoscalersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListAutoscalersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListAutoscalersRequest): google.cloud.compute.v1.AggregatedListAutoscalersRequest;

                    /**
                     * Encodes the specified AggregatedListAutoscalersRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListAutoscalersRequest.verify|verify} messages.
                     * @param message AggregatedListAutoscalersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListAutoscalersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListAutoscalersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListAutoscalersRequest.verify|verify} messages.
                     * @param message AggregatedListAutoscalersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListAutoscalersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListAutoscalersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListAutoscalersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListAutoscalersRequest;

                    /**
                     * Decodes an AggregatedListAutoscalersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListAutoscalersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListAutoscalersRequest;

                    /**
                     * Verifies an AggregatedListAutoscalersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListAutoscalersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListAutoscalersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListAutoscalersRequest;

                    /**
                     * Creates a plain object from an AggregatedListAutoscalersRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListAutoscalersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListAutoscalersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListAutoscalersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListAutoscalersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListBackendServicesRequest. */
                interface IAggregatedListBackendServicesRequest {

                    /** AggregatedListBackendServicesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListBackendServicesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListBackendServicesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListBackendServicesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListBackendServicesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListBackendServicesRequest project */
                    project?: (string|null);

                    /** AggregatedListBackendServicesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListBackendServicesRequest. */
                class AggregatedListBackendServicesRequest implements IAggregatedListBackendServicesRequest {

                    /**
                     * Constructs a new AggregatedListBackendServicesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListBackendServicesRequest);

                    /** AggregatedListBackendServicesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListBackendServicesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListBackendServicesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListBackendServicesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListBackendServicesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListBackendServicesRequest project. */
                    public project: string;

                    /** AggregatedListBackendServicesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListBackendServicesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListBackendServicesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListBackendServicesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListBackendServicesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListBackendServicesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListBackendServicesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListBackendServicesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListBackendServicesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListBackendServicesRequest): google.cloud.compute.v1.AggregatedListBackendServicesRequest;

                    /**
                     * Encodes the specified AggregatedListBackendServicesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListBackendServicesRequest.verify|verify} messages.
                     * @param message AggregatedListBackendServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListBackendServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListBackendServicesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListBackendServicesRequest.verify|verify} messages.
                     * @param message AggregatedListBackendServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListBackendServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListBackendServicesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListBackendServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListBackendServicesRequest;

                    /**
                     * Decodes an AggregatedListBackendServicesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListBackendServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListBackendServicesRequest;

                    /**
                     * Verifies an AggregatedListBackendServicesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListBackendServicesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListBackendServicesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListBackendServicesRequest;

                    /**
                     * Creates a plain object from an AggregatedListBackendServicesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListBackendServicesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListBackendServicesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListBackendServicesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListBackendServicesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListDiskTypesRequest. */
                interface IAggregatedListDiskTypesRequest {

                    /** AggregatedListDiskTypesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListDiskTypesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListDiskTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListDiskTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListDiskTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListDiskTypesRequest project */
                    project?: (string|null);

                    /** AggregatedListDiskTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListDiskTypesRequest. */
                class AggregatedListDiskTypesRequest implements IAggregatedListDiskTypesRequest {

                    /**
                     * Constructs a new AggregatedListDiskTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListDiskTypesRequest);

                    /** AggregatedListDiskTypesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListDiskTypesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListDiskTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListDiskTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListDiskTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListDiskTypesRequest project. */
                    public project: string;

                    /** AggregatedListDiskTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListDiskTypesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListDiskTypesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListDiskTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListDiskTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListDiskTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListDiskTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListDiskTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListDiskTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListDiskTypesRequest): google.cloud.compute.v1.AggregatedListDiskTypesRequest;

                    /**
                     * Encodes the specified AggregatedListDiskTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListDiskTypesRequest.verify|verify} messages.
                     * @param message AggregatedListDiskTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListDiskTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListDiskTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListDiskTypesRequest.verify|verify} messages.
                     * @param message AggregatedListDiskTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListDiskTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListDiskTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListDiskTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListDiskTypesRequest;

                    /**
                     * Decodes an AggregatedListDiskTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListDiskTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListDiskTypesRequest;

                    /**
                     * Verifies an AggregatedListDiskTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListDiskTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListDiskTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListDiskTypesRequest;

                    /**
                     * Creates a plain object from an AggregatedListDiskTypesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListDiskTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListDiskTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListDiskTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListDiskTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListDisksRequest. */
                interface IAggregatedListDisksRequest {

                    /** AggregatedListDisksRequest filter */
                    filter?: (string|null);

                    /** AggregatedListDisksRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListDisksRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListDisksRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListDisksRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListDisksRequest project */
                    project?: (string|null);

                    /** AggregatedListDisksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListDisksRequest. */
                class AggregatedListDisksRequest implements IAggregatedListDisksRequest {

                    /**
                     * Constructs a new AggregatedListDisksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListDisksRequest);

                    /** AggregatedListDisksRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListDisksRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListDisksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListDisksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListDisksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListDisksRequest project. */
                    public project: string;

                    /** AggregatedListDisksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListDisksRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListDisksRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListDisksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListDisksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListDisksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListDisksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListDisksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListDisksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListDisksRequest): google.cloud.compute.v1.AggregatedListDisksRequest;

                    /**
                     * Encodes the specified AggregatedListDisksRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListDisksRequest.verify|verify} messages.
                     * @param message AggregatedListDisksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListDisksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListDisksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListDisksRequest.verify|verify} messages.
                     * @param message AggregatedListDisksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListDisksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListDisksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListDisksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListDisksRequest;

                    /**
                     * Decodes an AggregatedListDisksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListDisksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListDisksRequest;

                    /**
                     * Verifies an AggregatedListDisksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListDisksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListDisksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListDisksRequest;

                    /**
                     * Creates a plain object from an AggregatedListDisksRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListDisksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListDisksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListDisksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListDisksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListForwardingRulesRequest. */
                interface IAggregatedListForwardingRulesRequest {

                    /** AggregatedListForwardingRulesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListForwardingRulesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListForwardingRulesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListForwardingRulesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListForwardingRulesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListForwardingRulesRequest project */
                    project?: (string|null);

                    /** AggregatedListForwardingRulesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListForwardingRulesRequest. */
                class AggregatedListForwardingRulesRequest implements IAggregatedListForwardingRulesRequest {

                    /**
                     * Constructs a new AggregatedListForwardingRulesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListForwardingRulesRequest);

                    /** AggregatedListForwardingRulesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListForwardingRulesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListForwardingRulesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListForwardingRulesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListForwardingRulesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListForwardingRulesRequest project. */
                    public project: string;

                    /** AggregatedListForwardingRulesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListForwardingRulesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListForwardingRulesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListForwardingRulesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListForwardingRulesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListForwardingRulesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListForwardingRulesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListForwardingRulesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListForwardingRulesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListForwardingRulesRequest): google.cloud.compute.v1.AggregatedListForwardingRulesRequest;

                    /**
                     * Encodes the specified AggregatedListForwardingRulesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListForwardingRulesRequest.verify|verify} messages.
                     * @param message AggregatedListForwardingRulesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListForwardingRulesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListForwardingRulesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListForwardingRulesRequest.verify|verify} messages.
                     * @param message AggregatedListForwardingRulesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListForwardingRulesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListForwardingRulesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListForwardingRulesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListForwardingRulesRequest;

                    /**
                     * Decodes an AggregatedListForwardingRulesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListForwardingRulesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListForwardingRulesRequest;

                    /**
                     * Verifies an AggregatedListForwardingRulesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListForwardingRulesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListForwardingRulesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListForwardingRulesRequest;

                    /**
                     * Creates a plain object from an AggregatedListForwardingRulesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListForwardingRulesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListForwardingRulesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListForwardingRulesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListForwardingRulesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListGlobalOperationsRequest. */
                interface IAggregatedListGlobalOperationsRequest {

                    /** AggregatedListGlobalOperationsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListGlobalOperationsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListGlobalOperationsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListGlobalOperationsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListGlobalOperationsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListGlobalOperationsRequest project */
                    project?: (string|null);

                    /** AggregatedListGlobalOperationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListGlobalOperationsRequest. */
                class AggregatedListGlobalOperationsRequest implements IAggregatedListGlobalOperationsRequest {

                    /**
                     * Constructs a new AggregatedListGlobalOperationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListGlobalOperationsRequest);

                    /** AggregatedListGlobalOperationsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListGlobalOperationsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListGlobalOperationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListGlobalOperationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListGlobalOperationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListGlobalOperationsRequest project. */
                    public project: string;

                    /** AggregatedListGlobalOperationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListGlobalOperationsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListGlobalOperationsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListGlobalOperationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListGlobalOperationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListGlobalOperationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListGlobalOperationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListGlobalOperationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListGlobalOperationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListGlobalOperationsRequest): google.cloud.compute.v1.AggregatedListGlobalOperationsRequest;

                    /**
                     * Encodes the specified AggregatedListGlobalOperationsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListGlobalOperationsRequest.verify|verify} messages.
                     * @param message AggregatedListGlobalOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListGlobalOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListGlobalOperationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListGlobalOperationsRequest.verify|verify} messages.
                     * @param message AggregatedListGlobalOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListGlobalOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListGlobalOperationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListGlobalOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListGlobalOperationsRequest;

                    /**
                     * Decodes an AggregatedListGlobalOperationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListGlobalOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListGlobalOperationsRequest;

                    /**
                     * Verifies an AggregatedListGlobalOperationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListGlobalOperationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListGlobalOperationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListGlobalOperationsRequest;

                    /**
                     * Creates a plain object from an AggregatedListGlobalOperationsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListGlobalOperationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListGlobalOperationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListGlobalOperationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListGlobalOperationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListHealthChecksRequest. */
                interface IAggregatedListHealthChecksRequest {

                    /** AggregatedListHealthChecksRequest filter */
                    filter?: (string|null);

                    /** AggregatedListHealthChecksRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListHealthChecksRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListHealthChecksRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListHealthChecksRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListHealthChecksRequest project */
                    project?: (string|null);

                    /** AggregatedListHealthChecksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListHealthChecksRequest. */
                class AggregatedListHealthChecksRequest implements IAggregatedListHealthChecksRequest {

                    /**
                     * Constructs a new AggregatedListHealthChecksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListHealthChecksRequest);

                    /** AggregatedListHealthChecksRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListHealthChecksRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListHealthChecksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListHealthChecksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListHealthChecksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListHealthChecksRequest project. */
                    public project: string;

                    /** AggregatedListHealthChecksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListHealthChecksRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListHealthChecksRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListHealthChecksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListHealthChecksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListHealthChecksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListHealthChecksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListHealthChecksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListHealthChecksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListHealthChecksRequest): google.cloud.compute.v1.AggregatedListHealthChecksRequest;

                    /**
                     * Encodes the specified AggregatedListHealthChecksRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListHealthChecksRequest.verify|verify} messages.
                     * @param message AggregatedListHealthChecksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListHealthChecksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListHealthChecksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListHealthChecksRequest.verify|verify} messages.
                     * @param message AggregatedListHealthChecksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListHealthChecksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListHealthChecksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListHealthChecksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListHealthChecksRequest;

                    /**
                     * Decodes an AggregatedListHealthChecksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListHealthChecksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListHealthChecksRequest;

                    /**
                     * Verifies an AggregatedListHealthChecksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListHealthChecksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListHealthChecksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListHealthChecksRequest;

                    /**
                     * Creates a plain object from an AggregatedListHealthChecksRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListHealthChecksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListHealthChecksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListHealthChecksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListHealthChecksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListInstanceGroupManagersRequest. */
                interface IAggregatedListInstanceGroupManagersRequest {

                    /** AggregatedListInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListInstanceGroupManagersRequest. */
                class AggregatedListInstanceGroupManagersRequest implements IAggregatedListInstanceGroupManagersRequest {

                    /**
                     * Constructs a new AggregatedListInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest);

                    /** AggregatedListInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListInstanceGroupManagersRequest project. */
                    public project: string;

                    /** AggregatedListInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListInstanceGroupManagersRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest): google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified AggregatedListInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message AggregatedListInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message AggregatedListInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest;

                    /**
                     * Decodes an AggregatedListInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest;

                    /**
                     * Verifies an AggregatedListInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from an AggregatedListInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListInstanceGroupsRequest. */
                interface IAggregatedListInstanceGroupsRequest {

                    /** AggregatedListInstanceGroupsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListInstanceGroupsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListInstanceGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListInstanceGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListInstanceGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListInstanceGroupsRequest project */
                    project?: (string|null);

                    /** AggregatedListInstanceGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListInstanceGroupsRequest. */
                class AggregatedListInstanceGroupsRequest implements IAggregatedListInstanceGroupsRequest {

                    /**
                     * Constructs a new AggregatedListInstanceGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListInstanceGroupsRequest);

                    /** AggregatedListInstanceGroupsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListInstanceGroupsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListInstanceGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListInstanceGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListInstanceGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListInstanceGroupsRequest project. */
                    public project: string;

                    /** AggregatedListInstanceGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListInstanceGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListInstanceGroupsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListInstanceGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListInstanceGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListInstanceGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListInstanceGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListInstanceGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListInstanceGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListInstanceGroupsRequest): google.cloud.compute.v1.AggregatedListInstanceGroupsRequest;

                    /**
                     * Encodes the specified AggregatedListInstanceGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInstanceGroupsRequest.verify|verify} messages.
                     * @param message AggregatedListInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListInstanceGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInstanceGroupsRequest.verify|verify} messages.
                     * @param message AggregatedListInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListInstanceGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListInstanceGroupsRequest;

                    /**
                     * Decodes an AggregatedListInstanceGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListInstanceGroupsRequest;

                    /**
                     * Verifies an AggregatedListInstanceGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListInstanceGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListInstanceGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListInstanceGroupsRequest;

                    /**
                     * Creates a plain object from an AggregatedListInstanceGroupsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListInstanceGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListInstanceGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListInstanceGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListInstanceGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListInstancesRequest. */
                interface IAggregatedListInstancesRequest {

                    /** AggregatedListInstancesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListInstancesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListInstancesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListInstancesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListInstancesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListInstancesRequest project */
                    project?: (string|null);

                    /** AggregatedListInstancesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListInstancesRequest. */
                class AggregatedListInstancesRequest implements IAggregatedListInstancesRequest {

                    /**
                     * Constructs a new AggregatedListInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListInstancesRequest);

                    /** AggregatedListInstancesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListInstancesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListInstancesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListInstancesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListInstancesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListInstancesRequest project. */
                    public project: string;

                    /** AggregatedListInstancesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListInstancesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListInstancesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListInstancesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListInstancesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListInstancesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListInstancesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListInstancesRequest): google.cloud.compute.v1.AggregatedListInstancesRequest;

                    /**
                     * Encodes the specified AggregatedListInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInstancesRequest.verify|verify} messages.
                     * @param message AggregatedListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInstancesRequest.verify|verify} messages.
                     * @param message AggregatedListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListInstancesRequest;

                    /**
                     * Decodes an AggregatedListInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListInstancesRequest;

                    /**
                     * Verifies an AggregatedListInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListInstancesRequest;

                    /**
                     * Creates a plain object from an AggregatedListInstancesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListInterconnectAttachmentsRequest. */
                interface IAggregatedListInterconnectAttachmentsRequest {

                    /** AggregatedListInterconnectAttachmentsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListInterconnectAttachmentsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListInterconnectAttachmentsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest project */
                    project?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListInterconnectAttachmentsRequest. */
                class AggregatedListInterconnectAttachmentsRequest implements IAggregatedListInterconnectAttachmentsRequest {

                    /**
                     * Constructs a new AggregatedListInterconnectAttachmentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListInterconnectAttachmentsRequest);

                    /** AggregatedListInterconnectAttachmentsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListInterconnectAttachmentsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListInterconnectAttachmentsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListInterconnectAttachmentsRequest project. */
                    public project: string;

                    /** AggregatedListInterconnectAttachmentsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListInterconnectAttachmentsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListInterconnectAttachmentsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListInterconnectAttachmentsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListInterconnectAttachmentsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListInterconnectAttachmentsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListInterconnectAttachmentsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListInterconnectAttachmentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListInterconnectAttachmentsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListInterconnectAttachmentsRequest): google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest;

                    /**
                     * Encodes the specified AggregatedListInterconnectAttachmentsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest.verify|verify} messages.
                     * @param message AggregatedListInterconnectAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListInterconnectAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListInterconnectAttachmentsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest.verify|verify} messages.
                     * @param message AggregatedListInterconnectAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListInterconnectAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListInterconnectAttachmentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListInterconnectAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest;

                    /**
                     * Decodes an AggregatedListInterconnectAttachmentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListInterconnectAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest;

                    /**
                     * Verifies an AggregatedListInterconnectAttachmentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListInterconnectAttachmentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListInterconnectAttachmentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest;

                    /**
                     * Creates a plain object from an AggregatedListInterconnectAttachmentsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListInterconnectAttachmentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListInterconnectAttachmentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListInterconnectAttachmentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListInterconnectAttachmentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListMachineTypesRequest. */
                interface IAggregatedListMachineTypesRequest {

                    /** AggregatedListMachineTypesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListMachineTypesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListMachineTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListMachineTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListMachineTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListMachineTypesRequest project */
                    project?: (string|null);

                    /** AggregatedListMachineTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListMachineTypesRequest. */
                class AggregatedListMachineTypesRequest implements IAggregatedListMachineTypesRequest {

                    /**
                     * Constructs a new AggregatedListMachineTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListMachineTypesRequest);

                    /** AggregatedListMachineTypesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListMachineTypesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListMachineTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListMachineTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListMachineTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListMachineTypesRequest project. */
                    public project: string;

                    /** AggregatedListMachineTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListMachineTypesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListMachineTypesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListMachineTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListMachineTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListMachineTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListMachineTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListMachineTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListMachineTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListMachineTypesRequest): google.cloud.compute.v1.AggregatedListMachineTypesRequest;

                    /**
                     * Encodes the specified AggregatedListMachineTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListMachineTypesRequest.verify|verify} messages.
                     * @param message AggregatedListMachineTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListMachineTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListMachineTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListMachineTypesRequest.verify|verify} messages.
                     * @param message AggregatedListMachineTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListMachineTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListMachineTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListMachineTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListMachineTypesRequest;

                    /**
                     * Decodes an AggregatedListMachineTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListMachineTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListMachineTypesRequest;

                    /**
                     * Verifies an AggregatedListMachineTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListMachineTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListMachineTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListMachineTypesRequest;

                    /**
                     * Creates a plain object from an AggregatedListMachineTypesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListMachineTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListMachineTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListMachineTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListMachineTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListNetworkEdgeSecurityServicesRequest. */
                interface IAggregatedListNetworkEdgeSecurityServicesRequest {

                    /** AggregatedListNetworkEdgeSecurityServicesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest project */
                    project?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListNetworkEdgeSecurityServicesRequest. */
                class AggregatedListNetworkEdgeSecurityServicesRequest implements IAggregatedListNetworkEdgeSecurityServicesRequest {

                    /**
                     * Constructs a new AggregatedListNetworkEdgeSecurityServicesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListNetworkEdgeSecurityServicesRequest);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest project. */
                    public project: string;

                    /** AggregatedListNetworkEdgeSecurityServicesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListNetworkEdgeSecurityServicesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListNetworkEdgeSecurityServicesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListNetworkEdgeSecurityServicesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListNetworkEdgeSecurityServicesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListNetworkEdgeSecurityServicesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListNetworkEdgeSecurityServicesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListNetworkEdgeSecurityServicesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListNetworkEdgeSecurityServicesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListNetworkEdgeSecurityServicesRequest): google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest;

                    /**
                     * Encodes the specified AggregatedListNetworkEdgeSecurityServicesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest.verify|verify} messages.
                     * @param message AggregatedListNetworkEdgeSecurityServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListNetworkEdgeSecurityServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListNetworkEdgeSecurityServicesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest.verify|verify} messages.
                     * @param message AggregatedListNetworkEdgeSecurityServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListNetworkEdgeSecurityServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListNetworkEdgeSecurityServicesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListNetworkEdgeSecurityServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest;

                    /**
                     * Decodes an AggregatedListNetworkEdgeSecurityServicesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListNetworkEdgeSecurityServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest;

                    /**
                     * Verifies an AggregatedListNetworkEdgeSecurityServicesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListNetworkEdgeSecurityServicesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListNetworkEdgeSecurityServicesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest;

                    /**
                     * Creates a plain object from an AggregatedListNetworkEdgeSecurityServicesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListNetworkEdgeSecurityServicesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListNetworkEdgeSecurityServicesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListNetworkEdgeSecurityServicesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListNetworkEdgeSecurityServicesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListNetworkEndpointGroupsRequest. */
                interface IAggregatedListNetworkEndpointGroupsRequest {

                    /** AggregatedListNetworkEndpointGroupsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListNetworkEndpointGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListNetworkEndpointGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest project */
                    project?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListNetworkEndpointGroupsRequest. */
                class AggregatedListNetworkEndpointGroupsRequest implements IAggregatedListNetworkEndpointGroupsRequest {

                    /**
                     * Constructs a new AggregatedListNetworkEndpointGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListNetworkEndpointGroupsRequest);

                    /** AggregatedListNetworkEndpointGroupsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListNetworkEndpointGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListNetworkEndpointGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListNetworkEndpointGroupsRequest project. */
                    public project: string;

                    /** AggregatedListNetworkEndpointGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListNetworkEndpointGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListNetworkEndpointGroupsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListNetworkEndpointGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListNetworkEndpointGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListNetworkEndpointGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListNetworkEndpointGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListNetworkEndpointGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListNetworkEndpointGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListNetworkEndpointGroupsRequest): google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest;

                    /**
                     * Encodes the specified AggregatedListNetworkEndpointGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message AggregatedListNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListNetworkEndpointGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message AggregatedListNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListNetworkEndpointGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest;

                    /**
                     * Decodes an AggregatedListNetworkEndpointGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest;

                    /**
                     * Verifies an AggregatedListNetworkEndpointGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListNetworkEndpointGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListNetworkEndpointGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest;

                    /**
                     * Creates a plain object from an AggregatedListNetworkEndpointGroupsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListNetworkEndpointGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListNetworkEndpointGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListNetworkEndpointGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListNetworkEndpointGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListNodeGroupsRequest. */
                interface IAggregatedListNodeGroupsRequest {

                    /** AggregatedListNodeGroupsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListNodeGroupsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListNodeGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListNodeGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListNodeGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListNodeGroupsRequest project */
                    project?: (string|null);

                    /** AggregatedListNodeGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListNodeGroupsRequest. */
                class AggregatedListNodeGroupsRequest implements IAggregatedListNodeGroupsRequest {

                    /**
                     * Constructs a new AggregatedListNodeGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListNodeGroupsRequest);

                    /** AggregatedListNodeGroupsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListNodeGroupsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListNodeGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListNodeGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListNodeGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListNodeGroupsRequest project. */
                    public project: string;

                    /** AggregatedListNodeGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListNodeGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListNodeGroupsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListNodeGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListNodeGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListNodeGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListNodeGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListNodeGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListNodeGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListNodeGroupsRequest): google.cloud.compute.v1.AggregatedListNodeGroupsRequest;

                    /**
                     * Encodes the specified AggregatedListNodeGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNodeGroupsRequest.verify|verify} messages.
                     * @param message AggregatedListNodeGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListNodeGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListNodeGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNodeGroupsRequest.verify|verify} messages.
                     * @param message AggregatedListNodeGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListNodeGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListNodeGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListNodeGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListNodeGroupsRequest;

                    /**
                     * Decodes an AggregatedListNodeGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListNodeGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListNodeGroupsRequest;

                    /**
                     * Verifies an AggregatedListNodeGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListNodeGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListNodeGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListNodeGroupsRequest;

                    /**
                     * Creates a plain object from an AggregatedListNodeGroupsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListNodeGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListNodeGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListNodeGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListNodeGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListNodeTemplatesRequest. */
                interface IAggregatedListNodeTemplatesRequest {

                    /** AggregatedListNodeTemplatesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListNodeTemplatesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListNodeTemplatesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListNodeTemplatesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListNodeTemplatesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListNodeTemplatesRequest project */
                    project?: (string|null);

                    /** AggregatedListNodeTemplatesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListNodeTemplatesRequest. */
                class AggregatedListNodeTemplatesRequest implements IAggregatedListNodeTemplatesRequest {

                    /**
                     * Constructs a new AggregatedListNodeTemplatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListNodeTemplatesRequest);

                    /** AggregatedListNodeTemplatesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListNodeTemplatesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListNodeTemplatesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListNodeTemplatesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListNodeTemplatesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListNodeTemplatesRequest project. */
                    public project: string;

                    /** AggregatedListNodeTemplatesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListNodeTemplatesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListNodeTemplatesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListNodeTemplatesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListNodeTemplatesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListNodeTemplatesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListNodeTemplatesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListNodeTemplatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListNodeTemplatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListNodeTemplatesRequest): google.cloud.compute.v1.AggregatedListNodeTemplatesRequest;

                    /**
                     * Encodes the specified AggregatedListNodeTemplatesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNodeTemplatesRequest.verify|verify} messages.
                     * @param message AggregatedListNodeTemplatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListNodeTemplatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListNodeTemplatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNodeTemplatesRequest.verify|verify} messages.
                     * @param message AggregatedListNodeTemplatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListNodeTemplatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListNodeTemplatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListNodeTemplatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListNodeTemplatesRequest;

                    /**
                     * Decodes an AggregatedListNodeTemplatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListNodeTemplatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListNodeTemplatesRequest;

                    /**
                     * Verifies an AggregatedListNodeTemplatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListNodeTemplatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListNodeTemplatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListNodeTemplatesRequest;

                    /**
                     * Creates a plain object from an AggregatedListNodeTemplatesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListNodeTemplatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListNodeTemplatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListNodeTemplatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListNodeTemplatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListNodeTypesRequest. */
                interface IAggregatedListNodeTypesRequest {

                    /** AggregatedListNodeTypesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListNodeTypesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListNodeTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListNodeTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListNodeTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListNodeTypesRequest project */
                    project?: (string|null);

                    /** AggregatedListNodeTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListNodeTypesRequest. */
                class AggregatedListNodeTypesRequest implements IAggregatedListNodeTypesRequest {

                    /**
                     * Constructs a new AggregatedListNodeTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListNodeTypesRequest);

                    /** AggregatedListNodeTypesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListNodeTypesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListNodeTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListNodeTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListNodeTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListNodeTypesRequest project. */
                    public project: string;

                    /** AggregatedListNodeTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListNodeTypesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListNodeTypesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListNodeTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListNodeTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListNodeTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListNodeTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListNodeTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListNodeTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListNodeTypesRequest): google.cloud.compute.v1.AggregatedListNodeTypesRequest;

                    /**
                     * Encodes the specified AggregatedListNodeTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNodeTypesRequest.verify|verify} messages.
                     * @param message AggregatedListNodeTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListNodeTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListNodeTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListNodeTypesRequest.verify|verify} messages.
                     * @param message AggregatedListNodeTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListNodeTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListNodeTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListNodeTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListNodeTypesRequest;

                    /**
                     * Decodes an AggregatedListNodeTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListNodeTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListNodeTypesRequest;

                    /**
                     * Verifies an AggregatedListNodeTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListNodeTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListNodeTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListNodeTypesRequest;

                    /**
                     * Creates a plain object from an AggregatedListNodeTypesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListNodeTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListNodeTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListNodeTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListNodeTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListPacketMirroringsRequest. */
                interface IAggregatedListPacketMirroringsRequest {

                    /** AggregatedListPacketMirroringsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListPacketMirroringsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListPacketMirroringsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListPacketMirroringsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListPacketMirroringsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListPacketMirroringsRequest project */
                    project?: (string|null);

                    /** AggregatedListPacketMirroringsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListPacketMirroringsRequest. */
                class AggregatedListPacketMirroringsRequest implements IAggregatedListPacketMirroringsRequest {

                    /**
                     * Constructs a new AggregatedListPacketMirroringsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListPacketMirroringsRequest);

                    /** AggregatedListPacketMirroringsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListPacketMirroringsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListPacketMirroringsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListPacketMirroringsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListPacketMirroringsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListPacketMirroringsRequest project. */
                    public project: string;

                    /** AggregatedListPacketMirroringsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListPacketMirroringsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListPacketMirroringsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListPacketMirroringsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListPacketMirroringsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListPacketMirroringsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListPacketMirroringsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListPacketMirroringsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListPacketMirroringsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListPacketMirroringsRequest): google.cloud.compute.v1.AggregatedListPacketMirroringsRequest;

                    /**
                     * Encodes the specified AggregatedListPacketMirroringsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListPacketMirroringsRequest.verify|verify} messages.
                     * @param message AggregatedListPacketMirroringsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListPacketMirroringsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListPacketMirroringsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListPacketMirroringsRequest.verify|verify} messages.
                     * @param message AggregatedListPacketMirroringsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListPacketMirroringsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListPacketMirroringsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListPacketMirroringsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListPacketMirroringsRequest;

                    /**
                     * Decodes an AggregatedListPacketMirroringsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListPacketMirroringsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListPacketMirroringsRequest;

                    /**
                     * Verifies an AggregatedListPacketMirroringsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListPacketMirroringsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListPacketMirroringsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListPacketMirroringsRequest;

                    /**
                     * Creates a plain object from an AggregatedListPacketMirroringsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListPacketMirroringsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListPacketMirroringsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListPacketMirroringsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListPacketMirroringsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListPublicDelegatedPrefixesRequest. */
                interface IAggregatedListPublicDelegatedPrefixesRequest {

                    /** AggregatedListPublicDelegatedPrefixesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest project */
                    project?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListPublicDelegatedPrefixesRequest. */
                class AggregatedListPublicDelegatedPrefixesRequest implements IAggregatedListPublicDelegatedPrefixesRequest {

                    /**
                     * Constructs a new AggregatedListPublicDelegatedPrefixesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListPublicDelegatedPrefixesRequest);

                    /** AggregatedListPublicDelegatedPrefixesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest project. */
                    public project: string;

                    /** AggregatedListPublicDelegatedPrefixesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListPublicDelegatedPrefixesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListPublicDelegatedPrefixesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListPublicDelegatedPrefixesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListPublicDelegatedPrefixesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListPublicDelegatedPrefixesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListPublicDelegatedPrefixesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListPublicDelegatedPrefixesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListPublicDelegatedPrefixesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListPublicDelegatedPrefixesRequest): google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest;

                    /**
                     * Encodes the specified AggregatedListPublicDelegatedPrefixesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest.verify|verify} messages.
                     * @param message AggregatedListPublicDelegatedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListPublicDelegatedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListPublicDelegatedPrefixesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest.verify|verify} messages.
                     * @param message AggregatedListPublicDelegatedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListPublicDelegatedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListPublicDelegatedPrefixesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListPublicDelegatedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest;

                    /**
                     * Decodes an AggregatedListPublicDelegatedPrefixesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListPublicDelegatedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest;

                    /**
                     * Verifies an AggregatedListPublicDelegatedPrefixesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListPublicDelegatedPrefixesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListPublicDelegatedPrefixesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest;

                    /**
                     * Creates a plain object from an AggregatedListPublicDelegatedPrefixesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListPublicDelegatedPrefixesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListPublicDelegatedPrefixesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListPublicDelegatedPrefixesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListPublicDelegatedPrefixesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListRegionCommitmentsRequest. */
                interface IAggregatedListRegionCommitmentsRequest {

                    /** AggregatedListRegionCommitmentsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListRegionCommitmentsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListRegionCommitmentsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest project */
                    project?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListRegionCommitmentsRequest. */
                class AggregatedListRegionCommitmentsRequest implements IAggregatedListRegionCommitmentsRequest {

                    /**
                     * Constructs a new AggregatedListRegionCommitmentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListRegionCommitmentsRequest);

                    /** AggregatedListRegionCommitmentsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListRegionCommitmentsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListRegionCommitmentsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListRegionCommitmentsRequest project. */
                    public project: string;

                    /** AggregatedListRegionCommitmentsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListRegionCommitmentsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListRegionCommitmentsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListRegionCommitmentsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListRegionCommitmentsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListRegionCommitmentsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListRegionCommitmentsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListRegionCommitmentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListRegionCommitmentsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListRegionCommitmentsRequest): google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest;

                    /**
                     * Encodes the specified AggregatedListRegionCommitmentsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest.verify|verify} messages.
                     * @param message AggregatedListRegionCommitmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListRegionCommitmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListRegionCommitmentsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest.verify|verify} messages.
                     * @param message AggregatedListRegionCommitmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListRegionCommitmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListRegionCommitmentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListRegionCommitmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest;

                    /**
                     * Decodes an AggregatedListRegionCommitmentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListRegionCommitmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest;

                    /**
                     * Verifies an AggregatedListRegionCommitmentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListRegionCommitmentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListRegionCommitmentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest;

                    /**
                     * Creates a plain object from an AggregatedListRegionCommitmentsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListRegionCommitmentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListRegionCommitmentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListRegionCommitmentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListRegionCommitmentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListReservationsRequest. */
                interface IAggregatedListReservationsRequest {

                    /** AggregatedListReservationsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListReservationsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListReservationsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListReservationsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListReservationsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListReservationsRequest project */
                    project?: (string|null);

                    /** AggregatedListReservationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListReservationsRequest. */
                class AggregatedListReservationsRequest implements IAggregatedListReservationsRequest {

                    /**
                     * Constructs a new AggregatedListReservationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListReservationsRequest);

                    /** AggregatedListReservationsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListReservationsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListReservationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListReservationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListReservationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListReservationsRequest project. */
                    public project: string;

                    /** AggregatedListReservationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListReservationsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListReservationsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListReservationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListReservationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListReservationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListReservationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListReservationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListReservationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListReservationsRequest): google.cloud.compute.v1.AggregatedListReservationsRequest;

                    /**
                     * Encodes the specified AggregatedListReservationsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListReservationsRequest.verify|verify} messages.
                     * @param message AggregatedListReservationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListReservationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListReservationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListReservationsRequest.verify|verify} messages.
                     * @param message AggregatedListReservationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListReservationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListReservationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListReservationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListReservationsRequest;

                    /**
                     * Decodes an AggregatedListReservationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListReservationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListReservationsRequest;

                    /**
                     * Verifies an AggregatedListReservationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListReservationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListReservationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListReservationsRequest;

                    /**
                     * Creates a plain object from an AggregatedListReservationsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListReservationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListReservationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListReservationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListReservationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListResourcePoliciesRequest. */
                interface IAggregatedListResourcePoliciesRequest {

                    /** AggregatedListResourcePoliciesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListResourcePoliciesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListResourcePoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListResourcePoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListResourcePoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListResourcePoliciesRequest project */
                    project?: (string|null);

                    /** AggregatedListResourcePoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListResourcePoliciesRequest. */
                class AggregatedListResourcePoliciesRequest implements IAggregatedListResourcePoliciesRequest {

                    /**
                     * Constructs a new AggregatedListResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListResourcePoliciesRequest);

                    /** AggregatedListResourcePoliciesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListResourcePoliciesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListResourcePoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListResourcePoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListResourcePoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListResourcePoliciesRequest project. */
                    public project: string;

                    /** AggregatedListResourcePoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListResourcePoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListResourcePoliciesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListResourcePoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListResourcePoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListResourcePoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListResourcePoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListResourcePoliciesRequest): google.cloud.compute.v1.AggregatedListResourcePoliciesRequest;

                    /**
                     * Encodes the specified AggregatedListResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListResourcePoliciesRequest.verify|verify} messages.
                     * @param message AggregatedListResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListResourcePoliciesRequest.verify|verify} messages.
                     * @param message AggregatedListResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListResourcePoliciesRequest;

                    /**
                     * Decodes an AggregatedListResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListResourcePoliciesRequest;

                    /**
                     * Verifies an AggregatedListResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListResourcePoliciesRequest;

                    /**
                     * Creates a plain object from an AggregatedListResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListRoutersRequest. */
                interface IAggregatedListRoutersRequest {

                    /** AggregatedListRoutersRequest filter */
                    filter?: (string|null);

                    /** AggregatedListRoutersRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListRoutersRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListRoutersRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListRoutersRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListRoutersRequest project */
                    project?: (string|null);

                    /** AggregatedListRoutersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListRoutersRequest. */
                class AggregatedListRoutersRequest implements IAggregatedListRoutersRequest {

                    /**
                     * Constructs a new AggregatedListRoutersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListRoutersRequest);

                    /** AggregatedListRoutersRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListRoutersRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListRoutersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListRoutersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListRoutersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListRoutersRequest project. */
                    public project: string;

                    /** AggregatedListRoutersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListRoutersRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListRoutersRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListRoutersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListRoutersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListRoutersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListRoutersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListRoutersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListRoutersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListRoutersRequest): google.cloud.compute.v1.AggregatedListRoutersRequest;

                    /**
                     * Encodes the specified AggregatedListRoutersRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListRoutersRequest.verify|verify} messages.
                     * @param message AggregatedListRoutersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListRoutersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListRoutersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListRoutersRequest.verify|verify} messages.
                     * @param message AggregatedListRoutersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListRoutersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListRoutersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListRoutersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListRoutersRequest;

                    /**
                     * Decodes an AggregatedListRoutersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListRoutersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListRoutersRequest;

                    /**
                     * Verifies an AggregatedListRoutersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListRoutersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListRoutersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListRoutersRequest;

                    /**
                     * Creates a plain object from an AggregatedListRoutersRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListRoutersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListRoutersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListRoutersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListRoutersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListSecurityPoliciesRequest. */
                interface IAggregatedListSecurityPoliciesRequest {

                    /** AggregatedListSecurityPoliciesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListSecurityPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListSecurityPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest project */
                    project?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListSecurityPoliciesRequest. */
                class AggregatedListSecurityPoliciesRequest implements IAggregatedListSecurityPoliciesRequest {

                    /**
                     * Constructs a new AggregatedListSecurityPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListSecurityPoliciesRequest);

                    /** AggregatedListSecurityPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListSecurityPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListSecurityPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListSecurityPoliciesRequest project. */
                    public project: string;

                    /** AggregatedListSecurityPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListSecurityPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListSecurityPoliciesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListSecurityPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListSecurityPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListSecurityPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListSecurityPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListSecurityPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListSecurityPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListSecurityPoliciesRequest): google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest;

                    /**
                     * Encodes the specified AggregatedListSecurityPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest.verify|verify} messages.
                     * @param message AggregatedListSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListSecurityPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest.verify|verify} messages.
                     * @param message AggregatedListSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListSecurityPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest;

                    /**
                     * Decodes an AggregatedListSecurityPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest;

                    /**
                     * Verifies an AggregatedListSecurityPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListSecurityPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListSecurityPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest;

                    /**
                     * Creates a plain object from an AggregatedListSecurityPoliciesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListSecurityPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListSecurityPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListSecurityPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListSecurityPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListServiceAttachmentsRequest. */
                interface IAggregatedListServiceAttachmentsRequest {

                    /** AggregatedListServiceAttachmentsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListServiceAttachmentsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListServiceAttachmentsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest project */
                    project?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListServiceAttachmentsRequest. */
                class AggregatedListServiceAttachmentsRequest implements IAggregatedListServiceAttachmentsRequest {

                    /**
                     * Constructs a new AggregatedListServiceAttachmentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListServiceAttachmentsRequest);

                    /** AggregatedListServiceAttachmentsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListServiceAttachmentsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListServiceAttachmentsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListServiceAttachmentsRequest project. */
                    public project: string;

                    /** AggregatedListServiceAttachmentsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListServiceAttachmentsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListServiceAttachmentsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListServiceAttachmentsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListServiceAttachmentsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListServiceAttachmentsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListServiceAttachmentsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListServiceAttachmentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListServiceAttachmentsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListServiceAttachmentsRequest): google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest;

                    /**
                     * Encodes the specified AggregatedListServiceAttachmentsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest.verify|verify} messages.
                     * @param message AggregatedListServiceAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListServiceAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListServiceAttachmentsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest.verify|verify} messages.
                     * @param message AggregatedListServiceAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListServiceAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListServiceAttachmentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListServiceAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest;

                    /**
                     * Decodes an AggregatedListServiceAttachmentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListServiceAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest;

                    /**
                     * Verifies an AggregatedListServiceAttachmentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListServiceAttachmentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListServiceAttachmentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest;

                    /**
                     * Creates a plain object from an AggregatedListServiceAttachmentsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListServiceAttachmentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListServiceAttachmentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListServiceAttachmentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListServiceAttachmentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListSslCertificatesRequest. */
                interface IAggregatedListSslCertificatesRequest {

                    /** AggregatedListSslCertificatesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListSslCertificatesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListSslCertificatesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListSslCertificatesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListSslCertificatesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListSslCertificatesRequest project */
                    project?: (string|null);

                    /** AggregatedListSslCertificatesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListSslCertificatesRequest. */
                class AggregatedListSslCertificatesRequest implements IAggregatedListSslCertificatesRequest {

                    /**
                     * Constructs a new AggregatedListSslCertificatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListSslCertificatesRequest);

                    /** AggregatedListSslCertificatesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListSslCertificatesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListSslCertificatesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListSslCertificatesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListSslCertificatesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListSslCertificatesRequest project. */
                    public project: string;

                    /** AggregatedListSslCertificatesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListSslCertificatesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListSslCertificatesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListSslCertificatesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListSslCertificatesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListSslCertificatesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListSslCertificatesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListSslCertificatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListSslCertificatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListSslCertificatesRequest): google.cloud.compute.v1.AggregatedListSslCertificatesRequest;

                    /**
                     * Encodes the specified AggregatedListSslCertificatesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSslCertificatesRequest.verify|verify} messages.
                     * @param message AggregatedListSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListSslCertificatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSslCertificatesRequest.verify|verify} messages.
                     * @param message AggregatedListSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListSslCertificatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListSslCertificatesRequest;

                    /**
                     * Decodes an AggregatedListSslCertificatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListSslCertificatesRequest;

                    /**
                     * Verifies an AggregatedListSslCertificatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListSslCertificatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListSslCertificatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListSslCertificatesRequest;

                    /**
                     * Creates a plain object from an AggregatedListSslCertificatesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListSslCertificatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListSslCertificatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListSslCertificatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListSslCertificatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListSslPoliciesRequest. */
                interface IAggregatedListSslPoliciesRequest {

                    /** AggregatedListSslPoliciesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListSslPoliciesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListSslPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListSslPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListSslPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListSslPoliciesRequest project */
                    project?: (string|null);

                    /** AggregatedListSslPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListSslPoliciesRequest. */
                class AggregatedListSslPoliciesRequest implements IAggregatedListSslPoliciesRequest {

                    /**
                     * Constructs a new AggregatedListSslPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListSslPoliciesRequest);

                    /** AggregatedListSslPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListSslPoliciesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListSslPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListSslPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListSslPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListSslPoliciesRequest project. */
                    public project: string;

                    /** AggregatedListSslPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListSslPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListSslPoliciesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListSslPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListSslPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListSslPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListSslPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListSslPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListSslPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListSslPoliciesRequest): google.cloud.compute.v1.AggregatedListSslPoliciesRequest;

                    /**
                     * Encodes the specified AggregatedListSslPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSslPoliciesRequest.verify|verify} messages.
                     * @param message AggregatedListSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListSslPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSslPoliciesRequest.verify|verify} messages.
                     * @param message AggregatedListSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListSslPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListSslPoliciesRequest;

                    /**
                     * Decodes an AggregatedListSslPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListSslPoliciesRequest;

                    /**
                     * Verifies an AggregatedListSslPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListSslPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListSslPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListSslPoliciesRequest;

                    /**
                     * Creates a plain object from an AggregatedListSslPoliciesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListSslPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListSslPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListSslPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListSslPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListSubnetworksRequest. */
                interface IAggregatedListSubnetworksRequest {

                    /** AggregatedListSubnetworksRequest filter */
                    filter?: (string|null);

                    /** AggregatedListSubnetworksRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListSubnetworksRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListSubnetworksRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListSubnetworksRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListSubnetworksRequest project */
                    project?: (string|null);

                    /** AggregatedListSubnetworksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListSubnetworksRequest. */
                class AggregatedListSubnetworksRequest implements IAggregatedListSubnetworksRequest {

                    /**
                     * Constructs a new AggregatedListSubnetworksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListSubnetworksRequest);

                    /** AggregatedListSubnetworksRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListSubnetworksRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListSubnetworksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListSubnetworksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListSubnetworksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListSubnetworksRequest project. */
                    public project: string;

                    /** AggregatedListSubnetworksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListSubnetworksRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListSubnetworksRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListSubnetworksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListSubnetworksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListSubnetworksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListSubnetworksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListSubnetworksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListSubnetworksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListSubnetworksRequest): google.cloud.compute.v1.AggregatedListSubnetworksRequest;

                    /**
                     * Encodes the specified AggregatedListSubnetworksRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSubnetworksRequest.verify|verify} messages.
                     * @param message AggregatedListSubnetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListSubnetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListSubnetworksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListSubnetworksRequest.verify|verify} messages.
                     * @param message AggregatedListSubnetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListSubnetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListSubnetworksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListSubnetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListSubnetworksRequest;

                    /**
                     * Decodes an AggregatedListSubnetworksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListSubnetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListSubnetworksRequest;

                    /**
                     * Verifies an AggregatedListSubnetworksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListSubnetworksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListSubnetworksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListSubnetworksRequest;

                    /**
                     * Creates a plain object from an AggregatedListSubnetworksRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListSubnetworksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListSubnetworksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListSubnetworksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListSubnetworksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListTargetHttpProxiesRequest. */
                interface IAggregatedListTargetHttpProxiesRequest {

                    /** AggregatedListTargetHttpProxiesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetHttpProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListTargetHttpProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest project */
                    project?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListTargetHttpProxiesRequest. */
                class AggregatedListTargetHttpProxiesRequest implements IAggregatedListTargetHttpProxiesRequest {

                    /**
                     * Constructs a new AggregatedListTargetHttpProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListTargetHttpProxiesRequest);

                    /** AggregatedListTargetHttpProxiesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetHttpProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListTargetHttpProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListTargetHttpProxiesRequest project. */
                    public project: string;

                    /** AggregatedListTargetHttpProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListTargetHttpProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListTargetHttpProxiesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListTargetHttpProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListTargetHttpProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListTargetHttpProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListTargetHttpProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListTargetHttpProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListTargetHttpProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListTargetHttpProxiesRequest): google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest;

                    /**
                     * Encodes the specified AggregatedListTargetHttpProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest.verify|verify} messages.
                     * @param message AggregatedListTargetHttpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListTargetHttpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListTargetHttpProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest.verify|verify} messages.
                     * @param message AggregatedListTargetHttpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListTargetHttpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListTargetHttpProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListTargetHttpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest;

                    /**
                     * Decodes an AggregatedListTargetHttpProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListTargetHttpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest;

                    /**
                     * Verifies an AggregatedListTargetHttpProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListTargetHttpProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListTargetHttpProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest;

                    /**
                     * Creates a plain object from an AggregatedListTargetHttpProxiesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListTargetHttpProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListTargetHttpProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListTargetHttpProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListTargetHttpProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListTargetHttpsProxiesRequest. */
                interface IAggregatedListTargetHttpsProxiesRequest {

                    /** AggregatedListTargetHttpsProxiesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetHttpsProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListTargetHttpsProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest project */
                    project?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListTargetHttpsProxiesRequest. */
                class AggregatedListTargetHttpsProxiesRequest implements IAggregatedListTargetHttpsProxiesRequest {

                    /**
                     * Constructs a new AggregatedListTargetHttpsProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListTargetHttpsProxiesRequest);

                    /** AggregatedListTargetHttpsProxiesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetHttpsProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListTargetHttpsProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListTargetHttpsProxiesRequest project. */
                    public project: string;

                    /** AggregatedListTargetHttpsProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListTargetHttpsProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListTargetHttpsProxiesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListTargetHttpsProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListTargetHttpsProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListTargetHttpsProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListTargetHttpsProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListTargetHttpsProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListTargetHttpsProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListTargetHttpsProxiesRequest): google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest;

                    /**
                     * Encodes the specified AggregatedListTargetHttpsProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest.verify|verify} messages.
                     * @param message AggregatedListTargetHttpsProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListTargetHttpsProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListTargetHttpsProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest.verify|verify} messages.
                     * @param message AggregatedListTargetHttpsProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListTargetHttpsProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListTargetHttpsProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListTargetHttpsProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest;

                    /**
                     * Decodes an AggregatedListTargetHttpsProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListTargetHttpsProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest;

                    /**
                     * Verifies an AggregatedListTargetHttpsProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListTargetHttpsProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListTargetHttpsProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest;

                    /**
                     * Creates a plain object from an AggregatedListTargetHttpsProxiesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListTargetHttpsProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListTargetHttpsProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListTargetHttpsProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListTargetHttpsProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListTargetInstancesRequest. */
                interface IAggregatedListTargetInstancesRequest {

                    /** AggregatedListTargetInstancesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListTargetInstancesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetInstancesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListTargetInstancesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListTargetInstancesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListTargetInstancesRequest project */
                    project?: (string|null);

                    /** AggregatedListTargetInstancesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListTargetInstancesRequest. */
                class AggregatedListTargetInstancesRequest implements IAggregatedListTargetInstancesRequest {

                    /**
                     * Constructs a new AggregatedListTargetInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListTargetInstancesRequest);

                    /** AggregatedListTargetInstancesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListTargetInstancesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetInstancesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListTargetInstancesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListTargetInstancesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListTargetInstancesRequest project. */
                    public project: string;

                    /** AggregatedListTargetInstancesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListTargetInstancesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListTargetInstancesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListTargetInstancesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListTargetInstancesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListTargetInstancesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListTargetInstancesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListTargetInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListTargetInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListTargetInstancesRequest): google.cloud.compute.v1.AggregatedListTargetInstancesRequest;

                    /**
                     * Encodes the specified AggregatedListTargetInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetInstancesRequest.verify|verify} messages.
                     * @param message AggregatedListTargetInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListTargetInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListTargetInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetInstancesRequest.verify|verify} messages.
                     * @param message AggregatedListTargetInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListTargetInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListTargetInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListTargetInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListTargetInstancesRequest;

                    /**
                     * Decodes an AggregatedListTargetInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListTargetInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListTargetInstancesRequest;

                    /**
                     * Verifies an AggregatedListTargetInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListTargetInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListTargetInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListTargetInstancesRequest;

                    /**
                     * Creates a plain object from an AggregatedListTargetInstancesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListTargetInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListTargetInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListTargetInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListTargetInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListTargetPoolsRequest. */
                interface IAggregatedListTargetPoolsRequest {

                    /** AggregatedListTargetPoolsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListTargetPoolsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetPoolsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListTargetPoolsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListTargetPoolsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListTargetPoolsRequest project */
                    project?: (string|null);

                    /** AggregatedListTargetPoolsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListTargetPoolsRequest. */
                class AggregatedListTargetPoolsRequest implements IAggregatedListTargetPoolsRequest {

                    /**
                     * Constructs a new AggregatedListTargetPoolsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListTargetPoolsRequest);

                    /** AggregatedListTargetPoolsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListTargetPoolsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetPoolsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListTargetPoolsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListTargetPoolsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListTargetPoolsRequest project. */
                    public project: string;

                    /** AggregatedListTargetPoolsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListTargetPoolsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListTargetPoolsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListTargetPoolsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListTargetPoolsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListTargetPoolsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListTargetPoolsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListTargetPoolsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListTargetPoolsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListTargetPoolsRequest): google.cloud.compute.v1.AggregatedListTargetPoolsRequest;

                    /**
                     * Encodes the specified AggregatedListTargetPoolsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetPoolsRequest.verify|verify} messages.
                     * @param message AggregatedListTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListTargetPoolsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetPoolsRequest.verify|verify} messages.
                     * @param message AggregatedListTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListTargetPoolsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListTargetPoolsRequest;

                    /**
                     * Decodes an AggregatedListTargetPoolsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListTargetPoolsRequest;

                    /**
                     * Verifies an AggregatedListTargetPoolsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListTargetPoolsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListTargetPoolsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListTargetPoolsRequest;

                    /**
                     * Creates a plain object from an AggregatedListTargetPoolsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListTargetPoolsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListTargetPoolsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListTargetPoolsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListTargetPoolsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListTargetVpnGatewaysRequest. */
                interface IAggregatedListTargetVpnGatewaysRequest {

                    /** AggregatedListTargetVpnGatewaysRequest filter */
                    filter?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetVpnGatewaysRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListTargetVpnGatewaysRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest project */
                    project?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListTargetVpnGatewaysRequest. */
                class AggregatedListTargetVpnGatewaysRequest implements IAggregatedListTargetVpnGatewaysRequest {

                    /**
                     * Constructs a new AggregatedListTargetVpnGatewaysRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListTargetVpnGatewaysRequest);

                    /** AggregatedListTargetVpnGatewaysRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListTargetVpnGatewaysRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListTargetVpnGatewaysRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListTargetVpnGatewaysRequest project. */
                    public project: string;

                    /** AggregatedListTargetVpnGatewaysRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListTargetVpnGatewaysRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListTargetVpnGatewaysRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListTargetVpnGatewaysRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListTargetVpnGatewaysRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListTargetVpnGatewaysRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListTargetVpnGatewaysRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListTargetVpnGatewaysRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListTargetVpnGatewaysRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListTargetVpnGatewaysRequest): google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest;

                    /**
                     * Encodes the specified AggregatedListTargetVpnGatewaysRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest.verify|verify} messages.
                     * @param message AggregatedListTargetVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListTargetVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListTargetVpnGatewaysRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest.verify|verify} messages.
                     * @param message AggregatedListTargetVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListTargetVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListTargetVpnGatewaysRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListTargetVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest;

                    /**
                     * Decodes an AggregatedListTargetVpnGatewaysRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListTargetVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest;

                    /**
                     * Verifies an AggregatedListTargetVpnGatewaysRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListTargetVpnGatewaysRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListTargetVpnGatewaysRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest;

                    /**
                     * Creates a plain object from an AggregatedListTargetVpnGatewaysRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListTargetVpnGatewaysRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListTargetVpnGatewaysRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListTargetVpnGatewaysRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListTargetVpnGatewaysRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListUrlMapsRequest. */
                interface IAggregatedListUrlMapsRequest {

                    /** AggregatedListUrlMapsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListUrlMapsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListUrlMapsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListUrlMapsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListUrlMapsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListUrlMapsRequest project */
                    project?: (string|null);

                    /** AggregatedListUrlMapsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListUrlMapsRequest. */
                class AggregatedListUrlMapsRequest implements IAggregatedListUrlMapsRequest {

                    /**
                     * Constructs a new AggregatedListUrlMapsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListUrlMapsRequest);

                    /** AggregatedListUrlMapsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListUrlMapsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListUrlMapsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListUrlMapsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListUrlMapsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListUrlMapsRequest project. */
                    public project: string;

                    /** AggregatedListUrlMapsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListUrlMapsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListUrlMapsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListUrlMapsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListUrlMapsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListUrlMapsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListUrlMapsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListUrlMapsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListUrlMapsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListUrlMapsRequest): google.cloud.compute.v1.AggregatedListUrlMapsRequest;

                    /**
                     * Encodes the specified AggregatedListUrlMapsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListUrlMapsRequest.verify|verify} messages.
                     * @param message AggregatedListUrlMapsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListUrlMapsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListUrlMapsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListUrlMapsRequest.verify|verify} messages.
                     * @param message AggregatedListUrlMapsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListUrlMapsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListUrlMapsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListUrlMapsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListUrlMapsRequest;

                    /**
                     * Decodes an AggregatedListUrlMapsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListUrlMapsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListUrlMapsRequest;

                    /**
                     * Verifies an AggregatedListUrlMapsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListUrlMapsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListUrlMapsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListUrlMapsRequest;

                    /**
                     * Creates a plain object from an AggregatedListUrlMapsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListUrlMapsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListUrlMapsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListUrlMapsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListUrlMapsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListVpnGatewaysRequest. */
                interface IAggregatedListVpnGatewaysRequest {

                    /** AggregatedListVpnGatewaysRequest filter */
                    filter?: (string|null);

                    /** AggregatedListVpnGatewaysRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListVpnGatewaysRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListVpnGatewaysRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListVpnGatewaysRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListVpnGatewaysRequest project */
                    project?: (string|null);

                    /** AggregatedListVpnGatewaysRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListVpnGatewaysRequest. */
                class AggregatedListVpnGatewaysRequest implements IAggregatedListVpnGatewaysRequest {

                    /**
                     * Constructs a new AggregatedListVpnGatewaysRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListVpnGatewaysRequest);

                    /** AggregatedListVpnGatewaysRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListVpnGatewaysRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListVpnGatewaysRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListVpnGatewaysRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListVpnGatewaysRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListVpnGatewaysRequest project. */
                    public project: string;

                    /** AggregatedListVpnGatewaysRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListVpnGatewaysRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListVpnGatewaysRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListVpnGatewaysRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListVpnGatewaysRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListVpnGatewaysRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListVpnGatewaysRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListVpnGatewaysRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListVpnGatewaysRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListVpnGatewaysRequest): google.cloud.compute.v1.AggregatedListVpnGatewaysRequest;

                    /**
                     * Encodes the specified AggregatedListVpnGatewaysRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListVpnGatewaysRequest.verify|verify} messages.
                     * @param message AggregatedListVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListVpnGatewaysRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListVpnGatewaysRequest.verify|verify} messages.
                     * @param message AggregatedListVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListVpnGatewaysRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListVpnGatewaysRequest;

                    /**
                     * Decodes an AggregatedListVpnGatewaysRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListVpnGatewaysRequest;

                    /**
                     * Verifies an AggregatedListVpnGatewaysRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListVpnGatewaysRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListVpnGatewaysRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListVpnGatewaysRequest;

                    /**
                     * Creates a plain object from an AggregatedListVpnGatewaysRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListVpnGatewaysRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListVpnGatewaysRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListVpnGatewaysRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListVpnGatewaysRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListVpnTunnelsRequest. */
                interface IAggregatedListVpnTunnelsRequest {

                    /** AggregatedListVpnTunnelsRequest filter */
                    filter?: (string|null);

                    /** AggregatedListVpnTunnelsRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListVpnTunnelsRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListVpnTunnelsRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListVpnTunnelsRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListVpnTunnelsRequest project */
                    project?: (string|null);

                    /** AggregatedListVpnTunnelsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents an AggregatedListVpnTunnelsRequest. */
                class AggregatedListVpnTunnelsRequest implements IAggregatedListVpnTunnelsRequest {

                    /**
                     * Constructs a new AggregatedListVpnTunnelsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAggregatedListVpnTunnelsRequest);

                    /** AggregatedListVpnTunnelsRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListVpnTunnelsRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListVpnTunnelsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListVpnTunnelsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListVpnTunnelsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListVpnTunnelsRequest project. */
                    public project: string;

                    /** AggregatedListVpnTunnelsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** AggregatedListVpnTunnelsRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListVpnTunnelsRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListVpnTunnelsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListVpnTunnelsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListVpnTunnelsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** AggregatedListVpnTunnelsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new AggregatedListVpnTunnelsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListVpnTunnelsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAggregatedListVpnTunnelsRequest): google.cloud.compute.v1.AggregatedListVpnTunnelsRequest;

                    /**
                     * Encodes the specified AggregatedListVpnTunnelsRequest message. Does not implicitly {@link google.cloud.compute.v1.AggregatedListVpnTunnelsRequest.verify|verify} messages.
                     * @param message AggregatedListVpnTunnelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAggregatedListVpnTunnelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListVpnTunnelsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AggregatedListVpnTunnelsRequest.verify|verify} messages.
                     * @param message AggregatedListVpnTunnelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAggregatedListVpnTunnelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListVpnTunnelsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListVpnTunnelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AggregatedListVpnTunnelsRequest;

                    /**
                     * Decodes an AggregatedListVpnTunnelsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListVpnTunnelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AggregatedListVpnTunnelsRequest;

                    /**
                     * Verifies an AggregatedListVpnTunnelsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListVpnTunnelsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListVpnTunnelsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AggregatedListVpnTunnelsRequest;

                    /**
                     * Creates a plain object from an AggregatedListVpnTunnelsRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListVpnTunnelsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AggregatedListVpnTunnelsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListVpnTunnelsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListVpnTunnelsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AliasIpRange. */
                interface IAliasIpRange {

                    /** AliasIpRange ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** AliasIpRange subnetworkRangeName */
                    subnetworkRangeName?: (string|null);
                }

                /** Represents an AliasIpRange. */
                class AliasIpRange implements IAliasIpRange {

                    /**
                     * Constructs a new AliasIpRange.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAliasIpRange);

                    /** AliasIpRange ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** AliasIpRange subnetworkRangeName. */
                    public subnetworkRangeName?: (string|null);

                    /** AliasIpRange _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** AliasIpRange _subnetworkRangeName. */
                    public _subnetworkRangeName?: "subnetworkRangeName";

                    /**
                     * Creates a new AliasIpRange instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AliasIpRange instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAliasIpRange): google.cloud.compute.v1.AliasIpRange;

                    /**
                     * Encodes the specified AliasIpRange message. Does not implicitly {@link google.cloud.compute.v1.AliasIpRange.verify|verify} messages.
                     * @param message AliasIpRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAliasIpRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AliasIpRange message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AliasIpRange.verify|verify} messages.
                     * @param message AliasIpRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAliasIpRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AliasIpRange message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AliasIpRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AliasIpRange;

                    /**
                     * Decodes an AliasIpRange message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AliasIpRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AliasIpRange;

                    /**
                     * Verifies an AliasIpRange message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AliasIpRange message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AliasIpRange
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AliasIpRange;

                    /**
                     * Creates a plain object from an AliasIpRange message. Also converts values to other types if specified.
                     * @param message AliasIpRange
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AliasIpRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AliasIpRange to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AliasIpRange
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk. */
                interface IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk {

                    /** AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk diskSizeGb */
                    diskSizeGb?: (number|Long|string|null);

                    /** AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk interface */
                    "interface"?: (string|null);
                }

                /** Represents an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk. */
                class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk implements IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk {

                    /**
                     * Constructs a new AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk);

                    /** AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk diskSizeGb. */
                    public diskSizeGb?: (number|Long|string|null);

                    /** AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk interface. */
                    public interface?: (string|null);

                    /** AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk _interface. */
                    public _interface?: "interface";

                    /**
                     * Creates a new AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk): google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk;

                    /**
                     * Encodes the specified AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message. Does not implicitly {@link google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk.verify|verify} messages.
                     * @param message AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk.verify|verify} messages.
                     * @param message AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk;

                    /**
                     * Decodes an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk;

                    /**
                     * Verifies an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk;

                    /**
                     * Creates a plain object from an AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk message. Also converts values to other types if specified.
                     * @param message AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk {

                    /** Interface enum. */
                    enum Interface {
                        UNDEFINED_INTERFACE = 0,
                        NVME = 2408800,
                        SCSI = 2539686
                    }
                }

                /** Properties of an AllocationSpecificSKUAllocationReservedInstanceProperties. */
                interface IAllocationSpecificSKUAllocationReservedInstanceProperties {

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties guestAccelerators */
                    guestAccelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties localSsds */
                    localSsds?: (google.cloud.compute.v1.IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk[]|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties locationHint */
                    locationHint?: (string|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties machineType */
                    machineType?: (string|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties minCpuPlatform */
                    minCpuPlatform?: (string|null);
                }

                /** Represents an AllocationSpecificSKUAllocationReservedInstanceProperties. */
                class AllocationSpecificSKUAllocationReservedInstanceProperties implements IAllocationSpecificSKUAllocationReservedInstanceProperties {

                    /**
                     * Constructs a new AllocationSpecificSKUAllocationReservedInstanceProperties.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAllocationSpecificSKUAllocationReservedInstanceProperties);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties guestAccelerators. */
                    public guestAccelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties localSsds. */
                    public localSsds: google.cloud.compute.v1.IAllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk[];

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties locationHint. */
                    public locationHint?: (string|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties machineType. */
                    public machineType?: (string|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties minCpuPlatform. */
                    public minCpuPlatform?: (string|null);

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties _locationHint. */
                    public _locationHint?: "locationHint";

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties _machineType. */
                    public _machineType?: "machineType";

                    /** AllocationSpecificSKUAllocationReservedInstanceProperties _minCpuPlatform. */
                    public _minCpuPlatform?: "minCpuPlatform";

                    /**
                     * Creates a new AllocationSpecificSKUAllocationReservedInstanceProperties instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AllocationSpecificSKUAllocationReservedInstanceProperties instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAllocationSpecificSKUAllocationReservedInstanceProperties): google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties;

                    /**
                     * Encodes the specified AllocationSpecificSKUAllocationReservedInstanceProperties message. Does not implicitly {@link google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties.verify|verify} messages.
                     * @param message AllocationSpecificSKUAllocationReservedInstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAllocationSpecificSKUAllocationReservedInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AllocationSpecificSKUAllocationReservedInstanceProperties message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties.verify|verify} messages.
                     * @param message AllocationSpecificSKUAllocationReservedInstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAllocationSpecificSKUAllocationReservedInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AllocationSpecificSKUAllocationReservedInstanceProperties message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AllocationSpecificSKUAllocationReservedInstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties;

                    /**
                     * Decodes an AllocationSpecificSKUAllocationReservedInstanceProperties message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AllocationSpecificSKUAllocationReservedInstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties;

                    /**
                     * Verifies an AllocationSpecificSKUAllocationReservedInstanceProperties message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AllocationSpecificSKUAllocationReservedInstanceProperties message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AllocationSpecificSKUAllocationReservedInstanceProperties
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties;

                    /**
                     * Creates a plain object from an AllocationSpecificSKUAllocationReservedInstanceProperties message. Also converts values to other types if specified.
                     * @param message AllocationSpecificSKUAllocationReservedInstanceProperties
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AllocationSpecificSKUAllocationReservedInstanceProperties, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AllocationSpecificSKUAllocationReservedInstanceProperties to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AllocationSpecificSKUAllocationReservedInstanceProperties
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AllocationSpecificSKUReservation. */
                interface IAllocationSpecificSKUReservation {

                    /** AllocationSpecificSKUReservation assuredCount */
                    assuredCount?: (number|Long|string|null);

                    /** AllocationSpecificSKUReservation count */
                    count?: (number|Long|string|null);

                    /** AllocationSpecificSKUReservation inUseCount */
                    inUseCount?: (number|Long|string|null);

                    /** AllocationSpecificSKUReservation instanceProperties */
                    instanceProperties?: (google.cloud.compute.v1.IAllocationSpecificSKUAllocationReservedInstanceProperties|null);
                }

                /** Represents an AllocationSpecificSKUReservation. */
                class AllocationSpecificSKUReservation implements IAllocationSpecificSKUReservation {

                    /**
                     * Constructs a new AllocationSpecificSKUReservation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAllocationSpecificSKUReservation);

                    /** AllocationSpecificSKUReservation assuredCount. */
                    public assuredCount?: (number|Long|string|null);

                    /** AllocationSpecificSKUReservation count. */
                    public count?: (number|Long|string|null);

                    /** AllocationSpecificSKUReservation inUseCount. */
                    public inUseCount?: (number|Long|string|null);

                    /** AllocationSpecificSKUReservation instanceProperties. */
                    public instanceProperties?: (google.cloud.compute.v1.IAllocationSpecificSKUAllocationReservedInstanceProperties|null);

                    /** AllocationSpecificSKUReservation _assuredCount. */
                    public _assuredCount?: "assuredCount";

                    /** AllocationSpecificSKUReservation _count. */
                    public _count?: "count";

                    /** AllocationSpecificSKUReservation _inUseCount. */
                    public _inUseCount?: "inUseCount";

                    /** AllocationSpecificSKUReservation _instanceProperties. */
                    public _instanceProperties?: "instanceProperties";

                    /**
                     * Creates a new AllocationSpecificSKUReservation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AllocationSpecificSKUReservation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAllocationSpecificSKUReservation): google.cloud.compute.v1.AllocationSpecificSKUReservation;

                    /**
                     * Encodes the specified AllocationSpecificSKUReservation message. Does not implicitly {@link google.cloud.compute.v1.AllocationSpecificSKUReservation.verify|verify} messages.
                     * @param message AllocationSpecificSKUReservation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAllocationSpecificSKUReservation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AllocationSpecificSKUReservation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AllocationSpecificSKUReservation.verify|verify} messages.
                     * @param message AllocationSpecificSKUReservation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAllocationSpecificSKUReservation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AllocationSpecificSKUReservation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AllocationSpecificSKUReservation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AllocationSpecificSKUReservation;

                    /**
                     * Decodes an AllocationSpecificSKUReservation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AllocationSpecificSKUReservation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AllocationSpecificSKUReservation;

                    /**
                     * Verifies an AllocationSpecificSKUReservation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AllocationSpecificSKUReservation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AllocationSpecificSKUReservation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AllocationSpecificSKUReservation;

                    /**
                     * Creates a plain object from an AllocationSpecificSKUReservation message. Also converts values to other types if specified.
                     * @param message AllocationSpecificSKUReservation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AllocationSpecificSKUReservation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AllocationSpecificSKUReservation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AllocationSpecificSKUReservation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Allowed. */
                interface IAllowed {

                    /** Allowed IPProtocol */
                    IPProtocol?: (string|null);

                    /** Allowed ports */
                    ports?: (string[]|null);
                }

                /** Represents an Allowed. */
                class Allowed implements IAllowed {

                    /**
                     * Constructs a new Allowed.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAllowed);

                    /** Allowed IPProtocol. */
                    public IPProtocol?: (string|null);

                    /** Allowed ports. */
                    public ports: string[];

                    /** Allowed _IPProtocol. */
                    public _IPProtocol?: "IPProtocol";

                    /**
                     * Creates a new Allowed instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Allowed instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAllowed): google.cloud.compute.v1.Allowed;

                    /**
                     * Encodes the specified Allowed message. Does not implicitly {@link google.cloud.compute.v1.Allowed.verify|verify} messages.
                     * @param message Allowed message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAllowed, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Allowed message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Allowed.verify|verify} messages.
                     * @param message Allowed message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAllowed, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Allowed message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Allowed
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Allowed;

                    /**
                     * Decodes an Allowed message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Allowed
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Allowed;

                    /**
                     * Verifies an Allowed message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Allowed message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Allowed
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Allowed;

                    /**
                     * Creates a plain object from an Allowed message. Also converts values to other types if specified.
                     * @param message Allowed
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Allowed, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Allowed to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Allowed
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ApplyUpdatesToInstancesInstanceGroupManagerRequest. */
                interface IApplyUpdatesToInstancesInstanceGroupManagerRequest {

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest instanceGroupManagersApplyUpdatesRequestResource */
                    instanceGroupManagersApplyUpdatesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersApplyUpdatesRequest|null);

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents an ApplyUpdatesToInstancesInstanceGroupManagerRequest. */
                class ApplyUpdatesToInstancesInstanceGroupManagerRequest implements IApplyUpdatesToInstancesInstanceGroupManagerRequest {

                    /**
                     * Constructs a new ApplyUpdatesToInstancesInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest);

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest instanceGroupManagersApplyUpdatesRequestResource. */
                    public instanceGroupManagersApplyUpdatesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersApplyUpdatesRequest|null);

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest project. */
                    public project: string;

                    /** ApplyUpdatesToInstancesInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new ApplyUpdatesToInstancesInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ApplyUpdatesToInstancesInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest): google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified ApplyUpdatesToInstancesInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ApplyUpdatesToInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ApplyUpdatesToInstancesInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ApplyUpdatesToInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ApplyUpdatesToInstancesInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ApplyUpdatesToInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest;

                    /**
                     * Decodes an ApplyUpdatesToInstancesInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ApplyUpdatesToInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest;

                    /**
                     * Verifies an ApplyUpdatesToInstancesInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ApplyUpdatesToInstancesInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ApplyUpdatesToInstancesInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an ApplyUpdatesToInstancesInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message ApplyUpdatesToInstancesInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ApplyUpdatesToInstancesInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ApplyUpdatesToInstancesInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ApplyUpdatesToInstancesInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest. */
                interface IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest {

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersApplyUpdatesRequestResource */
                    regionInstanceGroupManagersApplyUpdatesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersApplyUpdatesRequest|null);
                }

                /** Represents an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest. */
                class ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest implements IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest);

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersApplyUpdatesRequestResource. */
                    public regionInstanceGroupManagersApplyUpdatesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersApplyUpdatesRequest|null);

                    /**
                     * Creates a new ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest): google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AttachDiskInstanceRequest. */
                interface IAttachDiskInstanceRequest {

                    /** AttachDiskInstanceRequest attachedDiskResource */
                    attachedDiskResource?: (google.cloud.compute.v1.IAttachedDisk|null);

                    /** AttachDiskInstanceRequest forceAttach */
                    forceAttach?: (boolean|null);

                    /** AttachDiskInstanceRequest instance */
                    instance?: (string|null);

                    /** AttachDiskInstanceRequest project */
                    project?: (string|null);

                    /** AttachDiskInstanceRequest requestId */
                    requestId?: (string|null);

                    /** AttachDiskInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AttachDiskInstanceRequest. */
                class AttachDiskInstanceRequest implements IAttachDiskInstanceRequest {

                    /**
                     * Constructs a new AttachDiskInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAttachDiskInstanceRequest);

                    /** AttachDiskInstanceRequest attachedDiskResource. */
                    public attachedDiskResource?: (google.cloud.compute.v1.IAttachedDisk|null);

                    /** AttachDiskInstanceRequest forceAttach. */
                    public forceAttach?: (boolean|null);

                    /** AttachDiskInstanceRequest instance. */
                    public instance: string;

                    /** AttachDiskInstanceRequest project. */
                    public project: string;

                    /** AttachDiskInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** AttachDiskInstanceRequest zone. */
                    public zone: string;

                    /** AttachDiskInstanceRequest _forceAttach. */
                    public _forceAttach?: "forceAttach";

                    /** AttachDiskInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AttachDiskInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AttachDiskInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAttachDiskInstanceRequest): google.cloud.compute.v1.AttachDiskInstanceRequest;

                    /**
                     * Encodes the specified AttachDiskInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.AttachDiskInstanceRequest.verify|verify} messages.
                     * @param message AttachDiskInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAttachDiskInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AttachDiskInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AttachDiskInstanceRequest.verify|verify} messages.
                     * @param message AttachDiskInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAttachDiskInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AttachDiskInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AttachDiskInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AttachDiskInstanceRequest;

                    /**
                     * Decodes an AttachDiskInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AttachDiskInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AttachDiskInstanceRequest;

                    /**
                     * Verifies an AttachDiskInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AttachDiskInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AttachDiskInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AttachDiskInstanceRequest;

                    /**
                     * Creates a plain object from an AttachDiskInstanceRequest message. Also converts values to other types if specified.
                     * @param message AttachDiskInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AttachDiskInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AttachDiskInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AttachDiskInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest. */
                interface IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest {

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest globalNetworkEndpointGroupsAttachEndpointsRequestResource */
                    globalNetworkEndpointGroupsAttachEndpointsRequestResource?: (google.cloud.compute.v1.IGlobalNetworkEndpointGroupsAttachEndpointsRequest|null);

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest. */
                class AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest implements IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest);

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest globalNetworkEndpointGroupsAttachEndpointsRequestResource. */
                    public globalNetworkEndpointGroupsAttachEndpointsRequestResource?: (google.cloud.compute.v1.IGlobalNetworkEndpointGroupsAttachEndpointsRequest|null);

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest): google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Decodes an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Verifies an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from an AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AttachNetworkEndpointsNetworkEndpointGroupRequest. */
                interface IAttachNetworkEndpointsNetworkEndpointGroupRequest {

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroupsAttachEndpointsRequestResource */
                    networkEndpointGroupsAttachEndpointsRequestResource?: (google.cloud.compute.v1.INetworkEndpointGroupsAttachEndpointsRequest|null);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents an AttachNetworkEndpointsNetworkEndpointGroupRequest. */
                class AttachNetworkEndpointsNetworkEndpointGroupRequest implements IAttachNetworkEndpointsNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new AttachNetworkEndpointsNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAttachNetworkEndpointsNetworkEndpointGroupRequest);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroupsAttachEndpointsRequestResource. */
                    public networkEndpointGroupsAttachEndpointsRequestResource?: (google.cloud.compute.v1.INetworkEndpointGroupsAttachEndpointsRequest|null);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest zone. */
                    public zone: string;

                    /** AttachNetworkEndpointsNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new AttachNetworkEndpointsNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AttachNetworkEndpointsNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAttachNetworkEndpointsNetworkEndpointGroupRequest): google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified AttachNetworkEndpointsNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message AttachNetworkEndpointsNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAttachNetworkEndpointsNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AttachNetworkEndpointsNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message AttachNetworkEndpointsNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAttachNetworkEndpointsNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AttachNetworkEndpointsNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AttachNetworkEndpointsNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Decodes an AttachNetworkEndpointsNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AttachNetworkEndpointsNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Verifies an AttachNetworkEndpointsNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AttachNetworkEndpointsNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AttachNetworkEndpointsNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from an AttachNetworkEndpointsNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message AttachNetworkEndpointsNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AttachNetworkEndpointsNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AttachNetworkEndpointsNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AttachNetworkEndpointsNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AttachedDisk. */
                interface IAttachedDisk {

                    /** AttachedDisk architecture */
                    architecture?: (string|null);

                    /** AttachedDisk autoDelete */
                    autoDelete?: (boolean|null);

                    /** AttachedDisk boot */
                    boot?: (boolean|null);

                    /** AttachedDisk deviceName */
                    deviceName?: (string|null);

                    /** AttachedDisk diskEncryptionKey */
                    diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** AttachedDisk diskSizeGb */
                    diskSizeGb?: (number|Long|string|null);

                    /** AttachedDisk forceAttach */
                    forceAttach?: (boolean|null);

                    /** AttachedDisk guestOsFeatures */
                    guestOsFeatures?: (google.cloud.compute.v1.IGuestOsFeature[]|null);

                    /** AttachedDisk index */
                    index?: (number|null);

                    /** AttachedDisk initializeParams */
                    initializeParams?: (google.cloud.compute.v1.IAttachedDiskInitializeParams|null);

                    /** AttachedDisk interface */
                    "interface"?: (string|null);

                    /** AttachedDisk kind */
                    kind?: (string|null);

                    /** AttachedDisk licenses */
                    licenses?: (string[]|null);

                    /** AttachedDisk mode */
                    mode?: (string|null);

                    /** AttachedDisk shieldedInstanceInitialState */
                    shieldedInstanceInitialState?: (google.cloud.compute.v1.IInitialStateConfig|null);

                    /** AttachedDisk source */
                    source?: (string|null);

                    /** AttachedDisk type */
                    type?: (string|null);
                }

                /** Represents an AttachedDisk. */
                class AttachedDisk implements IAttachedDisk {

                    /**
                     * Constructs a new AttachedDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAttachedDisk);

                    /** AttachedDisk architecture. */
                    public architecture?: (string|null);

                    /** AttachedDisk autoDelete. */
                    public autoDelete?: (boolean|null);

                    /** AttachedDisk boot. */
                    public boot?: (boolean|null);

                    /** AttachedDisk deviceName. */
                    public deviceName?: (string|null);

                    /** AttachedDisk diskEncryptionKey. */
                    public diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** AttachedDisk diskSizeGb. */
                    public diskSizeGb?: (number|Long|string|null);

                    /** AttachedDisk forceAttach. */
                    public forceAttach?: (boolean|null);

                    /** AttachedDisk guestOsFeatures. */
                    public guestOsFeatures: google.cloud.compute.v1.IGuestOsFeature[];

                    /** AttachedDisk index. */
                    public index?: (number|null);

                    /** AttachedDisk initializeParams. */
                    public initializeParams?: (google.cloud.compute.v1.IAttachedDiskInitializeParams|null);

                    /** AttachedDisk interface. */
                    public interface?: (string|null);

                    /** AttachedDisk kind. */
                    public kind?: (string|null);

                    /** AttachedDisk licenses. */
                    public licenses: string[];

                    /** AttachedDisk mode. */
                    public mode?: (string|null);

                    /** AttachedDisk shieldedInstanceInitialState. */
                    public shieldedInstanceInitialState?: (google.cloud.compute.v1.IInitialStateConfig|null);

                    /** AttachedDisk source. */
                    public source?: (string|null);

                    /** AttachedDisk type. */
                    public type?: (string|null);

                    /** AttachedDisk _architecture. */
                    public _architecture?: "architecture";

                    /** AttachedDisk _autoDelete. */
                    public _autoDelete?: "autoDelete";

                    /** AttachedDisk _boot. */
                    public _boot?: "boot";

                    /** AttachedDisk _deviceName. */
                    public _deviceName?: "deviceName";

                    /** AttachedDisk _diskEncryptionKey. */
                    public _diskEncryptionKey?: "diskEncryptionKey";

                    /** AttachedDisk _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** AttachedDisk _forceAttach. */
                    public _forceAttach?: "forceAttach";

                    /** AttachedDisk _index. */
                    public _index?: "index";

                    /** AttachedDisk _initializeParams. */
                    public _initializeParams?: "initializeParams";

                    /** AttachedDisk _interface. */
                    public _interface?: "interface";

                    /** AttachedDisk _kind. */
                    public _kind?: "kind";

                    /** AttachedDisk _mode. */
                    public _mode?: "mode";

                    /** AttachedDisk _shieldedInstanceInitialState. */
                    public _shieldedInstanceInitialState?: "shieldedInstanceInitialState";

                    /** AttachedDisk _source. */
                    public _source?: "source";

                    /** AttachedDisk _type. */
                    public _type?: "type";

                    /**
                     * Creates a new AttachedDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AttachedDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAttachedDisk): google.cloud.compute.v1.AttachedDisk;

                    /**
                     * Encodes the specified AttachedDisk message. Does not implicitly {@link google.cloud.compute.v1.AttachedDisk.verify|verify} messages.
                     * @param message AttachedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAttachedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AttachedDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AttachedDisk.verify|verify} messages.
                     * @param message AttachedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAttachedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AttachedDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AttachedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AttachedDisk;

                    /**
                     * Decodes an AttachedDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AttachedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AttachedDisk;

                    /**
                     * Verifies an AttachedDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AttachedDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AttachedDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AttachedDisk;

                    /**
                     * Creates a plain object from an AttachedDisk message. Also converts values to other types if specified.
                     * @param message AttachedDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AttachedDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AttachedDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AttachedDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AttachedDisk {

                    /** Architecture enum. */
                    enum Architecture {
                        UNDEFINED_ARCHITECTURE = 0,
                        ARCHITECTURE_UNSPECIFIED = 394750507,
                        ARM64 = 62547450,
                        X86_64 = 425300551
                    }

                    /** Interface enum. */
                    enum Interface {
                        UNDEFINED_INTERFACE = 0,
                        NVME = 2408800,
                        SCSI = 2539686
                    }

                    /** Mode enum. */
                    enum Mode {
                        UNDEFINED_MODE = 0,
                        READ_ONLY = 91950261,
                        READ_WRITE = 173607894
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        PERSISTENT = 460683927,
                        SCRATCH = 496778970
                    }
                }

                /** Properties of an AttachedDiskInitializeParams. */
                interface IAttachedDiskInitializeParams {

                    /** AttachedDiskInitializeParams architecture */
                    architecture?: (string|null);

                    /** AttachedDiskInitializeParams description */
                    description?: (string|null);

                    /** AttachedDiskInitializeParams diskName */
                    diskName?: (string|null);

                    /** AttachedDiskInitializeParams diskSizeGb */
                    diskSizeGb?: (number|Long|string|null);

                    /** AttachedDiskInitializeParams diskType */
                    diskType?: (string|null);

                    /** AttachedDiskInitializeParams labels */
                    labels?: ({ [k: string]: string }|null);

                    /** AttachedDiskInitializeParams licenses */
                    licenses?: (string[]|null);

                    /** AttachedDiskInitializeParams onUpdateAction */
                    onUpdateAction?: (string|null);

                    /** AttachedDiskInitializeParams provisionedIops */
                    provisionedIops?: (number|Long|string|null);

                    /** AttachedDiskInitializeParams resourceManagerTags */
                    resourceManagerTags?: ({ [k: string]: string }|null);

                    /** AttachedDiskInitializeParams resourcePolicies */
                    resourcePolicies?: (string[]|null);

                    /** AttachedDiskInitializeParams sourceImage */
                    sourceImage?: (string|null);

                    /** AttachedDiskInitializeParams sourceImageEncryptionKey */
                    sourceImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** AttachedDiskInitializeParams sourceSnapshot */
                    sourceSnapshot?: (string|null);

                    /** AttachedDiskInitializeParams sourceSnapshotEncryptionKey */
                    sourceSnapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);
                }

                /** Represents an AttachedDiskInitializeParams. */
                class AttachedDiskInitializeParams implements IAttachedDiskInitializeParams {

                    /**
                     * Constructs a new AttachedDiskInitializeParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAttachedDiskInitializeParams);

                    /** AttachedDiskInitializeParams architecture. */
                    public architecture?: (string|null);

                    /** AttachedDiskInitializeParams description. */
                    public description?: (string|null);

                    /** AttachedDiskInitializeParams diskName. */
                    public diskName?: (string|null);

                    /** AttachedDiskInitializeParams diskSizeGb. */
                    public diskSizeGb?: (number|Long|string|null);

                    /** AttachedDiskInitializeParams diskType. */
                    public diskType?: (string|null);

                    /** AttachedDiskInitializeParams labels. */
                    public labels: { [k: string]: string };

                    /** AttachedDiskInitializeParams licenses. */
                    public licenses: string[];

                    /** AttachedDiskInitializeParams onUpdateAction. */
                    public onUpdateAction?: (string|null);

                    /** AttachedDiskInitializeParams provisionedIops. */
                    public provisionedIops?: (number|Long|string|null);

                    /** AttachedDiskInitializeParams resourceManagerTags. */
                    public resourceManagerTags: { [k: string]: string };

                    /** AttachedDiskInitializeParams resourcePolicies. */
                    public resourcePolicies: string[];

                    /** AttachedDiskInitializeParams sourceImage. */
                    public sourceImage?: (string|null);

                    /** AttachedDiskInitializeParams sourceImageEncryptionKey. */
                    public sourceImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** AttachedDiskInitializeParams sourceSnapshot. */
                    public sourceSnapshot?: (string|null);

                    /** AttachedDiskInitializeParams sourceSnapshotEncryptionKey. */
                    public sourceSnapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** AttachedDiskInitializeParams _architecture. */
                    public _architecture?: "architecture";

                    /** AttachedDiskInitializeParams _description. */
                    public _description?: "description";

                    /** AttachedDiskInitializeParams _diskName. */
                    public _diskName?: "diskName";

                    /** AttachedDiskInitializeParams _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** AttachedDiskInitializeParams _diskType. */
                    public _diskType?: "diskType";

                    /** AttachedDiskInitializeParams _onUpdateAction. */
                    public _onUpdateAction?: "onUpdateAction";

                    /** AttachedDiskInitializeParams _provisionedIops. */
                    public _provisionedIops?: "provisionedIops";

                    /** AttachedDiskInitializeParams _sourceImage. */
                    public _sourceImage?: "sourceImage";

                    /** AttachedDiskInitializeParams _sourceImageEncryptionKey. */
                    public _sourceImageEncryptionKey?: "sourceImageEncryptionKey";

                    /** AttachedDiskInitializeParams _sourceSnapshot. */
                    public _sourceSnapshot?: "sourceSnapshot";

                    /** AttachedDiskInitializeParams _sourceSnapshotEncryptionKey. */
                    public _sourceSnapshotEncryptionKey?: "sourceSnapshotEncryptionKey";

                    /**
                     * Creates a new AttachedDiskInitializeParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AttachedDiskInitializeParams instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAttachedDiskInitializeParams): google.cloud.compute.v1.AttachedDiskInitializeParams;

                    /**
                     * Encodes the specified AttachedDiskInitializeParams message. Does not implicitly {@link google.cloud.compute.v1.AttachedDiskInitializeParams.verify|verify} messages.
                     * @param message AttachedDiskInitializeParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAttachedDiskInitializeParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AttachedDiskInitializeParams message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AttachedDiskInitializeParams.verify|verify} messages.
                     * @param message AttachedDiskInitializeParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAttachedDiskInitializeParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AttachedDiskInitializeParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AttachedDiskInitializeParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AttachedDiskInitializeParams;

                    /**
                     * Decodes an AttachedDiskInitializeParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AttachedDiskInitializeParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AttachedDiskInitializeParams;

                    /**
                     * Verifies an AttachedDiskInitializeParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AttachedDiskInitializeParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AttachedDiskInitializeParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AttachedDiskInitializeParams;

                    /**
                     * Creates a plain object from an AttachedDiskInitializeParams message. Also converts values to other types if specified.
                     * @param message AttachedDiskInitializeParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AttachedDiskInitializeParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AttachedDiskInitializeParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AttachedDiskInitializeParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AttachedDiskInitializeParams {

                    /** Architecture enum. */
                    enum Architecture {
                        UNDEFINED_ARCHITECTURE = 0,
                        ARCHITECTURE_UNSPECIFIED = 394750507,
                        ARM64 = 62547450,
                        X86_64 = 425300551
                    }

                    /** OnUpdateAction enum. */
                    enum OnUpdateAction {
                        UNDEFINED_ON_UPDATE_ACTION = 0,
                        RECREATE_DISK = 494767853,
                        RECREATE_DISK_IF_SOURCE_CHANGED = 398099712,
                        USE_EXISTING_DISK = 232682233
                    }
                }

                /** Properties of an AuditConfig. */
                interface IAuditConfig {

                    /** AuditConfig auditLogConfigs */
                    auditLogConfigs?: (google.cloud.compute.v1.IAuditLogConfig[]|null);

                    /** AuditConfig exemptedMembers */
                    exemptedMembers?: (string[]|null);

                    /** AuditConfig service */
                    service?: (string|null);
                }

                /** Represents an AuditConfig. */
                class AuditConfig implements IAuditConfig {

                    /**
                     * Constructs a new AuditConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAuditConfig);

                    /** AuditConfig auditLogConfigs. */
                    public auditLogConfigs: google.cloud.compute.v1.IAuditLogConfig[];

                    /** AuditConfig exemptedMembers. */
                    public exemptedMembers: string[];

                    /** AuditConfig service. */
                    public service?: (string|null);

                    /** AuditConfig _service. */
                    public _service?: "service";

                    /**
                     * Creates a new AuditConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AuditConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAuditConfig): google.cloud.compute.v1.AuditConfig;

                    /**
                     * Encodes the specified AuditConfig message. Does not implicitly {@link google.cloud.compute.v1.AuditConfig.verify|verify} messages.
                     * @param message AuditConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAuditConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AuditConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AuditConfig.verify|verify} messages.
                     * @param message AuditConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAuditConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AuditConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AuditConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AuditConfig;

                    /**
                     * Decodes an AuditConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AuditConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AuditConfig;

                    /**
                     * Verifies an AuditConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AuditConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AuditConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AuditConfig;

                    /**
                     * Creates a plain object from an AuditConfig message. Also converts values to other types if specified.
                     * @param message AuditConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AuditConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AuditConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AuditConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AuditLogConfig. */
                interface IAuditLogConfig {

                    /** AuditLogConfig exemptedMembers */
                    exemptedMembers?: (string[]|null);

                    /** AuditLogConfig ignoreChildExemptions */
                    ignoreChildExemptions?: (boolean|null);

                    /** AuditLogConfig logType */
                    logType?: (string|null);
                }

                /** Represents an AuditLogConfig. */
                class AuditLogConfig implements IAuditLogConfig {

                    /**
                     * Constructs a new AuditLogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAuditLogConfig);

                    /** AuditLogConfig exemptedMembers. */
                    public exemptedMembers: string[];

                    /** AuditLogConfig ignoreChildExemptions. */
                    public ignoreChildExemptions?: (boolean|null);

                    /** AuditLogConfig logType. */
                    public logType?: (string|null);

                    /** AuditLogConfig _ignoreChildExemptions. */
                    public _ignoreChildExemptions?: "ignoreChildExemptions";

                    /** AuditLogConfig _logType. */
                    public _logType?: "logType";

                    /**
                     * Creates a new AuditLogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AuditLogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAuditLogConfig): google.cloud.compute.v1.AuditLogConfig;

                    /**
                     * Encodes the specified AuditLogConfig message. Does not implicitly {@link google.cloud.compute.v1.AuditLogConfig.verify|verify} messages.
                     * @param message AuditLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAuditLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AuditLogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AuditLogConfig.verify|verify} messages.
                     * @param message AuditLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAuditLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AuditLogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AuditLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AuditLogConfig;

                    /**
                     * Decodes an AuditLogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AuditLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AuditLogConfig;

                    /**
                     * Verifies an AuditLogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AuditLogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AuditLogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AuditLogConfig;

                    /**
                     * Creates a plain object from an AuditLogConfig message. Also converts values to other types if specified.
                     * @param message AuditLogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AuditLogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AuditLogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AuditLogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AuditLogConfig {

                    /** LogType enum. */
                    enum LogType {
                        UNDEFINED_LOG_TYPE = 0,
                        ADMIN_READ = 128951462,
                        DATA_READ = 305224971,
                        DATA_WRITE = 340181738,
                        LOG_TYPE_UNSPECIFIED = 154527053
                    }
                }

                /** Properties of an AuthorizationLoggingOptions. */
                interface IAuthorizationLoggingOptions {

                    /** AuthorizationLoggingOptions permissionType */
                    permissionType?: (string|null);
                }

                /** Represents an AuthorizationLoggingOptions. */
                class AuthorizationLoggingOptions implements IAuthorizationLoggingOptions {

                    /**
                     * Constructs a new AuthorizationLoggingOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAuthorizationLoggingOptions);

                    /** AuthorizationLoggingOptions permissionType. */
                    public permissionType?: (string|null);

                    /** AuthorizationLoggingOptions _permissionType. */
                    public _permissionType?: "permissionType";

                    /**
                     * Creates a new AuthorizationLoggingOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AuthorizationLoggingOptions instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAuthorizationLoggingOptions): google.cloud.compute.v1.AuthorizationLoggingOptions;

                    /**
                     * Encodes the specified AuthorizationLoggingOptions message. Does not implicitly {@link google.cloud.compute.v1.AuthorizationLoggingOptions.verify|verify} messages.
                     * @param message AuthorizationLoggingOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAuthorizationLoggingOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AuthorizationLoggingOptions message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AuthorizationLoggingOptions.verify|verify} messages.
                     * @param message AuthorizationLoggingOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAuthorizationLoggingOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AuthorizationLoggingOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AuthorizationLoggingOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AuthorizationLoggingOptions;

                    /**
                     * Decodes an AuthorizationLoggingOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AuthorizationLoggingOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AuthorizationLoggingOptions;

                    /**
                     * Verifies an AuthorizationLoggingOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AuthorizationLoggingOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AuthorizationLoggingOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AuthorizationLoggingOptions;

                    /**
                     * Creates a plain object from an AuthorizationLoggingOptions message. Also converts values to other types if specified.
                     * @param message AuthorizationLoggingOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AuthorizationLoggingOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AuthorizationLoggingOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AuthorizationLoggingOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AuthorizationLoggingOptions {

                    /** PermissionType enum. */
                    enum PermissionType {
                        UNDEFINED_PERMISSION_TYPE = 0,
                        ADMIN_READ = 128951462,
                        ADMIN_WRITE = 244412079,
                        DATA_READ = 305224971,
                        DATA_WRITE = 340181738,
                        PERMISSION_TYPE_UNSPECIFIED = 440313346
                    }
                }

                /** Properties of an Autoscaler. */
                interface IAutoscaler {

                    /** Autoscaler autoscalingPolicy */
                    autoscalingPolicy?: (google.cloud.compute.v1.IAutoscalingPolicy|null);

                    /** Autoscaler creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Autoscaler description */
                    description?: (string|null);

                    /** Autoscaler id */
                    id?: (number|Long|string|null);

                    /** Autoscaler kind */
                    kind?: (string|null);

                    /** Autoscaler name */
                    name?: (string|null);

                    /** Autoscaler recommendedSize */
                    recommendedSize?: (number|null);

                    /** Autoscaler region */
                    region?: (string|null);

                    /** Autoscaler scalingScheduleStatus */
                    scalingScheduleStatus?: ({ [k: string]: google.cloud.compute.v1.IScalingScheduleStatus }|null);

                    /** Autoscaler selfLink */
                    selfLink?: (string|null);

                    /** Autoscaler status */
                    status?: (string|null);

                    /** Autoscaler statusDetails */
                    statusDetails?: (google.cloud.compute.v1.IAutoscalerStatusDetails[]|null);

                    /** Autoscaler target */
                    target?: (string|null);

                    /** Autoscaler zone */
                    zone?: (string|null);
                }

                /** Represents an Autoscaler. */
                class Autoscaler implements IAutoscaler {

                    /**
                     * Constructs a new Autoscaler.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscaler);

                    /** Autoscaler autoscalingPolicy. */
                    public autoscalingPolicy?: (google.cloud.compute.v1.IAutoscalingPolicy|null);

                    /** Autoscaler creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Autoscaler description. */
                    public description?: (string|null);

                    /** Autoscaler id. */
                    public id?: (number|Long|string|null);

                    /** Autoscaler kind. */
                    public kind?: (string|null);

                    /** Autoscaler name. */
                    public name?: (string|null);

                    /** Autoscaler recommendedSize. */
                    public recommendedSize?: (number|null);

                    /** Autoscaler region. */
                    public region?: (string|null);

                    /** Autoscaler scalingScheduleStatus. */
                    public scalingScheduleStatus: { [k: string]: google.cloud.compute.v1.IScalingScheduleStatus };

                    /** Autoscaler selfLink. */
                    public selfLink?: (string|null);

                    /** Autoscaler status. */
                    public status?: (string|null);

                    /** Autoscaler statusDetails. */
                    public statusDetails: google.cloud.compute.v1.IAutoscalerStatusDetails[];

                    /** Autoscaler target. */
                    public target?: (string|null);

                    /** Autoscaler zone. */
                    public zone?: (string|null);

                    /** Autoscaler _autoscalingPolicy. */
                    public _autoscalingPolicy?: "autoscalingPolicy";

                    /** Autoscaler _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Autoscaler _description. */
                    public _description?: "description";

                    /** Autoscaler _id. */
                    public _id?: "id";

                    /** Autoscaler _kind. */
                    public _kind?: "kind";

                    /** Autoscaler _name. */
                    public _name?: "name";

                    /** Autoscaler _recommendedSize. */
                    public _recommendedSize?: "recommendedSize";

                    /** Autoscaler _region. */
                    public _region?: "region";

                    /** Autoscaler _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Autoscaler _status. */
                    public _status?: "status";

                    /** Autoscaler _target. */
                    public _target?: "target";

                    /** Autoscaler _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new Autoscaler instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Autoscaler instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscaler): google.cloud.compute.v1.Autoscaler;

                    /**
                     * Encodes the specified Autoscaler message. Does not implicitly {@link google.cloud.compute.v1.Autoscaler.verify|verify} messages.
                     * @param message Autoscaler message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscaler, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Autoscaler message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Autoscaler.verify|verify} messages.
                     * @param message Autoscaler message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscaler, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Autoscaler message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Autoscaler
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Autoscaler;

                    /**
                     * Decodes an Autoscaler message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Autoscaler
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Autoscaler;

                    /**
                     * Verifies an Autoscaler message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Autoscaler message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Autoscaler
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Autoscaler;

                    /**
                     * Creates a plain object from an Autoscaler message. Also converts values to other types if specified.
                     * @param message Autoscaler
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Autoscaler, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Autoscaler to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Autoscaler
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Autoscaler {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ACTIVE = 314733318,
                        DELETING = 528602024,
                        ERROR = 66247144,
                        PENDING = 35394935
                    }
                }

                /** Properties of an AutoscalerAggregatedList. */
                interface IAutoscalerAggregatedList {

                    /** AutoscalerAggregatedList id */
                    id?: (string|null);

                    /** AutoscalerAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IAutoscalersScopedList }|null);

                    /** AutoscalerAggregatedList kind */
                    kind?: (string|null);

                    /** AutoscalerAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AutoscalerAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** AutoscalerAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** AutoscalerAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AutoscalerAggregatedList. */
                class AutoscalerAggregatedList implements IAutoscalerAggregatedList {

                    /**
                     * Constructs a new AutoscalerAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalerAggregatedList);

                    /** AutoscalerAggregatedList id. */
                    public id?: (string|null);

                    /** AutoscalerAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IAutoscalersScopedList };

                    /** AutoscalerAggregatedList kind. */
                    public kind?: (string|null);

                    /** AutoscalerAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AutoscalerAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** AutoscalerAggregatedList unreachables. */
                    public unreachables: string[];

                    /** AutoscalerAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AutoscalerAggregatedList _id. */
                    public _id?: "id";

                    /** AutoscalerAggregatedList _kind. */
                    public _kind?: "kind";

                    /** AutoscalerAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AutoscalerAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AutoscalerAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AutoscalerAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalerAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalerAggregatedList): google.cloud.compute.v1.AutoscalerAggregatedList;

                    /**
                     * Encodes the specified AutoscalerAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.AutoscalerAggregatedList.verify|verify} messages.
                     * @param message AutoscalerAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalerAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalerAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalerAggregatedList.verify|verify} messages.
                     * @param message AutoscalerAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalerAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalerAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalerAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalerAggregatedList;

                    /**
                     * Decodes an AutoscalerAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalerAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalerAggregatedList;

                    /**
                     * Verifies an AutoscalerAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalerAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalerAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalerAggregatedList;

                    /**
                     * Creates a plain object from an AutoscalerAggregatedList message. Also converts values to other types if specified.
                     * @param message AutoscalerAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalerAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalerAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalerAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AutoscalerList. */
                interface IAutoscalerList {

                    /** AutoscalerList id */
                    id?: (string|null);

                    /** AutoscalerList items */
                    items?: (google.cloud.compute.v1.IAutoscaler[]|null);

                    /** AutoscalerList kind */
                    kind?: (string|null);

                    /** AutoscalerList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AutoscalerList selfLink */
                    selfLink?: (string|null);

                    /** AutoscalerList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AutoscalerList. */
                class AutoscalerList implements IAutoscalerList {

                    /**
                     * Constructs a new AutoscalerList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalerList);

                    /** AutoscalerList id. */
                    public id?: (string|null);

                    /** AutoscalerList items. */
                    public items: google.cloud.compute.v1.IAutoscaler[];

                    /** AutoscalerList kind. */
                    public kind?: (string|null);

                    /** AutoscalerList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AutoscalerList selfLink. */
                    public selfLink?: (string|null);

                    /** AutoscalerList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AutoscalerList _id. */
                    public _id?: "id";

                    /** AutoscalerList _kind. */
                    public _kind?: "kind";

                    /** AutoscalerList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AutoscalerList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AutoscalerList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AutoscalerList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalerList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalerList): google.cloud.compute.v1.AutoscalerList;

                    /**
                     * Encodes the specified AutoscalerList message. Does not implicitly {@link google.cloud.compute.v1.AutoscalerList.verify|verify} messages.
                     * @param message AutoscalerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalerList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalerList.verify|verify} messages.
                     * @param message AutoscalerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalerList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalerList;

                    /**
                     * Decodes an AutoscalerList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalerList;

                    /**
                     * Verifies an AutoscalerList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalerList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalerList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalerList;

                    /**
                     * Creates a plain object from an AutoscalerList message. Also converts values to other types if specified.
                     * @param message AutoscalerList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalerList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalerList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalerList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AutoscalerStatusDetails. */
                interface IAutoscalerStatusDetails {

                    /** AutoscalerStatusDetails message */
                    message?: (string|null);

                    /** AutoscalerStatusDetails type */
                    type?: (string|null);
                }

                /** Represents an AutoscalerStatusDetails. */
                class AutoscalerStatusDetails implements IAutoscalerStatusDetails {

                    /**
                     * Constructs a new AutoscalerStatusDetails.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalerStatusDetails);

                    /** AutoscalerStatusDetails message. */
                    public message?: (string|null);

                    /** AutoscalerStatusDetails type. */
                    public type?: (string|null);

                    /** AutoscalerStatusDetails _message. */
                    public _message?: "message";

                    /** AutoscalerStatusDetails _type. */
                    public _type?: "type";

                    /**
                     * Creates a new AutoscalerStatusDetails instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalerStatusDetails instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalerStatusDetails): google.cloud.compute.v1.AutoscalerStatusDetails;

                    /**
                     * Encodes the specified AutoscalerStatusDetails message. Does not implicitly {@link google.cloud.compute.v1.AutoscalerStatusDetails.verify|verify} messages.
                     * @param message AutoscalerStatusDetails message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalerStatusDetails, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalerStatusDetails message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalerStatusDetails.verify|verify} messages.
                     * @param message AutoscalerStatusDetails message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalerStatusDetails, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalerStatusDetails message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalerStatusDetails
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalerStatusDetails;

                    /**
                     * Decodes an AutoscalerStatusDetails message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalerStatusDetails
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalerStatusDetails;

                    /**
                     * Verifies an AutoscalerStatusDetails message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalerStatusDetails message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalerStatusDetails
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalerStatusDetails;

                    /**
                     * Creates a plain object from an AutoscalerStatusDetails message. Also converts values to other types if specified.
                     * @param message AutoscalerStatusDetails
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalerStatusDetails, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalerStatusDetails to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalerStatusDetails
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AutoscalerStatusDetails {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        ALL_INSTANCES_UNHEALTHY = 404965477,
                        BACKEND_SERVICE_DOES_NOT_EXIST = 191417626,
                        CAPPED_AT_MAX_NUM_REPLICAS = 518617,
                        CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328964659,
                        CUSTOM_METRIC_INVALID = 204430550,
                        MIN_EQUALS_MAX = 2821361,
                        MISSING_CUSTOM_METRIC_DATA_POINTS = 94885086,
                        MISSING_LOAD_BALANCING_DATA_POINTS = 509858898,
                        MODE_OFF = 164169907,
                        MODE_ONLY_SCALE_OUT = 3840994,
                        MODE_ONLY_UP = 100969842,
                        MORE_THAN_ONE_BACKEND_SERVICE = 151922141,
                        NOT_ENOUGH_QUOTA_AVAILABLE = 403101631,
                        REGION_RESOURCE_STOCKOUT = 528622846,
                        SCALING_TARGET_DOES_NOT_EXIST = 122636699,
                        SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29275586,
                        SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398287669,
                        UNKNOWN = 433141802,
                        UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330845009,
                        ZONE_RESOURCE_STOCKOUT = 210200502
                    }
                }

                /** Properties of an AutoscalersScopedList. */
                interface IAutoscalersScopedList {

                    /** AutoscalersScopedList autoscalers */
                    autoscalers?: (google.cloud.compute.v1.IAutoscaler[]|null);

                    /** AutoscalersScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an AutoscalersScopedList. */
                class AutoscalersScopedList implements IAutoscalersScopedList {

                    /**
                     * Constructs a new AutoscalersScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalersScopedList);

                    /** AutoscalersScopedList autoscalers. */
                    public autoscalers: google.cloud.compute.v1.IAutoscaler[];

                    /** AutoscalersScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** AutoscalersScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AutoscalersScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalersScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalersScopedList): google.cloud.compute.v1.AutoscalersScopedList;

                    /**
                     * Encodes the specified AutoscalersScopedList message. Does not implicitly {@link google.cloud.compute.v1.AutoscalersScopedList.verify|verify} messages.
                     * @param message AutoscalersScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalersScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalersScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalersScopedList.verify|verify} messages.
                     * @param message AutoscalersScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalersScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalersScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalersScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalersScopedList;

                    /**
                     * Decodes an AutoscalersScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalersScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalersScopedList;

                    /**
                     * Verifies an AutoscalersScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalersScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalersScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalersScopedList;

                    /**
                     * Creates a plain object from an AutoscalersScopedList message. Also converts values to other types if specified.
                     * @param message AutoscalersScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalersScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalersScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalersScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AutoscalingPolicy. */
                interface IAutoscalingPolicy {

                    /** AutoscalingPolicy coolDownPeriodSec */
                    coolDownPeriodSec?: (number|null);

                    /** AutoscalingPolicy cpuUtilization */
                    cpuUtilization?: (google.cloud.compute.v1.IAutoscalingPolicyCpuUtilization|null);

                    /** AutoscalingPolicy customMetricUtilizations */
                    customMetricUtilizations?: (google.cloud.compute.v1.IAutoscalingPolicyCustomMetricUtilization[]|null);

                    /** AutoscalingPolicy loadBalancingUtilization */
                    loadBalancingUtilization?: (google.cloud.compute.v1.IAutoscalingPolicyLoadBalancingUtilization|null);

                    /** AutoscalingPolicy maxNumReplicas */
                    maxNumReplicas?: (number|null);

                    /** AutoscalingPolicy minNumReplicas */
                    minNumReplicas?: (number|null);

                    /** AutoscalingPolicy mode */
                    mode?: (string|null);

                    /** AutoscalingPolicy scaleInControl */
                    scaleInControl?: (google.cloud.compute.v1.IAutoscalingPolicyScaleInControl|null);

                    /** AutoscalingPolicy scalingSchedules */
                    scalingSchedules?: ({ [k: string]: google.cloud.compute.v1.IAutoscalingPolicyScalingSchedule }|null);
                }

                /** Represents an AutoscalingPolicy. */
                class AutoscalingPolicy implements IAutoscalingPolicy {

                    /**
                     * Constructs a new AutoscalingPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalingPolicy);

                    /** AutoscalingPolicy coolDownPeriodSec. */
                    public coolDownPeriodSec?: (number|null);

                    /** AutoscalingPolicy cpuUtilization. */
                    public cpuUtilization?: (google.cloud.compute.v1.IAutoscalingPolicyCpuUtilization|null);

                    /** AutoscalingPolicy customMetricUtilizations. */
                    public customMetricUtilizations: google.cloud.compute.v1.IAutoscalingPolicyCustomMetricUtilization[];

                    /** AutoscalingPolicy loadBalancingUtilization. */
                    public loadBalancingUtilization?: (google.cloud.compute.v1.IAutoscalingPolicyLoadBalancingUtilization|null);

                    /** AutoscalingPolicy maxNumReplicas. */
                    public maxNumReplicas?: (number|null);

                    /** AutoscalingPolicy minNumReplicas. */
                    public minNumReplicas?: (number|null);

                    /** AutoscalingPolicy mode. */
                    public mode?: (string|null);

                    /** AutoscalingPolicy scaleInControl. */
                    public scaleInControl?: (google.cloud.compute.v1.IAutoscalingPolicyScaleInControl|null);

                    /** AutoscalingPolicy scalingSchedules. */
                    public scalingSchedules: { [k: string]: google.cloud.compute.v1.IAutoscalingPolicyScalingSchedule };

                    /** AutoscalingPolicy _coolDownPeriodSec. */
                    public _coolDownPeriodSec?: "coolDownPeriodSec";

                    /** AutoscalingPolicy _cpuUtilization. */
                    public _cpuUtilization?: "cpuUtilization";

                    /** AutoscalingPolicy _loadBalancingUtilization. */
                    public _loadBalancingUtilization?: "loadBalancingUtilization";

                    /** AutoscalingPolicy _maxNumReplicas. */
                    public _maxNumReplicas?: "maxNumReplicas";

                    /** AutoscalingPolicy _minNumReplicas. */
                    public _minNumReplicas?: "minNumReplicas";

                    /** AutoscalingPolicy _mode. */
                    public _mode?: "mode";

                    /** AutoscalingPolicy _scaleInControl. */
                    public _scaleInControl?: "scaleInControl";

                    /**
                     * Creates a new AutoscalingPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalingPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalingPolicy): google.cloud.compute.v1.AutoscalingPolicy;

                    /**
                     * Encodes the specified AutoscalingPolicy message. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicy.verify|verify} messages.
                     * @param message AutoscalingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalingPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicy.verify|verify} messages.
                     * @param message AutoscalingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalingPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalingPolicy;

                    /**
                     * Decodes an AutoscalingPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalingPolicy;

                    /**
                     * Verifies an AutoscalingPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalingPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalingPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalingPolicy;

                    /**
                     * Creates a plain object from an AutoscalingPolicy message. Also converts values to other types if specified.
                     * @param message AutoscalingPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalingPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalingPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalingPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AutoscalingPolicy {

                    /** Mode enum. */
                    enum Mode {
                        UNDEFINED_MODE = 0,
                        OFF = 78159,
                        ON = 2527,
                        ONLY_SCALE_OUT = 152713670,
                        ONLY_UP = 478095374
                    }
                }

                /** Properties of an AutoscalingPolicyCpuUtilization. */
                interface IAutoscalingPolicyCpuUtilization {

                    /** AutoscalingPolicyCpuUtilization predictiveMethod */
                    predictiveMethod?: (string|null);

                    /** AutoscalingPolicyCpuUtilization utilizationTarget */
                    utilizationTarget?: (number|null);
                }

                /** Represents an AutoscalingPolicyCpuUtilization. */
                class AutoscalingPolicyCpuUtilization implements IAutoscalingPolicyCpuUtilization {

                    /**
                     * Constructs a new AutoscalingPolicyCpuUtilization.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalingPolicyCpuUtilization);

                    /** AutoscalingPolicyCpuUtilization predictiveMethod. */
                    public predictiveMethod?: (string|null);

                    /** AutoscalingPolicyCpuUtilization utilizationTarget. */
                    public utilizationTarget?: (number|null);

                    /** AutoscalingPolicyCpuUtilization _predictiveMethod. */
                    public _predictiveMethod?: "predictiveMethod";

                    /** AutoscalingPolicyCpuUtilization _utilizationTarget. */
                    public _utilizationTarget?: "utilizationTarget";

                    /**
                     * Creates a new AutoscalingPolicyCpuUtilization instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalingPolicyCpuUtilization instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalingPolicyCpuUtilization): google.cloud.compute.v1.AutoscalingPolicyCpuUtilization;

                    /**
                     * Encodes the specified AutoscalingPolicyCpuUtilization message. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyCpuUtilization.verify|verify} messages.
                     * @param message AutoscalingPolicyCpuUtilization message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalingPolicyCpuUtilization, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalingPolicyCpuUtilization message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyCpuUtilization.verify|verify} messages.
                     * @param message AutoscalingPolicyCpuUtilization message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalingPolicyCpuUtilization, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalingPolicyCpuUtilization message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalingPolicyCpuUtilization
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalingPolicyCpuUtilization;

                    /**
                     * Decodes an AutoscalingPolicyCpuUtilization message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalingPolicyCpuUtilization
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalingPolicyCpuUtilization;

                    /**
                     * Verifies an AutoscalingPolicyCpuUtilization message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalingPolicyCpuUtilization message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalingPolicyCpuUtilization
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalingPolicyCpuUtilization;

                    /**
                     * Creates a plain object from an AutoscalingPolicyCpuUtilization message. Also converts values to other types if specified.
                     * @param message AutoscalingPolicyCpuUtilization
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalingPolicyCpuUtilization, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalingPolicyCpuUtilization to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalingPolicyCpuUtilization
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AutoscalingPolicyCpuUtilization {

                    /** PredictiveMethod enum. */
                    enum PredictiveMethod {
                        UNDEFINED_PREDICTIVE_METHOD = 0,
                        NONE = 2402104,
                        OPTIMIZE_AVAILABILITY = 11629437
                    }
                }

                /** Properties of an AutoscalingPolicyCustomMetricUtilization. */
                interface IAutoscalingPolicyCustomMetricUtilization {

                    /** AutoscalingPolicyCustomMetricUtilization filter */
                    filter?: (string|null);

                    /** AutoscalingPolicyCustomMetricUtilization metric */
                    metric?: (string|null);

                    /** AutoscalingPolicyCustomMetricUtilization singleInstanceAssignment */
                    singleInstanceAssignment?: (number|null);

                    /** AutoscalingPolicyCustomMetricUtilization utilizationTarget */
                    utilizationTarget?: (number|null);

                    /** AutoscalingPolicyCustomMetricUtilization utilizationTargetType */
                    utilizationTargetType?: (string|null);
                }

                /** Represents an AutoscalingPolicyCustomMetricUtilization. */
                class AutoscalingPolicyCustomMetricUtilization implements IAutoscalingPolicyCustomMetricUtilization {

                    /**
                     * Constructs a new AutoscalingPolicyCustomMetricUtilization.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalingPolicyCustomMetricUtilization);

                    /** AutoscalingPolicyCustomMetricUtilization filter. */
                    public filter?: (string|null);

                    /** AutoscalingPolicyCustomMetricUtilization metric. */
                    public metric?: (string|null);

                    /** AutoscalingPolicyCustomMetricUtilization singleInstanceAssignment. */
                    public singleInstanceAssignment?: (number|null);

                    /** AutoscalingPolicyCustomMetricUtilization utilizationTarget. */
                    public utilizationTarget?: (number|null);

                    /** AutoscalingPolicyCustomMetricUtilization utilizationTargetType. */
                    public utilizationTargetType?: (string|null);

                    /** AutoscalingPolicyCustomMetricUtilization _filter. */
                    public _filter?: "filter";

                    /** AutoscalingPolicyCustomMetricUtilization _metric. */
                    public _metric?: "metric";

                    /** AutoscalingPolicyCustomMetricUtilization _singleInstanceAssignment. */
                    public _singleInstanceAssignment?: "singleInstanceAssignment";

                    /** AutoscalingPolicyCustomMetricUtilization _utilizationTarget. */
                    public _utilizationTarget?: "utilizationTarget";

                    /** AutoscalingPolicyCustomMetricUtilization _utilizationTargetType. */
                    public _utilizationTargetType?: "utilizationTargetType";

                    /**
                     * Creates a new AutoscalingPolicyCustomMetricUtilization instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalingPolicyCustomMetricUtilization instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalingPolicyCustomMetricUtilization): google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization;

                    /**
                     * Encodes the specified AutoscalingPolicyCustomMetricUtilization message. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization.verify|verify} messages.
                     * @param message AutoscalingPolicyCustomMetricUtilization message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalingPolicyCustomMetricUtilization, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalingPolicyCustomMetricUtilization message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization.verify|verify} messages.
                     * @param message AutoscalingPolicyCustomMetricUtilization message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalingPolicyCustomMetricUtilization, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalingPolicyCustomMetricUtilization message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalingPolicyCustomMetricUtilization
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization;

                    /**
                     * Decodes an AutoscalingPolicyCustomMetricUtilization message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalingPolicyCustomMetricUtilization
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization;

                    /**
                     * Verifies an AutoscalingPolicyCustomMetricUtilization message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalingPolicyCustomMetricUtilization message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalingPolicyCustomMetricUtilization
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization;

                    /**
                     * Creates a plain object from an AutoscalingPolicyCustomMetricUtilization message. Also converts values to other types if specified.
                     * @param message AutoscalingPolicyCustomMetricUtilization
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalingPolicyCustomMetricUtilization, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalingPolicyCustomMetricUtilization to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalingPolicyCustomMetricUtilization
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace AutoscalingPolicyCustomMetricUtilization {

                    /** UtilizationTargetType enum. */
                    enum UtilizationTargetType {
                        UNDEFINED_UTILIZATION_TARGET_TYPE = 0,
                        DELTA_PER_MINUTE = 87432861,
                        DELTA_PER_SECOND = 255180029,
                        GAUGE = 67590361
                    }
                }

                /** Properties of an AutoscalingPolicyLoadBalancingUtilization. */
                interface IAutoscalingPolicyLoadBalancingUtilization {

                    /** AutoscalingPolicyLoadBalancingUtilization utilizationTarget */
                    utilizationTarget?: (number|null);
                }

                /** Represents an AutoscalingPolicyLoadBalancingUtilization. */
                class AutoscalingPolicyLoadBalancingUtilization implements IAutoscalingPolicyLoadBalancingUtilization {

                    /**
                     * Constructs a new AutoscalingPolicyLoadBalancingUtilization.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalingPolicyLoadBalancingUtilization);

                    /** AutoscalingPolicyLoadBalancingUtilization utilizationTarget. */
                    public utilizationTarget?: (number|null);

                    /** AutoscalingPolicyLoadBalancingUtilization _utilizationTarget. */
                    public _utilizationTarget?: "utilizationTarget";

                    /**
                     * Creates a new AutoscalingPolicyLoadBalancingUtilization instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalingPolicyLoadBalancingUtilization instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalingPolicyLoadBalancingUtilization): google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization;

                    /**
                     * Encodes the specified AutoscalingPolicyLoadBalancingUtilization message. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization.verify|verify} messages.
                     * @param message AutoscalingPolicyLoadBalancingUtilization message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalingPolicyLoadBalancingUtilization, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalingPolicyLoadBalancingUtilization message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization.verify|verify} messages.
                     * @param message AutoscalingPolicyLoadBalancingUtilization message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalingPolicyLoadBalancingUtilization, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalingPolicyLoadBalancingUtilization message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalingPolicyLoadBalancingUtilization
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization;

                    /**
                     * Decodes an AutoscalingPolicyLoadBalancingUtilization message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalingPolicyLoadBalancingUtilization
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization;

                    /**
                     * Verifies an AutoscalingPolicyLoadBalancingUtilization message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalingPolicyLoadBalancingUtilization message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalingPolicyLoadBalancingUtilization
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization;

                    /**
                     * Creates a plain object from an AutoscalingPolicyLoadBalancingUtilization message. Also converts values to other types if specified.
                     * @param message AutoscalingPolicyLoadBalancingUtilization
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalingPolicyLoadBalancingUtilization, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalingPolicyLoadBalancingUtilization to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalingPolicyLoadBalancingUtilization
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AutoscalingPolicyScaleInControl. */
                interface IAutoscalingPolicyScaleInControl {

                    /** AutoscalingPolicyScaleInControl maxScaledInReplicas */
                    maxScaledInReplicas?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** AutoscalingPolicyScaleInControl timeWindowSec */
                    timeWindowSec?: (number|null);
                }

                /** Represents an AutoscalingPolicyScaleInControl. */
                class AutoscalingPolicyScaleInControl implements IAutoscalingPolicyScaleInControl {

                    /**
                     * Constructs a new AutoscalingPolicyScaleInControl.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalingPolicyScaleInControl);

                    /** AutoscalingPolicyScaleInControl maxScaledInReplicas. */
                    public maxScaledInReplicas?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** AutoscalingPolicyScaleInControl timeWindowSec. */
                    public timeWindowSec?: (number|null);

                    /** AutoscalingPolicyScaleInControl _maxScaledInReplicas. */
                    public _maxScaledInReplicas?: "maxScaledInReplicas";

                    /** AutoscalingPolicyScaleInControl _timeWindowSec. */
                    public _timeWindowSec?: "timeWindowSec";

                    /**
                     * Creates a new AutoscalingPolicyScaleInControl instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalingPolicyScaleInControl instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalingPolicyScaleInControl): google.cloud.compute.v1.AutoscalingPolicyScaleInControl;

                    /**
                     * Encodes the specified AutoscalingPolicyScaleInControl message. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyScaleInControl.verify|verify} messages.
                     * @param message AutoscalingPolicyScaleInControl message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalingPolicyScaleInControl, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalingPolicyScaleInControl message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyScaleInControl.verify|verify} messages.
                     * @param message AutoscalingPolicyScaleInControl message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalingPolicyScaleInControl, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalingPolicyScaleInControl message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalingPolicyScaleInControl
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalingPolicyScaleInControl;

                    /**
                     * Decodes an AutoscalingPolicyScaleInControl message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalingPolicyScaleInControl
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalingPolicyScaleInControl;

                    /**
                     * Verifies an AutoscalingPolicyScaleInControl message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalingPolicyScaleInControl message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalingPolicyScaleInControl
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalingPolicyScaleInControl;

                    /**
                     * Creates a plain object from an AutoscalingPolicyScaleInControl message. Also converts values to other types if specified.
                     * @param message AutoscalingPolicyScaleInControl
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalingPolicyScaleInControl, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalingPolicyScaleInControl to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalingPolicyScaleInControl
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AutoscalingPolicyScalingSchedule. */
                interface IAutoscalingPolicyScalingSchedule {

                    /** AutoscalingPolicyScalingSchedule description */
                    description?: (string|null);

                    /** AutoscalingPolicyScalingSchedule disabled */
                    disabled?: (boolean|null);

                    /** AutoscalingPolicyScalingSchedule durationSec */
                    durationSec?: (number|null);

                    /** AutoscalingPolicyScalingSchedule minRequiredReplicas */
                    minRequiredReplicas?: (number|null);

                    /** AutoscalingPolicyScalingSchedule schedule */
                    schedule?: (string|null);

                    /** AutoscalingPolicyScalingSchedule timeZone */
                    timeZone?: (string|null);
                }

                /** Represents an AutoscalingPolicyScalingSchedule. */
                class AutoscalingPolicyScalingSchedule implements IAutoscalingPolicyScalingSchedule {

                    /**
                     * Constructs a new AutoscalingPolicyScalingSchedule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IAutoscalingPolicyScalingSchedule);

                    /** AutoscalingPolicyScalingSchedule description. */
                    public description?: (string|null);

                    /** AutoscalingPolicyScalingSchedule disabled. */
                    public disabled?: (boolean|null);

                    /** AutoscalingPolicyScalingSchedule durationSec. */
                    public durationSec?: (number|null);

                    /** AutoscalingPolicyScalingSchedule minRequiredReplicas. */
                    public minRequiredReplicas?: (number|null);

                    /** AutoscalingPolicyScalingSchedule schedule. */
                    public schedule?: (string|null);

                    /** AutoscalingPolicyScalingSchedule timeZone. */
                    public timeZone?: (string|null);

                    /** AutoscalingPolicyScalingSchedule _description. */
                    public _description?: "description";

                    /** AutoscalingPolicyScalingSchedule _disabled. */
                    public _disabled?: "disabled";

                    /** AutoscalingPolicyScalingSchedule _durationSec. */
                    public _durationSec?: "durationSec";

                    /** AutoscalingPolicyScalingSchedule _minRequiredReplicas. */
                    public _minRequiredReplicas?: "minRequiredReplicas";

                    /** AutoscalingPolicyScalingSchedule _schedule. */
                    public _schedule?: "schedule";

                    /** AutoscalingPolicyScalingSchedule _timeZone. */
                    public _timeZone?: "timeZone";

                    /**
                     * Creates a new AutoscalingPolicyScalingSchedule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoscalingPolicyScalingSchedule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IAutoscalingPolicyScalingSchedule): google.cloud.compute.v1.AutoscalingPolicyScalingSchedule;

                    /**
                     * Encodes the specified AutoscalingPolicyScalingSchedule message. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyScalingSchedule.verify|verify} messages.
                     * @param message AutoscalingPolicyScalingSchedule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IAutoscalingPolicyScalingSchedule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoscalingPolicyScalingSchedule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.AutoscalingPolicyScalingSchedule.verify|verify} messages.
                     * @param message AutoscalingPolicyScalingSchedule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IAutoscalingPolicyScalingSchedule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoscalingPolicyScalingSchedule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoscalingPolicyScalingSchedule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.AutoscalingPolicyScalingSchedule;

                    /**
                     * Decodes an AutoscalingPolicyScalingSchedule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoscalingPolicyScalingSchedule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.AutoscalingPolicyScalingSchedule;

                    /**
                     * Verifies an AutoscalingPolicyScalingSchedule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoscalingPolicyScalingSchedule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoscalingPolicyScalingSchedule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.AutoscalingPolicyScalingSchedule;

                    /**
                     * Creates a plain object from an AutoscalingPolicyScalingSchedule message. Also converts values to other types if specified.
                     * @param message AutoscalingPolicyScalingSchedule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.AutoscalingPolicyScalingSchedule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoscalingPolicyScalingSchedule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoscalingPolicyScalingSchedule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Backend. */
                interface IBackend {

                    /** Backend balancingMode */
                    balancingMode?: (string|null);

                    /** Backend capacityScaler */
                    capacityScaler?: (number|null);

                    /** Backend description */
                    description?: (string|null);

                    /** Backend failover */
                    failover?: (boolean|null);

                    /** Backend group */
                    group?: (string|null);

                    /** Backend maxConnections */
                    maxConnections?: (number|null);

                    /** Backend maxConnectionsPerEndpoint */
                    maxConnectionsPerEndpoint?: (number|null);

                    /** Backend maxConnectionsPerInstance */
                    maxConnectionsPerInstance?: (number|null);

                    /** Backend maxRate */
                    maxRate?: (number|null);

                    /** Backend maxRatePerEndpoint */
                    maxRatePerEndpoint?: (number|null);

                    /** Backend maxRatePerInstance */
                    maxRatePerInstance?: (number|null);

                    /** Backend maxUtilization */
                    maxUtilization?: (number|null);
                }

                /** Represents a Backend. */
                class Backend implements IBackend {

                    /**
                     * Constructs a new Backend.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackend);

                    /** Backend balancingMode. */
                    public balancingMode?: (string|null);

                    /** Backend capacityScaler. */
                    public capacityScaler?: (number|null);

                    /** Backend description. */
                    public description?: (string|null);

                    /** Backend failover. */
                    public failover?: (boolean|null);

                    /** Backend group. */
                    public group?: (string|null);

                    /** Backend maxConnections. */
                    public maxConnections?: (number|null);

                    /** Backend maxConnectionsPerEndpoint. */
                    public maxConnectionsPerEndpoint?: (number|null);

                    /** Backend maxConnectionsPerInstance. */
                    public maxConnectionsPerInstance?: (number|null);

                    /** Backend maxRate. */
                    public maxRate?: (number|null);

                    /** Backend maxRatePerEndpoint. */
                    public maxRatePerEndpoint?: (number|null);

                    /** Backend maxRatePerInstance. */
                    public maxRatePerInstance?: (number|null);

                    /** Backend maxUtilization. */
                    public maxUtilization?: (number|null);

                    /** Backend _balancingMode. */
                    public _balancingMode?: "balancingMode";

                    /** Backend _capacityScaler. */
                    public _capacityScaler?: "capacityScaler";

                    /** Backend _description. */
                    public _description?: "description";

                    /** Backend _failover. */
                    public _failover?: "failover";

                    /** Backend _group. */
                    public _group?: "group";

                    /** Backend _maxConnections. */
                    public _maxConnections?: "maxConnections";

                    /** Backend _maxConnectionsPerEndpoint. */
                    public _maxConnectionsPerEndpoint?: "maxConnectionsPerEndpoint";

                    /** Backend _maxConnectionsPerInstance. */
                    public _maxConnectionsPerInstance?: "maxConnectionsPerInstance";

                    /** Backend _maxRate. */
                    public _maxRate?: "maxRate";

                    /** Backend _maxRatePerEndpoint. */
                    public _maxRatePerEndpoint?: "maxRatePerEndpoint";

                    /** Backend _maxRatePerInstance. */
                    public _maxRatePerInstance?: "maxRatePerInstance";

                    /** Backend _maxUtilization. */
                    public _maxUtilization?: "maxUtilization";

                    /**
                     * Creates a new Backend instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Backend instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackend): google.cloud.compute.v1.Backend;

                    /**
                     * Encodes the specified Backend message. Does not implicitly {@link google.cloud.compute.v1.Backend.verify|verify} messages.
                     * @param message Backend message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackend, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Backend message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Backend.verify|verify} messages.
                     * @param message Backend message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackend, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Backend message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Backend
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Backend;

                    /**
                     * Decodes a Backend message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Backend
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Backend;

                    /**
                     * Verifies a Backend message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Backend message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Backend
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Backend;

                    /**
                     * Creates a plain object from a Backend message. Also converts values to other types if specified.
                     * @param message Backend
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Backend, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Backend to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Backend
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Backend {

                    /** BalancingMode enum. */
                    enum BalancingMode {
                        UNDEFINED_BALANCING_MODE = 0,
                        CONNECTION = 246311646,
                        RATE = 2508000,
                        UTILIZATION = 157008386
                    }
                }

                /** Properties of a BackendBucket. */
                interface IBackendBucket {

                    /** BackendBucket bucketName */
                    bucketName?: (string|null);

                    /** BackendBucket cdnPolicy */
                    cdnPolicy?: (google.cloud.compute.v1.IBackendBucketCdnPolicy|null);

                    /** BackendBucket compressionMode */
                    compressionMode?: (string|null);

                    /** BackendBucket creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** BackendBucket customResponseHeaders */
                    customResponseHeaders?: (string[]|null);

                    /** BackendBucket description */
                    description?: (string|null);

                    /** BackendBucket edgeSecurityPolicy */
                    edgeSecurityPolicy?: (string|null);

                    /** BackendBucket enableCdn */
                    enableCdn?: (boolean|null);

                    /** BackendBucket id */
                    id?: (number|Long|string|null);

                    /** BackendBucket kind */
                    kind?: (string|null);

                    /** BackendBucket name */
                    name?: (string|null);

                    /** BackendBucket selfLink */
                    selfLink?: (string|null);
                }

                /** Represents a BackendBucket. */
                class BackendBucket implements IBackendBucket {

                    /**
                     * Constructs a new BackendBucket.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendBucket);

                    /** BackendBucket bucketName. */
                    public bucketName?: (string|null);

                    /** BackendBucket cdnPolicy. */
                    public cdnPolicy?: (google.cloud.compute.v1.IBackendBucketCdnPolicy|null);

                    /** BackendBucket compressionMode. */
                    public compressionMode?: (string|null);

                    /** BackendBucket creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** BackendBucket customResponseHeaders. */
                    public customResponseHeaders: string[];

                    /** BackendBucket description. */
                    public description?: (string|null);

                    /** BackendBucket edgeSecurityPolicy. */
                    public edgeSecurityPolicy?: (string|null);

                    /** BackendBucket enableCdn. */
                    public enableCdn?: (boolean|null);

                    /** BackendBucket id. */
                    public id?: (number|Long|string|null);

                    /** BackendBucket kind. */
                    public kind?: (string|null);

                    /** BackendBucket name. */
                    public name?: (string|null);

                    /** BackendBucket selfLink. */
                    public selfLink?: (string|null);

                    /** BackendBucket _bucketName. */
                    public _bucketName?: "bucketName";

                    /** BackendBucket _cdnPolicy. */
                    public _cdnPolicy?: "cdnPolicy";

                    /** BackendBucket _compressionMode. */
                    public _compressionMode?: "compressionMode";

                    /** BackendBucket _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** BackendBucket _description. */
                    public _description?: "description";

                    /** BackendBucket _edgeSecurityPolicy. */
                    public _edgeSecurityPolicy?: "edgeSecurityPolicy";

                    /** BackendBucket _enableCdn. */
                    public _enableCdn?: "enableCdn";

                    /** BackendBucket _id. */
                    public _id?: "id";

                    /** BackendBucket _kind. */
                    public _kind?: "kind";

                    /** BackendBucket _name. */
                    public _name?: "name";

                    /** BackendBucket _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new BackendBucket instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendBucket instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendBucket): google.cloud.compute.v1.BackendBucket;

                    /**
                     * Encodes the specified BackendBucket message. Does not implicitly {@link google.cloud.compute.v1.BackendBucket.verify|verify} messages.
                     * @param message BackendBucket message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendBucket, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendBucket message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendBucket.verify|verify} messages.
                     * @param message BackendBucket message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendBucket, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendBucket message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendBucket
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendBucket;

                    /**
                     * Decodes a BackendBucket message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendBucket
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendBucket;

                    /**
                     * Verifies a BackendBucket message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendBucket message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendBucket
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendBucket;

                    /**
                     * Creates a plain object from a BackendBucket message. Also converts values to other types if specified.
                     * @param message BackendBucket
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendBucket, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendBucket to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendBucket
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BackendBucket {

                    /** CompressionMode enum. */
                    enum CompressionMode {
                        UNDEFINED_COMPRESSION_MODE = 0,
                        AUTOMATIC = 165298699,
                        DISABLED = 516696700
                    }
                }

                /** Properties of a BackendBucketCdnPolicy. */
                interface IBackendBucketCdnPolicy {

                    /** BackendBucketCdnPolicy bypassCacheOnRequestHeaders */
                    bypassCacheOnRequestHeaders?: (google.cloud.compute.v1.IBackendBucketCdnPolicyBypassCacheOnRequestHeader[]|null);

                    /** BackendBucketCdnPolicy cacheKeyPolicy */
                    cacheKeyPolicy?: (google.cloud.compute.v1.IBackendBucketCdnPolicyCacheKeyPolicy|null);

                    /** BackendBucketCdnPolicy cacheMode */
                    cacheMode?: (string|null);

                    /** BackendBucketCdnPolicy clientTtl */
                    clientTtl?: (number|null);

                    /** BackendBucketCdnPolicy defaultTtl */
                    defaultTtl?: (number|null);

                    /** BackendBucketCdnPolicy maxTtl */
                    maxTtl?: (number|null);

                    /** BackendBucketCdnPolicy negativeCaching */
                    negativeCaching?: (boolean|null);

                    /** BackendBucketCdnPolicy negativeCachingPolicy */
                    negativeCachingPolicy?: (google.cloud.compute.v1.IBackendBucketCdnPolicyNegativeCachingPolicy[]|null);

                    /** BackendBucketCdnPolicy requestCoalescing */
                    requestCoalescing?: (boolean|null);

                    /** BackendBucketCdnPolicy serveWhileStale */
                    serveWhileStale?: (number|null);

                    /** BackendBucketCdnPolicy signedUrlCacheMaxAgeSec */
                    signedUrlCacheMaxAgeSec?: (number|Long|string|null);

                    /** BackendBucketCdnPolicy signedUrlKeyNames */
                    signedUrlKeyNames?: (string[]|null);
                }

                /** Represents a BackendBucketCdnPolicy. */
                class BackendBucketCdnPolicy implements IBackendBucketCdnPolicy {

                    /**
                     * Constructs a new BackendBucketCdnPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicy);

                    /** BackendBucketCdnPolicy bypassCacheOnRequestHeaders. */
                    public bypassCacheOnRequestHeaders: google.cloud.compute.v1.IBackendBucketCdnPolicyBypassCacheOnRequestHeader[];

                    /** BackendBucketCdnPolicy cacheKeyPolicy. */
                    public cacheKeyPolicy?: (google.cloud.compute.v1.IBackendBucketCdnPolicyCacheKeyPolicy|null);

                    /** BackendBucketCdnPolicy cacheMode. */
                    public cacheMode?: (string|null);

                    /** BackendBucketCdnPolicy clientTtl. */
                    public clientTtl?: (number|null);

                    /** BackendBucketCdnPolicy defaultTtl. */
                    public defaultTtl?: (number|null);

                    /** BackendBucketCdnPolicy maxTtl. */
                    public maxTtl?: (number|null);

                    /** BackendBucketCdnPolicy negativeCaching. */
                    public negativeCaching?: (boolean|null);

                    /** BackendBucketCdnPolicy negativeCachingPolicy. */
                    public negativeCachingPolicy: google.cloud.compute.v1.IBackendBucketCdnPolicyNegativeCachingPolicy[];

                    /** BackendBucketCdnPolicy requestCoalescing. */
                    public requestCoalescing?: (boolean|null);

                    /** BackendBucketCdnPolicy serveWhileStale. */
                    public serveWhileStale?: (number|null);

                    /** BackendBucketCdnPolicy signedUrlCacheMaxAgeSec. */
                    public signedUrlCacheMaxAgeSec?: (number|Long|string|null);

                    /** BackendBucketCdnPolicy signedUrlKeyNames. */
                    public signedUrlKeyNames: string[];

                    /** BackendBucketCdnPolicy _cacheKeyPolicy. */
                    public _cacheKeyPolicy?: "cacheKeyPolicy";

                    /** BackendBucketCdnPolicy _cacheMode. */
                    public _cacheMode?: "cacheMode";

                    /** BackendBucketCdnPolicy _clientTtl. */
                    public _clientTtl?: "clientTtl";

                    /** BackendBucketCdnPolicy _defaultTtl. */
                    public _defaultTtl?: "defaultTtl";

                    /** BackendBucketCdnPolicy _maxTtl. */
                    public _maxTtl?: "maxTtl";

                    /** BackendBucketCdnPolicy _negativeCaching. */
                    public _negativeCaching?: "negativeCaching";

                    /** BackendBucketCdnPolicy _requestCoalescing. */
                    public _requestCoalescing?: "requestCoalescing";

                    /** BackendBucketCdnPolicy _serveWhileStale. */
                    public _serveWhileStale?: "serveWhileStale";

                    /** BackendBucketCdnPolicy _signedUrlCacheMaxAgeSec. */
                    public _signedUrlCacheMaxAgeSec?: "signedUrlCacheMaxAgeSec";

                    /**
                     * Creates a new BackendBucketCdnPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendBucketCdnPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicy): google.cloud.compute.v1.BackendBucketCdnPolicy;

                    /**
                     * Encodes the specified BackendBucketCdnPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicy.verify|verify} messages.
                     * @param message BackendBucketCdnPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendBucketCdnPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendBucketCdnPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicy.verify|verify} messages.
                     * @param message BackendBucketCdnPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendBucketCdnPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendBucketCdnPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendBucketCdnPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendBucketCdnPolicy;

                    /**
                     * Decodes a BackendBucketCdnPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendBucketCdnPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendBucketCdnPolicy;

                    /**
                     * Verifies a BackendBucketCdnPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendBucketCdnPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendBucketCdnPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendBucketCdnPolicy;

                    /**
                     * Creates a plain object from a BackendBucketCdnPolicy message. Also converts values to other types if specified.
                     * @param message BackendBucketCdnPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendBucketCdnPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendBucketCdnPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendBucketCdnPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BackendBucketCdnPolicy {

                    /** CacheMode enum. */
                    enum CacheMode {
                        UNDEFINED_CACHE_MODE = 0,
                        CACHE_ALL_STATIC = 355027945,
                        FORCE_CACHE_ALL = 486026928,
                        INVALID_CACHE_MODE = 381295560,
                        USE_ORIGIN_HEADERS = 55380261
                    }
                }

                /** Properties of a BackendBucketCdnPolicyBypassCacheOnRequestHeader. */
                interface IBackendBucketCdnPolicyBypassCacheOnRequestHeader {

                    /** BackendBucketCdnPolicyBypassCacheOnRequestHeader headerName */
                    headerName?: (string|null);
                }

                /** Represents a BackendBucketCdnPolicyBypassCacheOnRequestHeader. */
                class BackendBucketCdnPolicyBypassCacheOnRequestHeader implements IBackendBucketCdnPolicyBypassCacheOnRequestHeader {

                    /**
                     * Constructs a new BackendBucketCdnPolicyBypassCacheOnRequestHeader.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicyBypassCacheOnRequestHeader);

                    /** BackendBucketCdnPolicyBypassCacheOnRequestHeader headerName. */
                    public headerName?: (string|null);

                    /** BackendBucketCdnPolicyBypassCacheOnRequestHeader _headerName. */
                    public _headerName?: "headerName";

                    /**
                     * Creates a new BackendBucketCdnPolicyBypassCacheOnRequestHeader instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendBucketCdnPolicyBypassCacheOnRequestHeader instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicyBypassCacheOnRequestHeader): google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Encodes the specified BackendBucketCdnPolicyBypassCacheOnRequestHeader message. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader.verify|verify} messages.
                     * @param message BackendBucketCdnPolicyBypassCacheOnRequestHeader message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendBucketCdnPolicyBypassCacheOnRequestHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendBucketCdnPolicyBypassCacheOnRequestHeader message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader.verify|verify} messages.
                     * @param message BackendBucketCdnPolicyBypassCacheOnRequestHeader message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendBucketCdnPolicyBypassCacheOnRequestHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendBucketCdnPolicyBypassCacheOnRequestHeader message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendBucketCdnPolicyBypassCacheOnRequestHeader
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Decodes a BackendBucketCdnPolicyBypassCacheOnRequestHeader message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendBucketCdnPolicyBypassCacheOnRequestHeader
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Verifies a BackendBucketCdnPolicyBypassCacheOnRequestHeader message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendBucketCdnPolicyBypassCacheOnRequestHeader message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendBucketCdnPolicyBypassCacheOnRequestHeader
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Creates a plain object from a BackendBucketCdnPolicyBypassCacheOnRequestHeader message. Also converts values to other types if specified.
                     * @param message BackendBucketCdnPolicyBypassCacheOnRequestHeader
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendBucketCdnPolicyBypassCacheOnRequestHeader, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendBucketCdnPolicyBypassCacheOnRequestHeader to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendBucketCdnPolicyBypassCacheOnRequestHeader
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendBucketCdnPolicyCacheKeyPolicy. */
                interface IBackendBucketCdnPolicyCacheKeyPolicy {

                    /** BackendBucketCdnPolicyCacheKeyPolicy includeHttpHeaders */
                    includeHttpHeaders?: (string[]|null);

                    /** BackendBucketCdnPolicyCacheKeyPolicy queryStringWhitelist */
                    queryStringWhitelist?: (string[]|null);
                }

                /** Represents a BackendBucketCdnPolicyCacheKeyPolicy. */
                class BackendBucketCdnPolicyCacheKeyPolicy implements IBackendBucketCdnPolicyCacheKeyPolicy {

                    /**
                     * Constructs a new BackendBucketCdnPolicyCacheKeyPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicyCacheKeyPolicy);

                    /** BackendBucketCdnPolicyCacheKeyPolicy includeHttpHeaders. */
                    public includeHttpHeaders: string[];

                    /** BackendBucketCdnPolicyCacheKeyPolicy queryStringWhitelist. */
                    public queryStringWhitelist: string[];

                    /**
                     * Creates a new BackendBucketCdnPolicyCacheKeyPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendBucketCdnPolicyCacheKeyPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicyCacheKeyPolicy): google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy;

                    /**
                     * Encodes the specified BackendBucketCdnPolicyCacheKeyPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy.verify|verify} messages.
                     * @param message BackendBucketCdnPolicyCacheKeyPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendBucketCdnPolicyCacheKeyPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendBucketCdnPolicyCacheKeyPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy.verify|verify} messages.
                     * @param message BackendBucketCdnPolicyCacheKeyPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendBucketCdnPolicyCacheKeyPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendBucketCdnPolicyCacheKeyPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendBucketCdnPolicyCacheKeyPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy;

                    /**
                     * Decodes a BackendBucketCdnPolicyCacheKeyPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendBucketCdnPolicyCacheKeyPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy;

                    /**
                     * Verifies a BackendBucketCdnPolicyCacheKeyPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendBucketCdnPolicyCacheKeyPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendBucketCdnPolicyCacheKeyPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy;

                    /**
                     * Creates a plain object from a BackendBucketCdnPolicyCacheKeyPolicy message. Also converts values to other types if specified.
                     * @param message BackendBucketCdnPolicyCacheKeyPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendBucketCdnPolicyCacheKeyPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendBucketCdnPolicyCacheKeyPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendBucketCdnPolicyCacheKeyPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendBucketCdnPolicyNegativeCachingPolicy. */
                interface IBackendBucketCdnPolicyNegativeCachingPolicy {

                    /** BackendBucketCdnPolicyNegativeCachingPolicy code */
                    code?: (number|null);

                    /** BackendBucketCdnPolicyNegativeCachingPolicy ttl */
                    ttl?: (number|null);
                }

                /** Represents a BackendBucketCdnPolicyNegativeCachingPolicy. */
                class BackendBucketCdnPolicyNegativeCachingPolicy implements IBackendBucketCdnPolicyNegativeCachingPolicy {

                    /**
                     * Constructs a new BackendBucketCdnPolicyNegativeCachingPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicyNegativeCachingPolicy);

                    /** BackendBucketCdnPolicyNegativeCachingPolicy code. */
                    public code?: (number|null);

                    /** BackendBucketCdnPolicyNegativeCachingPolicy ttl. */
                    public ttl?: (number|null);

                    /** BackendBucketCdnPolicyNegativeCachingPolicy _code. */
                    public _code?: "code";

                    /** BackendBucketCdnPolicyNegativeCachingPolicy _ttl. */
                    public _ttl?: "ttl";

                    /**
                     * Creates a new BackendBucketCdnPolicyNegativeCachingPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendBucketCdnPolicyNegativeCachingPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendBucketCdnPolicyNegativeCachingPolicy): google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy;

                    /**
                     * Encodes the specified BackendBucketCdnPolicyNegativeCachingPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy.verify|verify} messages.
                     * @param message BackendBucketCdnPolicyNegativeCachingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendBucketCdnPolicyNegativeCachingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendBucketCdnPolicyNegativeCachingPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy.verify|verify} messages.
                     * @param message BackendBucketCdnPolicyNegativeCachingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendBucketCdnPolicyNegativeCachingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendBucketCdnPolicyNegativeCachingPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendBucketCdnPolicyNegativeCachingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy;

                    /**
                     * Decodes a BackendBucketCdnPolicyNegativeCachingPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendBucketCdnPolicyNegativeCachingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy;

                    /**
                     * Verifies a BackendBucketCdnPolicyNegativeCachingPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendBucketCdnPolicyNegativeCachingPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendBucketCdnPolicyNegativeCachingPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy;

                    /**
                     * Creates a plain object from a BackendBucketCdnPolicyNegativeCachingPolicy message. Also converts values to other types if specified.
                     * @param message BackendBucketCdnPolicyNegativeCachingPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendBucketCdnPolicyNegativeCachingPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendBucketCdnPolicyNegativeCachingPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendBucketCdnPolicyNegativeCachingPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendBucketList. */
                interface IBackendBucketList {

                    /** BackendBucketList id */
                    id?: (string|null);

                    /** BackendBucketList items */
                    items?: (google.cloud.compute.v1.IBackendBucket[]|null);

                    /** BackendBucketList kind */
                    kind?: (string|null);

                    /** BackendBucketList nextPageToken */
                    nextPageToken?: (string|null);

                    /** BackendBucketList selfLink */
                    selfLink?: (string|null);

                    /** BackendBucketList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a BackendBucketList. */
                class BackendBucketList implements IBackendBucketList {

                    /**
                     * Constructs a new BackendBucketList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendBucketList);

                    /** BackendBucketList id. */
                    public id?: (string|null);

                    /** BackendBucketList items. */
                    public items: google.cloud.compute.v1.IBackendBucket[];

                    /** BackendBucketList kind. */
                    public kind?: (string|null);

                    /** BackendBucketList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** BackendBucketList selfLink. */
                    public selfLink?: (string|null);

                    /** BackendBucketList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** BackendBucketList _id. */
                    public _id?: "id";

                    /** BackendBucketList _kind. */
                    public _kind?: "kind";

                    /** BackendBucketList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** BackendBucketList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** BackendBucketList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new BackendBucketList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendBucketList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendBucketList): google.cloud.compute.v1.BackendBucketList;

                    /**
                     * Encodes the specified BackendBucketList message. Does not implicitly {@link google.cloud.compute.v1.BackendBucketList.verify|verify} messages.
                     * @param message BackendBucketList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendBucketList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendBucketList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendBucketList.verify|verify} messages.
                     * @param message BackendBucketList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendBucketList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendBucketList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendBucketList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendBucketList;

                    /**
                     * Decodes a BackendBucketList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendBucketList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendBucketList;

                    /**
                     * Verifies a BackendBucketList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendBucketList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendBucketList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendBucketList;

                    /**
                     * Creates a plain object from a BackendBucketList message. Also converts values to other types if specified.
                     * @param message BackendBucketList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendBucketList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendBucketList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendBucketList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendService. */
                interface IBackendService {

                    /** BackendService affinityCookieTtlSec */
                    affinityCookieTtlSec?: (number|null);

                    /** BackendService backends */
                    backends?: (google.cloud.compute.v1.IBackend[]|null);

                    /** BackendService cdnPolicy */
                    cdnPolicy?: (google.cloud.compute.v1.IBackendServiceCdnPolicy|null);

                    /** BackendService circuitBreakers */
                    circuitBreakers?: (google.cloud.compute.v1.ICircuitBreakers|null);

                    /** BackendService compressionMode */
                    compressionMode?: (string|null);

                    /** BackendService connectionDraining */
                    connectionDraining?: (google.cloud.compute.v1.IConnectionDraining|null);

                    /** BackendService connectionTrackingPolicy */
                    connectionTrackingPolicy?: (google.cloud.compute.v1.IBackendServiceConnectionTrackingPolicy|null);

                    /** BackendService consistentHash */
                    consistentHash?: (google.cloud.compute.v1.IConsistentHashLoadBalancerSettings|null);

                    /** BackendService creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** BackendService customRequestHeaders */
                    customRequestHeaders?: (string[]|null);

                    /** BackendService customResponseHeaders */
                    customResponseHeaders?: (string[]|null);

                    /** BackendService description */
                    description?: (string|null);

                    /** BackendService edgeSecurityPolicy */
                    edgeSecurityPolicy?: (string|null);

                    /** BackendService enableCDN */
                    enableCDN?: (boolean|null);

                    /** BackendService failoverPolicy */
                    failoverPolicy?: (google.cloud.compute.v1.IBackendServiceFailoverPolicy|null);

                    /** BackendService fingerprint */
                    fingerprint?: (string|null);

                    /** BackendService healthChecks */
                    healthChecks?: (string[]|null);

                    /** BackendService iap */
                    iap?: (google.cloud.compute.v1.IBackendServiceIAP|null);

                    /** BackendService id */
                    id?: (number|Long|string|null);

                    /** BackendService kind */
                    kind?: (string|null);

                    /** BackendService loadBalancingScheme */
                    loadBalancingScheme?: (string|null);

                    /** BackendService localityLbPolicies */
                    localityLbPolicies?: (google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfig[]|null);

                    /** BackendService localityLbPolicy */
                    localityLbPolicy?: (string|null);

                    /** BackendService logConfig */
                    logConfig?: (google.cloud.compute.v1.IBackendServiceLogConfig|null);

                    /** BackendService maxStreamDuration */
                    maxStreamDuration?: (google.cloud.compute.v1.IDuration|null);

                    /** BackendService name */
                    name?: (string|null);

                    /** BackendService network */
                    network?: (string|null);

                    /** BackendService outlierDetection */
                    outlierDetection?: (google.cloud.compute.v1.IOutlierDetection|null);

                    /** BackendService port */
                    port?: (number|null);

                    /** BackendService portName */
                    portName?: (string|null);

                    /** BackendService protocol */
                    protocol?: (string|null);

                    /** BackendService region */
                    region?: (string|null);

                    /** BackendService securityPolicy */
                    securityPolicy?: (string|null);

                    /** BackendService securitySettings */
                    securitySettings?: (google.cloud.compute.v1.ISecuritySettings|null);

                    /** BackendService selfLink */
                    selfLink?: (string|null);

                    /** BackendService serviceBindings */
                    serviceBindings?: (string[]|null);

                    /** BackendService sessionAffinity */
                    sessionAffinity?: (string|null);

                    /** BackendService subsetting */
                    subsetting?: (google.cloud.compute.v1.ISubsetting|null);

                    /** BackendService timeoutSec */
                    timeoutSec?: (number|null);
                }

                /** Represents a BackendService. */
                class BackendService implements IBackendService {

                    /**
                     * Constructs a new BackendService.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendService);

                    /** BackendService affinityCookieTtlSec. */
                    public affinityCookieTtlSec?: (number|null);

                    /** BackendService backends. */
                    public backends: google.cloud.compute.v1.IBackend[];

                    /** BackendService cdnPolicy. */
                    public cdnPolicy?: (google.cloud.compute.v1.IBackendServiceCdnPolicy|null);

                    /** BackendService circuitBreakers. */
                    public circuitBreakers?: (google.cloud.compute.v1.ICircuitBreakers|null);

                    /** BackendService compressionMode. */
                    public compressionMode?: (string|null);

                    /** BackendService connectionDraining. */
                    public connectionDraining?: (google.cloud.compute.v1.IConnectionDraining|null);

                    /** BackendService connectionTrackingPolicy. */
                    public connectionTrackingPolicy?: (google.cloud.compute.v1.IBackendServiceConnectionTrackingPolicy|null);

                    /** BackendService consistentHash. */
                    public consistentHash?: (google.cloud.compute.v1.IConsistentHashLoadBalancerSettings|null);

                    /** BackendService creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** BackendService customRequestHeaders. */
                    public customRequestHeaders: string[];

                    /** BackendService customResponseHeaders. */
                    public customResponseHeaders: string[];

                    /** BackendService description. */
                    public description?: (string|null);

                    /** BackendService edgeSecurityPolicy. */
                    public edgeSecurityPolicy?: (string|null);

                    /** BackendService enableCDN. */
                    public enableCDN?: (boolean|null);

                    /** BackendService failoverPolicy. */
                    public failoverPolicy?: (google.cloud.compute.v1.IBackendServiceFailoverPolicy|null);

                    /** BackendService fingerprint. */
                    public fingerprint?: (string|null);

                    /** BackendService healthChecks. */
                    public healthChecks: string[];

                    /** BackendService iap. */
                    public iap?: (google.cloud.compute.v1.IBackendServiceIAP|null);

                    /** BackendService id. */
                    public id?: (number|Long|string|null);

                    /** BackendService kind. */
                    public kind?: (string|null);

                    /** BackendService loadBalancingScheme. */
                    public loadBalancingScheme?: (string|null);

                    /** BackendService localityLbPolicies. */
                    public localityLbPolicies: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfig[];

                    /** BackendService localityLbPolicy. */
                    public localityLbPolicy?: (string|null);

                    /** BackendService logConfig. */
                    public logConfig?: (google.cloud.compute.v1.IBackendServiceLogConfig|null);

                    /** BackendService maxStreamDuration. */
                    public maxStreamDuration?: (google.cloud.compute.v1.IDuration|null);

                    /** BackendService name. */
                    public name?: (string|null);

                    /** BackendService network. */
                    public network?: (string|null);

                    /** BackendService outlierDetection. */
                    public outlierDetection?: (google.cloud.compute.v1.IOutlierDetection|null);

                    /** BackendService port. */
                    public port?: (number|null);

                    /** BackendService portName. */
                    public portName?: (string|null);

                    /** BackendService protocol. */
                    public protocol?: (string|null);

                    /** BackendService region. */
                    public region?: (string|null);

                    /** BackendService securityPolicy. */
                    public securityPolicy?: (string|null);

                    /** BackendService securitySettings. */
                    public securitySettings?: (google.cloud.compute.v1.ISecuritySettings|null);

                    /** BackendService selfLink. */
                    public selfLink?: (string|null);

                    /** BackendService serviceBindings. */
                    public serviceBindings: string[];

                    /** BackendService sessionAffinity. */
                    public sessionAffinity?: (string|null);

                    /** BackendService subsetting. */
                    public subsetting?: (google.cloud.compute.v1.ISubsetting|null);

                    /** BackendService timeoutSec. */
                    public timeoutSec?: (number|null);

                    /** BackendService _affinityCookieTtlSec. */
                    public _affinityCookieTtlSec?: "affinityCookieTtlSec";

                    /** BackendService _cdnPolicy. */
                    public _cdnPolicy?: "cdnPolicy";

                    /** BackendService _circuitBreakers. */
                    public _circuitBreakers?: "circuitBreakers";

                    /** BackendService _compressionMode. */
                    public _compressionMode?: "compressionMode";

                    /** BackendService _connectionDraining. */
                    public _connectionDraining?: "connectionDraining";

                    /** BackendService _connectionTrackingPolicy. */
                    public _connectionTrackingPolicy?: "connectionTrackingPolicy";

                    /** BackendService _consistentHash. */
                    public _consistentHash?: "consistentHash";

                    /** BackendService _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** BackendService _description. */
                    public _description?: "description";

                    /** BackendService _edgeSecurityPolicy. */
                    public _edgeSecurityPolicy?: "edgeSecurityPolicy";

                    /** BackendService _enableCDN. */
                    public _enableCDN?: "enableCDN";

                    /** BackendService _failoverPolicy. */
                    public _failoverPolicy?: "failoverPolicy";

                    /** BackendService _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** BackendService _iap. */
                    public _iap?: "iap";

                    /** BackendService _id. */
                    public _id?: "id";

                    /** BackendService _kind. */
                    public _kind?: "kind";

                    /** BackendService _loadBalancingScheme. */
                    public _loadBalancingScheme?: "loadBalancingScheme";

                    /** BackendService _localityLbPolicy. */
                    public _localityLbPolicy?: "localityLbPolicy";

                    /** BackendService _logConfig. */
                    public _logConfig?: "logConfig";

                    /** BackendService _maxStreamDuration. */
                    public _maxStreamDuration?: "maxStreamDuration";

                    /** BackendService _name. */
                    public _name?: "name";

                    /** BackendService _network. */
                    public _network?: "network";

                    /** BackendService _outlierDetection. */
                    public _outlierDetection?: "outlierDetection";

                    /** BackendService _port. */
                    public _port?: "port";

                    /** BackendService _portName. */
                    public _portName?: "portName";

                    /** BackendService _protocol. */
                    public _protocol?: "protocol";

                    /** BackendService _region. */
                    public _region?: "region";

                    /** BackendService _securityPolicy. */
                    public _securityPolicy?: "securityPolicy";

                    /** BackendService _securitySettings. */
                    public _securitySettings?: "securitySettings";

                    /** BackendService _selfLink. */
                    public _selfLink?: "selfLink";

                    /** BackendService _sessionAffinity. */
                    public _sessionAffinity?: "sessionAffinity";

                    /** BackendService _subsetting. */
                    public _subsetting?: "subsetting";

                    /** BackendService _timeoutSec. */
                    public _timeoutSec?: "timeoutSec";

                    /**
                     * Creates a new BackendService instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendService instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendService): google.cloud.compute.v1.BackendService;

                    /**
                     * Encodes the specified BackendService message. Does not implicitly {@link google.cloud.compute.v1.BackendService.verify|verify} messages.
                     * @param message BackendService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendService message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendService.verify|verify} messages.
                     * @param message BackendService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendService message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendService;

                    /**
                     * Decodes a BackendService message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendService;

                    /**
                     * Verifies a BackendService message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendService message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendService
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendService;

                    /**
                     * Creates a plain object from a BackendService message. Also converts values to other types if specified.
                     * @param message BackendService
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendService, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendService to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendService
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BackendService {

                    /** CompressionMode enum. */
                    enum CompressionMode {
                        UNDEFINED_COMPRESSION_MODE = 0,
                        AUTOMATIC = 165298699,
                        DISABLED = 516696700
                    }

                    /** LoadBalancingScheme enum. */
                    enum LoadBalancingScheme {
                        UNDEFINED_LOAD_BALANCING_SCHEME = 0,
                        EXTERNAL = 35607499,
                        EXTERNAL_MANAGED = 512006923,
                        INTERNAL = 279295677,
                        INTERNAL_MANAGED = 37350397,
                        INTERNAL_SELF_MANAGED = 236211150,
                        INVALID_LOAD_BALANCING_SCHEME = 275352060
                    }

                    /** LocalityLbPolicy enum. */
                    enum LocalityLbPolicy {
                        UNDEFINED_LOCALITY_LB_POLICY = 0,
                        INVALID_LB_POLICY = 323318707,
                        LEAST_REQUEST = 46604921,
                        MAGLEV = 119180266,
                        ORIGINAL_DESTINATION = 166297216,
                        RANDOM = 262527171,
                        RING_HASH = 432795069,
                        ROUND_ROBIN = 153895801
                    }

                    /** Protocol enum. */
                    enum Protocol {
                        UNDEFINED_PROTOCOL = 0,
                        GRPC = 2196510,
                        HTTP = 2228360,
                        HTTP2 = 69079210,
                        HTTPS = 69079243,
                        SSL = 82412,
                        TCP = 82881,
                        UDP = 83873,
                        UNSPECIFIED = 526786327
                    }

                    /** SessionAffinity enum. */
                    enum SessionAffinity {
                        UNDEFINED_SESSION_AFFINITY = 0,
                        CLIENT_IP = 345665051,
                        CLIENT_IP_NO_DESTINATION = 106122516,
                        CLIENT_IP_PORT_PROTO = 221722926,
                        CLIENT_IP_PROTO = 25322148,
                        GENERATED_COOKIE = 370321204,
                        HEADER_FIELD = 200737960,
                        HTTP_COOKIE = 494981627,
                        NONE = 2402104
                    }
                }

                /** Properties of a BackendServiceAggregatedList. */
                interface IBackendServiceAggregatedList {

                    /** BackendServiceAggregatedList id */
                    id?: (string|null);

                    /** BackendServiceAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IBackendServicesScopedList }|null);

                    /** BackendServiceAggregatedList kind */
                    kind?: (string|null);

                    /** BackendServiceAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** BackendServiceAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** BackendServiceAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** BackendServiceAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a BackendServiceAggregatedList. */
                class BackendServiceAggregatedList implements IBackendServiceAggregatedList {

                    /**
                     * Constructs a new BackendServiceAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceAggregatedList);

                    /** BackendServiceAggregatedList id. */
                    public id?: (string|null);

                    /** BackendServiceAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IBackendServicesScopedList };

                    /** BackendServiceAggregatedList kind. */
                    public kind?: (string|null);

                    /** BackendServiceAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** BackendServiceAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** BackendServiceAggregatedList unreachables. */
                    public unreachables: string[];

                    /** BackendServiceAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** BackendServiceAggregatedList _id. */
                    public _id?: "id";

                    /** BackendServiceAggregatedList _kind. */
                    public _kind?: "kind";

                    /** BackendServiceAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** BackendServiceAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** BackendServiceAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new BackendServiceAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceAggregatedList): google.cloud.compute.v1.BackendServiceAggregatedList;

                    /**
                     * Encodes the specified BackendServiceAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceAggregatedList.verify|verify} messages.
                     * @param message BackendServiceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceAggregatedList.verify|verify} messages.
                     * @param message BackendServiceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceAggregatedList;

                    /**
                     * Decodes a BackendServiceAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceAggregatedList;

                    /**
                     * Verifies a BackendServiceAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceAggregatedList;

                    /**
                     * Creates a plain object from a BackendServiceAggregatedList message. Also converts values to other types if specified.
                     * @param message BackendServiceAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceCdnPolicy. */
                interface IBackendServiceCdnPolicy {

                    /** BackendServiceCdnPolicy bypassCacheOnRequestHeaders */
                    bypassCacheOnRequestHeaders?: (google.cloud.compute.v1.IBackendServiceCdnPolicyBypassCacheOnRequestHeader[]|null);

                    /** BackendServiceCdnPolicy cacheKeyPolicy */
                    cacheKeyPolicy?: (google.cloud.compute.v1.ICacheKeyPolicy|null);

                    /** BackendServiceCdnPolicy cacheMode */
                    cacheMode?: (string|null);

                    /** BackendServiceCdnPolicy clientTtl */
                    clientTtl?: (number|null);

                    /** BackendServiceCdnPolicy defaultTtl */
                    defaultTtl?: (number|null);

                    /** BackendServiceCdnPolicy maxTtl */
                    maxTtl?: (number|null);

                    /** BackendServiceCdnPolicy negativeCaching */
                    negativeCaching?: (boolean|null);

                    /** BackendServiceCdnPolicy negativeCachingPolicy */
                    negativeCachingPolicy?: (google.cloud.compute.v1.IBackendServiceCdnPolicyNegativeCachingPolicy[]|null);

                    /** BackendServiceCdnPolicy requestCoalescing */
                    requestCoalescing?: (boolean|null);

                    /** BackendServiceCdnPolicy serveWhileStale */
                    serveWhileStale?: (number|null);

                    /** BackendServiceCdnPolicy signedUrlCacheMaxAgeSec */
                    signedUrlCacheMaxAgeSec?: (number|Long|string|null);

                    /** BackendServiceCdnPolicy signedUrlKeyNames */
                    signedUrlKeyNames?: (string[]|null);
                }

                /** Represents a BackendServiceCdnPolicy. */
                class BackendServiceCdnPolicy implements IBackendServiceCdnPolicy {

                    /**
                     * Constructs a new BackendServiceCdnPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceCdnPolicy);

                    /** BackendServiceCdnPolicy bypassCacheOnRequestHeaders. */
                    public bypassCacheOnRequestHeaders: google.cloud.compute.v1.IBackendServiceCdnPolicyBypassCacheOnRequestHeader[];

                    /** BackendServiceCdnPolicy cacheKeyPolicy. */
                    public cacheKeyPolicy?: (google.cloud.compute.v1.ICacheKeyPolicy|null);

                    /** BackendServiceCdnPolicy cacheMode. */
                    public cacheMode?: (string|null);

                    /** BackendServiceCdnPolicy clientTtl. */
                    public clientTtl?: (number|null);

                    /** BackendServiceCdnPolicy defaultTtl. */
                    public defaultTtl?: (number|null);

                    /** BackendServiceCdnPolicy maxTtl. */
                    public maxTtl?: (number|null);

                    /** BackendServiceCdnPolicy negativeCaching. */
                    public negativeCaching?: (boolean|null);

                    /** BackendServiceCdnPolicy negativeCachingPolicy. */
                    public negativeCachingPolicy: google.cloud.compute.v1.IBackendServiceCdnPolicyNegativeCachingPolicy[];

                    /** BackendServiceCdnPolicy requestCoalescing. */
                    public requestCoalescing?: (boolean|null);

                    /** BackendServiceCdnPolicy serveWhileStale. */
                    public serveWhileStale?: (number|null);

                    /** BackendServiceCdnPolicy signedUrlCacheMaxAgeSec. */
                    public signedUrlCacheMaxAgeSec?: (number|Long|string|null);

                    /** BackendServiceCdnPolicy signedUrlKeyNames. */
                    public signedUrlKeyNames: string[];

                    /** BackendServiceCdnPolicy _cacheKeyPolicy. */
                    public _cacheKeyPolicy?: "cacheKeyPolicy";

                    /** BackendServiceCdnPolicy _cacheMode. */
                    public _cacheMode?: "cacheMode";

                    /** BackendServiceCdnPolicy _clientTtl. */
                    public _clientTtl?: "clientTtl";

                    /** BackendServiceCdnPolicy _defaultTtl. */
                    public _defaultTtl?: "defaultTtl";

                    /** BackendServiceCdnPolicy _maxTtl. */
                    public _maxTtl?: "maxTtl";

                    /** BackendServiceCdnPolicy _negativeCaching. */
                    public _negativeCaching?: "negativeCaching";

                    /** BackendServiceCdnPolicy _requestCoalescing. */
                    public _requestCoalescing?: "requestCoalescing";

                    /** BackendServiceCdnPolicy _serveWhileStale. */
                    public _serveWhileStale?: "serveWhileStale";

                    /** BackendServiceCdnPolicy _signedUrlCacheMaxAgeSec. */
                    public _signedUrlCacheMaxAgeSec?: "signedUrlCacheMaxAgeSec";

                    /**
                     * Creates a new BackendServiceCdnPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceCdnPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceCdnPolicy): google.cloud.compute.v1.BackendServiceCdnPolicy;

                    /**
                     * Encodes the specified BackendServiceCdnPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceCdnPolicy.verify|verify} messages.
                     * @param message BackendServiceCdnPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceCdnPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceCdnPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceCdnPolicy.verify|verify} messages.
                     * @param message BackendServiceCdnPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceCdnPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceCdnPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceCdnPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceCdnPolicy;

                    /**
                     * Decodes a BackendServiceCdnPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceCdnPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceCdnPolicy;

                    /**
                     * Verifies a BackendServiceCdnPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceCdnPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceCdnPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceCdnPolicy;

                    /**
                     * Creates a plain object from a BackendServiceCdnPolicy message. Also converts values to other types if specified.
                     * @param message BackendServiceCdnPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceCdnPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceCdnPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceCdnPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BackendServiceCdnPolicy {

                    /** CacheMode enum. */
                    enum CacheMode {
                        UNDEFINED_CACHE_MODE = 0,
                        CACHE_ALL_STATIC = 355027945,
                        FORCE_CACHE_ALL = 486026928,
                        INVALID_CACHE_MODE = 381295560,
                        USE_ORIGIN_HEADERS = 55380261
                    }
                }

                /** Properties of a BackendServiceCdnPolicyBypassCacheOnRequestHeader. */
                interface IBackendServiceCdnPolicyBypassCacheOnRequestHeader {

                    /** BackendServiceCdnPolicyBypassCacheOnRequestHeader headerName */
                    headerName?: (string|null);
                }

                /** Represents a BackendServiceCdnPolicyBypassCacheOnRequestHeader. */
                class BackendServiceCdnPolicyBypassCacheOnRequestHeader implements IBackendServiceCdnPolicyBypassCacheOnRequestHeader {

                    /**
                     * Constructs a new BackendServiceCdnPolicyBypassCacheOnRequestHeader.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceCdnPolicyBypassCacheOnRequestHeader);

                    /** BackendServiceCdnPolicyBypassCacheOnRequestHeader headerName. */
                    public headerName?: (string|null);

                    /** BackendServiceCdnPolicyBypassCacheOnRequestHeader _headerName. */
                    public _headerName?: "headerName";

                    /**
                     * Creates a new BackendServiceCdnPolicyBypassCacheOnRequestHeader instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceCdnPolicyBypassCacheOnRequestHeader instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceCdnPolicyBypassCacheOnRequestHeader): google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Encodes the specified BackendServiceCdnPolicyBypassCacheOnRequestHeader message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader.verify|verify} messages.
                     * @param message BackendServiceCdnPolicyBypassCacheOnRequestHeader message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceCdnPolicyBypassCacheOnRequestHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceCdnPolicyBypassCacheOnRequestHeader message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader.verify|verify} messages.
                     * @param message BackendServiceCdnPolicyBypassCacheOnRequestHeader message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceCdnPolicyBypassCacheOnRequestHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceCdnPolicyBypassCacheOnRequestHeader message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceCdnPolicyBypassCacheOnRequestHeader
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Decodes a BackendServiceCdnPolicyBypassCacheOnRequestHeader message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceCdnPolicyBypassCacheOnRequestHeader
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Verifies a BackendServiceCdnPolicyBypassCacheOnRequestHeader message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceCdnPolicyBypassCacheOnRequestHeader message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceCdnPolicyBypassCacheOnRequestHeader
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader;

                    /**
                     * Creates a plain object from a BackendServiceCdnPolicyBypassCacheOnRequestHeader message. Also converts values to other types if specified.
                     * @param message BackendServiceCdnPolicyBypassCacheOnRequestHeader
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceCdnPolicyBypassCacheOnRequestHeader, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceCdnPolicyBypassCacheOnRequestHeader to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceCdnPolicyBypassCacheOnRequestHeader
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceCdnPolicyNegativeCachingPolicy. */
                interface IBackendServiceCdnPolicyNegativeCachingPolicy {

                    /** BackendServiceCdnPolicyNegativeCachingPolicy code */
                    code?: (number|null);

                    /** BackendServiceCdnPolicyNegativeCachingPolicy ttl */
                    ttl?: (number|null);
                }

                /** Represents a BackendServiceCdnPolicyNegativeCachingPolicy. */
                class BackendServiceCdnPolicyNegativeCachingPolicy implements IBackendServiceCdnPolicyNegativeCachingPolicy {

                    /**
                     * Constructs a new BackendServiceCdnPolicyNegativeCachingPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceCdnPolicyNegativeCachingPolicy);

                    /** BackendServiceCdnPolicyNegativeCachingPolicy code. */
                    public code?: (number|null);

                    /** BackendServiceCdnPolicyNegativeCachingPolicy ttl. */
                    public ttl?: (number|null);

                    /** BackendServiceCdnPolicyNegativeCachingPolicy _code. */
                    public _code?: "code";

                    /** BackendServiceCdnPolicyNegativeCachingPolicy _ttl. */
                    public _ttl?: "ttl";

                    /**
                     * Creates a new BackendServiceCdnPolicyNegativeCachingPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceCdnPolicyNegativeCachingPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceCdnPolicyNegativeCachingPolicy): google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy;

                    /**
                     * Encodes the specified BackendServiceCdnPolicyNegativeCachingPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy.verify|verify} messages.
                     * @param message BackendServiceCdnPolicyNegativeCachingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceCdnPolicyNegativeCachingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceCdnPolicyNegativeCachingPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy.verify|verify} messages.
                     * @param message BackendServiceCdnPolicyNegativeCachingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceCdnPolicyNegativeCachingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceCdnPolicyNegativeCachingPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceCdnPolicyNegativeCachingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy;

                    /**
                     * Decodes a BackendServiceCdnPolicyNegativeCachingPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceCdnPolicyNegativeCachingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy;

                    /**
                     * Verifies a BackendServiceCdnPolicyNegativeCachingPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceCdnPolicyNegativeCachingPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceCdnPolicyNegativeCachingPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy;

                    /**
                     * Creates a plain object from a BackendServiceCdnPolicyNegativeCachingPolicy message. Also converts values to other types if specified.
                     * @param message BackendServiceCdnPolicyNegativeCachingPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceCdnPolicyNegativeCachingPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceCdnPolicyNegativeCachingPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceCdnPolicyNegativeCachingPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceConnectionTrackingPolicy. */
                interface IBackendServiceConnectionTrackingPolicy {

                    /** BackendServiceConnectionTrackingPolicy connectionPersistenceOnUnhealthyBackends */
                    connectionPersistenceOnUnhealthyBackends?: (string|null);

                    /** BackendServiceConnectionTrackingPolicy enableStrongAffinity */
                    enableStrongAffinity?: (boolean|null);

                    /** BackendServiceConnectionTrackingPolicy idleTimeoutSec */
                    idleTimeoutSec?: (number|null);

                    /** BackendServiceConnectionTrackingPolicy trackingMode */
                    trackingMode?: (string|null);
                }

                /** Represents a BackendServiceConnectionTrackingPolicy. */
                class BackendServiceConnectionTrackingPolicy implements IBackendServiceConnectionTrackingPolicy {

                    /**
                     * Constructs a new BackendServiceConnectionTrackingPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceConnectionTrackingPolicy);

                    /** BackendServiceConnectionTrackingPolicy connectionPersistenceOnUnhealthyBackends. */
                    public connectionPersistenceOnUnhealthyBackends?: (string|null);

                    /** BackendServiceConnectionTrackingPolicy enableStrongAffinity. */
                    public enableStrongAffinity?: (boolean|null);

                    /** BackendServiceConnectionTrackingPolicy idleTimeoutSec. */
                    public idleTimeoutSec?: (number|null);

                    /** BackendServiceConnectionTrackingPolicy trackingMode. */
                    public trackingMode?: (string|null);

                    /** BackendServiceConnectionTrackingPolicy _connectionPersistenceOnUnhealthyBackends. */
                    public _connectionPersistenceOnUnhealthyBackends?: "connectionPersistenceOnUnhealthyBackends";

                    /** BackendServiceConnectionTrackingPolicy _enableStrongAffinity. */
                    public _enableStrongAffinity?: "enableStrongAffinity";

                    /** BackendServiceConnectionTrackingPolicy _idleTimeoutSec. */
                    public _idleTimeoutSec?: "idleTimeoutSec";

                    /** BackendServiceConnectionTrackingPolicy _trackingMode. */
                    public _trackingMode?: "trackingMode";

                    /**
                     * Creates a new BackendServiceConnectionTrackingPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceConnectionTrackingPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceConnectionTrackingPolicy): google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy;

                    /**
                     * Encodes the specified BackendServiceConnectionTrackingPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy.verify|verify} messages.
                     * @param message BackendServiceConnectionTrackingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceConnectionTrackingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceConnectionTrackingPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy.verify|verify} messages.
                     * @param message BackendServiceConnectionTrackingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceConnectionTrackingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceConnectionTrackingPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceConnectionTrackingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy;

                    /**
                     * Decodes a BackendServiceConnectionTrackingPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceConnectionTrackingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy;

                    /**
                     * Verifies a BackendServiceConnectionTrackingPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceConnectionTrackingPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceConnectionTrackingPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy;

                    /**
                     * Creates a plain object from a BackendServiceConnectionTrackingPolicy message. Also converts values to other types if specified.
                     * @param message BackendServiceConnectionTrackingPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceConnectionTrackingPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceConnectionTrackingPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceConnectionTrackingPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BackendServiceConnectionTrackingPolicy {

                    /** ConnectionPersistenceOnUnhealthyBackends enum. */
                    enum ConnectionPersistenceOnUnhealthyBackends {
                        UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0,
                        ALWAYS_PERSIST = 38400900,
                        DEFAULT_FOR_PROTOCOL = 145265356,
                        NEVER_PERSIST = 138646241
                    }

                    /** TrackingMode enum. */
                    enum TrackingMode {
                        UNDEFINED_TRACKING_MODE = 0,
                        INVALID_TRACKING_MODE = 49234371,
                        PER_CONNECTION = 85162848,
                        PER_SESSION = 182099252
                    }
                }

                /** Properties of a BackendServiceFailoverPolicy. */
                interface IBackendServiceFailoverPolicy {

                    /** BackendServiceFailoverPolicy disableConnectionDrainOnFailover */
                    disableConnectionDrainOnFailover?: (boolean|null);

                    /** BackendServiceFailoverPolicy dropTrafficIfUnhealthy */
                    dropTrafficIfUnhealthy?: (boolean|null);

                    /** BackendServiceFailoverPolicy failoverRatio */
                    failoverRatio?: (number|null);
                }

                /** Represents a BackendServiceFailoverPolicy. */
                class BackendServiceFailoverPolicy implements IBackendServiceFailoverPolicy {

                    /**
                     * Constructs a new BackendServiceFailoverPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceFailoverPolicy);

                    /** BackendServiceFailoverPolicy disableConnectionDrainOnFailover. */
                    public disableConnectionDrainOnFailover?: (boolean|null);

                    /** BackendServiceFailoverPolicy dropTrafficIfUnhealthy. */
                    public dropTrafficIfUnhealthy?: (boolean|null);

                    /** BackendServiceFailoverPolicy failoverRatio. */
                    public failoverRatio?: (number|null);

                    /** BackendServiceFailoverPolicy _disableConnectionDrainOnFailover. */
                    public _disableConnectionDrainOnFailover?: "disableConnectionDrainOnFailover";

                    /** BackendServiceFailoverPolicy _dropTrafficIfUnhealthy. */
                    public _dropTrafficIfUnhealthy?: "dropTrafficIfUnhealthy";

                    /** BackendServiceFailoverPolicy _failoverRatio. */
                    public _failoverRatio?: "failoverRatio";

                    /**
                     * Creates a new BackendServiceFailoverPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceFailoverPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceFailoverPolicy): google.cloud.compute.v1.BackendServiceFailoverPolicy;

                    /**
                     * Encodes the specified BackendServiceFailoverPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceFailoverPolicy.verify|verify} messages.
                     * @param message BackendServiceFailoverPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceFailoverPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceFailoverPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceFailoverPolicy.verify|verify} messages.
                     * @param message BackendServiceFailoverPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceFailoverPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceFailoverPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceFailoverPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceFailoverPolicy;

                    /**
                     * Decodes a BackendServiceFailoverPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceFailoverPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceFailoverPolicy;

                    /**
                     * Verifies a BackendServiceFailoverPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceFailoverPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceFailoverPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceFailoverPolicy;

                    /**
                     * Creates a plain object from a BackendServiceFailoverPolicy message. Also converts values to other types if specified.
                     * @param message BackendServiceFailoverPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceFailoverPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceFailoverPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceFailoverPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceGroupHealth. */
                interface IBackendServiceGroupHealth {

                    /** BackendServiceGroupHealth annotations */
                    annotations?: ({ [k: string]: string }|null);

                    /** BackendServiceGroupHealth healthStatus */
                    healthStatus?: (google.cloud.compute.v1.IHealthStatus[]|null);

                    /** BackendServiceGroupHealth kind */
                    kind?: (string|null);
                }

                /** Represents a BackendServiceGroupHealth. */
                class BackendServiceGroupHealth implements IBackendServiceGroupHealth {

                    /**
                     * Constructs a new BackendServiceGroupHealth.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceGroupHealth);

                    /** BackendServiceGroupHealth annotations. */
                    public annotations: { [k: string]: string };

                    /** BackendServiceGroupHealth healthStatus. */
                    public healthStatus: google.cloud.compute.v1.IHealthStatus[];

                    /** BackendServiceGroupHealth kind. */
                    public kind?: (string|null);

                    /** BackendServiceGroupHealth _kind. */
                    public _kind?: "kind";

                    /**
                     * Creates a new BackendServiceGroupHealth instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceGroupHealth instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceGroupHealth): google.cloud.compute.v1.BackendServiceGroupHealth;

                    /**
                     * Encodes the specified BackendServiceGroupHealth message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceGroupHealth.verify|verify} messages.
                     * @param message BackendServiceGroupHealth message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceGroupHealth, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceGroupHealth message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceGroupHealth.verify|verify} messages.
                     * @param message BackendServiceGroupHealth message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceGroupHealth, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceGroupHealth message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceGroupHealth
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceGroupHealth;

                    /**
                     * Decodes a BackendServiceGroupHealth message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceGroupHealth
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceGroupHealth;

                    /**
                     * Verifies a BackendServiceGroupHealth message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceGroupHealth message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceGroupHealth
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceGroupHealth;

                    /**
                     * Creates a plain object from a BackendServiceGroupHealth message. Also converts values to other types if specified.
                     * @param message BackendServiceGroupHealth
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceGroupHealth, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceGroupHealth to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceGroupHealth
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceIAP. */
                interface IBackendServiceIAP {

                    /** BackendServiceIAP enabled */
                    enabled?: (boolean|null);

                    /** BackendServiceIAP oauth2ClientId */
                    oauth2ClientId?: (string|null);

                    /** BackendServiceIAP oauth2ClientSecret */
                    oauth2ClientSecret?: (string|null);

                    /** BackendServiceIAP oauth2ClientSecretSha256 */
                    oauth2ClientSecretSha256?: (string|null);
                }

                /** Represents a BackendServiceIAP. */
                class BackendServiceIAP implements IBackendServiceIAP {

                    /**
                     * Constructs a new BackendServiceIAP.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceIAP);

                    /** BackendServiceIAP enabled. */
                    public enabled?: (boolean|null);

                    /** BackendServiceIAP oauth2ClientId. */
                    public oauth2ClientId?: (string|null);

                    /** BackendServiceIAP oauth2ClientSecret. */
                    public oauth2ClientSecret?: (string|null);

                    /** BackendServiceIAP oauth2ClientSecretSha256. */
                    public oauth2ClientSecretSha256?: (string|null);

                    /** BackendServiceIAP _enabled. */
                    public _enabled?: "enabled";

                    /** BackendServiceIAP _oauth2ClientId. */
                    public _oauth2ClientId?: "oauth2ClientId";

                    /** BackendServiceIAP _oauth2ClientSecret. */
                    public _oauth2ClientSecret?: "oauth2ClientSecret";

                    /** BackendServiceIAP _oauth2ClientSecretSha256. */
                    public _oauth2ClientSecretSha256?: "oauth2ClientSecretSha256";

                    /**
                     * Creates a new BackendServiceIAP instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceIAP instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceIAP): google.cloud.compute.v1.BackendServiceIAP;

                    /**
                     * Encodes the specified BackendServiceIAP message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceIAP.verify|verify} messages.
                     * @param message BackendServiceIAP message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceIAP, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceIAP message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceIAP.verify|verify} messages.
                     * @param message BackendServiceIAP message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceIAP, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceIAP message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceIAP
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceIAP;

                    /**
                     * Decodes a BackendServiceIAP message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceIAP
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceIAP;

                    /**
                     * Verifies a BackendServiceIAP message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceIAP message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceIAP
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceIAP;

                    /**
                     * Creates a plain object from a BackendServiceIAP message. Also converts values to other types if specified.
                     * @param message BackendServiceIAP
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceIAP, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceIAP to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceIAP
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceList. */
                interface IBackendServiceList {

                    /** BackendServiceList id */
                    id?: (string|null);

                    /** BackendServiceList items */
                    items?: (google.cloud.compute.v1.IBackendService[]|null);

                    /** BackendServiceList kind */
                    kind?: (string|null);

                    /** BackendServiceList nextPageToken */
                    nextPageToken?: (string|null);

                    /** BackendServiceList selfLink */
                    selfLink?: (string|null);

                    /** BackendServiceList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a BackendServiceList. */
                class BackendServiceList implements IBackendServiceList {

                    /**
                     * Constructs a new BackendServiceList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceList);

                    /** BackendServiceList id. */
                    public id?: (string|null);

                    /** BackendServiceList items. */
                    public items: google.cloud.compute.v1.IBackendService[];

                    /** BackendServiceList kind. */
                    public kind?: (string|null);

                    /** BackendServiceList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** BackendServiceList selfLink. */
                    public selfLink?: (string|null);

                    /** BackendServiceList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** BackendServiceList _id. */
                    public _id?: "id";

                    /** BackendServiceList _kind. */
                    public _kind?: "kind";

                    /** BackendServiceList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** BackendServiceList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** BackendServiceList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new BackendServiceList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceList): google.cloud.compute.v1.BackendServiceList;

                    /**
                     * Encodes the specified BackendServiceList message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceList.verify|verify} messages.
                     * @param message BackendServiceList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceList.verify|verify} messages.
                     * @param message BackendServiceList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceList;

                    /**
                     * Decodes a BackendServiceList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceList;

                    /**
                     * Verifies a BackendServiceList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceList;

                    /**
                     * Creates a plain object from a BackendServiceList message. Also converts values to other types if specified.
                     * @param message BackendServiceList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceLocalityLoadBalancingPolicyConfig. */
                interface IBackendServiceLocalityLoadBalancingPolicyConfig {

                    /** BackendServiceLocalityLoadBalancingPolicyConfig customPolicy */
                    customPolicy?: (google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfig policy */
                    policy?: (google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigPolicy|null);
                }

                /** Represents a BackendServiceLocalityLoadBalancingPolicyConfig. */
                class BackendServiceLocalityLoadBalancingPolicyConfig implements IBackendServiceLocalityLoadBalancingPolicyConfig {

                    /**
                     * Constructs a new BackendServiceLocalityLoadBalancingPolicyConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfig);

                    /** BackendServiceLocalityLoadBalancingPolicyConfig customPolicy. */
                    public customPolicy?: (google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfig policy. */
                    public policy?: (google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigPolicy|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfig _customPolicy. */
                    public _customPolicy?: "customPolicy";

                    /** BackendServiceLocalityLoadBalancingPolicyConfig _policy. */
                    public _policy?: "policy";

                    /**
                     * Creates a new BackendServiceLocalityLoadBalancingPolicyConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfig): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig;

                    /**
                     * Encodes the specified BackendServiceLocalityLoadBalancingPolicyConfig message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig.verify|verify} messages.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceLocalityLoadBalancingPolicyConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig.verify|verify} messages.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceLocalityLoadBalancingPolicyConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig;

                    /**
                     * Decodes a BackendServiceLocalityLoadBalancingPolicyConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig;

                    /**
                     * Verifies a BackendServiceLocalityLoadBalancingPolicyConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceLocalityLoadBalancingPolicyConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig;

                    /**
                     * Creates a plain object from a BackendServiceLocalityLoadBalancingPolicyConfig message. Also converts values to other types if specified.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceLocalityLoadBalancingPolicyConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceLocalityLoadBalancingPolicyConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy. */
                interface IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy {

                    /** BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy data */
                    data?: (string|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy name */
                    name?: (string|null);
                }

                /** Represents a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy. */
                class BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy implements IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy {

                    /**
                     * Constructs a new BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy);

                    /** BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy data. */
                    public data?: (string|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy name. */
                    public name?: (string|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy _data. */
                    public _data?: "data";

                    /** BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy _name. */
                    public _name?: "name";

                    /**
                     * Creates a new BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy;

                    /**
                     * Encodes the specified BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.verify|verify} messages.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.verify|verify} messages.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy;

                    /**
                     * Decodes a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy;

                    /**
                     * Verifies a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy;

                    /**
                     * Creates a plain object from a BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy message. Also converts values to other types if specified.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceLocalityLoadBalancingPolicyConfigPolicy. */
                interface IBackendServiceLocalityLoadBalancingPolicyConfigPolicy {

                    /** BackendServiceLocalityLoadBalancingPolicyConfigPolicy name */
                    name?: (string|null);
                }

                /** Represents a BackendServiceLocalityLoadBalancingPolicyConfigPolicy. */
                class BackendServiceLocalityLoadBalancingPolicyConfigPolicy implements IBackendServiceLocalityLoadBalancingPolicyConfigPolicy {

                    /**
                     * Constructs a new BackendServiceLocalityLoadBalancingPolicyConfigPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigPolicy);

                    /** BackendServiceLocalityLoadBalancingPolicyConfigPolicy name. */
                    public name?: (string|null);

                    /** BackendServiceLocalityLoadBalancingPolicyConfigPolicy _name. */
                    public _name?: "name";

                    /**
                     * Creates a new BackendServiceLocalityLoadBalancingPolicyConfigPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigPolicy): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy;

                    /**
                     * Encodes the specified BackendServiceLocalityLoadBalancingPolicyConfigPolicy message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy.verify|verify} messages.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfigPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceLocalityLoadBalancingPolicyConfigPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy.verify|verify} messages.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfigPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceLocalityLoadBalancingPolicyConfigPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceLocalityLoadBalancingPolicyConfigPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy;

                    /**
                     * Decodes a BackendServiceLocalityLoadBalancingPolicyConfigPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy;

                    /**
                     * Verifies a BackendServiceLocalityLoadBalancingPolicyConfigPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceLocalityLoadBalancingPolicyConfigPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceLocalityLoadBalancingPolicyConfigPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy;

                    /**
                     * Creates a plain object from a BackendServiceLocalityLoadBalancingPolicyConfigPolicy message. Also converts values to other types if specified.
                     * @param message BackendServiceLocalityLoadBalancingPolicyConfigPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceLocalityLoadBalancingPolicyConfigPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceLocalityLoadBalancingPolicyConfigPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceLocalityLoadBalancingPolicyConfigPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BackendServiceLocalityLoadBalancingPolicyConfigPolicy {

                    /** Name enum. */
                    enum Name {
                        UNDEFINED_NAME = 0,
                        INVALID_LB_POLICY = 323318707,
                        LEAST_REQUEST = 46604921,
                        MAGLEV = 119180266,
                        ORIGINAL_DESTINATION = 166297216,
                        RANDOM = 262527171,
                        RING_HASH = 432795069,
                        ROUND_ROBIN = 153895801
                    }
                }

                /** Properties of a BackendServiceLogConfig. */
                interface IBackendServiceLogConfig {

                    /** BackendServiceLogConfig enable */
                    enable?: (boolean|null);

                    /** BackendServiceLogConfig sampleRate */
                    sampleRate?: (number|null);
                }

                /** Represents a BackendServiceLogConfig. */
                class BackendServiceLogConfig implements IBackendServiceLogConfig {

                    /**
                     * Constructs a new BackendServiceLogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceLogConfig);

                    /** BackendServiceLogConfig enable. */
                    public enable?: (boolean|null);

                    /** BackendServiceLogConfig sampleRate. */
                    public sampleRate?: (number|null);

                    /** BackendServiceLogConfig _enable. */
                    public _enable?: "enable";

                    /** BackendServiceLogConfig _sampleRate. */
                    public _sampleRate?: "sampleRate";

                    /**
                     * Creates a new BackendServiceLogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceLogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceLogConfig): google.cloud.compute.v1.BackendServiceLogConfig;

                    /**
                     * Encodes the specified BackendServiceLogConfig message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLogConfig.verify|verify} messages.
                     * @param message BackendServiceLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceLogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceLogConfig.verify|verify} messages.
                     * @param message BackendServiceLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceLogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceLogConfig;

                    /**
                     * Decodes a BackendServiceLogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceLogConfig;

                    /**
                     * Verifies a BackendServiceLogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceLogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceLogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceLogConfig;

                    /**
                     * Creates a plain object from a BackendServiceLogConfig message. Also converts values to other types if specified.
                     * @param message BackendServiceLogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceLogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceLogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceLogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServiceReference. */
                interface IBackendServiceReference {

                    /** BackendServiceReference backendService */
                    backendService?: (string|null);
                }

                /** Represents a BackendServiceReference. */
                class BackendServiceReference implements IBackendServiceReference {

                    /**
                     * Constructs a new BackendServiceReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServiceReference);

                    /** BackendServiceReference backendService. */
                    public backendService?: (string|null);

                    /** BackendServiceReference _backendService. */
                    public _backendService?: "backendService";

                    /**
                     * Creates a new BackendServiceReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServiceReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServiceReference): google.cloud.compute.v1.BackendServiceReference;

                    /**
                     * Encodes the specified BackendServiceReference message. Does not implicitly {@link google.cloud.compute.v1.BackendServiceReference.verify|verify} messages.
                     * @param message BackendServiceReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServiceReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServiceReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServiceReference.verify|verify} messages.
                     * @param message BackendServiceReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServiceReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServiceReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServiceReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServiceReference;

                    /**
                     * Decodes a BackendServiceReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServiceReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServiceReference;

                    /**
                     * Verifies a BackendServiceReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServiceReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServiceReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServiceReference;

                    /**
                     * Creates a plain object from a BackendServiceReference message. Also converts values to other types if specified.
                     * @param message BackendServiceReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServiceReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServiceReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServiceReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BackendServicesScopedList. */
                interface IBackendServicesScopedList {

                    /** BackendServicesScopedList backendServices */
                    backendServices?: (google.cloud.compute.v1.IBackendService[]|null);

                    /** BackendServicesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a BackendServicesScopedList. */
                class BackendServicesScopedList implements IBackendServicesScopedList {

                    /**
                     * Constructs a new BackendServicesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBackendServicesScopedList);

                    /** BackendServicesScopedList backendServices. */
                    public backendServices: google.cloud.compute.v1.IBackendService[];

                    /** BackendServicesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** BackendServicesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new BackendServicesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BackendServicesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBackendServicesScopedList): google.cloud.compute.v1.BackendServicesScopedList;

                    /**
                     * Encodes the specified BackendServicesScopedList message. Does not implicitly {@link google.cloud.compute.v1.BackendServicesScopedList.verify|verify} messages.
                     * @param message BackendServicesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBackendServicesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BackendServicesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BackendServicesScopedList.verify|verify} messages.
                     * @param message BackendServicesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBackendServicesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BackendServicesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BackendServicesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BackendServicesScopedList;

                    /**
                     * Decodes a BackendServicesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BackendServicesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BackendServicesScopedList;

                    /**
                     * Verifies a BackendServicesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BackendServicesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BackendServicesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BackendServicesScopedList;

                    /**
                     * Creates a plain object from a BackendServicesScopedList message. Also converts values to other types if specified.
                     * @param message BackendServicesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BackendServicesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BackendServicesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BackendServicesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BfdPacket. */
                interface IBfdPacket {

                    /** BfdPacket authenticationPresent */
                    authenticationPresent?: (boolean|null);

                    /** BfdPacket controlPlaneIndependent */
                    controlPlaneIndependent?: (boolean|null);

                    /** BfdPacket demand */
                    demand?: (boolean|null);

                    /** BfdPacket diagnostic */
                    diagnostic?: (string|null);

                    /** BfdPacket final */
                    final?: (boolean|null);

                    /** BfdPacket length */
                    length?: (number|null);

                    /** BfdPacket minEchoRxIntervalMs */
                    minEchoRxIntervalMs?: (number|null);

                    /** BfdPacket minRxIntervalMs */
                    minRxIntervalMs?: (number|null);

                    /** BfdPacket minTxIntervalMs */
                    minTxIntervalMs?: (number|null);

                    /** BfdPacket multiplier */
                    multiplier?: (number|null);

                    /** BfdPacket multipoint */
                    multipoint?: (boolean|null);

                    /** BfdPacket myDiscriminator */
                    myDiscriminator?: (number|null);

                    /** BfdPacket poll */
                    poll?: (boolean|null);

                    /** BfdPacket state */
                    state?: (string|null);

                    /** BfdPacket version */
                    version?: (number|null);

                    /** BfdPacket yourDiscriminator */
                    yourDiscriminator?: (number|null);
                }

                /** Represents a BfdPacket. */
                class BfdPacket implements IBfdPacket {

                    /**
                     * Constructs a new BfdPacket.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBfdPacket);

                    /** BfdPacket authenticationPresent. */
                    public authenticationPresent?: (boolean|null);

                    /** BfdPacket controlPlaneIndependent. */
                    public controlPlaneIndependent?: (boolean|null);

                    /** BfdPacket demand. */
                    public demand?: (boolean|null);

                    /** BfdPacket diagnostic. */
                    public diagnostic?: (string|null);

                    /** BfdPacket final. */
                    public final?: (boolean|null);

                    /** BfdPacket length. */
                    public length?: (number|null);

                    /** BfdPacket minEchoRxIntervalMs. */
                    public minEchoRxIntervalMs?: (number|null);

                    /** BfdPacket minRxIntervalMs. */
                    public minRxIntervalMs?: (number|null);

                    /** BfdPacket minTxIntervalMs. */
                    public minTxIntervalMs?: (number|null);

                    /** BfdPacket multiplier. */
                    public multiplier?: (number|null);

                    /** BfdPacket multipoint. */
                    public multipoint?: (boolean|null);

                    /** BfdPacket myDiscriminator. */
                    public myDiscriminator?: (number|null);

                    /** BfdPacket poll. */
                    public poll?: (boolean|null);

                    /** BfdPacket state. */
                    public state?: (string|null);

                    /** BfdPacket version. */
                    public version?: (number|null);

                    /** BfdPacket yourDiscriminator. */
                    public yourDiscriminator?: (number|null);

                    /** BfdPacket _authenticationPresent. */
                    public _authenticationPresent?: "authenticationPresent";

                    /** BfdPacket _controlPlaneIndependent. */
                    public _controlPlaneIndependent?: "controlPlaneIndependent";

                    /** BfdPacket _demand. */
                    public _demand?: "demand";

                    /** BfdPacket _diagnostic. */
                    public _diagnostic?: "diagnostic";

                    /** BfdPacket _final. */
                    public _final?: "final";

                    /** BfdPacket _length. */
                    public _length?: "length";

                    /** BfdPacket _minEchoRxIntervalMs. */
                    public _minEchoRxIntervalMs?: "minEchoRxIntervalMs";

                    /** BfdPacket _minRxIntervalMs. */
                    public _minRxIntervalMs?: "minRxIntervalMs";

                    /** BfdPacket _minTxIntervalMs. */
                    public _minTxIntervalMs?: "minTxIntervalMs";

                    /** BfdPacket _multiplier. */
                    public _multiplier?: "multiplier";

                    /** BfdPacket _multipoint. */
                    public _multipoint?: "multipoint";

                    /** BfdPacket _myDiscriminator. */
                    public _myDiscriminator?: "myDiscriminator";

                    /** BfdPacket _poll. */
                    public _poll?: "poll";

                    /** BfdPacket _state. */
                    public _state?: "state";

                    /** BfdPacket _version. */
                    public _version?: "version";

                    /** BfdPacket _yourDiscriminator. */
                    public _yourDiscriminator?: "yourDiscriminator";

                    /**
                     * Creates a new BfdPacket instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BfdPacket instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBfdPacket): google.cloud.compute.v1.BfdPacket;

                    /**
                     * Encodes the specified BfdPacket message. Does not implicitly {@link google.cloud.compute.v1.BfdPacket.verify|verify} messages.
                     * @param message BfdPacket message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBfdPacket, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BfdPacket message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BfdPacket.verify|verify} messages.
                     * @param message BfdPacket message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBfdPacket, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BfdPacket message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BfdPacket
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BfdPacket;

                    /**
                     * Decodes a BfdPacket message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BfdPacket
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BfdPacket;

                    /**
                     * Verifies a BfdPacket message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BfdPacket message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BfdPacket
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BfdPacket;

                    /**
                     * Creates a plain object from a BfdPacket message. Also converts values to other types if specified.
                     * @param message BfdPacket
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BfdPacket, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BfdPacket to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BfdPacket
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BfdPacket {

                    /** Diagnostic enum. */
                    enum Diagnostic {
                        UNDEFINED_DIAGNOSTIC = 0,
                        ADMINISTRATIVELY_DOWN = 121685798,
                        CONCATENATED_PATH_DOWN = 26186892,
                        CONTROL_DETECTION_TIME_EXPIRED = 135478383,
                        DIAGNOSTIC_UNSPECIFIED = 58720895,
                        ECHO_FUNCTION_FAILED = 220687466,
                        FORWARDING_PLANE_RESET = 19715882,
                        NEIGHBOR_SIGNALED_SESSION_DOWN = 374226742,
                        NO_DIAGNOSTIC = 222503141,
                        PATH_DOWN = 290605180,
                        REVERSE_CONCATENATED_PATH_DOWN = 479337129
                    }

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ADMIN_DOWN = 128544690,
                        DOWN = 2104482,
                        INIT = 2252048,
                        STATE_UNSPECIFIED = 470755401,
                        UP = 2715
                    }
                }

                /** Properties of a BfdStatus. */
                interface IBfdStatus {

                    /** BfdStatus bfdSessionInitializationMode */
                    bfdSessionInitializationMode?: (string|null);

                    /** BfdStatus configUpdateTimestampMicros */
                    configUpdateTimestampMicros?: (number|Long|string|null);

                    /** BfdStatus controlPacketCounts */
                    controlPacketCounts?: (google.cloud.compute.v1.IBfdStatusPacketCounts|null);

                    /** BfdStatus controlPacketIntervals */
                    controlPacketIntervals?: (google.cloud.compute.v1.IPacketIntervals[]|null);

                    /** BfdStatus localDiagnostic */
                    localDiagnostic?: (string|null);

                    /** BfdStatus localState */
                    localState?: (string|null);

                    /** BfdStatus negotiatedLocalControlTxIntervalMs */
                    negotiatedLocalControlTxIntervalMs?: (number|null);

                    /** BfdStatus rxPacket */
                    rxPacket?: (google.cloud.compute.v1.IBfdPacket|null);

                    /** BfdStatus txPacket */
                    txPacket?: (google.cloud.compute.v1.IBfdPacket|null);

                    /** BfdStatus uptimeMs */
                    uptimeMs?: (number|Long|string|null);
                }

                /** Represents a BfdStatus. */
                class BfdStatus implements IBfdStatus {

                    /**
                     * Constructs a new BfdStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBfdStatus);

                    /** BfdStatus bfdSessionInitializationMode. */
                    public bfdSessionInitializationMode?: (string|null);

                    /** BfdStatus configUpdateTimestampMicros. */
                    public configUpdateTimestampMicros?: (number|Long|string|null);

                    /** BfdStatus controlPacketCounts. */
                    public controlPacketCounts?: (google.cloud.compute.v1.IBfdStatusPacketCounts|null);

                    /** BfdStatus controlPacketIntervals. */
                    public controlPacketIntervals: google.cloud.compute.v1.IPacketIntervals[];

                    /** BfdStatus localDiagnostic. */
                    public localDiagnostic?: (string|null);

                    /** BfdStatus localState. */
                    public localState?: (string|null);

                    /** BfdStatus negotiatedLocalControlTxIntervalMs. */
                    public negotiatedLocalControlTxIntervalMs?: (number|null);

                    /** BfdStatus rxPacket. */
                    public rxPacket?: (google.cloud.compute.v1.IBfdPacket|null);

                    /** BfdStatus txPacket. */
                    public txPacket?: (google.cloud.compute.v1.IBfdPacket|null);

                    /** BfdStatus uptimeMs. */
                    public uptimeMs?: (number|Long|string|null);

                    /** BfdStatus _bfdSessionInitializationMode. */
                    public _bfdSessionInitializationMode?: "bfdSessionInitializationMode";

                    /** BfdStatus _configUpdateTimestampMicros. */
                    public _configUpdateTimestampMicros?: "configUpdateTimestampMicros";

                    /** BfdStatus _controlPacketCounts. */
                    public _controlPacketCounts?: "controlPacketCounts";

                    /** BfdStatus _localDiagnostic. */
                    public _localDiagnostic?: "localDiagnostic";

                    /** BfdStatus _localState. */
                    public _localState?: "localState";

                    /** BfdStatus _negotiatedLocalControlTxIntervalMs. */
                    public _negotiatedLocalControlTxIntervalMs?: "negotiatedLocalControlTxIntervalMs";

                    /** BfdStatus _rxPacket. */
                    public _rxPacket?: "rxPacket";

                    /** BfdStatus _txPacket. */
                    public _txPacket?: "txPacket";

                    /** BfdStatus _uptimeMs. */
                    public _uptimeMs?: "uptimeMs";

                    /**
                     * Creates a new BfdStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BfdStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBfdStatus): google.cloud.compute.v1.BfdStatus;

                    /**
                     * Encodes the specified BfdStatus message. Does not implicitly {@link google.cloud.compute.v1.BfdStatus.verify|verify} messages.
                     * @param message BfdStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBfdStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BfdStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BfdStatus.verify|verify} messages.
                     * @param message BfdStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBfdStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BfdStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BfdStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BfdStatus;

                    /**
                     * Decodes a BfdStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BfdStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BfdStatus;

                    /**
                     * Verifies a BfdStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BfdStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BfdStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BfdStatus;

                    /**
                     * Creates a plain object from a BfdStatus message. Also converts values to other types if specified.
                     * @param message BfdStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BfdStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BfdStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BfdStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BfdStatus {

                    /** BfdSessionInitializationMode enum. */
                    enum BfdSessionInitializationMode {
                        UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0,
                        ACTIVE = 314733318,
                        DISABLED = 516696700,
                        PASSIVE = 462813959
                    }

                    /** LocalDiagnostic enum. */
                    enum LocalDiagnostic {
                        UNDEFINED_LOCAL_DIAGNOSTIC = 0,
                        ADMINISTRATIVELY_DOWN = 121685798,
                        CONCATENATED_PATH_DOWN = 26186892,
                        CONTROL_DETECTION_TIME_EXPIRED = 135478383,
                        DIAGNOSTIC_UNSPECIFIED = 58720895,
                        ECHO_FUNCTION_FAILED = 220687466,
                        FORWARDING_PLANE_RESET = 19715882,
                        NEIGHBOR_SIGNALED_SESSION_DOWN = 374226742,
                        NO_DIAGNOSTIC = 222503141,
                        PATH_DOWN = 290605180,
                        REVERSE_CONCATENATED_PATH_DOWN = 479337129
                    }

                    /** LocalState enum. */
                    enum LocalState {
                        UNDEFINED_LOCAL_STATE = 0,
                        ADMIN_DOWN = 128544690,
                        DOWN = 2104482,
                        INIT = 2252048,
                        STATE_UNSPECIFIED = 470755401,
                        UP = 2715
                    }
                }

                /** Properties of a BfdStatusPacketCounts. */
                interface IBfdStatusPacketCounts {

                    /** BfdStatusPacketCounts numRx */
                    numRx?: (number|null);

                    /** BfdStatusPacketCounts numRxRejected */
                    numRxRejected?: (number|null);

                    /** BfdStatusPacketCounts numRxSuccessful */
                    numRxSuccessful?: (number|null);

                    /** BfdStatusPacketCounts numTx */
                    numTx?: (number|null);
                }

                /** Represents a BfdStatusPacketCounts. */
                class BfdStatusPacketCounts implements IBfdStatusPacketCounts {

                    /**
                     * Constructs a new BfdStatusPacketCounts.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBfdStatusPacketCounts);

                    /** BfdStatusPacketCounts numRx. */
                    public numRx?: (number|null);

                    /** BfdStatusPacketCounts numRxRejected. */
                    public numRxRejected?: (number|null);

                    /** BfdStatusPacketCounts numRxSuccessful. */
                    public numRxSuccessful?: (number|null);

                    /** BfdStatusPacketCounts numTx. */
                    public numTx?: (number|null);

                    /** BfdStatusPacketCounts _numRx. */
                    public _numRx?: "numRx";

                    /** BfdStatusPacketCounts _numRxRejected. */
                    public _numRxRejected?: "numRxRejected";

                    /** BfdStatusPacketCounts _numRxSuccessful. */
                    public _numRxSuccessful?: "numRxSuccessful";

                    /** BfdStatusPacketCounts _numTx. */
                    public _numTx?: "numTx";

                    /**
                     * Creates a new BfdStatusPacketCounts instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BfdStatusPacketCounts instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBfdStatusPacketCounts): google.cloud.compute.v1.BfdStatusPacketCounts;

                    /**
                     * Encodes the specified BfdStatusPacketCounts message. Does not implicitly {@link google.cloud.compute.v1.BfdStatusPacketCounts.verify|verify} messages.
                     * @param message BfdStatusPacketCounts message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBfdStatusPacketCounts, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BfdStatusPacketCounts message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BfdStatusPacketCounts.verify|verify} messages.
                     * @param message BfdStatusPacketCounts message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBfdStatusPacketCounts, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BfdStatusPacketCounts message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BfdStatusPacketCounts
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BfdStatusPacketCounts;

                    /**
                     * Decodes a BfdStatusPacketCounts message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BfdStatusPacketCounts
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BfdStatusPacketCounts;

                    /**
                     * Verifies a BfdStatusPacketCounts message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BfdStatusPacketCounts message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BfdStatusPacketCounts
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BfdStatusPacketCounts;

                    /**
                     * Creates a plain object from a BfdStatusPacketCounts message. Also converts values to other types if specified.
                     * @param message BfdStatusPacketCounts
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BfdStatusPacketCounts, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BfdStatusPacketCounts to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BfdStatusPacketCounts
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Binding. */
                interface IBinding {

                    /** Binding bindingId */
                    bindingId?: (string|null);

                    /** Binding condition */
                    condition?: (google.cloud.compute.v1.IExpr|null);

                    /** Binding members */
                    members?: (string[]|null);

                    /** Binding role */
                    role?: (string|null);
                }

                /** Represents a Binding. */
                class Binding implements IBinding {

                    /**
                     * Constructs a new Binding.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBinding);

                    /** Binding bindingId. */
                    public bindingId?: (string|null);

                    /** Binding condition. */
                    public condition?: (google.cloud.compute.v1.IExpr|null);

                    /** Binding members. */
                    public members: string[];

                    /** Binding role. */
                    public role?: (string|null);

                    /** Binding _bindingId. */
                    public _bindingId?: "bindingId";

                    /** Binding _condition. */
                    public _condition?: "condition";

                    /** Binding _role. */
                    public _role?: "role";

                    /**
                     * Creates a new Binding instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Binding instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBinding): google.cloud.compute.v1.Binding;

                    /**
                     * Encodes the specified Binding message. Does not implicitly {@link google.cloud.compute.v1.Binding.verify|verify} messages.
                     * @param message Binding message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBinding, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Binding message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Binding.verify|verify} messages.
                     * @param message Binding message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBinding, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Binding message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Binding
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Binding;

                    /**
                     * Decodes a Binding message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Binding
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Binding;

                    /**
                     * Verifies a Binding message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Binding message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Binding
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Binding;

                    /**
                     * Creates a plain object from a Binding message. Also converts values to other types if specified.
                     * @param message Binding
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Binding, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Binding to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Binding
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BulkInsertInstanceRequest. */
                interface IBulkInsertInstanceRequest {

                    /** BulkInsertInstanceRequest bulkInsertInstanceResourceResource */
                    bulkInsertInstanceResourceResource?: (google.cloud.compute.v1.IBulkInsertInstanceResource|null);

                    /** BulkInsertInstanceRequest project */
                    project?: (string|null);

                    /** BulkInsertInstanceRequest requestId */
                    requestId?: (string|null);

                    /** BulkInsertInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a BulkInsertInstanceRequest. */
                class BulkInsertInstanceRequest implements IBulkInsertInstanceRequest {

                    /**
                     * Constructs a new BulkInsertInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBulkInsertInstanceRequest);

                    /** BulkInsertInstanceRequest bulkInsertInstanceResourceResource. */
                    public bulkInsertInstanceResourceResource?: (google.cloud.compute.v1.IBulkInsertInstanceResource|null);

                    /** BulkInsertInstanceRequest project. */
                    public project: string;

                    /** BulkInsertInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** BulkInsertInstanceRequest zone. */
                    public zone: string;

                    /** BulkInsertInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new BulkInsertInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BulkInsertInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBulkInsertInstanceRequest): google.cloud.compute.v1.BulkInsertInstanceRequest;

                    /**
                     * Encodes the specified BulkInsertInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.BulkInsertInstanceRequest.verify|verify} messages.
                     * @param message BulkInsertInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBulkInsertInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BulkInsertInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BulkInsertInstanceRequest.verify|verify} messages.
                     * @param message BulkInsertInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBulkInsertInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BulkInsertInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BulkInsertInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BulkInsertInstanceRequest;

                    /**
                     * Decodes a BulkInsertInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BulkInsertInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BulkInsertInstanceRequest;

                    /**
                     * Verifies a BulkInsertInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BulkInsertInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BulkInsertInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BulkInsertInstanceRequest;

                    /**
                     * Creates a plain object from a BulkInsertInstanceRequest message. Also converts values to other types if specified.
                     * @param message BulkInsertInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BulkInsertInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BulkInsertInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BulkInsertInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BulkInsertInstanceResource. */
                interface IBulkInsertInstanceResource {

                    /** BulkInsertInstanceResource count */
                    count?: (number|Long|string|null);

                    /** BulkInsertInstanceResource instanceProperties */
                    instanceProperties?: (google.cloud.compute.v1.IInstanceProperties|null);

                    /** BulkInsertInstanceResource locationPolicy */
                    locationPolicy?: (google.cloud.compute.v1.ILocationPolicy|null);

                    /** BulkInsertInstanceResource minCount */
                    minCount?: (number|Long|string|null);

                    /** BulkInsertInstanceResource namePattern */
                    namePattern?: (string|null);

                    /** BulkInsertInstanceResource perInstanceProperties */
                    perInstanceProperties?: ({ [k: string]: google.cloud.compute.v1.IBulkInsertInstanceResourcePerInstanceProperties }|null);

                    /** BulkInsertInstanceResource sourceInstanceTemplate */
                    sourceInstanceTemplate?: (string|null);
                }

                /** Represents a BulkInsertInstanceResource. */
                class BulkInsertInstanceResource implements IBulkInsertInstanceResource {

                    /**
                     * Constructs a new BulkInsertInstanceResource.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBulkInsertInstanceResource);

                    /** BulkInsertInstanceResource count. */
                    public count?: (number|Long|string|null);

                    /** BulkInsertInstanceResource instanceProperties. */
                    public instanceProperties?: (google.cloud.compute.v1.IInstanceProperties|null);

                    /** BulkInsertInstanceResource locationPolicy. */
                    public locationPolicy?: (google.cloud.compute.v1.ILocationPolicy|null);

                    /** BulkInsertInstanceResource minCount. */
                    public minCount?: (number|Long|string|null);

                    /** BulkInsertInstanceResource namePattern. */
                    public namePattern?: (string|null);

                    /** BulkInsertInstanceResource perInstanceProperties. */
                    public perInstanceProperties: { [k: string]: google.cloud.compute.v1.IBulkInsertInstanceResourcePerInstanceProperties };

                    /** BulkInsertInstanceResource sourceInstanceTemplate. */
                    public sourceInstanceTemplate?: (string|null);

                    /** BulkInsertInstanceResource _count. */
                    public _count?: "count";

                    /** BulkInsertInstanceResource _instanceProperties. */
                    public _instanceProperties?: "instanceProperties";

                    /** BulkInsertInstanceResource _locationPolicy. */
                    public _locationPolicy?: "locationPolicy";

                    /** BulkInsertInstanceResource _minCount. */
                    public _minCount?: "minCount";

                    /** BulkInsertInstanceResource _namePattern. */
                    public _namePattern?: "namePattern";

                    /** BulkInsertInstanceResource _sourceInstanceTemplate. */
                    public _sourceInstanceTemplate?: "sourceInstanceTemplate";

                    /**
                     * Creates a new BulkInsertInstanceResource instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BulkInsertInstanceResource instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBulkInsertInstanceResource): google.cloud.compute.v1.BulkInsertInstanceResource;

                    /**
                     * Encodes the specified BulkInsertInstanceResource message. Does not implicitly {@link google.cloud.compute.v1.BulkInsertInstanceResource.verify|verify} messages.
                     * @param message BulkInsertInstanceResource message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBulkInsertInstanceResource, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BulkInsertInstanceResource message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BulkInsertInstanceResource.verify|verify} messages.
                     * @param message BulkInsertInstanceResource message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBulkInsertInstanceResource, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BulkInsertInstanceResource message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BulkInsertInstanceResource
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BulkInsertInstanceResource;

                    /**
                     * Decodes a BulkInsertInstanceResource message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BulkInsertInstanceResource
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BulkInsertInstanceResource;

                    /**
                     * Verifies a BulkInsertInstanceResource message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BulkInsertInstanceResource message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BulkInsertInstanceResource
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BulkInsertInstanceResource;

                    /**
                     * Creates a plain object from a BulkInsertInstanceResource message. Also converts values to other types if specified.
                     * @param message BulkInsertInstanceResource
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BulkInsertInstanceResource, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BulkInsertInstanceResource to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BulkInsertInstanceResource
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BulkInsertInstanceResourcePerInstanceProperties. */
                interface IBulkInsertInstanceResourcePerInstanceProperties {

                    /** BulkInsertInstanceResourcePerInstanceProperties name */
                    name?: (string|null);
                }

                /** Represents a BulkInsertInstanceResourcePerInstanceProperties. */
                class BulkInsertInstanceResourcePerInstanceProperties implements IBulkInsertInstanceResourcePerInstanceProperties {

                    /**
                     * Constructs a new BulkInsertInstanceResourcePerInstanceProperties.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBulkInsertInstanceResourcePerInstanceProperties);

                    /** BulkInsertInstanceResourcePerInstanceProperties name. */
                    public name?: (string|null);

                    /** BulkInsertInstanceResourcePerInstanceProperties _name. */
                    public _name?: "name";

                    /**
                     * Creates a new BulkInsertInstanceResourcePerInstanceProperties instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BulkInsertInstanceResourcePerInstanceProperties instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBulkInsertInstanceResourcePerInstanceProperties): google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties;

                    /**
                     * Encodes the specified BulkInsertInstanceResourcePerInstanceProperties message. Does not implicitly {@link google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties.verify|verify} messages.
                     * @param message BulkInsertInstanceResourcePerInstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBulkInsertInstanceResourcePerInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BulkInsertInstanceResourcePerInstanceProperties message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties.verify|verify} messages.
                     * @param message BulkInsertInstanceResourcePerInstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBulkInsertInstanceResourcePerInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BulkInsertInstanceResourcePerInstanceProperties message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BulkInsertInstanceResourcePerInstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties;

                    /**
                     * Decodes a BulkInsertInstanceResourcePerInstanceProperties message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BulkInsertInstanceResourcePerInstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties;

                    /**
                     * Verifies a BulkInsertInstanceResourcePerInstanceProperties message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BulkInsertInstanceResourcePerInstanceProperties message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BulkInsertInstanceResourcePerInstanceProperties
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties;

                    /**
                     * Creates a plain object from a BulkInsertInstanceResourcePerInstanceProperties message. Also converts values to other types if specified.
                     * @param message BulkInsertInstanceResourcePerInstanceProperties
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BulkInsertInstanceResourcePerInstanceProperties, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BulkInsertInstanceResourcePerInstanceProperties to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BulkInsertInstanceResourcePerInstanceProperties
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BulkInsertRegionInstanceRequest. */
                interface IBulkInsertRegionInstanceRequest {

                    /** BulkInsertRegionInstanceRequest bulkInsertInstanceResourceResource */
                    bulkInsertInstanceResourceResource?: (google.cloud.compute.v1.IBulkInsertInstanceResource|null);

                    /** BulkInsertRegionInstanceRequest project */
                    project?: (string|null);

                    /** BulkInsertRegionInstanceRequest region */
                    region?: (string|null);

                    /** BulkInsertRegionInstanceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a BulkInsertRegionInstanceRequest. */
                class BulkInsertRegionInstanceRequest implements IBulkInsertRegionInstanceRequest {

                    /**
                     * Constructs a new BulkInsertRegionInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IBulkInsertRegionInstanceRequest);

                    /** BulkInsertRegionInstanceRequest bulkInsertInstanceResourceResource. */
                    public bulkInsertInstanceResourceResource?: (google.cloud.compute.v1.IBulkInsertInstanceResource|null);

                    /** BulkInsertRegionInstanceRequest project. */
                    public project: string;

                    /** BulkInsertRegionInstanceRequest region. */
                    public region: string;

                    /** BulkInsertRegionInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** BulkInsertRegionInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new BulkInsertRegionInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BulkInsertRegionInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IBulkInsertRegionInstanceRequest): google.cloud.compute.v1.BulkInsertRegionInstanceRequest;

                    /**
                     * Encodes the specified BulkInsertRegionInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.BulkInsertRegionInstanceRequest.verify|verify} messages.
                     * @param message BulkInsertRegionInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IBulkInsertRegionInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BulkInsertRegionInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.BulkInsertRegionInstanceRequest.verify|verify} messages.
                     * @param message BulkInsertRegionInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IBulkInsertRegionInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BulkInsertRegionInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BulkInsertRegionInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.BulkInsertRegionInstanceRequest;

                    /**
                     * Decodes a BulkInsertRegionInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BulkInsertRegionInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.BulkInsertRegionInstanceRequest;

                    /**
                     * Verifies a BulkInsertRegionInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BulkInsertRegionInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BulkInsertRegionInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.BulkInsertRegionInstanceRequest;

                    /**
                     * Creates a plain object from a BulkInsertRegionInstanceRequest message. Also converts values to other types if specified.
                     * @param message BulkInsertRegionInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.BulkInsertRegionInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BulkInsertRegionInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BulkInsertRegionInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CacheInvalidationRule. */
                interface ICacheInvalidationRule {

                    /** CacheInvalidationRule host */
                    host?: (string|null);

                    /** CacheInvalidationRule path */
                    path?: (string|null);
                }

                /** Represents a CacheInvalidationRule. */
                class CacheInvalidationRule implements ICacheInvalidationRule {

                    /**
                     * Constructs a new CacheInvalidationRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICacheInvalidationRule);

                    /** CacheInvalidationRule host. */
                    public host?: (string|null);

                    /** CacheInvalidationRule path. */
                    public path?: (string|null);

                    /** CacheInvalidationRule _host. */
                    public _host?: "host";

                    /** CacheInvalidationRule _path. */
                    public _path?: "path";

                    /**
                     * Creates a new CacheInvalidationRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CacheInvalidationRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICacheInvalidationRule): google.cloud.compute.v1.CacheInvalidationRule;

                    /**
                     * Encodes the specified CacheInvalidationRule message. Does not implicitly {@link google.cloud.compute.v1.CacheInvalidationRule.verify|verify} messages.
                     * @param message CacheInvalidationRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICacheInvalidationRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CacheInvalidationRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CacheInvalidationRule.verify|verify} messages.
                     * @param message CacheInvalidationRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICacheInvalidationRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CacheInvalidationRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CacheInvalidationRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CacheInvalidationRule;

                    /**
                     * Decodes a CacheInvalidationRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CacheInvalidationRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CacheInvalidationRule;

                    /**
                     * Verifies a CacheInvalidationRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CacheInvalidationRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CacheInvalidationRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CacheInvalidationRule;

                    /**
                     * Creates a plain object from a CacheInvalidationRule message. Also converts values to other types if specified.
                     * @param message CacheInvalidationRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CacheInvalidationRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CacheInvalidationRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CacheInvalidationRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CacheKeyPolicy. */
                interface ICacheKeyPolicy {

                    /** CacheKeyPolicy includeHost */
                    includeHost?: (boolean|null);

                    /** CacheKeyPolicy includeHttpHeaders */
                    includeHttpHeaders?: (string[]|null);

                    /** CacheKeyPolicy includeNamedCookies */
                    includeNamedCookies?: (string[]|null);

                    /** CacheKeyPolicy includeProtocol */
                    includeProtocol?: (boolean|null);

                    /** CacheKeyPolicy includeQueryString */
                    includeQueryString?: (boolean|null);

                    /** CacheKeyPolicy queryStringBlacklist */
                    queryStringBlacklist?: (string[]|null);

                    /** CacheKeyPolicy queryStringWhitelist */
                    queryStringWhitelist?: (string[]|null);
                }

                /** Represents a CacheKeyPolicy. */
                class CacheKeyPolicy implements ICacheKeyPolicy {

                    /**
                     * Constructs a new CacheKeyPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICacheKeyPolicy);

                    /** CacheKeyPolicy includeHost. */
                    public includeHost?: (boolean|null);

                    /** CacheKeyPolicy includeHttpHeaders. */
                    public includeHttpHeaders: string[];

                    /** CacheKeyPolicy includeNamedCookies. */
                    public includeNamedCookies: string[];

                    /** CacheKeyPolicy includeProtocol. */
                    public includeProtocol?: (boolean|null);

                    /** CacheKeyPolicy includeQueryString. */
                    public includeQueryString?: (boolean|null);

                    /** CacheKeyPolicy queryStringBlacklist. */
                    public queryStringBlacklist: string[];

                    /** CacheKeyPolicy queryStringWhitelist. */
                    public queryStringWhitelist: string[];

                    /** CacheKeyPolicy _includeHost. */
                    public _includeHost?: "includeHost";

                    /** CacheKeyPolicy _includeProtocol. */
                    public _includeProtocol?: "includeProtocol";

                    /** CacheKeyPolicy _includeQueryString. */
                    public _includeQueryString?: "includeQueryString";

                    /**
                     * Creates a new CacheKeyPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CacheKeyPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICacheKeyPolicy): google.cloud.compute.v1.CacheKeyPolicy;

                    /**
                     * Encodes the specified CacheKeyPolicy message. Does not implicitly {@link google.cloud.compute.v1.CacheKeyPolicy.verify|verify} messages.
                     * @param message CacheKeyPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICacheKeyPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CacheKeyPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CacheKeyPolicy.verify|verify} messages.
                     * @param message CacheKeyPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICacheKeyPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CacheKeyPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CacheKeyPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CacheKeyPolicy;

                    /**
                     * Decodes a CacheKeyPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CacheKeyPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CacheKeyPolicy;

                    /**
                     * Verifies a CacheKeyPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CacheKeyPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CacheKeyPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CacheKeyPolicy;

                    /**
                     * Creates a plain object from a CacheKeyPolicy message. Also converts values to other types if specified.
                     * @param message CacheKeyPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CacheKeyPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CacheKeyPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CacheKeyPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CircuitBreakers. */
                interface ICircuitBreakers {

                    /** CircuitBreakers maxConnections */
                    maxConnections?: (number|null);

                    /** CircuitBreakers maxPendingRequests */
                    maxPendingRequests?: (number|null);

                    /** CircuitBreakers maxRequests */
                    maxRequests?: (number|null);

                    /** CircuitBreakers maxRequestsPerConnection */
                    maxRequestsPerConnection?: (number|null);

                    /** CircuitBreakers maxRetries */
                    maxRetries?: (number|null);
                }

                /** Represents a CircuitBreakers. */
                class CircuitBreakers implements ICircuitBreakers {

                    /**
                     * Constructs a new CircuitBreakers.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICircuitBreakers);

                    /** CircuitBreakers maxConnections. */
                    public maxConnections?: (number|null);

                    /** CircuitBreakers maxPendingRequests. */
                    public maxPendingRequests?: (number|null);

                    /** CircuitBreakers maxRequests. */
                    public maxRequests?: (number|null);

                    /** CircuitBreakers maxRequestsPerConnection. */
                    public maxRequestsPerConnection?: (number|null);

                    /** CircuitBreakers maxRetries. */
                    public maxRetries?: (number|null);

                    /** CircuitBreakers _maxConnections. */
                    public _maxConnections?: "maxConnections";

                    /** CircuitBreakers _maxPendingRequests. */
                    public _maxPendingRequests?: "maxPendingRequests";

                    /** CircuitBreakers _maxRequests. */
                    public _maxRequests?: "maxRequests";

                    /** CircuitBreakers _maxRequestsPerConnection. */
                    public _maxRequestsPerConnection?: "maxRequestsPerConnection";

                    /** CircuitBreakers _maxRetries. */
                    public _maxRetries?: "maxRetries";

                    /**
                     * Creates a new CircuitBreakers instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CircuitBreakers instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICircuitBreakers): google.cloud.compute.v1.CircuitBreakers;

                    /**
                     * Encodes the specified CircuitBreakers message. Does not implicitly {@link google.cloud.compute.v1.CircuitBreakers.verify|verify} messages.
                     * @param message CircuitBreakers message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICircuitBreakers, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CircuitBreakers message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CircuitBreakers.verify|verify} messages.
                     * @param message CircuitBreakers message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICircuitBreakers, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CircuitBreakers message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CircuitBreakers
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CircuitBreakers;

                    /**
                     * Decodes a CircuitBreakers message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CircuitBreakers
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CircuitBreakers;

                    /**
                     * Verifies a CircuitBreakers message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CircuitBreakers message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CircuitBreakers
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CircuitBreakers;

                    /**
                     * Creates a plain object from a CircuitBreakers message. Also converts values to other types if specified.
                     * @param message CircuitBreakers
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CircuitBreakers, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CircuitBreakers to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CircuitBreakers
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CloneRulesFirewallPolicyRequest. */
                interface ICloneRulesFirewallPolicyRequest {

                    /** CloneRulesFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** CloneRulesFirewallPolicyRequest requestId */
                    requestId?: (string|null);

                    /** CloneRulesFirewallPolicyRequest sourceFirewallPolicy */
                    sourceFirewallPolicy?: (string|null);
                }

                /** Represents a CloneRulesFirewallPolicyRequest. */
                class CloneRulesFirewallPolicyRequest implements ICloneRulesFirewallPolicyRequest {

                    /**
                     * Constructs a new CloneRulesFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICloneRulesFirewallPolicyRequest);

                    /** CloneRulesFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** CloneRulesFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** CloneRulesFirewallPolicyRequest sourceFirewallPolicy. */
                    public sourceFirewallPolicy?: (string|null);

                    /** CloneRulesFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /** CloneRulesFirewallPolicyRequest _sourceFirewallPolicy. */
                    public _sourceFirewallPolicy?: "sourceFirewallPolicy";

                    /**
                     * Creates a new CloneRulesFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CloneRulesFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICloneRulesFirewallPolicyRequest): google.cloud.compute.v1.CloneRulesFirewallPolicyRequest;

                    /**
                     * Encodes the specified CloneRulesFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.CloneRulesFirewallPolicyRequest.verify|verify} messages.
                     * @param message CloneRulesFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICloneRulesFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CloneRulesFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CloneRulesFirewallPolicyRequest.verify|verify} messages.
                     * @param message CloneRulesFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICloneRulesFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CloneRulesFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CloneRulesFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CloneRulesFirewallPolicyRequest;

                    /**
                     * Decodes a CloneRulesFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CloneRulesFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CloneRulesFirewallPolicyRequest;

                    /**
                     * Verifies a CloneRulesFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CloneRulesFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CloneRulesFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CloneRulesFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a CloneRulesFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message CloneRulesFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CloneRulesFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CloneRulesFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CloneRulesFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CloneRulesNetworkFirewallPolicyRequest. */
                interface ICloneRulesNetworkFirewallPolicyRequest {

                    /** CloneRulesNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** CloneRulesNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** CloneRulesNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);

                    /** CloneRulesNetworkFirewallPolicyRequest sourceFirewallPolicy */
                    sourceFirewallPolicy?: (string|null);
                }

                /** Represents a CloneRulesNetworkFirewallPolicyRequest. */
                class CloneRulesNetworkFirewallPolicyRequest implements ICloneRulesNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new CloneRulesNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICloneRulesNetworkFirewallPolicyRequest);

                    /** CloneRulesNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** CloneRulesNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** CloneRulesNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** CloneRulesNetworkFirewallPolicyRequest sourceFirewallPolicy. */
                    public sourceFirewallPolicy?: (string|null);

                    /** CloneRulesNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /** CloneRulesNetworkFirewallPolicyRequest _sourceFirewallPolicy. */
                    public _sourceFirewallPolicy?: "sourceFirewallPolicy";

                    /**
                     * Creates a new CloneRulesNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CloneRulesNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICloneRulesNetworkFirewallPolicyRequest): google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified CloneRulesNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message CloneRulesNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICloneRulesNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CloneRulesNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message CloneRulesNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICloneRulesNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CloneRulesNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CloneRulesNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a CloneRulesNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CloneRulesNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a CloneRulesNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CloneRulesNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CloneRulesNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a CloneRulesNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message CloneRulesNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CloneRulesNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CloneRulesNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CloneRulesNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CloneRulesRegionNetworkFirewallPolicyRequest. */
                interface ICloneRulesRegionNetworkFirewallPolicyRequest {

                    /** CloneRulesRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest sourceFirewallPolicy */
                    sourceFirewallPolicy?: (string|null);
                }

                /** Represents a CloneRulesRegionNetworkFirewallPolicyRequest. */
                class CloneRulesRegionNetworkFirewallPolicyRequest implements ICloneRulesRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new CloneRulesRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICloneRulesRegionNetworkFirewallPolicyRequest);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** CloneRulesRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** CloneRulesRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** CloneRulesRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest sourceFirewallPolicy. */
                    public sourceFirewallPolicy?: (string|null);

                    /** CloneRulesRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /** CloneRulesRegionNetworkFirewallPolicyRequest _sourceFirewallPolicy. */
                    public _sourceFirewallPolicy?: "sourceFirewallPolicy";

                    /**
                     * Creates a new CloneRulesRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CloneRulesRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICloneRulesRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified CloneRulesRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message CloneRulesRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICloneRulesRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CloneRulesRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message CloneRulesRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICloneRulesRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CloneRulesRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CloneRulesRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a CloneRulesRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CloneRulesRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a CloneRulesRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CloneRulesRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CloneRulesRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a CloneRulesRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message CloneRulesRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CloneRulesRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CloneRulesRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CloneRulesRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Commitment. */
                interface ICommitment {

                    /** Commitment autoRenew */
                    autoRenew?: (boolean|null);

                    /** Commitment category */
                    category?: (string|null);

                    /** Commitment creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Commitment description */
                    description?: (string|null);

                    /** Commitment endTimestamp */
                    endTimestamp?: (string|null);

                    /** Commitment id */
                    id?: (number|Long|string|null);

                    /** Commitment kind */
                    kind?: (string|null);

                    /** Commitment licenseResource */
                    licenseResource?: (google.cloud.compute.v1.ILicenseResourceCommitment|null);

                    /** Commitment mergeSourceCommitments */
                    mergeSourceCommitments?: (string[]|null);

                    /** Commitment name */
                    name?: (string|null);

                    /** Commitment plan */
                    plan?: (string|null);

                    /** Commitment region */
                    region?: (string|null);

                    /** Commitment reservations */
                    reservations?: (google.cloud.compute.v1.IReservation[]|null);

                    /** Commitment resources */
                    resources?: (google.cloud.compute.v1.IResourceCommitment[]|null);

                    /** Commitment selfLink */
                    selfLink?: (string|null);

                    /** Commitment splitSourceCommitment */
                    splitSourceCommitment?: (string|null);

                    /** Commitment startTimestamp */
                    startTimestamp?: (string|null);

                    /** Commitment status */
                    status?: (string|null);

                    /** Commitment statusMessage */
                    statusMessage?: (string|null);

                    /** Commitment type */
                    type?: (string|null);
                }

                /** Represents a Commitment. */
                class Commitment implements ICommitment {

                    /**
                     * Constructs a new Commitment.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICommitment);

                    /** Commitment autoRenew. */
                    public autoRenew?: (boolean|null);

                    /** Commitment category. */
                    public category?: (string|null);

                    /** Commitment creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Commitment description. */
                    public description?: (string|null);

                    /** Commitment endTimestamp. */
                    public endTimestamp?: (string|null);

                    /** Commitment id. */
                    public id?: (number|Long|string|null);

                    /** Commitment kind. */
                    public kind?: (string|null);

                    /** Commitment licenseResource. */
                    public licenseResource?: (google.cloud.compute.v1.ILicenseResourceCommitment|null);

                    /** Commitment mergeSourceCommitments. */
                    public mergeSourceCommitments: string[];

                    /** Commitment name. */
                    public name?: (string|null);

                    /** Commitment plan. */
                    public plan?: (string|null);

                    /** Commitment region. */
                    public region?: (string|null);

                    /** Commitment reservations. */
                    public reservations: google.cloud.compute.v1.IReservation[];

                    /** Commitment resources. */
                    public resources: google.cloud.compute.v1.IResourceCommitment[];

                    /** Commitment selfLink. */
                    public selfLink?: (string|null);

                    /** Commitment splitSourceCommitment. */
                    public splitSourceCommitment?: (string|null);

                    /** Commitment startTimestamp. */
                    public startTimestamp?: (string|null);

                    /** Commitment status. */
                    public status?: (string|null);

                    /** Commitment statusMessage. */
                    public statusMessage?: (string|null);

                    /** Commitment type. */
                    public type?: (string|null);

                    /** Commitment _autoRenew. */
                    public _autoRenew?: "autoRenew";

                    /** Commitment _category. */
                    public _category?: "category";

                    /** Commitment _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Commitment _description. */
                    public _description?: "description";

                    /** Commitment _endTimestamp. */
                    public _endTimestamp?: "endTimestamp";

                    /** Commitment _id. */
                    public _id?: "id";

                    /** Commitment _kind. */
                    public _kind?: "kind";

                    /** Commitment _licenseResource. */
                    public _licenseResource?: "licenseResource";

                    /** Commitment _name. */
                    public _name?: "name";

                    /** Commitment _plan. */
                    public _plan?: "plan";

                    /** Commitment _region. */
                    public _region?: "region";

                    /** Commitment _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Commitment _splitSourceCommitment. */
                    public _splitSourceCommitment?: "splitSourceCommitment";

                    /** Commitment _startTimestamp. */
                    public _startTimestamp?: "startTimestamp";

                    /** Commitment _status. */
                    public _status?: "status";

                    /** Commitment _statusMessage. */
                    public _statusMessage?: "statusMessage";

                    /** Commitment _type. */
                    public _type?: "type";

                    /**
                     * Creates a new Commitment instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Commitment instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICommitment): google.cloud.compute.v1.Commitment;

                    /**
                     * Encodes the specified Commitment message. Does not implicitly {@link google.cloud.compute.v1.Commitment.verify|verify} messages.
                     * @param message Commitment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICommitment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Commitment message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Commitment.verify|verify} messages.
                     * @param message Commitment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICommitment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Commitment message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Commitment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Commitment;

                    /**
                     * Decodes a Commitment message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Commitment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Commitment;

                    /**
                     * Verifies a Commitment message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Commitment message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Commitment
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Commitment;

                    /**
                     * Creates a plain object from a Commitment message. Also converts values to other types if specified.
                     * @param message Commitment
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Commitment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Commitment to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Commitment
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Commitment {

                    /** Category enum. */
                    enum Category {
                        UNDEFINED_CATEGORY = 0,
                        CATEGORY_UNSPECIFIED = 509189462,
                        LICENSE = 347869217,
                        MACHINE = 469553191
                    }

                    /** Plan enum. */
                    enum Plan {
                        UNDEFINED_PLAN = 0,
                        INVALID = 530283991,
                        THIRTY_SIX_MONTH = 266295942,
                        TWELVE_MONTH = 173083962
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ACTIVE = 314733318,
                        CANCELLED = 41957681,
                        CREATING = 455564985,
                        EXPIRED = 482489093,
                        NOT_YET_ACTIVE = 20607337
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        ACCELERATOR_OPTIMIZED = 280848403,
                        COMPUTE_OPTIMIZED = 158349023,
                        COMPUTE_OPTIMIZED_C2D = 383246453,
                        GENERAL_PURPOSE = 299793543,
                        GENERAL_PURPOSE_E2 = 301911877,
                        GENERAL_PURPOSE_N2 = 301912156,
                        GENERAL_PURPOSE_N2D = 232471400,
                        GENERAL_PURPOSE_T2D = 232477166,
                        MEMORY_OPTIMIZED = 281753417,
                        MEMORY_OPTIMIZED_M3 = 276301372,
                        TYPE_UNSPECIFIED = 437714322
                    }
                }

                /** Properties of a CommitmentAggregatedList. */
                interface ICommitmentAggregatedList {

                    /** CommitmentAggregatedList id */
                    id?: (string|null);

                    /** CommitmentAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ICommitmentsScopedList }|null);

                    /** CommitmentAggregatedList kind */
                    kind?: (string|null);

                    /** CommitmentAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** CommitmentAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** CommitmentAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** CommitmentAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a CommitmentAggregatedList. */
                class CommitmentAggregatedList implements ICommitmentAggregatedList {

                    /**
                     * Constructs a new CommitmentAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICommitmentAggregatedList);

                    /** CommitmentAggregatedList id. */
                    public id?: (string|null);

                    /** CommitmentAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ICommitmentsScopedList };

                    /** CommitmentAggregatedList kind. */
                    public kind?: (string|null);

                    /** CommitmentAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** CommitmentAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** CommitmentAggregatedList unreachables. */
                    public unreachables: string[];

                    /** CommitmentAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** CommitmentAggregatedList _id. */
                    public _id?: "id";

                    /** CommitmentAggregatedList _kind. */
                    public _kind?: "kind";

                    /** CommitmentAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** CommitmentAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** CommitmentAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new CommitmentAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CommitmentAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICommitmentAggregatedList): google.cloud.compute.v1.CommitmentAggregatedList;

                    /**
                     * Encodes the specified CommitmentAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.CommitmentAggregatedList.verify|verify} messages.
                     * @param message CommitmentAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICommitmentAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CommitmentAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CommitmentAggregatedList.verify|verify} messages.
                     * @param message CommitmentAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICommitmentAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CommitmentAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CommitmentAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CommitmentAggregatedList;

                    /**
                     * Decodes a CommitmentAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CommitmentAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CommitmentAggregatedList;

                    /**
                     * Verifies a CommitmentAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CommitmentAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CommitmentAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CommitmentAggregatedList;

                    /**
                     * Creates a plain object from a CommitmentAggregatedList message. Also converts values to other types if specified.
                     * @param message CommitmentAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CommitmentAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CommitmentAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CommitmentAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CommitmentList. */
                interface ICommitmentList {

                    /** CommitmentList id */
                    id?: (string|null);

                    /** CommitmentList items */
                    items?: (google.cloud.compute.v1.ICommitment[]|null);

                    /** CommitmentList kind */
                    kind?: (string|null);

                    /** CommitmentList nextPageToken */
                    nextPageToken?: (string|null);

                    /** CommitmentList selfLink */
                    selfLink?: (string|null);

                    /** CommitmentList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a CommitmentList. */
                class CommitmentList implements ICommitmentList {

                    /**
                     * Constructs a new CommitmentList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICommitmentList);

                    /** CommitmentList id. */
                    public id?: (string|null);

                    /** CommitmentList items. */
                    public items: google.cloud.compute.v1.ICommitment[];

                    /** CommitmentList kind. */
                    public kind?: (string|null);

                    /** CommitmentList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** CommitmentList selfLink. */
                    public selfLink?: (string|null);

                    /** CommitmentList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** CommitmentList _id. */
                    public _id?: "id";

                    /** CommitmentList _kind. */
                    public _kind?: "kind";

                    /** CommitmentList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** CommitmentList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** CommitmentList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new CommitmentList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CommitmentList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICommitmentList): google.cloud.compute.v1.CommitmentList;

                    /**
                     * Encodes the specified CommitmentList message. Does not implicitly {@link google.cloud.compute.v1.CommitmentList.verify|verify} messages.
                     * @param message CommitmentList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICommitmentList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CommitmentList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CommitmentList.verify|verify} messages.
                     * @param message CommitmentList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICommitmentList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CommitmentList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CommitmentList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CommitmentList;

                    /**
                     * Decodes a CommitmentList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CommitmentList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CommitmentList;

                    /**
                     * Verifies a CommitmentList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CommitmentList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CommitmentList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CommitmentList;

                    /**
                     * Creates a plain object from a CommitmentList message. Also converts values to other types if specified.
                     * @param message CommitmentList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CommitmentList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CommitmentList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CommitmentList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CommitmentsScopedList. */
                interface ICommitmentsScopedList {

                    /** CommitmentsScopedList commitments */
                    commitments?: (google.cloud.compute.v1.ICommitment[]|null);

                    /** CommitmentsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a CommitmentsScopedList. */
                class CommitmentsScopedList implements ICommitmentsScopedList {

                    /**
                     * Constructs a new CommitmentsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICommitmentsScopedList);

                    /** CommitmentsScopedList commitments. */
                    public commitments: google.cloud.compute.v1.ICommitment[];

                    /** CommitmentsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** CommitmentsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new CommitmentsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CommitmentsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICommitmentsScopedList): google.cloud.compute.v1.CommitmentsScopedList;

                    /**
                     * Encodes the specified CommitmentsScopedList message. Does not implicitly {@link google.cloud.compute.v1.CommitmentsScopedList.verify|verify} messages.
                     * @param message CommitmentsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICommitmentsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CommitmentsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CommitmentsScopedList.verify|verify} messages.
                     * @param message CommitmentsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICommitmentsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CommitmentsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CommitmentsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CommitmentsScopedList;

                    /**
                     * Decodes a CommitmentsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CommitmentsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CommitmentsScopedList;

                    /**
                     * Verifies a CommitmentsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CommitmentsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CommitmentsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CommitmentsScopedList;

                    /**
                     * Creates a plain object from a CommitmentsScopedList message. Also converts values to other types if specified.
                     * @param message CommitmentsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CommitmentsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CommitmentsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CommitmentsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Condition. */
                interface ICondition {

                    /** Condition iam */
                    iam?: (string|null);

                    /** Condition op */
                    op?: (string|null);

                    /** Condition svc */
                    svc?: (string|null);

                    /** Condition sys */
                    sys?: (string|null);

                    /** Condition values */
                    values?: (string[]|null);
                }

                /** Represents a Condition. */
                class Condition implements ICondition {

                    /**
                     * Constructs a new Condition.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICondition);

                    /** Condition iam. */
                    public iam?: (string|null);

                    /** Condition op. */
                    public op?: (string|null);

                    /** Condition svc. */
                    public svc?: (string|null);

                    /** Condition sys. */
                    public sys?: (string|null);

                    /** Condition values. */
                    public values: string[];

                    /** Condition _iam. */
                    public _iam?: "iam";

                    /** Condition _op. */
                    public _op?: "op";

                    /** Condition _svc. */
                    public _svc?: "svc";

                    /** Condition _sys. */
                    public _sys?: "sys";

                    /**
                     * Creates a new Condition instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Condition instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICondition): google.cloud.compute.v1.Condition;

                    /**
                     * Encodes the specified Condition message. Does not implicitly {@link google.cloud.compute.v1.Condition.verify|verify} messages.
                     * @param message Condition message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICondition, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Condition message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Condition.verify|verify} messages.
                     * @param message Condition message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICondition, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Condition message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Condition
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Condition;

                    /**
                     * Decodes a Condition message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Condition
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Condition;

                    /**
                     * Verifies a Condition message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Condition message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Condition
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Condition;

                    /**
                     * Creates a plain object from a Condition message. Also converts values to other types if specified.
                     * @param message Condition
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Condition, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Condition to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Condition
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Condition {

                    /** Iam enum. */
                    enum Iam {
                        UNDEFINED_IAM = 0,
                        APPROVER = 357258949,
                        ATTRIBUTION = 232465503,
                        AUTHORITY = 504108835,
                        CREDENTIALS_TYPE = 348222141,
                        CREDS_ASSERTION = 332343272,
                        JUSTIFICATION_TYPE = 206147719,
                        SECURITY_REALM = 526269616
                    }

                    /** Op enum. */
                    enum Op {
                        UNDEFINED_OP = 0,
                        DISCHARGED = 266338274,
                        EQUALS = 442201023,
                        IN = 2341,
                        NOT_EQUALS = 19718859,
                        NOT_IN = 161144369,
                        NO_OP = 74481951
                    }

                    /** Sys enum. */
                    enum Sys {
                        UNDEFINED_SYS = 0,
                        IP = 2343,
                        NAME = 2388619,
                        REGION = 266017524,
                        SERVICE = 17781397
                    }
                }

                /** Properties of a ConfidentialInstanceConfig. */
                interface IConfidentialInstanceConfig {

                    /** ConfidentialInstanceConfig enableConfidentialCompute */
                    enableConfidentialCompute?: (boolean|null);
                }

                /** Represents a ConfidentialInstanceConfig. */
                class ConfidentialInstanceConfig implements IConfidentialInstanceConfig {

                    /**
                     * Constructs a new ConfidentialInstanceConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IConfidentialInstanceConfig);

                    /** ConfidentialInstanceConfig enableConfidentialCompute. */
                    public enableConfidentialCompute?: (boolean|null);

                    /** ConfidentialInstanceConfig _enableConfidentialCompute. */
                    public _enableConfidentialCompute?: "enableConfidentialCompute";

                    /**
                     * Creates a new ConfidentialInstanceConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ConfidentialInstanceConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IConfidentialInstanceConfig): google.cloud.compute.v1.ConfidentialInstanceConfig;

                    /**
                     * Encodes the specified ConfidentialInstanceConfig message. Does not implicitly {@link google.cloud.compute.v1.ConfidentialInstanceConfig.verify|verify} messages.
                     * @param message ConfidentialInstanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IConfidentialInstanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ConfidentialInstanceConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ConfidentialInstanceConfig.verify|verify} messages.
                     * @param message ConfidentialInstanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IConfidentialInstanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ConfidentialInstanceConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ConfidentialInstanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ConfidentialInstanceConfig;

                    /**
                     * Decodes a ConfidentialInstanceConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ConfidentialInstanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ConfidentialInstanceConfig;

                    /**
                     * Verifies a ConfidentialInstanceConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ConfidentialInstanceConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ConfidentialInstanceConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ConfidentialInstanceConfig;

                    /**
                     * Creates a plain object from a ConfidentialInstanceConfig message. Also converts values to other types if specified.
                     * @param message ConfidentialInstanceConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ConfidentialInstanceConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ConfidentialInstanceConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ConfidentialInstanceConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ConnectionDraining. */
                interface IConnectionDraining {

                    /** ConnectionDraining drainingTimeoutSec */
                    drainingTimeoutSec?: (number|null);
                }

                /** Represents a ConnectionDraining. */
                class ConnectionDraining implements IConnectionDraining {

                    /**
                     * Constructs a new ConnectionDraining.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IConnectionDraining);

                    /** ConnectionDraining drainingTimeoutSec. */
                    public drainingTimeoutSec?: (number|null);

                    /** ConnectionDraining _drainingTimeoutSec. */
                    public _drainingTimeoutSec?: "drainingTimeoutSec";

                    /**
                     * Creates a new ConnectionDraining instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ConnectionDraining instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IConnectionDraining): google.cloud.compute.v1.ConnectionDraining;

                    /**
                     * Encodes the specified ConnectionDraining message. Does not implicitly {@link google.cloud.compute.v1.ConnectionDraining.verify|verify} messages.
                     * @param message ConnectionDraining message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IConnectionDraining, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ConnectionDraining message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ConnectionDraining.verify|verify} messages.
                     * @param message ConnectionDraining message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IConnectionDraining, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ConnectionDraining message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ConnectionDraining
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ConnectionDraining;

                    /**
                     * Decodes a ConnectionDraining message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ConnectionDraining
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ConnectionDraining;

                    /**
                     * Verifies a ConnectionDraining message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ConnectionDraining message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ConnectionDraining
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ConnectionDraining;

                    /**
                     * Creates a plain object from a ConnectionDraining message. Also converts values to other types if specified.
                     * @param message ConnectionDraining
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ConnectionDraining, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ConnectionDraining to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ConnectionDraining
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ConsistentHashLoadBalancerSettings. */
                interface IConsistentHashLoadBalancerSettings {

                    /** ConsistentHashLoadBalancerSettings httpCookie */
                    httpCookie?: (google.cloud.compute.v1.IConsistentHashLoadBalancerSettingsHttpCookie|null);

                    /** ConsistentHashLoadBalancerSettings httpHeaderName */
                    httpHeaderName?: (string|null);

                    /** ConsistentHashLoadBalancerSettings minimumRingSize */
                    minimumRingSize?: (number|Long|string|null);
                }

                /** Represents a ConsistentHashLoadBalancerSettings. */
                class ConsistentHashLoadBalancerSettings implements IConsistentHashLoadBalancerSettings {

                    /**
                     * Constructs a new ConsistentHashLoadBalancerSettings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IConsistentHashLoadBalancerSettings);

                    /** ConsistentHashLoadBalancerSettings httpCookie. */
                    public httpCookie?: (google.cloud.compute.v1.IConsistentHashLoadBalancerSettingsHttpCookie|null);

                    /** ConsistentHashLoadBalancerSettings httpHeaderName. */
                    public httpHeaderName?: (string|null);

                    /** ConsistentHashLoadBalancerSettings minimumRingSize. */
                    public minimumRingSize?: (number|Long|string|null);

                    /** ConsistentHashLoadBalancerSettings _httpCookie. */
                    public _httpCookie?: "httpCookie";

                    /** ConsistentHashLoadBalancerSettings _httpHeaderName. */
                    public _httpHeaderName?: "httpHeaderName";

                    /** ConsistentHashLoadBalancerSettings _minimumRingSize. */
                    public _minimumRingSize?: "minimumRingSize";

                    /**
                     * Creates a new ConsistentHashLoadBalancerSettings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ConsistentHashLoadBalancerSettings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IConsistentHashLoadBalancerSettings): google.cloud.compute.v1.ConsistentHashLoadBalancerSettings;

                    /**
                     * Encodes the specified ConsistentHashLoadBalancerSettings message. Does not implicitly {@link google.cloud.compute.v1.ConsistentHashLoadBalancerSettings.verify|verify} messages.
                     * @param message ConsistentHashLoadBalancerSettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IConsistentHashLoadBalancerSettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ConsistentHashLoadBalancerSettings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ConsistentHashLoadBalancerSettings.verify|verify} messages.
                     * @param message ConsistentHashLoadBalancerSettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IConsistentHashLoadBalancerSettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ConsistentHashLoadBalancerSettings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ConsistentHashLoadBalancerSettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ConsistentHashLoadBalancerSettings;

                    /**
                     * Decodes a ConsistentHashLoadBalancerSettings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ConsistentHashLoadBalancerSettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ConsistentHashLoadBalancerSettings;

                    /**
                     * Verifies a ConsistentHashLoadBalancerSettings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ConsistentHashLoadBalancerSettings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ConsistentHashLoadBalancerSettings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ConsistentHashLoadBalancerSettings;

                    /**
                     * Creates a plain object from a ConsistentHashLoadBalancerSettings message. Also converts values to other types if specified.
                     * @param message ConsistentHashLoadBalancerSettings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ConsistentHashLoadBalancerSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ConsistentHashLoadBalancerSettings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ConsistentHashLoadBalancerSettings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ConsistentHashLoadBalancerSettingsHttpCookie. */
                interface IConsistentHashLoadBalancerSettingsHttpCookie {

                    /** ConsistentHashLoadBalancerSettingsHttpCookie name */
                    name?: (string|null);

                    /** ConsistentHashLoadBalancerSettingsHttpCookie path */
                    path?: (string|null);

                    /** ConsistentHashLoadBalancerSettingsHttpCookie ttl */
                    ttl?: (google.cloud.compute.v1.IDuration|null);
                }

                /** Represents a ConsistentHashLoadBalancerSettingsHttpCookie. */
                class ConsistentHashLoadBalancerSettingsHttpCookie implements IConsistentHashLoadBalancerSettingsHttpCookie {

                    /**
                     * Constructs a new ConsistentHashLoadBalancerSettingsHttpCookie.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IConsistentHashLoadBalancerSettingsHttpCookie);

                    /** ConsistentHashLoadBalancerSettingsHttpCookie name. */
                    public name?: (string|null);

                    /** ConsistentHashLoadBalancerSettingsHttpCookie path. */
                    public path?: (string|null);

                    /** ConsistentHashLoadBalancerSettingsHttpCookie ttl. */
                    public ttl?: (google.cloud.compute.v1.IDuration|null);

                    /** ConsistentHashLoadBalancerSettingsHttpCookie _name. */
                    public _name?: "name";

                    /** ConsistentHashLoadBalancerSettingsHttpCookie _path. */
                    public _path?: "path";

                    /** ConsistentHashLoadBalancerSettingsHttpCookie _ttl. */
                    public _ttl?: "ttl";

                    /**
                     * Creates a new ConsistentHashLoadBalancerSettingsHttpCookie instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ConsistentHashLoadBalancerSettingsHttpCookie instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IConsistentHashLoadBalancerSettingsHttpCookie): google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie;

                    /**
                     * Encodes the specified ConsistentHashLoadBalancerSettingsHttpCookie message. Does not implicitly {@link google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie.verify|verify} messages.
                     * @param message ConsistentHashLoadBalancerSettingsHttpCookie message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IConsistentHashLoadBalancerSettingsHttpCookie, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ConsistentHashLoadBalancerSettingsHttpCookie message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie.verify|verify} messages.
                     * @param message ConsistentHashLoadBalancerSettingsHttpCookie message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IConsistentHashLoadBalancerSettingsHttpCookie, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ConsistentHashLoadBalancerSettingsHttpCookie message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ConsistentHashLoadBalancerSettingsHttpCookie
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie;

                    /**
                     * Decodes a ConsistentHashLoadBalancerSettingsHttpCookie message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ConsistentHashLoadBalancerSettingsHttpCookie
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie;

                    /**
                     * Verifies a ConsistentHashLoadBalancerSettingsHttpCookie message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ConsistentHashLoadBalancerSettingsHttpCookie message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ConsistentHashLoadBalancerSettingsHttpCookie
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie;

                    /**
                     * Creates a plain object from a ConsistentHashLoadBalancerSettingsHttpCookie message. Also converts values to other types if specified.
                     * @param message ConsistentHashLoadBalancerSettingsHttpCookie
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ConsistentHashLoadBalancerSettingsHttpCookie, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ConsistentHashLoadBalancerSettingsHttpCookie to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ConsistentHashLoadBalancerSettingsHttpCookie
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CorsPolicy. */
                interface ICorsPolicy {

                    /** CorsPolicy allowCredentials */
                    allowCredentials?: (boolean|null);

                    /** CorsPolicy allowHeaders */
                    allowHeaders?: (string[]|null);

                    /** CorsPolicy allowMethods */
                    allowMethods?: (string[]|null);

                    /** CorsPolicy allowOriginRegexes */
                    allowOriginRegexes?: (string[]|null);

                    /** CorsPolicy allowOrigins */
                    allowOrigins?: (string[]|null);

                    /** CorsPolicy disabled */
                    disabled?: (boolean|null);

                    /** CorsPolicy exposeHeaders */
                    exposeHeaders?: (string[]|null);

                    /** CorsPolicy maxAge */
                    maxAge?: (number|null);
                }

                /** Represents a CorsPolicy. */
                class CorsPolicy implements ICorsPolicy {

                    /**
                     * Constructs a new CorsPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICorsPolicy);

                    /** CorsPolicy allowCredentials. */
                    public allowCredentials?: (boolean|null);

                    /** CorsPolicy allowHeaders. */
                    public allowHeaders: string[];

                    /** CorsPolicy allowMethods. */
                    public allowMethods: string[];

                    /** CorsPolicy allowOriginRegexes. */
                    public allowOriginRegexes: string[];

                    /** CorsPolicy allowOrigins. */
                    public allowOrigins: string[];

                    /** CorsPolicy disabled. */
                    public disabled?: (boolean|null);

                    /** CorsPolicy exposeHeaders. */
                    public exposeHeaders: string[];

                    /** CorsPolicy maxAge. */
                    public maxAge?: (number|null);

                    /** CorsPolicy _allowCredentials. */
                    public _allowCredentials?: "allowCredentials";

                    /** CorsPolicy _disabled. */
                    public _disabled?: "disabled";

                    /** CorsPolicy _maxAge. */
                    public _maxAge?: "maxAge";

                    /**
                     * Creates a new CorsPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CorsPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICorsPolicy): google.cloud.compute.v1.CorsPolicy;

                    /**
                     * Encodes the specified CorsPolicy message. Does not implicitly {@link google.cloud.compute.v1.CorsPolicy.verify|verify} messages.
                     * @param message CorsPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICorsPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CorsPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CorsPolicy.verify|verify} messages.
                     * @param message CorsPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICorsPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CorsPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CorsPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CorsPolicy;

                    /**
                     * Decodes a CorsPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CorsPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CorsPolicy;

                    /**
                     * Verifies a CorsPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CorsPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CorsPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CorsPolicy;

                    /**
                     * Creates a plain object from a CorsPolicy message. Also converts values to other types if specified.
                     * @param message CorsPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CorsPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CorsPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CorsPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CreateInstancesInstanceGroupManagerRequest. */
                interface ICreateInstancesInstanceGroupManagerRequest {

                    /** CreateInstancesInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** CreateInstancesInstanceGroupManagerRequest instanceGroupManagersCreateInstancesRequestResource */
                    instanceGroupManagersCreateInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersCreateInstancesRequest|null);

                    /** CreateInstancesInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** CreateInstancesInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** CreateInstancesInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a CreateInstancesInstanceGroupManagerRequest. */
                class CreateInstancesInstanceGroupManagerRequest implements ICreateInstancesInstanceGroupManagerRequest {

                    /**
                     * Constructs a new CreateInstancesInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest);

                    /** CreateInstancesInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** CreateInstancesInstanceGroupManagerRequest instanceGroupManagersCreateInstancesRequestResource. */
                    public instanceGroupManagersCreateInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersCreateInstancesRequest|null);

                    /** CreateInstancesInstanceGroupManagerRequest project. */
                    public project: string;

                    /** CreateInstancesInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** CreateInstancesInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** CreateInstancesInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new CreateInstancesInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CreateInstancesInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest): google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified CreateInstancesInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message CreateInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CreateInstancesInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message CreateInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CreateInstancesInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CreateInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Decodes a CreateInstancesInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CreateInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Verifies a CreateInstancesInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CreateInstancesInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CreateInstancesInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a CreateInstancesInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message CreateInstancesInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CreateInstancesInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CreateInstancesInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CreateInstancesInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CreateInstancesRegionInstanceGroupManagerRequest. */
                interface ICreateInstancesRegionInstanceGroupManagerRequest {

                    /** CreateInstancesRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** CreateInstancesRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** CreateInstancesRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** CreateInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersCreateInstancesRequestResource */
                    regionInstanceGroupManagersCreateInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersCreateInstancesRequest|null);

                    /** CreateInstancesRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a CreateInstancesRegionInstanceGroupManagerRequest. */
                class CreateInstancesRegionInstanceGroupManagerRequest implements ICreateInstancesRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new CreateInstancesRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest);

                    /** CreateInstancesRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** CreateInstancesRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** CreateInstancesRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** CreateInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersCreateInstancesRequestResource. */
                    public regionInstanceGroupManagersCreateInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersCreateInstancesRequest|null);

                    /** CreateInstancesRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** CreateInstancesRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new CreateInstancesRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CreateInstancesRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest): google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified CreateInstancesRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message CreateInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CreateInstancesRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message CreateInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CreateInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CreateInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a CreateInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CreateInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a CreateInstancesRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CreateInstancesRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CreateInstancesRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a CreateInstancesRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message CreateInstancesRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CreateInstancesRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CreateInstancesRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CreateInstancesRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CreateSnapshotDiskRequest. */
                interface ICreateSnapshotDiskRequest {

                    /** CreateSnapshotDiskRequest disk */
                    disk?: (string|null);

                    /** CreateSnapshotDiskRequest guestFlush */
                    guestFlush?: (boolean|null);

                    /** CreateSnapshotDiskRequest project */
                    project?: (string|null);

                    /** CreateSnapshotDiskRequest requestId */
                    requestId?: (string|null);

                    /** CreateSnapshotDiskRequest snapshotResource */
                    snapshotResource?: (google.cloud.compute.v1.ISnapshot|null);

                    /** CreateSnapshotDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a CreateSnapshotDiskRequest. */
                class CreateSnapshotDiskRequest implements ICreateSnapshotDiskRequest {

                    /**
                     * Constructs a new CreateSnapshotDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICreateSnapshotDiskRequest);

                    /** CreateSnapshotDiskRequest disk. */
                    public disk: string;

                    /** CreateSnapshotDiskRequest guestFlush. */
                    public guestFlush?: (boolean|null);

                    /** CreateSnapshotDiskRequest project. */
                    public project: string;

                    /** CreateSnapshotDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** CreateSnapshotDiskRequest snapshotResource. */
                    public snapshotResource?: (google.cloud.compute.v1.ISnapshot|null);

                    /** CreateSnapshotDiskRequest zone. */
                    public zone: string;

                    /** CreateSnapshotDiskRequest _guestFlush. */
                    public _guestFlush?: "guestFlush";

                    /** CreateSnapshotDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new CreateSnapshotDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CreateSnapshotDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICreateSnapshotDiskRequest): google.cloud.compute.v1.CreateSnapshotDiskRequest;

                    /**
                     * Encodes the specified CreateSnapshotDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.CreateSnapshotDiskRequest.verify|verify} messages.
                     * @param message CreateSnapshotDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICreateSnapshotDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CreateSnapshotDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CreateSnapshotDiskRequest.verify|verify} messages.
                     * @param message CreateSnapshotDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICreateSnapshotDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CreateSnapshotDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CreateSnapshotDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CreateSnapshotDiskRequest;

                    /**
                     * Decodes a CreateSnapshotDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CreateSnapshotDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CreateSnapshotDiskRequest;

                    /**
                     * Verifies a CreateSnapshotDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CreateSnapshotDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CreateSnapshotDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CreateSnapshotDiskRequest;

                    /**
                     * Creates a plain object from a CreateSnapshotDiskRequest message. Also converts values to other types if specified.
                     * @param message CreateSnapshotDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CreateSnapshotDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CreateSnapshotDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CreateSnapshotDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CreateSnapshotRegionDiskRequest. */
                interface ICreateSnapshotRegionDiskRequest {

                    /** CreateSnapshotRegionDiskRequest disk */
                    disk?: (string|null);

                    /** CreateSnapshotRegionDiskRequest project */
                    project?: (string|null);

                    /** CreateSnapshotRegionDiskRequest region */
                    region?: (string|null);

                    /** CreateSnapshotRegionDiskRequest requestId */
                    requestId?: (string|null);

                    /** CreateSnapshotRegionDiskRequest snapshotResource */
                    snapshotResource?: (google.cloud.compute.v1.ISnapshot|null);
                }

                /** Represents a CreateSnapshotRegionDiskRequest. */
                class CreateSnapshotRegionDiskRequest implements ICreateSnapshotRegionDiskRequest {

                    /**
                     * Constructs a new CreateSnapshotRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICreateSnapshotRegionDiskRequest);

                    /** CreateSnapshotRegionDiskRequest disk. */
                    public disk: string;

                    /** CreateSnapshotRegionDiskRequest project. */
                    public project: string;

                    /** CreateSnapshotRegionDiskRequest region. */
                    public region: string;

                    /** CreateSnapshotRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** CreateSnapshotRegionDiskRequest snapshotResource. */
                    public snapshotResource?: (google.cloud.compute.v1.ISnapshot|null);

                    /** CreateSnapshotRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new CreateSnapshotRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CreateSnapshotRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICreateSnapshotRegionDiskRequest): google.cloud.compute.v1.CreateSnapshotRegionDiskRequest;

                    /**
                     * Encodes the specified CreateSnapshotRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.CreateSnapshotRegionDiskRequest.verify|verify} messages.
                     * @param message CreateSnapshotRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICreateSnapshotRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CreateSnapshotRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CreateSnapshotRegionDiskRequest.verify|verify} messages.
                     * @param message CreateSnapshotRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICreateSnapshotRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CreateSnapshotRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CreateSnapshotRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CreateSnapshotRegionDiskRequest;

                    /**
                     * Decodes a CreateSnapshotRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CreateSnapshotRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CreateSnapshotRegionDiskRequest;

                    /**
                     * Verifies a CreateSnapshotRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CreateSnapshotRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CreateSnapshotRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CreateSnapshotRegionDiskRequest;

                    /**
                     * Creates a plain object from a CreateSnapshotRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message CreateSnapshotRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CreateSnapshotRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CreateSnapshotRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CreateSnapshotRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CustomerEncryptionKey. */
                interface ICustomerEncryptionKey {

                    /** CustomerEncryptionKey kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** CustomerEncryptionKey kmsKeyServiceAccount */
                    kmsKeyServiceAccount?: (string|null);

                    /** CustomerEncryptionKey rawKey */
                    rawKey?: (string|null);

                    /** CustomerEncryptionKey rsaEncryptedKey */
                    rsaEncryptedKey?: (string|null);

                    /** CustomerEncryptionKey sha256 */
                    sha256?: (string|null);
                }

                /** Represents a CustomerEncryptionKey. */
                class CustomerEncryptionKey implements ICustomerEncryptionKey {

                    /**
                     * Constructs a new CustomerEncryptionKey.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICustomerEncryptionKey);

                    /** CustomerEncryptionKey kmsKeyName. */
                    public kmsKeyName?: (string|null);

                    /** CustomerEncryptionKey kmsKeyServiceAccount. */
                    public kmsKeyServiceAccount?: (string|null);

                    /** CustomerEncryptionKey rawKey. */
                    public rawKey?: (string|null);

                    /** CustomerEncryptionKey rsaEncryptedKey. */
                    public rsaEncryptedKey?: (string|null);

                    /** CustomerEncryptionKey sha256. */
                    public sha256?: (string|null);

                    /** CustomerEncryptionKey _kmsKeyName. */
                    public _kmsKeyName?: "kmsKeyName";

                    /** CustomerEncryptionKey _kmsKeyServiceAccount. */
                    public _kmsKeyServiceAccount?: "kmsKeyServiceAccount";

                    /** CustomerEncryptionKey _rawKey. */
                    public _rawKey?: "rawKey";

                    /** CustomerEncryptionKey _rsaEncryptedKey. */
                    public _rsaEncryptedKey?: "rsaEncryptedKey";

                    /** CustomerEncryptionKey _sha256. */
                    public _sha256?: "sha256";

                    /**
                     * Creates a new CustomerEncryptionKey instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CustomerEncryptionKey instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICustomerEncryptionKey): google.cloud.compute.v1.CustomerEncryptionKey;

                    /**
                     * Encodes the specified CustomerEncryptionKey message. Does not implicitly {@link google.cloud.compute.v1.CustomerEncryptionKey.verify|verify} messages.
                     * @param message CustomerEncryptionKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICustomerEncryptionKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CustomerEncryptionKey message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CustomerEncryptionKey.verify|verify} messages.
                     * @param message CustomerEncryptionKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICustomerEncryptionKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CustomerEncryptionKey message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CustomerEncryptionKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CustomerEncryptionKey;

                    /**
                     * Decodes a CustomerEncryptionKey message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CustomerEncryptionKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CustomerEncryptionKey;

                    /**
                     * Verifies a CustomerEncryptionKey message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CustomerEncryptionKey message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CustomerEncryptionKey
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CustomerEncryptionKey;

                    /**
                     * Creates a plain object from a CustomerEncryptionKey message. Also converts values to other types if specified.
                     * @param message CustomerEncryptionKey
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CustomerEncryptionKey, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CustomerEncryptionKey to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CustomerEncryptionKey
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CustomerEncryptionKeyProtectedDisk. */
                interface ICustomerEncryptionKeyProtectedDisk {

                    /** CustomerEncryptionKeyProtectedDisk diskEncryptionKey */
                    diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** CustomerEncryptionKeyProtectedDisk source */
                    source?: (string|null);
                }

                /** Represents a CustomerEncryptionKeyProtectedDisk. */
                class CustomerEncryptionKeyProtectedDisk implements ICustomerEncryptionKeyProtectedDisk {

                    /**
                     * Constructs a new CustomerEncryptionKeyProtectedDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ICustomerEncryptionKeyProtectedDisk);

                    /** CustomerEncryptionKeyProtectedDisk diskEncryptionKey. */
                    public diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** CustomerEncryptionKeyProtectedDisk source. */
                    public source?: (string|null);

                    /** CustomerEncryptionKeyProtectedDisk _diskEncryptionKey. */
                    public _diskEncryptionKey?: "diskEncryptionKey";

                    /** CustomerEncryptionKeyProtectedDisk _source. */
                    public _source?: "source";

                    /**
                     * Creates a new CustomerEncryptionKeyProtectedDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CustomerEncryptionKeyProtectedDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ICustomerEncryptionKeyProtectedDisk): google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk;

                    /**
                     * Encodes the specified CustomerEncryptionKeyProtectedDisk message. Does not implicitly {@link google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk.verify|verify} messages.
                     * @param message CustomerEncryptionKeyProtectedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ICustomerEncryptionKeyProtectedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CustomerEncryptionKeyProtectedDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk.verify|verify} messages.
                     * @param message CustomerEncryptionKeyProtectedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ICustomerEncryptionKeyProtectedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CustomerEncryptionKeyProtectedDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CustomerEncryptionKeyProtectedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk;

                    /**
                     * Decodes a CustomerEncryptionKeyProtectedDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CustomerEncryptionKeyProtectedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk;

                    /**
                     * Verifies a CustomerEncryptionKeyProtectedDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CustomerEncryptionKeyProtectedDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CustomerEncryptionKeyProtectedDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk;

                    /**
                     * Creates a plain object from a CustomerEncryptionKeyProtectedDisk message. Also converts values to other types if specified.
                     * @param message CustomerEncryptionKeyProtectedDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.CustomerEncryptionKeyProtectedDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CustomerEncryptionKeyProtectedDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CustomerEncryptionKeyProtectedDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Data. */
                interface IData {

                    /** Data key */
                    key?: (string|null);

                    /** Data value */
                    value?: (string|null);
                }

                /** Represents a Data. */
                class Data implements IData {

                    /**
                     * Constructs a new Data.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IData);

                    /** Data key. */
                    public key?: (string|null);

                    /** Data value. */
                    public value?: (string|null);

                    /** Data _key. */
                    public _key?: "key";

                    /** Data _value. */
                    public _value?: "value";

                    /**
                     * Creates a new Data instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Data instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IData): google.cloud.compute.v1.Data;

                    /**
                     * Encodes the specified Data message. Does not implicitly {@link google.cloud.compute.v1.Data.verify|verify} messages.
                     * @param message Data message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Data message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Data.verify|verify} messages.
                     * @param message Data message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Data message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Data
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Data;

                    /**
                     * Decodes a Data message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Data
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Data;

                    /**
                     * Verifies a Data message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Data message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Data
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Data;

                    /**
                     * Creates a plain object from a Data message. Also converts values to other types if specified.
                     * @param message Data
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Data, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Data to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Data
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteAccessConfigInstanceRequest. */
                interface IDeleteAccessConfigInstanceRequest {

                    /** DeleteAccessConfigInstanceRequest accessConfig */
                    accessConfig?: (string|null);

                    /** DeleteAccessConfigInstanceRequest instance */
                    instance?: (string|null);

                    /** DeleteAccessConfigInstanceRequest networkInterface */
                    networkInterface?: (string|null);

                    /** DeleteAccessConfigInstanceRequest project */
                    project?: (string|null);

                    /** DeleteAccessConfigInstanceRequest requestId */
                    requestId?: (string|null);

                    /** DeleteAccessConfigInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteAccessConfigInstanceRequest. */
                class DeleteAccessConfigInstanceRequest implements IDeleteAccessConfigInstanceRequest {

                    /**
                     * Constructs a new DeleteAccessConfigInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteAccessConfigInstanceRequest);

                    /** DeleteAccessConfigInstanceRequest accessConfig. */
                    public accessConfig: string;

                    /** DeleteAccessConfigInstanceRequest instance. */
                    public instance: string;

                    /** DeleteAccessConfigInstanceRequest networkInterface. */
                    public networkInterface: string;

                    /** DeleteAccessConfigInstanceRequest project. */
                    public project: string;

                    /** DeleteAccessConfigInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteAccessConfigInstanceRequest zone. */
                    public zone: string;

                    /** DeleteAccessConfigInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteAccessConfigInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteAccessConfigInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteAccessConfigInstanceRequest): google.cloud.compute.v1.DeleteAccessConfigInstanceRequest;

                    /**
                     * Encodes the specified DeleteAccessConfigInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteAccessConfigInstanceRequest.verify|verify} messages.
                     * @param message DeleteAccessConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteAccessConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteAccessConfigInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteAccessConfigInstanceRequest.verify|verify} messages.
                     * @param message DeleteAccessConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteAccessConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteAccessConfigInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteAccessConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteAccessConfigInstanceRequest;

                    /**
                     * Decodes a DeleteAccessConfigInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteAccessConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteAccessConfigInstanceRequest;

                    /**
                     * Verifies a DeleteAccessConfigInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteAccessConfigInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteAccessConfigInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteAccessConfigInstanceRequest;

                    /**
                     * Creates a plain object from a DeleteAccessConfigInstanceRequest message. Also converts values to other types if specified.
                     * @param message DeleteAccessConfigInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteAccessConfigInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteAccessConfigInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteAccessConfigInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteAddressRequest. */
                interface IDeleteAddressRequest {

                    /** DeleteAddressRequest address */
                    address?: (string|null);

                    /** DeleteAddressRequest project */
                    project?: (string|null);

                    /** DeleteAddressRequest region */
                    region?: (string|null);

                    /** DeleteAddressRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteAddressRequest. */
                class DeleteAddressRequest implements IDeleteAddressRequest {

                    /**
                     * Constructs a new DeleteAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteAddressRequest);

                    /** DeleteAddressRequest address. */
                    public address: string;

                    /** DeleteAddressRequest project. */
                    public project: string;

                    /** DeleteAddressRequest region. */
                    public region: string;

                    /** DeleteAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteAddressRequest): google.cloud.compute.v1.DeleteAddressRequest;

                    /**
                     * Encodes the specified DeleteAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteAddressRequest.verify|verify} messages.
                     * @param message DeleteAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteAddressRequest.verify|verify} messages.
                     * @param message DeleteAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteAddressRequest;

                    /**
                     * Decodes a DeleteAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteAddressRequest;

                    /**
                     * Verifies a DeleteAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteAddressRequest;

                    /**
                     * Creates a plain object from a DeleteAddressRequest message. Also converts values to other types if specified.
                     * @param message DeleteAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteAutoscalerRequest. */
                interface IDeleteAutoscalerRequest {

                    /** DeleteAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** DeleteAutoscalerRequest project */
                    project?: (string|null);

                    /** DeleteAutoscalerRequest requestId */
                    requestId?: (string|null);

                    /** DeleteAutoscalerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteAutoscalerRequest. */
                class DeleteAutoscalerRequest implements IDeleteAutoscalerRequest {

                    /**
                     * Constructs a new DeleteAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteAutoscalerRequest);

                    /** DeleteAutoscalerRequest autoscaler. */
                    public autoscaler: string;

                    /** DeleteAutoscalerRequest project. */
                    public project: string;

                    /** DeleteAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteAutoscalerRequest zone. */
                    public zone: string;

                    /** DeleteAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteAutoscalerRequest): google.cloud.compute.v1.DeleteAutoscalerRequest;

                    /**
                     * Encodes the specified DeleteAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteAutoscalerRequest.verify|verify} messages.
                     * @param message DeleteAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteAutoscalerRequest.verify|verify} messages.
                     * @param message DeleteAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteAutoscalerRequest;

                    /**
                     * Decodes a DeleteAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteAutoscalerRequest;

                    /**
                     * Verifies a DeleteAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteAutoscalerRequest;

                    /**
                     * Creates a plain object from a DeleteAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message DeleteAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteBackendBucketRequest. */
                interface IDeleteBackendBucketRequest {

                    /** DeleteBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** DeleteBackendBucketRequest project */
                    project?: (string|null);

                    /** DeleteBackendBucketRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteBackendBucketRequest. */
                class DeleteBackendBucketRequest implements IDeleteBackendBucketRequest {

                    /**
                     * Constructs a new DeleteBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteBackendBucketRequest);

                    /** DeleteBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** DeleteBackendBucketRequest project. */
                    public project: string;

                    /** DeleteBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteBackendBucketRequest): google.cloud.compute.v1.DeleteBackendBucketRequest;

                    /**
                     * Encodes the specified DeleteBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteBackendBucketRequest.verify|verify} messages.
                     * @param message DeleteBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteBackendBucketRequest.verify|verify} messages.
                     * @param message DeleteBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteBackendBucketRequest;

                    /**
                     * Decodes a DeleteBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteBackendBucketRequest;

                    /**
                     * Verifies a DeleteBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteBackendBucketRequest;

                    /**
                     * Creates a plain object from a DeleteBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message DeleteBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteBackendServiceRequest. */
                interface IDeleteBackendServiceRequest {

                    /** DeleteBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** DeleteBackendServiceRequest project */
                    project?: (string|null);

                    /** DeleteBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteBackendServiceRequest. */
                class DeleteBackendServiceRequest implements IDeleteBackendServiceRequest {

                    /**
                     * Constructs a new DeleteBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteBackendServiceRequest);

                    /** DeleteBackendServiceRequest backendService. */
                    public backendService: string;

                    /** DeleteBackendServiceRequest project. */
                    public project: string;

                    /** DeleteBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteBackendServiceRequest): google.cloud.compute.v1.DeleteBackendServiceRequest;

                    /**
                     * Encodes the specified DeleteBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteBackendServiceRequest.verify|verify} messages.
                     * @param message DeleteBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteBackendServiceRequest.verify|verify} messages.
                     * @param message DeleteBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteBackendServiceRequest;

                    /**
                     * Decodes a DeleteBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteBackendServiceRequest;

                    /**
                     * Verifies a DeleteBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteBackendServiceRequest;

                    /**
                     * Creates a plain object from a DeleteBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message DeleteBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteDiskRequest. */
                interface IDeleteDiskRequest {

                    /** DeleteDiskRequest disk */
                    disk?: (string|null);

                    /** DeleteDiskRequest project */
                    project?: (string|null);

                    /** DeleteDiskRequest requestId */
                    requestId?: (string|null);

                    /** DeleteDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteDiskRequest. */
                class DeleteDiskRequest implements IDeleteDiskRequest {

                    /**
                     * Constructs a new DeleteDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteDiskRequest);

                    /** DeleteDiskRequest disk. */
                    public disk: string;

                    /** DeleteDiskRequest project. */
                    public project: string;

                    /** DeleteDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteDiskRequest zone. */
                    public zone: string;

                    /** DeleteDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteDiskRequest): google.cloud.compute.v1.DeleteDiskRequest;

                    /**
                     * Encodes the specified DeleteDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteDiskRequest.verify|verify} messages.
                     * @param message DeleteDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteDiskRequest.verify|verify} messages.
                     * @param message DeleteDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteDiskRequest;

                    /**
                     * Decodes a DeleteDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteDiskRequest;

                    /**
                     * Verifies a DeleteDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteDiskRequest;

                    /**
                     * Creates a plain object from a DeleteDiskRequest message. Also converts values to other types if specified.
                     * @param message DeleteDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteExternalVpnGatewayRequest. */
                interface IDeleteExternalVpnGatewayRequest {

                    /** DeleteExternalVpnGatewayRequest externalVpnGateway */
                    externalVpnGateway?: (string|null);

                    /** DeleteExternalVpnGatewayRequest project */
                    project?: (string|null);

                    /** DeleteExternalVpnGatewayRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteExternalVpnGatewayRequest. */
                class DeleteExternalVpnGatewayRequest implements IDeleteExternalVpnGatewayRequest {

                    /**
                     * Constructs a new DeleteExternalVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteExternalVpnGatewayRequest);

                    /** DeleteExternalVpnGatewayRequest externalVpnGateway. */
                    public externalVpnGateway: string;

                    /** DeleteExternalVpnGatewayRequest project. */
                    public project: string;

                    /** DeleteExternalVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteExternalVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteExternalVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteExternalVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteExternalVpnGatewayRequest): google.cloud.compute.v1.DeleteExternalVpnGatewayRequest;

                    /**
                     * Encodes the specified DeleteExternalVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message DeleteExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteExternalVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message DeleteExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteExternalVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteExternalVpnGatewayRequest;

                    /**
                     * Decodes a DeleteExternalVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteExternalVpnGatewayRequest;

                    /**
                     * Verifies a DeleteExternalVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteExternalVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteExternalVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteExternalVpnGatewayRequest;

                    /**
                     * Creates a plain object from a DeleteExternalVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message DeleteExternalVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteExternalVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteExternalVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteExternalVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteFirewallPolicyRequest. */
                interface IDeleteFirewallPolicyRequest {

                    /** DeleteFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** DeleteFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteFirewallPolicyRequest. */
                class DeleteFirewallPolicyRequest implements IDeleteFirewallPolicyRequest {

                    /**
                     * Constructs a new DeleteFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteFirewallPolicyRequest);

                    /** DeleteFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** DeleteFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteFirewallPolicyRequest): google.cloud.compute.v1.DeleteFirewallPolicyRequest;

                    /**
                     * Encodes the specified DeleteFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteFirewallPolicyRequest.verify|verify} messages.
                     * @param message DeleteFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteFirewallPolicyRequest.verify|verify} messages.
                     * @param message DeleteFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteFirewallPolicyRequest;

                    /**
                     * Decodes a DeleteFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteFirewallPolicyRequest;

                    /**
                     * Verifies a DeleteFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteFirewallRequest. */
                interface IDeleteFirewallRequest {

                    /** DeleteFirewallRequest firewall */
                    firewall?: (string|null);

                    /** DeleteFirewallRequest project */
                    project?: (string|null);

                    /** DeleteFirewallRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteFirewallRequest. */
                class DeleteFirewallRequest implements IDeleteFirewallRequest {

                    /**
                     * Constructs a new DeleteFirewallRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteFirewallRequest);

                    /** DeleteFirewallRequest firewall. */
                    public firewall: string;

                    /** DeleteFirewallRequest project. */
                    public project: string;

                    /** DeleteFirewallRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteFirewallRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteFirewallRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteFirewallRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteFirewallRequest): google.cloud.compute.v1.DeleteFirewallRequest;

                    /**
                     * Encodes the specified DeleteFirewallRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteFirewallRequest.verify|verify} messages.
                     * @param message DeleteFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteFirewallRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteFirewallRequest.verify|verify} messages.
                     * @param message DeleteFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteFirewallRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteFirewallRequest;

                    /**
                     * Decodes a DeleteFirewallRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteFirewallRequest;

                    /**
                     * Verifies a DeleteFirewallRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteFirewallRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteFirewallRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteFirewallRequest;

                    /**
                     * Creates a plain object from a DeleteFirewallRequest message. Also converts values to other types if specified.
                     * @param message DeleteFirewallRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteFirewallRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteFirewallRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteFirewallRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteForwardingRuleRequest. */
                interface IDeleteForwardingRuleRequest {

                    /** DeleteForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** DeleteForwardingRuleRequest project */
                    project?: (string|null);

                    /** DeleteForwardingRuleRequest region */
                    region?: (string|null);

                    /** DeleteForwardingRuleRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteForwardingRuleRequest. */
                class DeleteForwardingRuleRequest implements IDeleteForwardingRuleRequest {

                    /**
                     * Constructs a new DeleteForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteForwardingRuleRequest);

                    /** DeleteForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** DeleteForwardingRuleRequest project. */
                    public project: string;

                    /** DeleteForwardingRuleRequest region. */
                    public region: string;

                    /** DeleteForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteForwardingRuleRequest): google.cloud.compute.v1.DeleteForwardingRuleRequest;

                    /**
                     * Encodes the specified DeleteForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteForwardingRuleRequest.verify|verify} messages.
                     * @param message DeleteForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteForwardingRuleRequest.verify|verify} messages.
                     * @param message DeleteForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteForwardingRuleRequest;

                    /**
                     * Decodes a DeleteForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteForwardingRuleRequest;

                    /**
                     * Verifies a DeleteForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteForwardingRuleRequest;

                    /**
                     * Creates a plain object from a DeleteForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message DeleteForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalAddressRequest. */
                interface IDeleteGlobalAddressRequest {

                    /** DeleteGlobalAddressRequest address */
                    address?: (string|null);

                    /** DeleteGlobalAddressRequest project */
                    project?: (string|null);

                    /** DeleteGlobalAddressRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteGlobalAddressRequest. */
                class DeleteGlobalAddressRequest implements IDeleteGlobalAddressRequest {

                    /**
                     * Constructs a new DeleteGlobalAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalAddressRequest);

                    /** DeleteGlobalAddressRequest address. */
                    public address: string;

                    /** DeleteGlobalAddressRequest project. */
                    public project: string;

                    /** DeleteGlobalAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteGlobalAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteGlobalAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalAddressRequest): google.cloud.compute.v1.DeleteGlobalAddressRequest;

                    /**
                     * Encodes the specified DeleteGlobalAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalAddressRequest.verify|verify} messages.
                     * @param message DeleteGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalAddressRequest.verify|verify} messages.
                     * @param message DeleteGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalAddressRequest;

                    /**
                     * Decodes a DeleteGlobalAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalAddressRequest;

                    /**
                     * Verifies a DeleteGlobalAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalAddressRequest;

                    /**
                     * Creates a plain object from a DeleteGlobalAddressRequest message. Also converts values to other types if specified.
                     * @param message DeleteGlobalAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalForwardingRuleRequest. */
                interface IDeleteGlobalForwardingRuleRequest {

                    /** DeleteGlobalForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** DeleteGlobalForwardingRuleRequest project */
                    project?: (string|null);

                    /** DeleteGlobalForwardingRuleRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteGlobalForwardingRuleRequest. */
                class DeleteGlobalForwardingRuleRequest implements IDeleteGlobalForwardingRuleRequest {

                    /**
                     * Constructs a new DeleteGlobalForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalForwardingRuleRequest);

                    /** DeleteGlobalForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** DeleteGlobalForwardingRuleRequest project. */
                    public project: string;

                    /** DeleteGlobalForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteGlobalForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteGlobalForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalForwardingRuleRequest): google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest;

                    /**
                     * Encodes the specified DeleteGlobalForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message DeleteGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message DeleteGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest;

                    /**
                     * Decodes a DeleteGlobalForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest;

                    /**
                     * Verifies a DeleteGlobalForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest;

                    /**
                     * Creates a plain object from a DeleteGlobalForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message DeleteGlobalForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalNetworkEndpointGroupRequest. */
                interface IDeleteGlobalNetworkEndpointGroupRequest {

                    /** DeleteGlobalNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** DeleteGlobalNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** DeleteGlobalNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteGlobalNetworkEndpointGroupRequest. */
                class DeleteGlobalNetworkEndpointGroupRequest implements IDeleteGlobalNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new DeleteGlobalNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest);

                    /** DeleteGlobalNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** DeleteGlobalNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** DeleteGlobalNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteGlobalNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteGlobalNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest): google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified DeleteGlobalNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DeleteGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DeleteGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest;

                    /**
                     * Decodes a DeleteGlobalNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest;

                    /**
                     * Verifies a DeleteGlobalNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a DeleteGlobalNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message DeleteGlobalNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalOperationRequest. */
                interface IDeleteGlobalOperationRequest {

                    /** DeleteGlobalOperationRequest operation */
                    operation?: (string|null);

                    /** DeleteGlobalOperationRequest project */
                    project?: (string|null);
                }

                /** Represents a DeleteGlobalOperationRequest. */
                class DeleteGlobalOperationRequest implements IDeleteGlobalOperationRequest {

                    /**
                     * Constructs a new DeleteGlobalOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalOperationRequest);

                    /** DeleteGlobalOperationRequest operation. */
                    public operation: string;

                    /** DeleteGlobalOperationRequest project. */
                    public project: string;

                    /**
                     * Creates a new DeleteGlobalOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalOperationRequest): google.cloud.compute.v1.DeleteGlobalOperationRequest;

                    /**
                     * Encodes the specified DeleteGlobalOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOperationRequest.verify|verify} messages.
                     * @param message DeleteGlobalOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOperationRequest.verify|verify} messages.
                     * @param message DeleteGlobalOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalOperationRequest;

                    /**
                     * Decodes a DeleteGlobalOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalOperationRequest;

                    /**
                     * Verifies a DeleteGlobalOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalOperationRequest;

                    /**
                     * Creates a plain object from a DeleteGlobalOperationRequest message. Also converts values to other types if specified.
                     * @param message DeleteGlobalOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalOperationResponse. */
                interface IDeleteGlobalOperationResponse {
                }

                /** Represents a DeleteGlobalOperationResponse. */
                class DeleteGlobalOperationResponse implements IDeleteGlobalOperationResponse {

                    /**
                     * Constructs a new DeleteGlobalOperationResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalOperationResponse);

                    /**
                     * Creates a new DeleteGlobalOperationResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalOperationResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalOperationResponse): google.cloud.compute.v1.DeleteGlobalOperationResponse;

                    /**
                     * Encodes the specified DeleteGlobalOperationResponse message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOperationResponse.verify|verify} messages.
                     * @param message DeleteGlobalOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalOperationResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOperationResponse.verify|verify} messages.
                     * @param message DeleteGlobalOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalOperationResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalOperationResponse;

                    /**
                     * Decodes a DeleteGlobalOperationResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalOperationResponse;

                    /**
                     * Verifies a DeleteGlobalOperationResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalOperationResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalOperationResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalOperationResponse;

                    /**
                     * Creates a plain object from a DeleteGlobalOperationResponse message. Also converts values to other types if specified.
                     * @param message DeleteGlobalOperationResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalOperationResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalOperationResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalOperationResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalOrganizationOperationRequest. */
                interface IDeleteGlobalOrganizationOperationRequest {

                    /** DeleteGlobalOrganizationOperationRequest operation */
                    operation?: (string|null);

                    /** DeleteGlobalOrganizationOperationRequest parentId */
                    parentId?: (string|null);
                }

                /** Represents a DeleteGlobalOrganizationOperationRequest. */
                class DeleteGlobalOrganizationOperationRequest implements IDeleteGlobalOrganizationOperationRequest {

                    /**
                     * Constructs a new DeleteGlobalOrganizationOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationRequest);

                    /** DeleteGlobalOrganizationOperationRequest operation. */
                    public operation: string;

                    /** DeleteGlobalOrganizationOperationRequest parentId. */
                    public parentId?: (string|null);

                    /** DeleteGlobalOrganizationOperationRequest _parentId. */
                    public _parentId?: "parentId";

                    /**
                     * Creates a new DeleteGlobalOrganizationOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalOrganizationOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationRequest): google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest;

                    /**
                     * Encodes the specified DeleteGlobalOrganizationOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest.verify|verify} messages.
                     * @param message DeleteGlobalOrganizationOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalOrganizationOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest.verify|verify} messages.
                     * @param message DeleteGlobalOrganizationOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalOrganizationOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalOrganizationOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest;

                    /**
                     * Decodes a DeleteGlobalOrganizationOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalOrganizationOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest;

                    /**
                     * Verifies a DeleteGlobalOrganizationOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalOrganizationOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalOrganizationOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest;

                    /**
                     * Creates a plain object from a DeleteGlobalOrganizationOperationRequest message. Also converts values to other types if specified.
                     * @param message DeleteGlobalOrganizationOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalOrganizationOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalOrganizationOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalOrganizationOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalOrganizationOperationResponse. */
                interface IDeleteGlobalOrganizationOperationResponse {
                }

                /** Represents a DeleteGlobalOrganizationOperationResponse. */
                class DeleteGlobalOrganizationOperationResponse implements IDeleteGlobalOrganizationOperationResponse {

                    /**
                     * Constructs a new DeleteGlobalOrganizationOperationResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationResponse);

                    /**
                     * Creates a new DeleteGlobalOrganizationOperationResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalOrganizationOperationResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationResponse): google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse;

                    /**
                     * Encodes the specified DeleteGlobalOrganizationOperationResponse message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse.verify|verify} messages.
                     * @param message DeleteGlobalOrganizationOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalOrganizationOperationResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse.verify|verify} messages.
                     * @param message DeleteGlobalOrganizationOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalOrganizationOperationResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalOrganizationOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse;

                    /**
                     * Decodes a DeleteGlobalOrganizationOperationResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalOrganizationOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse;

                    /**
                     * Verifies a DeleteGlobalOrganizationOperationResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalOrganizationOperationResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalOrganizationOperationResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse;

                    /**
                     * Creates a plain object from a DeleteGlobalOrganizationOperationResponse message. Also converts values to other types if specified.
                     * @param message DeleteGlobalOrganizationOperationResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalOrganizationOperationResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalOrganizationOperationResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteGlobalPublicDelegatedPrefixeRequest. */
                interface IDeleteGlobalPublicDelegatedPrefixeRequest {

                    /** DeleteGlobalPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** DeleteGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefix */
                    publicDelegatedPrefix?: (string|null);

                    /** DeleteGlobalPublicDelegatedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteGlobalPublicDelegatedPrefixeRequest. */
                class DeleteGlobalPublicDelegatedPrefixeRequest implements IDeleteGlobalPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new DeleteGlobalPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteGlobalPublicDelegatedPrefixeRequest);

                    /** DeleteGlobalPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** DeleteGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefix. */
                    public publicDelegatedPrefix: string;

                    /** DeleteGlobalPublicDelegatedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteGlobalPublicDelegatedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteGlobalPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteGlobalPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteGlobalPublicDelegatedPrefixeRequest): google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified DeleteGlobalPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message DeleteGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteGlobalPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message DeleteGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes a DeleteGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies a DeleteGlobalPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteGlobalPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteGlobalPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from a DeleteGlobalPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message DeleteGlobalPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteGlobalPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteGlobalPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteGlobalPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteHealthCheckRequest. */
                interface IDeleteHealthCheckRequest {

                    /** DeleteHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** DeleteHealthCheckRequest project */
                    project?: (string|null);

                    /** DeleteHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteHealthCheckRequest. */
                class DeleteHealthCheckRequest implements IDeleteHealthCheckRequest {

                    /**
                     * Constructs a new DeleteHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteHealthCheckRequest);

                    /** DeleteHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** DeleteHealthCheckRequest project. */
                    public project: string;

                    /** DeleteHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteHealthCheckRequest): google.cloud.compute.v1.DeleteHealthCheckRequest;

                    /**
                     * Encodes the specified DeleteHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteHealthCheckRequest.verify|verify} messages.
                     * @param message DeleteHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteHealthCheckRequest.verify|verify} messages.
                     * @param message DeleteHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteHealthCheckRequest;

                    /**
                     * Decodes a DeleteHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteHealthCheckRequest;

                    /**
                     * Verifies a DeleteHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteHealthCheckRequest;

                    /**
                     * Creates a plain object from a DeleteHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message DeleteHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteImageRequest. */
                interface IDeleteImageRequest {

                    /** DeleteImageRequest image */
                    image?: (string|null);

                    /** DeleteImageRequest project */
                    project?: (string|null);

                    /** DeleteImageRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteImageRequest. */
                class DeleteImageRequest implements IDeleteImageRequest {

                    /**
                     * Constructs a new DeleteImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteImageRequest);

                    /** DeleteImageRequest image. */
                    public image: string;

                    /** DeleteImageRequest project. */
                    public project: string;

                    /** DeleteImageRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteImageRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteImageRequest): google.cloud.compute.v1.DeleteImageRequest;

                    /**
                     * Encodes the specified DeleteImageRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteImageRequest.verify|verify} messages.
                     * @param message DeleteImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteImageRequest.verify|verify} messages.
                     * @param message DeleteImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteImageRequest;

                    /**
                     * Decodes a DeleteImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteImageRequest;

                    /**
                     * Verifies a DeleteImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteImageRequest;

                    /**
                     * Creates a plain object from a DeleteImageRequest message. Also converts values to other types if specified.
                     * @param message DeleteImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInstanceGroupManagerRequest. */
                interface IDeleteInstanceGroupManagerRequest {

                    /** DeleteInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** DeleteInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** DeleteInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** DeleteInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteInstanceGroupManagerRequest. */
                class DeleteInstanceGroupManagerRequest implements IDeleteInstanceGroupManagerRequest {

                    /**
                     * Constructs a new DeleteInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest);

                    /** DeleteInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** DeleteInstanceGroupManagerRequest project. */
                    public project: string;

                    /** DeleteInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** DeleteInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest): google.cloud.compute.v1.DeleteInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified DeleteInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInstanceGroupManagerRequest;

                    /**
                     * Decodes a DeleteInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInstanceGroupManagerRequest;

                    /**
                     * Verifies a DeleteInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a DeleteInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message DeleteInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInstanceGroupRequest. */
                interface IDeleteInstanceGroupRequest {

                    /** DeleteInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** DeleteInstanceGroupRequest project */
                    project?: (string|null);

                    /** DeleteInstanceGroupRequest requestId */
                    requestId?: (string|null);

                    /** DeleteInstanceGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteInstanceGroupRequest. */
                class DeleteInstanceGroupRequest implements IDeleteInstanceGroupRequest {

                    /**
                     * Constructs a new DeleteInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInstanceGroupRequest);

                    /** DeleteInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** DeleteInstanceGroupRequest project. */
                    public project: string;

                    /** DeleteInstanceGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInstanceGroupRequest zone. */
                    public zone: string;

                    /** DeleteInstanceGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInstanceGroupRequest): google.cloud.compute.v1.DeleteInstanceGroupRequest;

                    /**
                     * Encodes the specified DeleteInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceGroupRequest.verify|verify} messages.
                     * @param message DeleteInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceGroupRequest.verify|verify} messages.
                     * @param message DeleteInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInstanceGroupRequest;

                    /**
                     * Decodes a DeleteInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInstanceGroupRequest;

                    /**
                     * Verifies a DeleteInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInstanceGroupRequest;

                    /**
                     * Creates a plain object from a DeleteInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message DeleteInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInstanceRequest. */
                interface IDeleteInstanceRequest {

                    /** DeleteInstanceRequest instance */
                    instance?: (string|null);

                    /** DeleteInstanceRequest project */
                    project?: (string|null);

                    /** DeleteInstanceRequest requestId */
                    requestId?: (string|null);

                    /** DeleteInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteInstanceRequest. */
                class DeleteInstanceRequest implements IDeleteInstanceRequest {

                    /**
                     * Constructs a new DeleteInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInstanceRequest);

                    /** DeleteInstanceRequest instance. */
                    public instance: string;

                    /** DeleteInstanceRequest project. */
                    public project: string;

                    /** DeleteInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInstanceRequest zone. */
                    public zone: string;

                    /** DeleteInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInstanceRequest): google.cloud.compute.v1.DeleteInstanceRequest;

                    /**
                     * Encodes the specified DeleteInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceRequest.verify|verify} messages.
                     * @param message DeleteInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceRequest.verify|verify} messages.
                     * @param message DeleteInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInstanceRequest;

                    /**
                     * Decodes a DeleteInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInstanceRequest;

                    /**
                     * Verifies a DeleteInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInstanceRequest;

                    /**
                     * Creates a plain object from a DeleteInstanceRequest message. Also converts values to other types if specified.
                     * @param message DeleteInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInstanceTemplateRequest. */
                interface IDeleteInstanceTemplateRequest {

                    /** DeleteInstanceTemplateRequest instanceTemplate */
                    instanceTemplate?: (string|null);

                    /** DeleteInstanceTemplateRequest project */
                    project?: (string|null);

                    /** DeleteInstanceTemplateRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteInstanceTemplateRequest. */
                class DeleteInstanceTemplateRequest implements IDeleteInstanceTemplateRequest {

                    /**
                     * Constructs a new DeleteInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInstanceTemplateRequest);

                    /** DeleteInstanceTemplateRequest instanceTemplate. */
                    public instanceTemplate: string;

                    /** DeleteInstanceTemplateRequest project. */
                    public project: string;

                    /** DeleteInstanceTemplateRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInstanceTemplateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInstanceTemplateRequest): google.cloud.compute.v1.DeleteInstanceTemplateRequest;

                    /**
                     * Encodes the specified DeleteInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceTemplateRequest.verify|verify} messages.
                     * @param message DeleteInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInstanceTemplateRequest.verify|verify} messages.
                     * @param message DeleteInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInstanceTemplateRequest;

                    /**
                     * Decodes a DeleteInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInstanceTemplateRequest;

                    /**
                     * Verifies a DeleteInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInstanceTemplateRequest;

                    /**
                     * Creates a plain object from a DeleteInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message DeleteInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInstancesInstanceGroupManagerRequest. */
                interface IDeleteInstancesInstanceGroupManagerRequest {

                    /** DeleteInstancesInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** DeleteInstancesInstanceGroupManagerRequest instanceGroupManagersDeleteInstancesRequestResource */
                    instanceGroupManagersDeleteInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersDeleteInstancesRequest|null);

                    /** DeleteInstancesInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** DeleteInstancesInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** DeleteInstancesInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteInstancesInstanceGroupManagerRequest. */
                class DeleteInstancesInstanceGroupManagerRequest implements IDeleteInstancesInstanceGroupManagerRequest {

                    /**
                     * Constructs a new DeleteInstancesInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest);

                    /** DeleteInstancesInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** DeleteInstancesInstanceGroupManagerRequest instanceGroupManagersDeleteInstancesRequestResource. */
                    public instanceGroupManagersDeleteInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersDeleteInstancesRequest|null);

                    /** DeleteInstancesInstanceGroupManagerRequest project. */
                    public project: string;

                    /** DeleteInstancesInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInstancesInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** DeleteInstancesInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInstancesInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInstancesInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest): google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified DeleteInstancesInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInstancesInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInstancesInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest;

                    /**
                     * Decodes a DeleteInstancesInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest;

                    /**
                     * Verifies a DeleteInstancesInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInstancesInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInstancesInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a DeleteInstancesInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message DeleteInstancesInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInstancesInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInstancesInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInstancesInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInstancesRegionInstanceGroupManagerRequest. */
                interface IDeleteInstancesRegionInstanceGroupManagerRequest {

                    /** DeleteInstancesRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersDeleteInstancesRequestResource */
                    regionInstanceGroupManagersDeleteInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersDeleteInstancesRequest|null);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteInstancesRegionInstanceGroupManagerRequest. */
                class DeleteInstancesRegionInstanceGroupManagerRequest implements IDeleteInstancesRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new DeleteInstancesRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** DeleteInstancesRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** DeleteInstancesRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** DeleteInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersDeleteInstancesRequestResource. */
                    public regionInstanceGroupManagersDeleteInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersDeleteInstancesRequest|null);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInstancesRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInstancesRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInstancesRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest): google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified DeleteInstancesRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInstancesRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a DeleteInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a DeleteInstancesRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInstancesRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInstancesRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a DeleteInstancesRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message DeleteInstancesRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInstancesRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInstancesRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInstancesRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInterconnectAttachmentRequest. */
                interface IDeleteInterconnectAttachmentRequest {

                    /** DeleteInterconnectAttachmentRequest interconnectAttachment */
                    interconnectAttachment?: (string|null);

                    /** DeleteInterconnectAttachmentRequest project */
                    project?: (string|null);

                    /** DeleteInterconnectAttachmentRequest region */
                    region?: (string|null);

                    /** DeleteInterconnectAttachmentRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteInterconnectAttachmentRequest. */
                class DeleteInterconnectAttachmentRequest implements IDeleteInterconnectAttachmentRequest {

                    /**
                     * Constructs a new DeleteInterconnectAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInterconnectAttachmentRequest);

                    /** DeleteInterconnectAttachmentRequest interconnectAttachment. */
                    public interconnectAttachment: string;

                    /** DeleteInterconnectAttachmentRequest project. */
                    public project: string;

                    /** DeleteInterconnectAttachmentRequest region. */
                    public region: string;

                    /** DeleteInterconnectAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInterconnectAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInterconnectAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInterconnectAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInterconnectAttachmentRequest): google.cloud.compute.v1.DeleteInterconnectAttachmentRequest;

                    /**
                     * Encodes the specified DeleteInterconnectAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message DeleteInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInterconnectAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message DeleteInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInterconnectAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInterconnectAttachmentRequest;

                    /**
                     * Decodes a DeleteInterconnectAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInterconnectAttachmentRequest;

                    /**
                     * Verifies a DeleteInterconnectAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInterconnectAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInterconnectAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInterconnectAttachmentRequest;

                    /**
                     * Creates a plain object from a DeleteInterconnectAttachmentRequest message. Also converts values to other types if specified.
                     * @param message DeleteInterconnectAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInterconnectAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInterconnectAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInterconnectAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteInterconnectRequest. */
                interface IDeleteInterconnectRequest {

                    /** DeleteInterconnectRequest interconnect */
                    interconnect?: (string|null);

                    /** DeleteInterconnectRequest project */
                    project?: (string|null);

                    /** DeleteInterconnectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteInterconnectRequest. */
                class DeleteInterconnectRequest implements IDeleteInterconnectRequest {

                    /**
                     * Constructs a new DeleteInterconnectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteInterconnectRequest);

                    /** DeleteInterconnectRequest interconnect. */
                    public interconnect: string;

                    /** DeleteInterconnectRequest project. */
                    public project: string;

                    /** DeleteInterconnectRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteInterconnectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteInterconnectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteInterconnectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteInterconnectRequest): google.cloud.compute.v1.DeleteInterconnectRequest;

                    /**
                     * Encodes the specified DeleteInterconnectRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteInterconnectRequest.verify|verify} messages.
                     * @param message DeleteInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteInterconnectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteInterconnectRequest.verify|verify} messages.
                     * @param message DeleteInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteInterconnectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteInterconnectRequest;

                    /**
                     * Decodes a DeleteInterconnectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteInterconnectRequest;

                    /**
                     * Verifies a DeleteInterconnectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteInterconnectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteInterconnectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteInterconnectRequest;

                    /**
                     * Creates a plain object from a DeleteInterconnectRequest message. Also converts values to other types if specified.
                     * @param message DeleteInterconnectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteInterconnectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteInterconnectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteInterconnectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteLicenseRequest. */
                interface IDeleteLicenseRequest {

                    /** DeleteLicenseRequest license */
                    license?: (string|null);

                    /** DeleteLicenseRequest project */
                    project?: (string|null);

                    /** DeleteLicenseRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteLicenseRequest. */
                class DeleteLicenseRequest implements IDeleteLicenseRequest {

                    /**
                     * Constructs a new DeleteLicenseRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteLicenseRequest);

                    /** DeleteLicenseRequest license. */
                    public license: string;

                    /** DeleteLicenseRequest project. */
                    public project: string;

                    /** DeleteLicenseRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteLicenseRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteLicenseRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteLicenseRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteLicenseRequest): google.cloud.compute.v1.DeleteLicenseRequest;

                    /**
                     * Encodes the specified DeleteLicenseRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteLicenseRequest.verify|verify} messages.
                     * @param message DeleteLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteLicenseRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteLicenseRequest.verify|verify} messages.
                     * @param message DeleteLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteLicenseRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteLicenseRequest;

                    /**
                     * Decodes a DeleteLicenseRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteLicenseRequest;

                    /**
                     * Verifies a DeleteLicenseRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteLicenseRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteLicenseRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteLicenseRequest;

                    /**
                     * Creates a plain object from a DeleteLicenseRequest message. Also converts values to other types if specified.
                     * @param message DeleteLicenseRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteLicenseRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteLicenseRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteLicenseRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteMachineImageRequest. */
                interface IDeleteMachineImageRequest {

                    /** DeleteMachineImageRequest machineImage */
                    machineImage?: (string|null);

                    /** DeleteMachineImageRequest project */
                    project?: (string|null);

                    /** DeleteMachineImageRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteMachineImageRequest. */
                class DeleteMachineImageRequest implements IDeleteMachineImageRequest {

                    /**
                     * Constructs a new DeleteMachineImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteMachineImageRequest);

                    /** DeleteMachineImageRequest machineImage. */
                    public machineImage: string;

                    /** DeleteMachineImageRequest project. */
                    public project: string;

                    /** DeleteMachineImageRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteMachineImageRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteMachineImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteMachineImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteMachineImageRequest): google.cloud.compute.v1.DeleteMachineImageRequest;

                    /**
                     * Encodes the specified DeleteMachineImageRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteMachineImageRequest.verify|verify} messages.
                     * @param message DeleteMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteMachineImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteMachineImageRequest.verify|verify} messages.
                     * @param message DeleteMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteMachineImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteMachineImageRequest;

                    /**
                     * Decodes a DeleteMachineImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteMachineImageRequest;

                    /**
                     * Verifies a DeleteMachineImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteMachineImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteMachineImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteMachineImageRequest;

                    /**
                     * Creates a plain object from a DeleteMachineImageRequest message. Also converts values to other types if specified.
                     * @param message DeleteMachineImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteMachineImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteMachineImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteMachineImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNetworkEdgeSecurityServiceRequest. */
                interface IDeleteNetworkEdgeSecurityServiceRequest {

                    /** DeleteNetworkEdgeSecurityServiceRequest networkEdgeSecurityService */
                    networkEdgeSecurityService?: (string|null);

                    /** DeleteNetworkEdgeSecurityServiceRequest project */
                    project?: (string|null);

                    /** DeleteNetworkEdgeSecurityServiceRequest region */
                    region?: (string|null);

                    /** DeleteNetworkEdgeSecurityServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteNetworkEdgeSecurityServiceRequest. */
                class DeleteNetworkEdgeSecurityServiceRequest implements IDeleteNetworkEdgeSecurityServiceRequest {

                    /**
                     * Constructs a new DeleteNetworkEdgeSecurityServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNetworkEdgeSecurityServiceRequest);

                    /** DeleteNetworkEdgeSecurityServiceRequest networkEdgeSecurityService. */
                    public networkEdgeSecurityService: string;

                    /** DeleteNetworkEdgeSecurityServiceRequest project. */
                    public project: string;

                    /** DeleteNetworkEdgeSecurityServiceRequest region. */
                    public region: string;

                    /** DeleteNetworkEdgeSecurityServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNetworkEdgeSecurityServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNetworkEdgeSecurityServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNetworkEdgeSecurityServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNetworkEdgeSecurityServiceRequest): google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest;

                    /**
                     * Encodes the specified DeleteNetworkEdgeSecurityServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message DeleteNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNetworkEdgeSecurityServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message DeleteNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNetworkEdgeSecurityServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest;

                    /**
                     * Decodes a DeleteNetworkEdgeSecurityServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest;

                    /**
                     * Verifies a DeleteNetworkEdgeSecurityServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNetworkEdgeSecurityServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNetworkEdgeSecurityServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest;

                    /**
                     * Creates a plain object from a DeleteNetworkEdgeSecurityServiceRequest message. Also converts values to other types if specified.
                     * @param message DeleteNetworkEdgeSecurityServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNetworkEdgeSecurityServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNetworkEdgeSecurityServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNetworkEdgeSecurityServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNetworkEndpointGroupRequest. */
                interface IDeleteNetworkEndpointGroupRequest {

                    /** DeleteNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** DeleteNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** DeleteNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);

                    /** DeleteNetworkEndpointGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteNetworkEndpointGroupRequest. */
                class DeleteNetworkEndpointGroupRequest implements IDeleteNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new DeleteNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNetworkEndpointGroupRequest);

                    /** DeleteNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** DeleteNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** DeleteNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNetworkEndpointGroupRequest zone. */
                    public zone: string;

                    /** DeleteNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNetworkEndpointGroupRequest): google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified DeleteNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DeleteNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DeleteNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest;

                    /**
                     * Decodes a DeleteNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest;

                    /**
                     * Verifies a DeleteNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a DeleteNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message DeleteNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNetworkFirewallPolicyRequest. */
                interface IDeleteNetworkFirewallPolicyRequest {

                    /** DeleteNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** DeleteNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** DeleteNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteNetworkFirewallPolicyRequest. */
                class DeleteNetworkFirewallPolicyRequest implements IDeleteNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new DeleteNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNetworkFirewallPolicyRequest);

                    /** DeleteNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** DeleteNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** DeleteNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNetworkFirewallPolicyRequest): google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified DeleteNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message DeleteNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message DeleteNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a DeleteNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a DeleteNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNetworkRequest. */
                interface IDeleteNetworkRequest {

                    /** DeleteNetworkRequest network */
                    network?: (string|null);

                    /** DeleteNetworkRequest project */
                    project?: (string|null);

                    /** DeleteNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteNetworkRequest. */
                class DeleteNetworkRequest implements IDeleteNetworkRequest {

                    /**
                     * Constructs a new DeleteNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNetworkRequest);

                    /** DeleteNetworkRequest network. */
                    public network: string;

                    /** DeleteNetworkRequest project. */
                    public project: string;

                    /** DeleteNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNetworkRequest): google.cloud.compute.v1.DeleteNetworkRequest;

                    /**
                     * Encodes the specified DeleteNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkRequest.verify|verify} messages.
                     * @param message DeleteNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNetworkRequest.verify|verify} messages.
                     * @param message DeleteNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNetworkRequest;

                    /**
                     * Decodes a DeleteNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNetworkRequest;

                    /**
                     * Verifies a DeleteNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNetworkRequest;

                    /**
                     * Creates a plain object from a DeleteNetworkRequest message. Also converts values to other types if specified.
                     * @param message DeleteNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNodeGroupRequest. */
                interface IDeleteNodeGroupRequest {

                    /** DeleteNodeGroupRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** DeleteNodeGroupRequest project */
                    project?: (string|null);

                    /** DeleteNodeGroupRequest requestId */
                    requestId?: (string|null);

                    /** DeleteNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteNodeGroupRequest. */
                class DeleteNodeGroupRequest implements IDeleteNodeGroupRequest {

                    /**
                     * Constructs a new DeleteNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNodeGroupRequest);

                    /** DeleteNodeGroupRequest nodeGroup. */
                    public nodeGroup: string;

                    /** DeleteNodeGroupRequest project. */
                    public project: string;

                    /** DeleteNodeGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNodeGroupRequest zone. */
                    public zone: string;

                    /** DeleteNodeGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNodeGroupRequest): google.cloud.compute.v1.DeleteNodeGroupRequest;

                    /**
                     * Encodes the specified DeleteNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNodeGroupRequest.verify|verify} messages.
                     * @param message DeleteNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNodeGroupRequest.verify|verify} messages.
                     * @param message DeleteNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNodeGroupRequest;

                    /**
                     * Decodes a DeleteNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNodeGroupRequest;

                    /**
                     * Verifies a DeleteNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNodeGroupRequest;

                    /**
                     * Creates a plain object from a DeleteNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message DeleteNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNodeTemplateRequest. */
                interface IDeleteNodeTemplateRequest {

                    /** DeleteNodeTemplateRequest nodeTemplate */
                    nodeTemplate?: (string|null);

                    /** DeleteNodeTemplateRequest project */
                    project?: (string|null);

                    /** DeleteNodeTemplateRequest region */
                    region?: (string|null);

                    /** DeleteNodeTemplateRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteNodeTemplateRequest. */
                class DeleteNodeTemplateRequest implements IDeleteNodeTemplateRequest {

                    /**
                     * Constructs a new DeleteNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNodeTemplateRequest);

                    /** DeleteNodeTemplateRequest nodeTemplate. */
                    public nodeTemplate: string;

                    /** DeleteNodeTemplateRequest project. */
                    public project: string;

                    /** DeleteNodeTemplateRequest region. */
                    public region: string;

                    /** DeleteNodeTemplateRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNodeTemplateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNodeTemplateRequest): google.cloud.compute.v1.DeleteNodeTemplateRequest;

                    /**
                     * Encodes the specified DeleteNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNodeTemplateRequest.verify|verify} messages.
                     * @param message DeleteNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNodeTemplateRequest.verify|verify} messages.
                     * @param message DeleteNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNodeTemplateRequest;

                    /**
                     * Decodes a DeleteNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNodeTemplateRequest;

                    /**
                     * Verifies a DeleteNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNodeTemplateRequest;

                    /**
                     * Creates a plain object from a DeleteNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message DeleteNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteNodesNodeGroupRequest. */
                interface IDeleteNodesNodeGroupRequest {

                    /** DeleteNodesNodeGroupRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** DeleteNodesNodeGroupRequest nodeGroupsDeleteNodesRequestResource */
                    nodeGroupsDeleteNodesRequestResource?: (google.cloud.compute.v1.INodeGroupsDeleteNodesRequest|null);

                    /** DeleteNodesNodeGroupRequest project */
                    project?: (string|null);

                    /** DeleteNodesNodeGroupRequest requestId */
                    requestId?: (string|null);

                    /** DeleteNodesNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteNodesNodeGroupRequest. */
                class DeleteNodesNodeGroupRequest implements IDeleteNodesNodeGroupRequest {

                    /**
                     * Constructs a new DeleteNodesNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteNodesNodeGroupRequest);

                    /** DeleteNodesNodeGroupRequest nodeGroup. */
                    public nodeGroup: string;

                    /** DeleteNodesNodeGroupRequest nodeGroupsDeleteNodesRequestResource. */
                    public nodeGroupsDeleteNodesRequestResource?: (google.cloud.compute.v1.INodeGroupsDeleteNodesRequest|null);

                    /** DeleteNodesNodeGroupRequest project. */
                    public project: string;

                    /** DeleteNodesNodeGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteNodesNodeGroupRequest zone. */
                    public zone: string;

                    /** DeleteNodesNodeGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteNodesNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteNodesNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteNodesNodeGroupRequest): google.cloud.compute.v1.DeleteNodesNodeGroupRequest;

                    /**
                     * Encodes the specified DeleteNodesNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteNodesNodeGroupRequest.verify|verify} messages.
                     * @param message DeleteNodesNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteNodesNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteNodesNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteNodesNodeGroupRequest.verify|verify} messages.
                     * @param message DeleteNodesNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteNodesNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteNodesNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteNodesNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteNodesNodeGroupRequest;

                    /**
                     * Decodes a DeleteNodesNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteNodesNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteNodesNodeGroupRequest;

                    /**
                     * Verifies a DeleteNodesNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteNodesNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteNodesNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteNodesNodeGroupRequest;

                    /**
                     * Creates a plain object from a DeleteNodesNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message DeleteNodesNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteNodesNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteNodesNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteNodesNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeletePacketMirroringRequest. */
                interface IDeletePacketMirroringRequest {

                    /** DeletePacketMirroringRequest packetMirroring */
                    packetMirroring?: (string|null);

                    /** DeletePacketMirroringRequest project */
                    project?: (string|null);

                    /** DeletePacketMirroringRequest region */
                    region?: (string|null);

                    /** DeletePacketMirroringRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeletePacketMirroringRequest. */
                class DeletePacketMirroringRequest implements IDeletePacketMirroringRequest {

                    /**
                     * Constructs a new DeletePacketMirroringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeletePacketMirroringRequest);

                    /** DeletePacketMirroringRequest packetMirroring. */
                    public packetMirroring: string;

                    /** DeletePacketMirroringRequest project. */
                    public project: string;

                    /** DeletePacketMirroringRequest region. */
                    public region: string;

                    /** DeletePacketMirroringRequest requestId. */
                    public requestId?: (string|null);

                    /** DeletePacketMirroringRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeletePacketMirroringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeletePacketMirroringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeletePacketMirroringRequest): google.cloud.compute.v1.DeletePacketMirroringRequest;

                    /**
                     * Encodes the specified DeletePacketMirroringRequest message. Does not implicitly {@link google.cloud.compute.v1.DeletePacketMirroringRequest.verify|verify} messages.
                     * @param message DeletePacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeletePacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeletePacketMirroringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeletePacketMirroringRequest.verify|verify} messages.
                     * @param message DeletePacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeletePacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeletePacketMirroringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeletePacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeletePacketMirroringRequest;

                    /**
                     * Decodes a DeletePacketMirroringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeletePacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeletePacketMirroringRequest;

                    /**
                     * Verifies a DeletePacketMirroringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeletePacketMirroringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeletePacketMirroringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeletePacketMirroringRequest;

                    /**
                     * Creates a plain object from a DeletePacketMirroringRequest message. Also converts values to other types if specified.
                     * @param message DeletePacketMirroringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeletePacketMirroringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeletePacketMirroringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeletePacketMirroringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeletePerInstanceConfigsInstanceGroupManagerRequest. */
                interface IDeletePerInstanceConfigsInstanceGroupManagerRequest {

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManagersDeletePerInstanceConfigsReqResource */
                    instanceGroupManagersDeletePerInstanceConfigsReqResource?: (google.cloud.compute.v1.IInstanceGroupManagersDeletePerInstanceConfigsReq|null);

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeletePerInstanceConfigsInstanceGroupManagerRequest. */
                class DeletePerInstanceConfigsInstanceGroupManagerRequest implements IDeletePerInstanceConfigsInstanceGroupManagerRequest {

                    /**
                     * Constructs a new DeletePerInstanceConfigsInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest);

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManagersDeletePerInstanceConfigsReqResource. */
                    public instanceGroupManagersDeletePerInstanceConfigsReqResource?: (google.cloud.compute.v1.IInstanceGroupManagersDeletePerInstanceConfigsReq|null);

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest project. */
                    public project: string;

                    /** DeletePerInstanceConfigsInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new DeletePerInstanceConfigsInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeletePerInstanceConfigsInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest): google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified DeletePerInstanceConfigsInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeletePerInstanceConfigsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeletePerInstanceConfigsInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeletePerInstanceConfigsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeletePerInstanceConfigsInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeletePerInstanceConfigsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Decodes a DeletePerInstanceConfigsInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeletePerInstanceConfigsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Verifies a DeletePerInstanceConfigsInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeletePerInstanceConfigsInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeletePerInstanceConfigsInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a DeletePerInstanceConfigsInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message DeletePerInstanceConfigsInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeletePerInstanceConfigsInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeletePerInstanceConfigsInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeletePerInstanceConfigsInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest. */
                interface IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest {

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest regionInstanceGroupManagerDeleteInstanceConfigReqResource */
                    regionInstanceGroupManagerDeleteInstanceConfigReqResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagerDeleteInstanceConfigReq|null);
                }

                /** Represents a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest. */
                class DeletePerInstanceConfigsRegionInstanceGroupManagerRequest implements IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new DeletePerInstanceConfigsRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest);

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** DeletePerInstanceConfigsRegionInstanceGroupManagerRequest regionInstanceGroupManagerDeleteInstanceConfigReqResource. */
                    public regionInstanceGroupManagerDeleteInstanceConfigReqResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagerDeleteInstanceConfigReq|null);

                    /**
                     * Creates a new DeletePerInstanceConfigsRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeletePerInstanceConfigsRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest): google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeletePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeletePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeletePerInstanceConfigsRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message DeletePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeletePerInstanceConfigsRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeletePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeletePublicAdvertisedPrefixeRequest. */
                interface IDeletePublicAdvertisedPrefixeRequest {

                    /** DeletePublicAdvertisedPrefixeRequest project */
                    project?: (string|null);

                    /** DeletePublicAdvertisedPrefixeRequest publicAdvertisedPrefix */
                    publicAdvertisedPrefix?: (string|null);

                    /** DeletePublicAdvertisedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeletePublicAdvertisedPrefixeRequest. */
                class DeletePublicAdvertisedPrefixeRequest implements IDeletePublicAdvertisedPrefixeRequest {

                    /**
                     * Constructs a new DeletePublicAdvertisedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeletePublicAdvertisedPrefixeRequest);

                    /** DeletePublicAdvertisedPrefixeRequest project. */
                    public project: string;

                    /** DeletePublicAdvertisedPrefixeRequest publicAdvertisedPrefix. */
                    public publicAdvertisedPrefix: string;

                    /** DeletePublicAdvertisedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** DeletePublicAdvertisedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeletePublicAdvertisedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeletePublicAdvertisedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeletePublicAdvertisedPrefixeRequest): google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest;

                    /**
                     * Encodes the specified DeletePublicAdvertisedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message DeletePublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeletePublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeletePublicAdvertisedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message DeletePublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeletePublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeletePublicAdvertisedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeletePublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest;

                    /**
                     * Decodes a DeletePublicAdvertisedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeletePublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest;

                    /**
                     * Verifies a DeletePublicAdvertisedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeletePublicAdvertisedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeletePublicAdvertisedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest;

                    /**
                     * Creates a plain object from a DeletePublicAdvertisedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message DeletePublicAdvertisedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeletePublicAdvertisedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeletePublicAdvertisedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeletePublicAdvertisedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeletePublicDelegatedPrefixeRequest. */
                interface IDeletePublicDelegatedPrefixeRequest {

                    /** DeletePublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** DeletePublicDelegatedPrefixeRequest publicDelegatedPrefix */
                    publicDelegatedPrefix?: (string|null);

                    /** DeletePublicDelegatedPrefixeRequest region */
                    region?: (string|null);

                    /** DeletePublicDelegatedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeletePublicDelegatedPrefixeRequest. */
                class DeletePublicDelegatedPrefixeRequest implements IDeletePublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new DeletePublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeletePublicDelegatedPrefixeRequest);

                    /** DeletePublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** DeletePublicDelegatedPrefixeRequest publicDelegatedPrefix. */
                    public publicDelegatedPrefix: string;

                    /** DeletePublicDelegatedPrefixeRequest region. */
                    public region: string;

                    /** DeletePublicDelegatedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** DeletePublicDelegatedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeletePublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeletePublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeletePublicDelegatedPrefixeRequest): google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified DeletePublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message DeletePublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeletePublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeletePublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message DeletePublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeletePublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeletePublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeletePublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest;

                    /**
                     * Decodes a DeletePublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeletePublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest;

                    /**
                     * Verifies a DeletePublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeletePublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeletePublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from a DeletePublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message DeletePublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeletePublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeletePublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeletePublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionAutoscalerRequest. */
                interface IDeleteRegionAutoscalerRequest {

                    /** DeleteRegionAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** DeleteRegionAutoscalerRequest project */
                    project?: (string|null);

                    /** DeleteRegionAutoscalerRequest region */
                    region?: (string|null);

                    /** DeleteRegionAutoscalerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionAutoscalerRequest. */
                class DeleteRegionAutoscalerRequest implements IDeleteRegionAutoscalerRequest {

                    /**
                     * Constructs a new DeleteRegionAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionAutoscalerRequest);

                    /** DeleteRegionAutoscalerRequest autoscaler. */
                    public autoscaler: string;

                    /** DeleteRegionAutoscalerRequest project. */
                    public project: string;

                    /** DeleteRegionAutoscalerRequest region. */
                    public region: string;

                    /** DeleteRegionAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionAutoscalerRequest): google.cloud.compute.v1.DeleteRegionAutoscalerRequest;

                    /**
                     * Encodes the specified DeleteRegionAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionAutoscalerRequest.verify|verify} messages.
                     * @param message DeleteRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionAutoscalerRequest.verify|verify} messages.
                     * @param message DeleteRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionAutoscalerRequest;

                    /**
                     * Decodes a DeleteRegionAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionAutoscalerRequest;

                    /**
                     * Verifies a DeleteRegionAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionAutoscalerRequest;

                    /**
                     * Creates a plain object from a DeleteRegionAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionBackendServiceRequest. */
                interface IDeleteRegionBackendServiceRequest {

                    /** DeleteRegionBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** DeleteRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** DeleteRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** DeleteRegionBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionBackendServiceRequest. */
                class DeleteRegionBackendServiceRequest implements IDeleteRegionBackendServiceRequest {

                    /**
                     * Constructs a new DeleteRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionBackendServiceRequest);

                    /** DeleteRegionBackendServiceRequest backendService. */
                    public backendService: string;

                    /** DeleteRegionBackendServiceRequest project. */
                    public project: string;

                    /** DeleteRegionBackendServiceRequest region. */
                    public region: string;

                    /** DeleteRegionBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionBackendServiceRequest): google.cloud.compute.v1.DeleteRegionBackendServiceRequest;

                    /**
                     * Encodes the specified DeleteRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionBackendServiceRequest.verify|verify} messages.
                     * @param message DeleteRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionBackendServiceRequest.verify|verify} messages.
                     * @param message DeleteRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionBackendServiceRequest;

                    /**
                     * Decodes a DeleteRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionBackendServiceRequest;

                    /**
                     * Verifies a DeleteRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from a DeleteRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionDiskRequest. */
                interface IDeleteRegionDiskRequest {

                    /** DeleteRegionDiskRequest disk */
                    disk?: (string|null);

                    /** DeleteRegionDiskRequest project */
                    project?: (string|null);

                    /** DeleteRegionDiskRequest region */
                    region?: (string|null);

                    /** DeleteRegionDiskRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionDiskRequest. */
                class DeleteRegionDiskRequest implements IDeleteRegionDiskRequest {

                    /**
                     * Constructs a new DeleteRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionDiskRequest);

                    /** DeleteRegionDiskRequest disk. */
                    public disk: string;

                    /** DeleteRegionDiskRequest project. */
                    public project: string;

                    /** DeleteRegionDiskRequest region. */
                    public region: string;

                    /** DeleteRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionDiskRequest): google.cloud.compute.v1.DeleteRegionDiskRequest;

                    /**
                     * Encodes the specified DeleteRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionDiskRequest.verify|verify} messages.
                     * @param message DeleteRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionDiskRequest.verify|verify} messages.
                     * @param message DeleteRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionDiskRequest;

                    /**
                     * Decodes a DeleteRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionDiskRequest;

                    /**
                     * Verifies a DeleteRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionDiskRequest;

                    /**
                     * Creates a plain object from a DeleteRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionHealthCheckRequest. */
                interface IDeleteRegionHealthCheckRequest {

                    /** DeleteRegionHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** DeleteRegionHealthCheckRequest project */
                    project?: (string|null);

                    /** DeleteRegionHealthCheckRequest region */
                    region?: (string|null);

                    /** DeleteRegionHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionHealthCheckRequest. */
                class DeleteRegionHealthCheckRequest implements IDeleteRegionHealthCheckRequest {

                    /**
                     * Constructs a new DeleteRegionHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionHealthCheckRequest);

                    /** DeleteRegionHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** DeleteRegionHealthCheckRequest project. */
                    public project: string;

                    /** DeleteRegionHealthCheckRequest region. */
                    public region: string;

                    /** DeleteRegionHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionHealthCheckRequest): google.cloud.compute.v1.DeleteRegionHealthCheckRequest;

                    /**
                     * Encodes the specified DeleteRegionHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionHealthCheckRequest.verify|verify} messages.
                     * @param message DeleteRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionHealthCheckRequest.verify|verify} messages.
                     * @param message DeleteRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionHealthCheckRequest;

                    /**
                     * Decodes a DeleteRegionHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionHealthCheckRequest;

                    /**
                     * Verifies a DeleteRegionHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionHealthCheckRequest;

                    /**
                     * Creates a plain object from a DeleteRegionHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionHealthCheckServiceRequest. */
                interface IDeleteRegionHealthCheckServiceRequest {

                    /** DeleteRegionHealthCheckServiceRequest healthCheckService */
                    healthCheckService?: (string|null);

                    /** DeleteRegionHealthCheckServiceRequest project */
                    project?: (string|null);

                    /** DeleteRegionHealthCheckServiceRequest region */
                    region?: (string|null);

                    /** DeleteRegionHealthCheckServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionHealthCheckServiceRequest. */
                class DeleteRegionHealthCheckServiceRequest implements IDeleteRegionHealthCheckServiceRequest {

                    /**
                     * Constructs a new DeleteRegionHealthCheckServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionHealthCheckServiceRequest);

                    /** DeleteRegionHealthCheckServiceRequest healthCheckService. */
                    public healthCheckService: string;

                    /** DeleteRegionHealthCheckServiceRequest project. */
                    public project: string;

                    /** DeleteRegionHealthCheckServiceRequest region. */
                    public region: string;

                    /** DeleteRegionHealthCheckServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionHealthCheckServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionHealthCheckServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionHealthCheckServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionHealthCheckServiceRequest): google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest;

                    /**
                     * Encodes the specified DeleteRegionHealthCheckServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message DeleteRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionHealthCheckServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message DeleteRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionHealthCheckServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest;

                    /**
                     * Decodes a DeleteRegionHealthCheckServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest;

                    /**
                     * Verifies a DeleteRegionHealthCheckServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionHealthCheckServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionHealthCheckServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest;

                    /**
                     * Creates a plain object from a DeleteRegionHealthCheckServiceRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionHealthCheckServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionHealthCheckServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionHealthCheckServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionHealthCheckServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionInstanceGroupManagerRequest. */
                interface IDeleteRegionInstanceGroupManagerRequest {

                    /** DeleteRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** DeleteRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** DeleteRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** DeleteRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionInstanceGroupManagerRequest. */
                class DeleteRegionInstanceGroupManagerRequest implements IDeleteRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new DeleteRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest);

                    /** DeleteRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** DeleteRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** DeleteRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** DeleteRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest): google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified DeleteRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message DeleteRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a DeleteRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a DeleteRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a DeleteRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionNetworkEndpointGroupRequest. */
                interface IDeleteRegionNetworkEndpointGroupRequest {

                    /** DeleteRegionNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** DeleteRegionNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** DeleteRegionNetworkEndpointGroupRequest region */
                    region?: (string|null);

                    /** DeleteRegionNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionNetworkEndpointGroupRequest. */
                class DeleteRegionNetworkEndpointGroupRequest implements IDeleteRegionNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new DeleteRegionNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionNetworkEndpointGroupRequest);

                    /** DeleteRegionNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** DeleteRegionNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** DeleteRegionNetworkEndpointGroupRequest region. */
                    public region: string;

                    /** DeleteRegionNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionNetworkEndpointGroupRequest): google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified DeleteRegionNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DeleteRegionNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DeleteRegionNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest;

                    /**
                     * Decodes a DeleteRegionNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest;

                    /**
                     * Verifies a DeleteRegionNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a DeleteRegionNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionNetworkFirewallPolicyRequest. */
                interface IDeleteRegionNetworkFirewallPolicyRequest {

                    /** DeleteRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** DeleteRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** DeleteRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** DeleteRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionNetworkFirewallPolicyRequest. */
                class DeleteRegionNetworkFirewallPolicyRequest implements IDeleteRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new DeleteRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionNetworkFirewallPolicyRequest);

                    /** DeleteRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** DeleteRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** DeleteRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** DeleteRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified DeleteRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message DeleteRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message DeleteRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a DeleteRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a DeleteRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionNotificationEndpointRequest. */
                interface IDeleteRegionNotificationEndpointRequest {

                    /** DeleteRegionNotificationEndpointRequest notificationEndpoint */
                    notificationEndpoint?: (string|null);

                    /** DeleteRegionNotificationEndpointRequest project */
                    project?: (string|null);

                    /** DeleteRegionNotificationEndpointRequest region */
                    region?: (string|null);

                    /** DeleteRegionNotificationEndpointRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteRegionNotificationEndpointRequest. */
                class DeleteRegionNotificationEndpointRequest implements IDeleteRegionNotificationEndpointRequest {

                    /**
                     * Constructs a new DeleteRegionNotificationEndpointRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionNotificationEndpointRequest);

                    /** DeleteRegionNotificationEndpointRequest notificationEndpoint. */
                    public notificationEndpoint: string;

                    /** DeleteRegionNotificationEndpointRequest project. */
                    public project: string;

                    /** DeleteRegionNotificationEndpointRequest region. */
                    public region: string;

                    /** DeleteRegionNotificationEndpointRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionNotificationEndpointRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionNotificationEndpointRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionNotificationEndpointRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionNotificationEndpointRequest): google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest;

                    /**
                     * Encodes the specified DeleteRegionNotificationEndpointRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest.verify|verify} messages.
                     * @param message DeleteRegionNotificationEndpointRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionNotificationEndpointRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionNotificationEndpointRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest.verify|verify} messages.
                     * @param message DeleteRegionNotificationEndpointRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionNotificationEndpointRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionNotificationEndpointRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionNotificationEndpointRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest;

                    /**
                     * Decodes a DeleteRegionNotificationEndpointRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionNotificationEndpointRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest;

                    /**
                     * Verifies a DeleteRegionNotificationEndpointRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionNotificationEndpointRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionNotificationEndpointRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest;

                    /**
                     * Creates a plain object from a DeleteRegionNotificationEndpointRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionNotificationEndpointRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionNotificationEndpointRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionNotificationEndpointRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionNotificationEndpointRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionOperationRequest. */
                interface IDeleteRegionOperationRequest {

                    /** DeleteRegionOperationRequest operation */
                    operation?: (string|null);

                    /** DeleteRegionOperationRequest project */
                    project?: (string|null);

                    /** DeleteRegionOperationRequest region */
                    region?: (string|null);
                }

                /** Represents a DeleteRegionOperationRequest. */
                class DeleteRegionOperationRequest implements IDeleteRegionOperationRequest {

                    /**
                     * Constructs a new DeleteRegionOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionOperationRequest);

                    /** DeleteRegionOperationRequest operation. */
                    public operation: string;

                    /** DeleteRegionOperationRequest project. */
                    public project: string;

                    /** DeleteRegionOperationRequest region. */
                    public region: string;

                    /**
                     * Creates a new DeleteRegionOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionOperationRequest): google.cloud.compute.v1.DeleteRegionOperationRequest;

                    /**
                     * Encodes the specified DeleteRegionOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionOperationRequest.verify|verify} messages.
                     * @param message DeleteRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionOperationRequest.verify|verify} messages.
                     * @param message DeleteRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionOperationRequest;

                    /**
                     * Decodes a DeleteRegionOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionOperationRequest;

                    /**
                     * Verifies a DeleteRegionOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionOperationRequest;

                    /**
                     * Creates a plain object from a DeleteRegionOperationRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionOperationResponse. */
                interface IDeleteRegionOperationResponse {
                }

                /** Represents a DeleteRegionOperationResponse. */
                class DeleteRegionOperationResponse implements IDeleteRegionOperationResponse {

                    /**
                     * Constructs a new DeleteRegionOperationResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionOperationResponse);

                    /**
                     * Creates a new DeleteRegionOperationResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionOperationResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionOperationResponse): google.cloud.compute.v1.DeleteRegionOperationResponse;

                    /**
                     * Encodes the specified DeleteRegionOperationResponse message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionOperationResponse.verify|verify} messages.
                     * @param message DeleteRegionOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionOperationResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionOperationResponse.verify|verify} messages.
                     * @param message DeleteRegionOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionOperationResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionOperationResponse;

                    /**
                     * Decodes a DeleteRegionOperationResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionOperationResponse;

                    /**
                     * Verifies a DeleteRegionOperationResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionOperationResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionOperationResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionOperationResponse;

                    /**
                     * Creates a plain object from a DeleteRegionOperationResponse message. Also converts values to other types if specified.
                     * @param message DeleteRegionOperationResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionOperationResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionOperationResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionOperationResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionSecurityPolicyRequest. */
                interface IDeleteRegionSecurityPolicyRequest {

                    /** DeleteRegionSecurityPolicyRequest project */
                    project?: (string|null);

                    /** DeleteRegionSecurityPolicyRequest region */
                    region?: (string|null);

                    /** DeleteRegionSecurityPolicyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a DeleteRegionSecurityPolicyRequest. */
                class DeleteRegionSecurityPolicyRequest implements IDeleteRegionSecurityPolicyRequest {

                    /**
                     * Constructs a new DeleteRegionSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionSecurityPolicyRequest);

                    /** DeleteRegionSecurityPolicyRequest project. */
                    public project: string;

                    /** DeleteRegionSecurityPolicyRequest region. */
                    public region: string;

                    /** DeleteRegionSecurityPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** DeleteRegionSecurityPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionSecurityPolicyRequest): google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest;

                    /**
                     * Encodes the specified DeleteRegionSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message DeleteRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message DeleteRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest;

                    /**
                     * Decodes a DeleteRegionSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest;

                    /**
                     * Verifies a DeleteRegionSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteRegionSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionSslCertificateRequest. */
                interface IDeleteRegionSslCertificateRequest {

                    /** DeleteRegionSslCertificateRequest project */
                    project?: (string|null);

                    /** DeleteRegionSslCertificateRequest region */
                    region?: (string|null);

                    /** DeleteRegionSslCertificateRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionSslCertificateRequest sslCertificate */
                    sslCertificate?: (string|null);
                }

                /** Represents a DeleteRegionSslCertificateRequest. */
                class DeleteRegionSslCertificateRequest implements IDeleteRegionSslCertificateRequest {

                    /**
                     * Constructs a new DeleteRegionSslCertificateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionSslCertificateRequest);

                    /** DeleteRegionSslCertificateRequest project. */
                    public project: string;

                    /** DeleteRegionSslCertificateRequest region. */
                    public region: string;

                    /** DeleteRegionSslCertificateRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionSslCertificateRequest sslCertificate. */
                    public sslCertificate: string;

                    /** DeleteRegionSslCertificateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionSslCertificateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionSslCertificateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionSslCertificateRequest): google.cloud.compute.v1.DeleteRegionSslCertificateRequest;

                    /**
                     * Encodes the specified DeleteRegionSslCertificateRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionSslCertificateRequest.verify|verify} messages.
                     * @param message DeleteRegionSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionSslCertificateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionSslCertificateRequest.verify|verify} messages.
                     * @param message DeleteRegionSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionSslCertificateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionSslCertificateRequest;

                    /**
                     * Decodes a DeleteRegionSslCertificateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionSslCertificateRequest;

                    /**
                     * Verifies a DeleteRegionSslCertificateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionSslCertificateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionSslCertificateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionSslCertificateRequest;

                    /**
                     * Creates a plain object from a DeleteRegionSslCertificateRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionSslCertificateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionSslCertificateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionSslCertificateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionSslCertificateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionSslPolicyRequest. */
                interface IDeleteRegionSslPolicyRequest {

                    /** DeleteRegionSslPolicyRequest project */
                    project?: (string|null);

                    /** DeleteRegionSslPolicyRequest region */
                    region?: (string|null);

                    /** DeleteRegionSslPolicyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionSslPolicyRequest sslPolicy */
                    sslPolicy?: (string|null);
                }

                /** Represents a DeleteRegionSslPolicyRequest. */
                class DeleteRegionSslPolicyRequest implements IDeleteRegionSslPolicyRequest {

                    /**
                     * Constructs a new DeleteRegionSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionSslPolicyRequest);

                    /** DeleteRegionSslPolicyRequest project. */
                    public project: string;

                    /** DeleteRegionSslPolicyRequest region. */
                    public region: string;

                    /** DeleteRegionSslPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionSslPolicyRequest sslPolicy. */
                    public sslPolicy: string;

                    /** DeleteRegionSslPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionSslPolicyRequest): google.cloud.compute.v1.DeleteRegionSslPolicyRequest;

                    /**
                     * Encodes the specified DeleteRegionSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionSslPolicyRequest.verify|verify} messages.
                     * @param message DeleteRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionSslPolicyRequest.verify|verify} messages.
                     * @param message DeleteRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionSslPolicyRequest;

                    /**
                     * Decodes a DeleteRegionSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionSslPolicyRequest;

                    /**
                     * Verifies a DeleteRegionSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionSslPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteRegionSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionTargetHttpProxyRequest. */
                interface IDeleteRegionTargetHttpProxyRequest {

                    /** DeleteRegionTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** DeleteRegionTargetHttpProxyRequest region */
                    region?: (string|null);

                    /** DeleteRegionTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);
                }

                /** Represents a DeleteRegionTargetHttpProxyRequest. */
                class DeleteRegionTargetHttpProxyRequest implements IDeleteRegionTargetHttpProxyRequest {

                    /**
                     * Constructs a new DeleteRegionTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionTargetHttpProxyRequest);

                    /** DeleteRegionTargetHttpProxyRequest project. */
                    public project: string;

                    /** DeleteRegionTargetHttpProxyRequest region. */
                    public region: string;

                    /** DeleteRegionTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /** DeleteRegionTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionTargetHttpProxyRequest): google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest;

                    /**
                     * Encodes the specified DeleteRegionTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message DeleteRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message DeleteRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest;

                    /**
                     * Decodes a DeleteRegionTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest;

                    /**
                     * Verifies a DeleteRegionTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a DeleteRegionTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionTargetHttpsProxyRequest. */
                interface IDeleteRegionTargetHttpsProxyRequest {

                    /** DeleteRegionTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** DeleteRegionTargetHttpsProxyRequest region */
                    region?: (string|null);

                    /** DeleteRegionTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a DeleteRegionTargetHttpsProxyRequest. */
                class DeleteRegionTargetHttpsProxyRequest implements IDeleteRegionTargetHttpsProxyRequest {

                    /**
                     * Constructs a new DeleteRegionTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionTargetHttpsProxyRequest);

                    /** DeleteRegionTargetHttpsProxyRequest project. */
                    public project: string;

                    /** DeleteRegionTargetHttpsProxyRequest region. */
                    public region: string;

                    /** DeleteRegionTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** DeleteRegionTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionTargetHttpsProxyRequest): google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified DeleteRegionTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message DeleteRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message DeleteRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest;

                    /**
                     * Decodes a DeleteRegionTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest;

                    /**
                     * Verifies a DeleteRegionTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a DeleteRegionTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionTargetTcpProxyRequest. */
                interface IDeleteRegionTargetTcpProxyRequest {

                    /** DeleteRegionTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** DeleteRegionTargetTcpProxyRequest region */
                    region?: (string|null);

                    /** DeleteRegionTargetTcpProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionTargetTcpProxyRequest targetTcpProxy */
                    targetTcpProxy?: (string|null);
                }

                /** Represents a DeleteRegionTargetTcpProxyRequest. */
                class DeleteRegionTargetTcpProxyRequest implements IDeleteRegionTargetTcpProxyRequest {

                    /**
                     * Constructs a new DeleteRegionTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionTargetTcpProxyRequest);

                    /** DeleteRegionTargetTcpProxyRequest project. */
                    public project: string;

                    /** DeleteRegionTargetTcpProxyRequest region. */
                    public region: string;

                    /** DeleteRegionTargetTcpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionTargetTcpProxyRequest targetTcpProxy. */
                    public targetTcpProxy: string;

                    /** DeleteRegionTargetTcpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionTargetTcpProxyRequest): google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest;

                    /**
                     * Encodes the specified DeleteRegionTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest.verify|verify} messages.
                     * @param message DeleteRegionTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest.verify|verify} messages.
                     * @param message DeleteRegionTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest;

                    /**
                     * Decodes a DeleteRegionTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest;

                    /**
                     * Verifies a DeleteRegionTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from a DeleteRegionTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRegionUrlMapRequest. */
                interface IDeleteRegionUrlMapRequest {

                    /** DeleteRegionUrlMapRequest project */
                    project?: (string|null);

                    /** DeleteRegionUrlMapRequest region */
                    region?: (string|null);

                    /** DeleteRegionUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRegionUrlMapRequest urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a DeleteRegionUrlMapRequest. */
                class DeleteRegionUrlMapRequest implements IDeleteRegionUrlMapRequest {

                    /**
                     * Constructs a new DeleteRegionUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRegionUrlMapRequest);

                    /** DeleteRegionUrlMapRequest project. */
                    public project: string;

                    /** DeleteRegionUrlMapRequest region. */
                    public region: string;

                    /** DeleteRegionUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRegionUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** DeleteRegionUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRegionUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRegionUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRegionUrlMapRequest): google.cloud.compute.v1.DeleteRegionUrlMapRequest;

                    /**
                     * Encodes the specified DeleteRegionUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionUrlMapRequest.verify|verify} messages.
                     * @param message DeleteRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRegionUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRegionUrlMapRequest.verify|verify} messages.
                     * @param message DeleteRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRegionUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRegionUrlMapRequest;

                    /**
                     * Decodes a DeleteRegionUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRegionUrlMapRequest;

                    /**
                     * Verifies a DeleteRegionUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRegionUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRegionUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRegionUrlMapRequest;

                    /**
                     * Creates a plain object from a DeleteRegionUrlMapRequest message. Also converts values to other types if specified.
                     * @param message DeleteRegionUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRegionUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRegionUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRegionUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteReservationRequest. */
                interface IDeleteReservationRequest {

                    /** DeleteReservationRequest project */
                    project?: (string|null);

                    /** DeleteReservationRequest requestId */
                    requestId?: (string|null);

                    /** DeleteReservationRequest reservation */
                    reservation?: (string|null);

                    /** DeleteReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteReservationRequest. */
                class DeleteReservationRequest implements IDeleteReservationRequest {

                    /**
                     * Constructs a new DeleteReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteReservationRequest);

                    /** DeleteReservationRequest project. */
                    public project: string;

                    /** DeleteReservationRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteReservationRequest reservation. */
                    public reservation: string;

                    /** DeleteReservationRequest zone. */
                    public zone: string;

                    /** DeleteReservationRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteReservationRequest): google.cloud.compute.v1.DeleteReservationRequest;

                    /**
                     * Encodes the specified DeleteReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteReservationRequest.verify|verify} messages.
                     * @param message DeleteReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteReservationRequest.verify|verify} messages.
                     * @param message DeleteReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteReservationRequest;

                    /**
                     * Decodes a DeleteReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteReservationRequest;

                    /**
                     * Verifies a DeleteReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteReservationRequest;

                    /**
                     * Creates a plain object from a DeleteReservationRequest message. Also converts values to other types if specified.
                     * @param message DeleteReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteResourcePolicyRequest. */
                interface IDeleteResourcePolicyRequest {

                    /** DeleteResourcePolicyRequest project */
                    project?: (string|null);

                    /** DeleteResourcePolicyRequest region */
                    region?: (string|null);

                    /** DeleteResourcePolicyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteResourcePolicyRequest resourcePolicy */
                    resourcePolicy?: (string|null);
                }

                /** Represents a DeleteResourcePolicyRequest. */
                class DeleteResourcePolicyRequest implements IDeleteResourcePolicyRequest {

                    /**
                     * Constructs a new DeleteResourcePolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteResourcePolicyRequest);

                    /** DeleteResourcePolicyRequest project. */
                    public project: string;

                    /** DeleteResourcePolicyRequest region. */
                    public region: string;

                    /** DeleteResourcePolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteResourcePolicyRequest resourcePolicy. */
                    public resourcePolicy: string;

                    /** DeleteResourcePolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteResourcePolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteResourcePolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteResourcePolicyRequest): google.cloud.compute.v1.DeleteResourcePolicyRequest;

                    /**
                     * Encodes the specified DeleteResourcePolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteResourcePolicyRequest.verify|verify} messages.
                     * @param message DeleteResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteResourcePolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteResourcePolicyRequest.verify|verify} messages.
                     * @param message DeleteResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteResourcePolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteResourcePolicyRequest;

                    /**
                     * Decodes a DeleteResourcePolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteResourcePolicyRequest;

                    /**
                     * Verifies a DeleteResourcePolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteResourcePolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteResourcePolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteResourcePolicyRequest;

                    /**
                     * Creates a plain object from a DeleteResourcePolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteResourcePolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteResourcePolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteResourcePolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteResourcePolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRouteRequest. */
                interface IDeleteRouteRequest {

                    /** DeleteRouteRequest project */
                    project?: (string|null);

                    /** DeleteRouteRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRouteRequest route */
                    route?: (string|null);
                }

                /** Represents a DeleteRouteRequest. */
                class DeleteRouteRequest implements IDeleteRouteRequest {

                    /**
                     * Constructs a new DeleteRouteRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRouteRequest);

                    /** DeleteRouteRequest project. */
                    public project: string;

                    /** DeleteRouteRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRouteRequest route. */
                    public route: string;

                    /** DeleteRouteRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRouteRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRouteRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRouteRequest): google.cloud.compute.v1.DeleteRouteRequest;

                    /**
                     * Encodes the specified DeleteRouteRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRouteRequest.verify|verify} messages.
                     * @param message DeleteRouteRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRouteRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRouteRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRouteRequest.verify|verify} messages.
                     * @param message DeleteRouteRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRouteRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRouteRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRouteRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRouteRequest;

                    /**
                     * Decodes a DeleteRouteRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRouteRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRouteRequest;

                    /**
                     * Verifies a DeleteRouteRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRouteRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRouteRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRouteRequest;

                    /**
                     * Creates a plain object from a DeleteRouteRequest message. Also converts values to other types if specified.
                     * @param message DeleteRouteRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRouteRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRouteRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRouteRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteRouterRequest. */
                interface IDeleteRouterRequest {

                    /** DeleteRouterRequest project */
                    project?: (string|null);

                    /** DeleteRouterRequest region */
                    region?: (string|null);

                    /** DeleteRouterRequest requestId */
                    requestId?: (string|null);

                    /** DeleteRouterRequest router */
                    router?: (string|null);
                }

                /** Represents a DeleteRouterRequest. */
                class DeleteRouterRequest implements IDeleteRouterRequest {

                    /**
                     * Constructs a new DeleteRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteRouterRequest);

                    /** DeleteRouterRequest project. */
                    public project: string;

                    /** DeleteRouterRequest region. */
                    public region: string;

                    /** DeleteRouterRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteRouterRequest router. */
                    public router: string;

                    /** DeleteRouterRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteRouterRequest): google.cloud.compute.v1.DeleteRouterRequest;

                    /**
                     * Encodes the specified DeleteRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteRouterRequest.verify|verify} messages.
                     * @param message DeleteRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteRouterRequest.verify|verify} messages.
                     * @param message DeleteRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteRouterRequest;

                    /**
                     * Decodes a DeleteRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteRouterRequest;

                    /**
                     * Verifies a DeleteRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteRouterRequest;

                    /**
                     * Creates a plain object from a DeleteRouterRequest message. Also converts values to other types if specified.
                     * @param message DeleteRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSecurityPolicyRequest. */
                interface IDeleteSecurityPolicyRequest {

                    /** DeleteSecurityPolicyRequest project */
                    project?: (string|null);

                    /** DeleteSecurityPolicyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a DeleteSecurityPolicyRequest. */
                class DeleteSecurityPolicyRequest implements IDeleteSecurityPolicyRequest {

                    /**
                     * Constructs a new DeleteSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSecurityPolicyRequest);

                    /** DeleteSecurityPolicyRequest project. */
                    public project: string;

                    /** DeleteSecurityPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** DeleteSecurityPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSecurityPolicyRequest): google.cloud.compute.v1.DeleteSecurityPolicyRequest;

                    /**
                     * Encodes the specified DeleteSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSecurityPolicyRequest.verify|verify} messages.
                     * @param message DeleteSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSecurityPolicyRequest.verify|verify} messages.
                     * @param message DeleteSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSecurityPolicyRequest;

                    /**
                     * Decodes a DeleteSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSecurityPolicyRequest;

                    /**
                     * Verifies a DeleteSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteServiceAttachmentRequest. */
                interface IDeleteServiceAttachmentRequest {

                    /** DeleteServiceAttachmentRequest project */
                    project?: (string|null);

                    /** DeleteServiceAttachmentRequest region */
                    region?: (string|null);

                    /** DeleteServiceAttachmentRequest requestId */
                    requestId?: (string|null);

                    /** DeleteServiceAttachmentRequest serviceAttachment */
                    serviceAttachment?: (string|null);
                }

                /** Represents a DeleteServiceAttachmentRequest. */
                class DeleteServiceAttachmentRequest implements IDeleteServiceAttachmentRequest {

                    /**
                     * Constructs a new DeleteServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteServiceAttachmentRequest);

                    /** DeleteServiceAttachmentRequest project. */
                    public project: string;

                    /** DeleteServiceAttachmentRequest region. */
                    public region: string;

                    /** DeleteServiceAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteServiceAttachmentRequest serviceAttachment. */
                    public serviceAttachment: string;

                    /** DeleteServiceAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteServiceAttachmentRequest): google.cloud.compute.v1.DeleteServiceAttachmentRequest;

                    /**
                     * Encodes the specified DeleteServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteServiceAttachmentRequest.verify|verify} messages.
                     * @param message DeleteServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteServiceAttachmentRequest.verify|verify} messages.
                     * @param message DeleteServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteServiceAttachmentRequest;

                    /**
                     * Decodes a DeleteServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteServiceAttachmentRequest;

                    /**
                     * Verifies a DeleteServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteServiceAttachmentRequest;

                    /**
                     * Creates a plain object from a DeleteServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message DeleteServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSignedUrlKeyBackendBucketRequest. */
                interface IDeleteSignedUrlKeyBackendBucketRequest {

                    /** DeleteSignedUrlKeyBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** DeleteSignedUrlKeyBackendBucketRequest keyName */
                    keyName?: (string|null);

                    /** DeleteSignedUrlKeyBackendBucketRequest project */
                    project?: (string|null);

                    /** DeleteSignedUrlKeyBackendBucketRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteSignedUrlKeyBackendBucketRequest. */
                class DeleteSignedUrlKeyBackendBucketRequest implements IDeleteSignedUrlKeyBackendBucketRequest {

                    /**
                     * Constructs a new DeleteSignedUrlKeyBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendBucketRequest);

                    /** DeleteSignedUrlKeyBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** DeleteSignedUrlKeyBackendBucketRequest keyName. */
                    public keyName: string;

                    /** DeleteSignedUrlKeyBackendBucketRequest project. */
                    public project: string;

                    /** DeleteSignedUrlKeyBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSignedUrlKeyBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSignedUrlKeyBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSignedUrlKeyBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendBucketRequest): google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest;

                    /**
                     * Encodes the specified DeleteSignedUrlKeyBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest.verify|verify} messages.
                     * @param message DeleteSignedUrlKeyBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSignedUrlKeyBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest.verify|verify} messages.
                     * @param message DeleteSignedUrlKeyBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSignedUrlKeyBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSignedUrlKeyBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest;

                    /**
                     * Decodes a DeleteSignedUrlKeyBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSignedUrlKeyBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest;

                    /**
                     * Verifies a DeleteSignedUrlKeyBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSignedUrlKeyBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSignedUrlKeyBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest;

                    /**
                     * Creates a plain object from a DeleteSignedUrlKeyBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message DeleteSignedUrlKeyBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSignedUrlKeyBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSignedUrlKeyBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSignedUrlKeyBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSignedUrlKeyBackendServiceRequest. */
                interface IDeleteSignedUrlKeyBackendServiceRequest {

                    /** DeleteSignedUrlKeyBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** DeleteSignedUrlKeyBackendServiceRequest keyName */
                    keyName?: (string|null);

                    /** DeleteSignedUrlKeyBackendServiceRequest project */
                    project?: (string|null);

                    /** DeleteSignedUrlKeyBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteSignedUrlKeyBackendServiceRequest. */
                class DeleteSignedUrlKeyBackendServiceRequest implements IDeleteSignedUrlKeyBackendServiceRequest {

                    /**
                     * Constructs a new DeleteSignedUrlKeyBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendServiceRequest);

                    /** DeleteSignedUrlKeyBackendServiceRequest backendService. */
                    public backendService: string;

                    /** DeleteSignedUrlKeyBackendServiceRequest keyName. */
                    public keyName: string;

                    /** DeleteSignedUrlKeyBackendServiceRequest project. */
                    public project: string;

                    /** DeleteSignedUrlKeyBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSignedUrlKeyBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSignedUrlKeyBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSignedUrlKeyBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendServiceRequest): google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest;

                    /**
                     * Encodes the specified DeleteSignedUrlKeyBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest.verify|verify} messages.
                     * @param message DeleteSignedUrlKeyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSignedUrlKeyBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest.verify|verify} messages.
                     * @param message DeleteSignedUrlKeyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSignedUrlKeyBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSignedUrlKeyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest;

                    /**
                     * Decodes a DeleteSignedUrlKeyBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSignedUrlKeyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest;

                    /**
                     * Verifies a DeleteSignedUrlKeyBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSignedUrlKeyBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSignedUrlKeyBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest;

                    /**
                     * Creates a plain object from a DeleteSignedUrlKeyBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message DeleteSignedUrlKeyBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSignedUrlKeyBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSignedUrlKeyBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSignedUrlKeyBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSnapshotRequest. */
                interface IDeleteSnapshotRequest {

                    /** DeleteSnapshotRequest project */
                    project?: (string|null);

                    /** DeleteSnapshotRequest requestId */
                    requestId?: (string|null);

                    /** DeleteSnapshotRequest snapshot */
                    snapshot?: (string|null);
                }

                /** Represents a DeleteSnapshotRequest. */
                class DeleteSnapshotRequest implements IDeleteSnapshotRequest {

                    /**
                     * Constructs a new DeleteSnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSnapshotRequest);

                    /** DeleteSnapshotRequest project. */
                    public project: string;

                    /** DeleteSnapshotRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSnapshotRequest snapshot. */
                    public snapshot: string;

                    /** DeleteSnapshotRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSnapshotRequest): google.cloud.compute.v1.DeleteSnapshotRequest;

                    /**
                     * Encodes the specified DeleteSnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSnapshotRequest.verify|verify} messages.
                     * @param message DeleteSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSnapshotRequest.verify|verify} messages.
                     * @param message DeleteSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSnapshotRequest;

                    /**
                     * Decodes a DeleteSnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSnapshotRequest;

                    /**
                     * Verifies a DeleteSnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSnapshotRequest;

                    /**
                     * Creates a plain object from a DeleteSnapshotRequest message. Also converts values to other types if specified.
                     * @param message DeleteSnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSslCertificateRequest. */
                interface IDeleteSslCertificateRequest {

                    /** DeleteSslCertificateRequest project */
                    project?: (string|null);

                    /** DeleteSslCertificateRequest requestId */
                    requestId?: (string|null);

                    /** DeleteSslCertificateRequest sslCertificate */
                    sslCertificate?: (string|null);
                }

                /** Represents a DeleteSslCertificateRequest. */
                class DeleteSslCertificateRequest implements IDeleteSslCertificateRequest {

                    /**
                     * Constructs a new DeleteSslCertificateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSslCertificateRequest);

                    /** DeleteSslCertificateRequest project. */
                    public project: string;

                    /** DeleteSslCertificateRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSslCertificateRequest sslCertificate. */
                    public sslCertificate: string;

                    /** DeleteSslCertificateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSslCertificateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSslCertificateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSslCertificateRequest): google.cloud.compute.v1.DeleteSslCertificateRequest;

                    /**
                     * Encodes the specified DeleteSslCertificateRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSslCertificateRequest.verify|verify} messages.
                     * @param message DeleteSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSslCertificateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSslCertificateRequest.verify|verify} messages.
                     * @param message DeleteSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSslCertificateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSslCertificateRequest;

                    /**
                     * Decodes a DeleteSslCertificateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSslCertificateRequest;

                    /**
                     * Verifies a DeleteSslCertificateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSslCertificateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSslCertificateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSslCertificateRequest;

                    /**
                     * Creates a plain object from a DeleteSslCertificateRequest message. Also converts values to other types if specified.
                     * @param message DeleteSslCertificateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSslCertificateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSslCertificateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSslCertificateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSslPolicyRequest. */
                interface IDeleteSslPolicyRequest {

                    /** DeleteSslPolicyRequest project */
                    project?: (string|null);

                    /** DeleteSslPolicyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteSslPolicyRequest sslPolicy */
                    sslPolicy?: (string|null);
                }

                /** Represents a DeleteSslPolicyRequest. */
                class DeleteSslPolicyRequest implements IDeleteSslPolicyRequest {

                    /**
                     * Constructs a new DeleteSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSslPolicyRequest);

                    /** DeleteSslPolicyRequest project. */
                    public project: string;

                    /** DeleteSslPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSslPolicyRequest sslPolicy. */
                    public sslPolicy: string;

                    /** DeleteSslPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSslPolicyRequest): google.cloud.compute.v1.DeleteSslPolicyRequest;

                    /**
                     * Encodes the specified DeleteSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSslPolicyRequest.verify|verify} messages.
                     * @param message DeleteSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSslPolicyRequest.verify|verify} messages.
                     * @param message DeleteSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSslPolicyRequest;

                    /**
                     * Decodes a DeleteSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSslPolicyRequest;

                    /**
                     * Verifies a DeleteSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSslPolicyRequest;

                    /**
                     * Creates a plain object from a DeleteSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message DeleteSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteSubnetworkRequest. */
                interface IDeleteSubnetworkRequest {

                    /** DeleteSubnetworkRequest project */
                    project?: (string|null);

                    /** DeleteSubnetworkRequest region */
                    region?: (string|null);

                    /** DeleteSubnetworkRequest requestId */
                    requestId?: (string|null);

                    /** DeleteSubnetworkRequest subnetwork */
                    subnetwork?: (string|null);
                }

                /** Represents a DeleteSubnetworkRequest. */
                class DeleteSubnetworkRequest implements IDeleteSubnetworkRequest {

                    /**
                     * Constructs a new DeleteSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteSubnetworkRequest);

                    /** DeleteSubnetworkRequest project. */
                    public project: string;

                    /** DeleteSubnetworkRequest region. */
                    public region: string;

                    /** DeleteSubnetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteSubnetworkRequest subnetwork. */
                    public subnetwork: string;

                    /** DeleteSubnetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteSubnetworkRequest): google.cloud.compute.v1.DeleteSubnetworkRequest;

                    /**
                     * Encodes the specified DeleteSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteSubnetworkRequest.verify|verify} messages.
                     * @param message DeleteSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteSubnetworkRequest.verify|verify} messages.
                     * @param message DeleteSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteSubnetworkRequest;

                    /**
                     * Decodes a DeleteSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteSubnetworkRequest;

                    /**
                     * Verifies a DeleteSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteSubnetworkRequest;

                    /**
                     * Creates a plain object from a DeleteSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message DeleteSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetGrpcProxyRequest. */
                interface IDeleteTargetGrpcProxyRequest {

                    /** DeleteTargetGrpcProxyRequest project */
                    project?: (string|null);

                    /** DeleteTargetGrpcProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetGrpcProxyRequest targetGrpcProxy */
                    targetGrpcProxy?: (string|null);
                }

                /** Represents a DeleteTargetGrpcProxyRequest. */
                class DeleteTargetGrpcProxyRequest implements IDeleteTargetGrpcProxyRequest {

                    /**
                     * Constructs a new DeleteTargetGrpcProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetGrpcProxyRequest);

                    /** DeleteTargetGrpcProxyRequest project. */
                    public project: string;

                    /** DeleteTargetGrpcProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetGrpcProxyRequest targetGrpcProxy. */
                    public targetGrpcProxy: string;

                    /** DeleteTargetGrpcProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetGrpcProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetGrpcProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetGrpcProxyRequest): google.cloud.compute.v1.DeleteTargetGrpcProxyRequest;

                    /**
                     * Encodes the specified DeleteTargetGrpcProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetGrpcProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetGrpcProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetGrpcProxyRequest;

                    /**
                     * Decodes a DeleteTargetGrpcProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetGrpcProxyRequest;

                    /**
                     * Verifies a DeleteTargetGrpcProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetGrpcProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetGrpcProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetGrpcProxyRequest;

                    /**
                     * Creates a plain object from a DeleteTargetGrpcProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetGrpcProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetGrpcProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetGrpcProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetGrpcProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetHttpProxyRequest. */
                interface IDeleteTargetHttpProxyRequest {

                    /** DeleteTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** DeleteTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);
                }

                /** Represents a DeleteTargetHttpProxyRequest. */
                class DeleteTargetHttpProxyRequest implements IDeleteTargetHttpProxyRequest {

                    /**
                     * Constructs a new DeleteTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetHttpProxyRequest);

                    /** DeleteTargetHttpProxyRequest project. */
                    public project: string;

                    /** DeleteTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /** DeleteTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetHttpProxyRequest): google.cloud.compute.v1.DeleteTargetHttpProxyRequest;

                    /**
                     * Encodes the specified DeleteTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetHttpProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetHttpProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetHttpProxyRequest;

                    /**
                     * Decodes a DeleteTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetHttpProxyRequest;

                    /**
                     * Verifies a DeleteTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a DeleteTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetHttpsProxyRequest. */
                interface IDeleteTargetHttpsProxyRequest {

                    /** DeleteTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** DeleteTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a DeleteTargetHttpsProxyRequest. */
                class DeleteTargetHttpsProxyRequest implements IDeleteTargetHttpsProxyRequest {

                    /**
                     * Constructs a new DeleteTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetHttpsProxyRequest);

                    /** DeleteTargetHttpsProxyRequest project. */
                    public project: string;

                    /** DeleteTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** DeleteTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetHttpsProxyRequest): google.cloud.compute.v1.DeleteTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified DeleteTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetHttpsProxyRequest;

                    /**
                     * Decodes a DeleteTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetHttpsProxyRequest;

                    /**
                     * Verifies a DeleteTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a DeleteTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetInstanceRequest. */
                interface IDeleteTargetInstanceRequest {

                    /** DeleteTargetInstanceRequest project */
                    project?: (string|null);

                    /** DeleteTargetInstanceRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetInstanceRequest targetInstance */
                    targetInstance?: (string|null);

                    /** DeleteTargetInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteTargetInstanceRequest. */
                class DeleteTargetInstanceRequest implements IDeleteTargetInstanceRequest {

                    /**
                     * Constructs a new DeleteTargetInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetInstanceRequest);

                    /** DeleteTargetInstanceRequest project. */
                    public project: string;

                    /** DeleteTargetInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetInstanceRequest targetInstance. */
                    public targetInstance: string;

                    /** DeleteTargetInstanceRequest zone. */
                    public zone: string;

                    /** DeleteTargetInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetInstanceRequest): google.cloud.compute.v1.DeleteTargetInstanceRequest;

                    /**
                     * Encodes the specified DeleteTargetInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetInstanceRequest.verify|verify} messages.
                     * @param message DeleteTargetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetInstanceRequest.verify|verify} messages.
                     * @param message DeleteTargetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetInstanceRequest;

                    /**
                     * Decodes a DeleteTargetInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetInstanceRequest;

                    /**
                     * Verifies a DeleteTargetInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetInstanceRequest;

                    /**
                     * Creates a plain object from a DeleteTargetInstanceRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetPoolRequest. */
                interface IDeleteTargetPoolRequest {

                    /** DeleteTargetPoolRequest project */
                    project?: (string|null);

                    /** DeleteTargetPoolRequest region */
                    region?: (string|null);

                    /** DeleteTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetPoolRequest targetPool */
                    targetPool?: (string|null);
                }

                /** Represents a DeleteTargetPoolRequest. */
                class DeleteTargetPoolRequest implements IDeleteTargetPoolRequest {

                    /**
                     * Constructs a new DeleteTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetPoolRequest);

                    /** DeleteTargetPoolRequest project. */
                    public project: string;

                    /** DeleteTargetPoolRequest region. */
                    public region: string;

                    /** DeleteTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /** DeleteTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetPoolRequest): google.cloud.compute.v1.DeleteTargetPoolRequest;

                    /**
                     * Encodes the specified DeleteTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetPoolRequest.verify|verify} messages.
                     * @param message DeleteTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetPoolRequest.verify|verify} messages.
                     * @param message DeleteTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetPoolRequest;

                    /**
                     * Decodes a DeleteTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetPoolRequest;

                    /**
                     * Verifies a DeleteTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetPoolRequest;

                    /**
                     * Creates a plain object from a DeleteTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetSslProxyRequest. */
                interface IDeleteTargetSslProxyRequest {

                    /** DeleteTargetSslProxyRequest project */
                    project?: (string|null);

                    /** DeleteTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a DeleteTargetSslProxyRequest. */
                class DeleteTargetSslProxyRequest implements IDeleteTargetSslProxyRequest {

                    /**
                     * Constructs a new DeleteTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetSslProxyRequest);

                    /** DeleteTargetSslProxyRequest project. */
                    public project: string;

                    /** DeleteTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /** DeleteTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetSslProxyRequest): google.cloud.compute.v1.DeleteTargetSslProxyRequest;

                    /**
                     * Encodes the specified DeleteTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetSslProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetSslProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetSslProxyRequest;

                    /**
                     * Decodes a DeleteTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetSslProxyRequest;

                    /**
                     * Verifies a DeleteTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a DeleteTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetTcpProxyRequest. */
                interface IDeleteTargetTcpProxyRequest {

                    /** DeleteTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** DeleteTargetTcpProxyRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetTcpProxyRequest targetTcpProxy */
                    targetTcpProxy?: (string|null);
                }

                /** Represents a DeleteTargetTcpProxyRequest. */
                class DeleteTargetTcpProxyRequest implements IDeleteTargetTcpProxyRequest {

                    /**
                     * Constructs a new DeleteTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetTcpProxyRequest);

                    /** DeleteTargetTcpProxyRequest project. */
                    public project: string;

                    /** DeleteTargetTcpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetTcpProxyRequest targetTcpProxy. */
                    public targetTcpProxy: string;

                    /** DeleteTargetTcpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetTcpProxyRequest): google.cloud.compute.v1.DeleteTargetTcpProxyRequest;

                    /**
                     * Encodes the specified DeleteTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetTcpProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetTcpProxyRequest.verify|verify} messages.
                     * @param message DeleteTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetTcpProxyRequest;

                    /**
                     * Decodes a DeleteTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetTcpProxyRequest;

                    /**
                     * Verifies a DeleteTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from a DeleteTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteTargetVpnGatewayRequest. */
                interface IDeleteTargetVpnGatewayRequest {

                    /** DeleteTargetVpnGatewayRequest project */
                    project?: (string|null);

                    /** DeleteTargetVpnGatewayRequest region */
                    region?: (string|null);

                    /** DeleteTargetVpnGatewayRequest requestId */
                    requestId?: (string|null);

                    /** DeleteTargetVpnGatewayRequest targetVpnGateway */
                    targetVpnGateway?: (string|null);
                }

                /** Represents a DeleteTargetVpnGatewayRequest. */
                class DeleteTargetVpnGatewayRequest implements IDeleteTargetVpnGatewayRequest {

                    /**
                     * Constructs a new DeleteTargetVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteTargetVpnGatewayRequest);

                    /** DeleteTargetVpnGatewayRequest project. */
                    public project: string;

                    /** DeleteTargetVpnGatewayRequest region. */
                    public region: string;

                    /** DeleteTargetVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteTargetVpnGatewayRequest targetVpnGateway. */
                    public targetVpnGateway: string;

                    /** DeleteTargetVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteTargetVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteTargetVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteTargetVpnGatewayRequest): google.cloud.compute.v1.DeleteTargetVpnGatewayRequest;

                    /**
                     * Encodes the specified DeleteTargetVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message DeleteTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteTargetVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message DeleteTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteTargetVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteTargetVpnGatewayRequest;

                    /**
                     * Decodes a DeleteTargetVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteTargetVpnGatewayRequest;

                    /**
                     * Verifies a DeleteTargetVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteTargetVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteTargetVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteTargetVpnGatewayRequest;

                    /**
                     * Creates a plain object from a DeleteTargetVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message DeleteTargetVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteTargetVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteTargetVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteTargetVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteUrlMapRequest. */
                interface IDeleteUrlMapRequest {

                    /** DeleteUrlMapRequest project */
                    project?: (string|null);

                    /** DeleteUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** DeleteUrlMapRequest urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a DeleteUrlMapRequest. */
                class DeleteUrlMapRequest implements IDeleteUrlMapRequest {

                    /**
                     * Constructs a new DeleteUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteUrlMapRequest);

                    /** DeleteUrlMapRequest project. */
                    public project: string;

                    /** DeleteUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** DeleteUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteUrlMapRequest): google.cloud.compute.v1.DeleteUrlMapRequest;

                    /**
                     * Encodes the specified DeleteUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteUrlMapRequest.verify|verify} messages.
                     * @param message DeleteUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteUrlMapRequest.verify|verify} messages.
                     * @param message DeleteUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteUrlMapRequest;

                    /**
                     * Decodes a DeleteUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteUrlMapRequest;

                    /**
                     * Verifies a DeleteUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteUrlMapRequest;

                    /**
                     * Creates a plain object from a DeleteUrlMapRequest message. Also converts values to other types if specified.
                     * @param message DeleteUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteVpnGatewayRequest. */
                interface IDeleteVpnGatewayRequest {

                    /** DeleteVpnGatewayRequest project */
                    project?: (string|null);

                    /** DeleteVpnGatewayRequest region */
                    region?: (string|null);

                    /** DeleteVpnGatewayRequest requestId */
                    requestId?: (string|null);

                    /** DeleteVpnGatewayRequest vpnGateway */
                    vpnGateway?: (string|null);
                }

                /** Represents a DeleteVpnGatewayRequest. */
                class DeleteVpnGatewayRequest implements IDeleteVpnGatewayRequest {

                    /**
                     * Constructs a new DeleteVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteVpnGatewayRequest);

                    /** DeleteVpnGatewayRequest project. */
                    public project: string;

                    /** DeleteVpnGatewayRequest region. */
                    public region: string;

                    /** DeleteVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteVpnGatewayRequest vpnGateway. */
                    public vpnGateway: string;

                    /** DeleteVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteVpnGatewayRequest): google.cloud.compute.v1.DeleteVpnGatewayRequest;

                    /**
                     * Encodes the specified DeleteVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteVpnGatewayRequest.verify|verify} messages.
                     * @param message DeleteVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteVpnGatewayRequest.verify|verify} messages.
                     * @param message DeleteVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteVpnGatewayRequest;

                    /**
                     * Decodes a DeleteVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteVpnGatewayRequest;

                    /**
                     * Verifies a DeleteVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteVpnGatewayRequest;

                    /**
                     * Creates a plain object from a DeleteVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message DeleteVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteVpnTunnelRequest. */
                interface IDeleteVpnTunnelRequest {

                    /** DeleteVpnTunnelRequest project */
                    project?: (string|null);

                    /** DeleteVpnTunnelRequest region */
                    region?: (string|null);

                    /** DeleteVpnTunnelRequest requestId */
                    requestId?: (string|null);

                    /** DeleteVpnTunnelRequest vpnTunnel */
                    vpnTunnel?: (string|null);
                }

                /** Represents a DeleteVpnTunnelRequest. */
                class DeleteVpnTunnelRequest implements IDeleteVpnTunnelRequest {

                    /**
                     * Constructs a new DeleteVpnTunnelRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteVpnTunnelRequest);

                    /** DeleteVpnTunnelRequest project. */
                    public project: string;

                    /** DeleteVpnTunnelRequest region. */
                    public region: string;

                    /** DeleteVpnTunnelRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteVpnTunnelRequest vpnTunnel. */
                    public vpnTunnel: string;

                    /** DeleteVpnTunnelRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteVpnTunnelRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteVpnTunnelRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteVpnTunnelRequest): google.cloud.compute.v1.DeleteVpnTunnelRequest;

                    /**
                     * Encodes the specified DeleteVpnTunnelRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteVpnTunnelRequest.verify|verify} messages.
                     * @param message DeleteVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteVpnTunnelRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteVpnTunnelRequest.verify|verify} messages.
                     * @param message DeleteVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteVpnTunnelRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteVpnTunnelRequest;

                    /**
                     * Decodes a DeleteVpnTunnelRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteVpnTunnelRequest;

                    /**
                     * Verifies a DeleteVpnTunnelRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteVpnTunnelRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteVpnTunnelRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteVpnTunnelRequest;

                    /**
                     * Creates a plain object from a DeleteVpnTunnelRequest message. Also converts values to other types if specified.
                     * @param message DeleteVpnTunnelRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteVpnTunnelRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteVpnTunnelRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteVpnTunnelRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteZoneOperationRequest. */
                interface IDeleteZoneOperationRequest {

                    /** DeleteZoneOperationRequest operation */
                    operation?: (string|null);

                    /** DeleteZoneOperationRequest project */
                    project?: (string|null);

                    /** DeleteZoneOperationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DeleteZoneOperationRequest. */
                class DeleteZoneOperationRequest implements IDeleteZoneOperationRequest {

                    /**
                     * Constructs a new DeleteZoneOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteZoneOperationRequest);

                    /** DeleteZoneOperationRequest operation. */
                    public operation: string;

                    /** DeleteZoneOperationRequest project. */
                    public project: string;

                    /** DeleteZoneOperationRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new DeleteZoneOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteZoneOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteZoneOperationRequest): google.cloud.compute.v1.DeleteZoneOperationRequest;

                    /**
                     * Encodes the specified DeleteZoneOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.DeleteZoneOperationRequest.verify|verify} messages.
                     * @param message DeleteZoneOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteZoneOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteZoneOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteZoneOperationRequest.verify|verify} messages.
                     * @param message DeleteZoneOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteZoneOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteZoneOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteZoneOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteZoneOperationRequest;

                    /**
                     * Decodes a DeleteZoneOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteZoneOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteZoneOperationRequest;

                    /**
                     * Verifies a DeleteZoneOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteZoneOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteZoneOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteZoneOperationRequest;

                    /**
                     * Creates a plain object from a DeleteZoneOperationRequest message. Also converts values to other types if specified.
                     * @param message DeleteZoneOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteZoneOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteZoneOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteZoneOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteZoneOperationResponse. */
                interface IDeleteZoneOperationResponse {
                }

                /** Represents a DeleteZoneOperationResponse. */
                class DeleteZoneOperationResponse implements IDeleteZoneOperationResponse {

                    /**
                     * Constructs a new DeleteZoneOperationResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeleteZoneOperationResponse);

                    /**
                     * Creates a new DeleteZoneOperationResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteZoneOperationResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeleteZoneOperationResponse): google.cloud.compute.v1.DeleteZoneOperationResponse;

                    /**
                     * Encodes the specified DeleteZoneOperationResponse message. Does not implicitly {@link google.cloud.compute.v1.DeleteZoneOperationResponse.verify|verify} messages.
                     * @param message DeleteZoneOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeleteZoneOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteZoneOperationResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeleteZoneOperationResponse.verify|verify} messages.
                     * @param message DeleteZoneOperationResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeleteZoneOperationResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteZoneOperationResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteZoneOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeleteZoneOperationResponse;

                    /**
                     * Decodes a DeleteZoneOperationResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteZoneOperationResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeleteZoneOperationResponse;

                    /**
                     * Verifies a DeleteZoneOperationResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteZoneOperationResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteZoneOperationResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeleteZoneOperationResponse;

                    /**
                     * Creates a plain object from a DeleteZoneOperationResponse message. Also converts values to other types if specified.
                     * @param message DeleteZoneOperationResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeleteZoneOperationResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteZoneOperationResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteZoneOperationResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Denied. */
                interface IDenied {

                    /** Denied IPProtocol */
                    IPProtocol?: (string|null);

                    /** Denied ports */
                    ports?: (string[]|null);
                }

                /** Represents a Denied. */
                class Denied implements IDenied {

                    /**
                     * Constructs a new Denied.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDenied);

                    /** Denied IPProtocol. */
                    public IPProtocol?: (string|null);

                    /** Denied ports. */
                    public ports: string[];

                    /** Denied _IPProtocol. */
                    public _IPProtocol?: "IPProtocol";

                    /**
                     * Creates a new Denied instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Denied instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDenied): google.cloud.compute.v1.Denied;

                    /**
                     * Encodes the specified Denied message. Does not implicitly {@link google.cloud.compute.v1.Denied.verify|verify} messages.
                     * @param message Denied message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDenied, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Denied message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Denied.verify|verify} messages.
                     * @param message Denied message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDenied, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Denied message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Denied
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Denied;

                    /**
                     * Decodes a Denied message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Denied
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Denied;

                    /**
                     * Verifies a Denied message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Denied message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Denied
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Denied;

                    /**
                     * Creates a plain object from a Denied message. Also converts values to other types if specified.
                     * @param message Denied
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Denied, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Denied to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Denied
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeprecateImageRequest. */
                interface IDeprecateImageRequest {

                    /** DeprecateImageRequest deprecationStatusResource */
                    deprecationStatusResource?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** DeprecateImageRequest image */
                    image?: (string|null);

                    /** DeprecateImageRequest project */
                    project?: (string|null);

                    /** DeprecateImageRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeprecateImageRequest. */
                class DeprecateImageRequest implements IDeprecateImageRequest {

                    /**
                     * Constructs a new DeprecateImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeprecateImageRequest);

                    /** DeprecateImageRequest deprecationStatusResource. */
                    public deprecationStatusResource?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** DeprecateImageRequest image. */
                    public image: string;

                    /** DeprecateImageRequest project. */
                    public project: string;

                    /** DeprecateImageRequest requestId. */
                    public requestId?: (string|null);

                    /** DeprecateImageRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeprecateImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeprecateImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeprecateImageRequest): google.cloud.compute.v1.DeprecateImageRequest;

                    /**
                     * Encodes the specified DeprecateImageRequest message. Does not implicitly {@link google.cloud.compute.v1.DeprecateImageRequest.verify|verify} messages.
                     * @param message DeprecateImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeprecateImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeprecateImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeprecateImageRequest.verify|verify} messages.
                     * @param message DeprecateImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeprecateImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeprecateImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeprecateImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeprecateImageRequest;

                    /**
                     * Decodes a DeprecateImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeprecateImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeprecateImageRequest;

                    /**
                     * Verifies a DeprecateImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeprecateImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeprecateImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeprecateImageRequest;

                    /**
                     * Creates a plain object from a DeprecateImageRequest message. Also converts values to other types if specified.
                     * @param message DeprecateImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeprecateImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeprecateImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeprecateImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeprecationStatus. */
                interface IDeprecationStatus {

                    /** DeprecationStatus deleted */
                    deleted?: (string|null);

                    /** DeprecationStatus deprecated */
                    deprecated?: (string|null);

                    /** DeprecationStatus obsolete */
                    obsolete?: (string|null);

                    /** DeprecationStatus replacement */
                    replacement?: (string|null);

                    /** DeprecationStatus state */
                    state?: (string|null);
                }

                /** Represents a DeprecationStatus. */
                class DeprecationStatus implements IDeprecationStatus {

                    /**
                     * Constructs a new DeprecationStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDeprecationStatus);

                    /** DeprecationStatus deleted. */
                    public deleted?: (string|null);

                    /** DeprecationStatus deprecated. */
                    public deprecated?: (string|null);

                    /** DeprecationStatus obsolete. */
                    public obsolete?: (string|null);

                    /** DeprecationStatus replacement. */
                    public replacement?: (string|null);

                    /** DeprecationStatus state. */
                    public state?: (string|null);

                    /** DeprecationStatus _deleted. */
                    public _deleted?: "deleted";

                    /** DeprecationStatus _deprecated. */
                    public _deprecated?: "deprecated";

                    /** DeprecationStatus _obsolete. */
                    public _obsolete?: "obsolete";

                    /** DeprecationStatus _replacement. */
                    public _replacement?: "replacement";

                    /** DeprecationStatus _state. */
                    public _state?: "state";

                    /**
                     * Creates a new DeprecationStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeprecationStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDeprecationStatus): google.cloud.compute.v1.DeprecationStatus;

                    /**
                     * Encodes the specified DeprecationStatus message. Does not implicitly {@link google.cloud.compute.v1.DeprecationStatus.verify|verify} messages.
                     * @param message DeprecationStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDeprecationStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeprecationStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DeprecationStatus.verify|verify} messages.
                     * @param message DeprecationStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDeprecationStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeprecationStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeprecationStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DeprecationStatus;

                    /**
                     * Decodes a DeprecationStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeprecationStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DeprecationStatus;

                    /**
                     * Verifies a DeprecationStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeprecationStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeprecationStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DeprecationStatus;

                    /**
                     * Creates a plain object from a DeprecationStatus message. Also converts values to other types if specified.
                     * @param message DeprecationStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DeprecationStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeprecationStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeprecationStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DeprecationStatus {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        DELETED = 120962041,
                        DEPRECATED = 463360435,
                        OBSOLETE = 66532761
                    }
                }

                /** Properties of a DetachDiskInstanceRequest. */
                interface IDetachDiskInstanceRequest {

                    /** DetachDiskInstanceRequest deviceName */
                    deviceName?: (string|null);

                    /** DetachDiskInstanceRequest instance */
                    instance?: (string|null);

                    /** DetachDiskInstanceRequest project */
                    project?: (string|null);

                    /** DetachDiskInstanceRequest requestId */
                    requestId?: (string|null);

                    /** DetachDiskInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DetachDiskInstanceRequest. */
                class DetachDiskInstanceRequest implements IDetachDiskInstanceRequest {

                    /**
                     * Constructs a new DetachDiskInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDetachDiskInstanceRequest);

                    /** DetachDiskInstanceRequest deviceName. */
                    public deviceName: string;

                    /** DetachDiskInstanceRequest instance. */
                    public instance: string;

                    /** DetachDiskInstanceRequest project. */
                    public project: string;

                    /** DetachDiskInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** DetachDiskInstanceRequest zone. */
                    public zone: string;

                    /** DetachDiskInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DetachDiskInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DetachDiskInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDetachDiskInstanceRequest): google.cloud.compute.v1.DetachDiskInstanceRequest;

                    /**
                     * Encodes the specified DetachDiskInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.DetachDiskInstanceRequest.verify|verify} messages.
                     * @param message DetachDiskInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDetachDiskInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DetachDiskInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DetachDiskInstanceRequest.verify|verify} messages.
                     * @param message DetachDiskInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDetachDiskInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DetachDiskInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DetachDiskInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DetachDiskInstanceRequest;

                    /**
                     * Decodes a DetachDiskInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DetachDiskInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DetachDiskInstanceRequest;

                    /**
                     * Verifies a DetachDiskInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DetachDiskInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DetachDiskInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DetachDiskInstanceRequest;

                    /**
                     * Creates a plain object from a DetachDiskInstanceRequest message. Also converts values to other types if specified.
                     * @param message DetachDiskInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DetachDiskInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DetachDiskInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DetachDiskInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest. */
                interface IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest {

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest globalNetworkEndpointGroupsDetachEndpointsRequestResource */
                    globalNetworkEndpointGroupsDetachEndpointsRequestResource?: (google.cloud.compute.v1.IGlobalNetworkEndpointGroupsDetachEndpointsRequest|null);

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest. */
                class DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest implements IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest);

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest globalNetworkEndpointGroupsDetachEndpointsRequestResource. */
                    public globalNetworkEndpointGroupsDetachEndpointsRequestResource?: (google.cloud.compute.v1.IGlobalNetworkEndpointGroupsDetachEndpointsRequest|null);

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest): google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Decodes a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Verifies a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DetachNetworkEndpointsNetworkEndpointGroupRequest. */
                interface IDetachNetworkEndpointsNetworkEndpointGroupRequest {

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroupsDetachEndpointsRequestResource */
                    networkEndpointGroupsDetachEndpointsRequestResource?: (google.cloud.compute.v1.INetworkEndpointGroupsDetachEndpointsRequest|null);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a DetachNetworkEndpointsNetworkEndpointGroupRequest. */
                class DetachNetworkEndpointsNetworkEndpointGroupRequest implements IDetachNetworkEndpointsNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new DetachNetworkEndpointsNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDetachNetworkEndpointsNetworkEndpointGroupRequest);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest networkEndpointGroupsDetachEndpointsRequestResource. */
                    public networkEndpointGroupsDetachEndpointsRequestResource?: (google.cloud.compute.v1.INetworkEndpointGroupsDetachEndpointsRequest|null);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest zone. */
                    public zone: string;

                    /** DetachNetworkEndpointsNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DetachNetworkEndpointsNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DetachNetworkEndpointsNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDetachNetworkEndpointsNetworkEndpointGroupRequest): google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified DetachNetworkEndpointsNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DetachNetworkEndpointsNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDetachNetworkEndpointsNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DetachNetworkEndpointsNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message DetachNetworkEndpointsNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDetachNetworkEndpointsNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DetachNetworkEndpointsNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DetachNetworkEndpointsNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Decodes a DetachNetworkEndpointsNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DetachNetworkEndpointsNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Verifies a DetachNetworkEndpointsNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DetachNetworkEndpointsNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DetachNetworkEndpointsNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a DetachNetworkEndpointsNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message DetachNetworkEndpointsNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DetachNetworkEndpointsNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DetachNetworkEndpointsNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DetachNetworkEndpointsNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableXpnHostProjectRequest. */
                interface IDisableXpnHostProjectRequest {

                    /** DisableXpnHostProjectRequest project */
                    project?: (string|null);

                    /** DisableXpnHostProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DisableXpnHostProjectRequest. */
                class DisableXpnHostProjectRequest implements IDisableXpnHostProjectRequest {

                    /**
                     * Constructs a new DisableXpnHostProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisableXpnHostProjectRequest);

                    /** DisableXpnHostProjectRequest project. */
                    public project: string;

                    /** DisableXpnHostProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** DisableXpnHostProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DisableXpnHostProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableXpnHostProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisableXpnHostProjectRequest): google.cloud.compute.v1.DisableXpnHostProjectRequest;

                    /**
                     * Encodes the specified DisableXpnHostProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.DisableXpnHostProjectRequest.verify|verify} messages.
                     * @param message DisableXpnHostProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisableXpnHostProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableXpnHostProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisableXpnHostProjectRequest.verify|verify} messages.
                     * @param message DisableXpnHostProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisableXpnHostProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableXpnHostProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableXpnHostProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisableXpnHostProjectRequest;

                    /**
                     * Decodes a DisableXpnHostProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableXpnHostProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisableXpnHostProjectRequest;

                    /**
                     * Verifies a DisableXpnHostProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableXpnHostProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableXpnHostProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisableXpnHostProjectRequest;

                    /**
                     * Creates a plain object from a DisableXpnHostProjectRequest message. Also converts values to other types if specified.
                     * @param message DisableXpnHostProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisableXpnHostProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableXpnHostProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableXpnHostProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableXpnResourceProjectRequest. */
                interface IDisableXpnResourceProjectRequest {

                    /** DisableXpnResourceProjectRequest project */
                    project?: (string|null);

                    /** DisableXpnResourceProjectRequest projectsDisableXpnResourceRequestResource */
                    projectsDisableXpnResourceRequestResource?: (google.cloud.compute.v1.IProjectsDisableXpnResourceRequest|null);

                    /** DisableXpnResourceProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DisableXpnResourceProjectRequest. */
                class DisableXpnResourceProjectRequest implements IDisableXpnResourceProjectRequest {

                    /**
                     * Constructs a new DisableXpnResourceProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisableXpnResourceProjectRequest);

                    /** DisableXpnResourceProjectRequest project. */
                    public project: string;

                    /** DisableXpnResourceProjectRequest projectsDisableXpnResourceRequestResource. */
                    public projectsDisableXpnResourceRequestResource?: (google.cloud.compute.v1.IProjectsDisableXpnResourceRequest|null);

                    /** DisableXpnResourceProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** DisableXpnResourceProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DisableXpnResourceProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableXpnResourceProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisableXpnResourceProjectRequest): google.cloud.compute.v1.DisableXpnResourceProjectRequest;

                    /**
                     * Encodes the specified DisableXpnResourceProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.DisableXpnResourceProjectRequest.verify|verify} messages.
                     * @param message DisableXpnResourceProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisableXpnResourceProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableXpnResourceProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisableXpnResourceProjectRequest.verify|verify} messages.
                     * @param message DisableXpnResourceProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisableXpnResourceProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableXpnResourceProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableXpnResourceProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisableXpnResourceProjectRequest;

                    /**
                     * Decodes a DisableXpnResourceProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableXpnResourceProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisableXpnResourceProjectRequest;

                    /**
                     * Verifies a DisableXpnResourceProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableXpnResourceProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableXpnResourceProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisableXpnResourceProjectRequest;

                    /**
                     * Creates a plain object from a DisableXpnResourceProjectRequest message. Also converts values to other types if specified.
                     * @param message DisableXpnResourceProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisableXpnResourceProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableXpnResourceProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableXpnResourceProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Disk. */
                interface IDisk {

                    /** Disk architecture */
                    architecture?: (string|null);

                    /** Disk creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Disk description */
                    description?: (string|null);

                    /** Disk diskEncryptionKey */
                    diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Disk guestOsFeatures */
                    guestOsFeatures?: (google.cloud.compute.v1.IGuestOsFeature[]|null);

                    /** Disk id */
                    id?: (number|Long|string|null);

                    /** Disk kind */
                    kind?: (string|null);

                    /** Disk labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** Disk labels */
                    labels?: ({ [k: string]: string }|null);

                    /** Disk lastAttachTimestamp */
                    lastAttachTimestamp?: (string|null);

                    /** Disk lastDetachTimestamp */
                    lastDetachTimestamp?: (string|null);

                    /** Disk licenseCodes */
                    licenseCodes?: ((number|Long|string)[]|null);

                    /** Disk licenses */
                    licenses?: (string[]|null);

                    /** Disk locationHint */
                    locationHint?: (string|null);

                    /** Disk name */
                    name?: (string|null);

                    /** Disk options */
                    options?: (string|null);

                    /** Disk params */
                    params?: (google.cloud.compute.v1.IDiskParams|null);

                    /** Disk physicalBlockSizeBytes */
                    physicalBlockSizeBytes?: (number|Long|string|null);

                    /** Disk provisionedIops */
                    provisionedIops?: (number|Long|string|null);

                    /** Disk region */
                    region?: (string|null);

                    /** Disk replicaZones */
                    replicaZones?: (string[]|null);

                    /** Disk resourcePolicies */
                    resourcePolicies?: (string[]|null);

                    /** Disk satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Disk selfLink */
                    selfLink?: (string|null);

                    /** Disk sizeGb */
                    sizeGb?: (number|Long|string|null);

                    /** Disk sourceDisk */
                    sourceDisk?: (string|null);

                    /** Disk sourceDiskId */
                    sourceDiskId?: (string|null);

                    /** Disk sourceImage */
                    sourceImage?: (string|null);

                    /** Disk sourceImageEncryptionKey */
                    sourceImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Disk sourceImageId */
                    sourceImageId?: (string|null);

                    /** Disk sourceSnapshot */
                    sourceSnapshot?: (string|null);

                    /** Disk sourceSnapshotEncryptionKey */
                    sourceSnapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Disk sourceSnapshotId */
                    sourceSnapshotId?: (string|null);

                    /** Disk sourceStorageObject */
                    sourceStorageObject?: (string|null);

                    /** Disk status */
                    status?: (string|null);

                    /** Disk type */
                    type?: (string|null);

                    /** Disk users */
                    users?: (string[]|null);

                    /** Disk zone */
                    zone?: (string|null);
                }

                /** Represents a Disk. */
                class Disk implements IDisk {

                    /**
                     * Constructs a new Disk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisk);

                    /** Disk architecture. */
                    public architecture?: (string|null);

                    /** Disk creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Disk description. */
                    public description?: (string|null);

                    /** Disk diskEncryptionKey. */
                    public diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Disk guestOsFeatures. */
                    public guestOsFeatures: google.cloud.compute.v1.IGuestOsFeature[];

                    /** Disk id. */
                    public id?: (number|Long|string|null);

                    /** Disk kind. */
                    public kind?: (string|null);

                    /** Disk labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** Disk labels. */
                    public labels: { [k: string]: string };

                    /** Disk lastAttachTimestamp. */
                    public lastAttachTimestamp?: (string|null);

                    /** Disk lastDetachTimestamp. */
                    public lastDetachTimestamp?: (string|null);

                    /** Disk licenseCodes. */
                    public licenseCodes: (number|Long|string)[];

                    /** Disk licenses. */
                    public licenses: string[];

                    /** Disk locationHint. */
                    public locationHint?: (string|null);

                    /** Disk name. */
                    public name?: (string|null);

                    /** Disk options. */
                    public options?: (string|null);

                    /** Disk params. */
                    public params?: (google.cloud.compute.v1.IDiskParams|null);

                    /** Disk physicalBlockSizeBytes. */
                    public physicalBlockSizeBytes?: (number|Long|string|null);

                    /** Disk provisionedIops. */
                    public provisionedIops?: (number|Long|string|null);

                    /** Disk region. */
                    public region?: (string|null);

                    /** Disk replicaZones. */
                    public replicaZones: string[];

                    /** Disk resourcePolicies. */
                    public resourcePolicies: string[];

                    /** Disk satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** Disk selfLink. */
                    public selfLink?: (string|null);

                    /** Disk sizeGb. */
                    public sizeGb?: (number|Long|string|null);

                    /** Disk sourceDisk. */
                    public sourceDisk?: (string|null);

                    /** Disk sourceDiskId. */
                    public sourceDiskId?: (string|null);

                    /** Disk sourceImage. */
                    public sourceImage?: (string|null);

                    /** Disk sourceImageEncryptionKey. */
                    public sourceImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Disk sourceImageId. */
                    public sourceImageId?: (string|null);

                    /** Disk sourceSnapshot. */
                    public sourceSnapshot?: (string|null);

                    /** Disk sourceSnapshotEncryptionKey. */
                    public sourceSnapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Disk sourceSnapshotId. */
                    public sourceSnapshotId?: (string|null);

                    /** Disk sourceStorageObject. */
                    public sourceStorageObject?: (string|null);

                    /** Disk status. */
                    public status?: (string|null);

                    /** Disk type. */
                    public type?: (string|null);

                    /** Disk users. */
                    public users: string[];

                    /** Disk zone. */
                    public zone?: (string|null);

                    /** Disk _architecture. */
                    public _architecture?: "architecture";

                    /** Disk _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Disk _description. */
                    public _description?: "description";

                    /** Disk _diskEncryptionKey. */
                    public _diskEncryptionKey?: "diskEncryptionKey";

                    /** Disk _id. */
                    public _id?: "id";

                    /** Disk _kind. */
                    public _kind?: "kind";

                    /** Disk _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** Disk _lastAttachTimestamp. */
                    public _lastAttachTimestamp?: "lastAttachTimestamp";

                    /** Disk _lastDetachTimestamp. */
                    public _lastDetachTimestamp?: "lastDetachTimestamp";

                    /** Disk _locationHint. */
                    public _locationHint?: "locationHint";

                    /** Disk _name. */
                    public _name?: "name";

                    /** Disk _options. */
                    public _options?: "options";

                    /** Disk _params. */
                    public _params?: "params";

                    /** Disk _physicalBlockSizeBytes. */
                    public _physicalBlockSizeBytes?: "physicalBlockSizeBytes";

                    /** Disk _provisionedIops. */
                    public _provisionedIops?: "provisionedIops";

                    /** Disk _region. */
                    public _region?: "region";

                    /** Disk _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** Disk _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Disk _sizeGb. */
                    public _sizeGb?: "sizeGb";

                    /** Disk _sourceDisk. */
                    public _sourceDisk?: "sourceDisk";

                    /** Disk _sourceDiskId. */
                    public _sourceDiskId?: "sourceDiskId";

                    /** Disk _sourceImage. */
                    public _sourceImage?: "sourceImage";

                    /** Disk _sourceImageEncryptionKey. */
                    public _sourceImageEncryptionKey?: "sourceImageEncryptionKey";

                    /** Disk _sourceImageId. */
                    public _sourceImageId?: "sourceImageId";

                    /** Disk _sourceSnapshot. */
                    public _sourceSnapshot?: "sourceSnapshot";

                    /** Disk _sourceSnapshotEncryptionKey. */
                    public _sourceSnapshotEncryptionKey?: "sourceSnapshotEncryptionKey";

                    /** Disk _sourceSnapshotId. */
                    public _sourceSnapshotId?: "sourceSnapshotId";

                    /** Disk _sourceStorageObject. */
                    public _sourceStorageObject?: "sourceStorageObject";

                    /** Disk _status. */
                    public _status?: "status";

                    /** Disk _type. */
                    public _type?: "type";

                    /** Disk _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new Disk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Disk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisk): google.cloud.compute.v1.Disk;

                    /**
                     * Encodes the specified Disk message. Does not implicitly {@link google.cloud.compute.v1.Disk.verify|verify} messages.
                     * @param message Disk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Disk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Disk.verify|verify} messages.
                     * @param message Disk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Disk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Disk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Disk;

                    /**
                     * Decodes a Disk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Disk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Disk;

                    /**
                     * Verifies a Disk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Disk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Disk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Disk;

                    /**
                     * Creates a plain object from a Disk message. Also converts values to other types if specified.
                     * @param message Disk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Disk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Disk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Disk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Disk {

                    /** Architecture enum. */
                    enum Architecture {
                        UNDEFINED_ARCHITECTURE = 0,
                        ARCHITECTURE_UNSPECIFIED = 394750507,
                        ARM64 = 62547450,
                        X86_64 = 425300551
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        FAILED = 455706685,
                        READY = 77848963,
                        RESTORING = 404263851
                    }
                }

                /** Properties of a DiskAggregatedList. */
                interface IDiskAggregatedList {

                    /** DiskAggregatedList id */
                    id?: (string|null);

                    /** DiskAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IDisksScopedList }|null);

                    /** DiskAggregatedList kind */
                    kind?: (string|null);

                    /** DiskAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** DiskAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** DiskAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** DiskAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a DiskAggregatedList. */
                class DiskAggregatedList implements IDiskAggregatedList {

                    /**
                     * Constructs a new DiskAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskAggregatedList);

                    /** DiskAggregatedList id. */
                    public id?: (string|null);

                    /** DiskAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IDisksScopedList };

                    /** DiskAggregatedList kind. */
                    public kind?: (string|null);

                    /** DiskAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** DiskAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** DiskAggregatedList unreachables. */
                    public unreachables: string[];

                    /** DiskAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** DiskAggregatedList _id. */
                    public _id?: "id";

                    /** DiskAggregatedList _kind. */
                    public _kind?: "kind";

                    /** DiskAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** DiskAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** DiskAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new DiskAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskAggregatedList): google.cloud.compute.v1.DiskAggregatedList;

                    /**
                     * Encodes the specified DiskAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.DiskAggregatedList.verify|verify} messages.
                     * @param message DiskAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskAggregatedList.verify|verify} messages.
                     * @param message DiskAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskAggregatedList;

                    /**
                     * Decodes a DiskAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskAggregatedList;

                    /**
                     * Verifies a DiskAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskAggregatedList;

                    /**
                     * Creates a plain object from a DiskAggregatedList message. Also converts values to other types if specified.
                     * @param message DiskAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskInstantiationConfig. */
                interface IDiskInstantiationConfig {

                    /** DiskInstantiationConfig autoDelete */
                    autoDelete?: (boolean|null);

                    /** DiskInstantiationConfig customImage */
                    customImage?: (string|null);

                    /** DiskInstantiationConfig deviceName */
                    deviceName?: (string|null);

                    /** DiskInstantiationConfig instantiateFrom */
                    instantiateFrom?: (string|null);
                }

                /** Represents a DiskInstantiationConfig. */
                class DiskInstantiationConfig implements IDiskInstantiationConfig {

                    /**
                     * Constructs a new DiskInstantiationConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskInstantiationConfig);

                    /** DiskInstantiationConfig autoDelete. */
                    public autoDelete?: (boolean|null);

                    /** DiskInstantiationConfig customImage. */
                    public customImage?: (string|null);

                    /** DiskInstantiationConfig deviceName. */
                    public deviceName?: (string|null);

                    /** DiskInstantiationConfig instantiateFrom. */
                    public instantiateFrom?: (string|null);

                    /** DiskInstantiationConfig _autoDelete. */
                    public _autoDelete?: "autoDelete";

                    /** DiskInstantiationConfig _customImage. */
                    public _customImage?: "customImage";

                    /** DiskInstantiationConfig _deviceName. */
                    public _deviceName?: "deviceName";

                    /** DiskInstantiationConfig _instantiateFrom. */
                    public _instantiateFrom?: "instantiateFrom";

                    /**
                     * Creates a new DiskInstantiationConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskInstantiationConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskInstantiationConfig): google.cloud.compute.v1.DiskInstantiationConfig;

                    /**
                     * Encodes the specified DiskInstantiationConfig message. Does not implicitly {@link google.cloud.compute.v1.DiskInstantiationConfig.verify|verify} messages.
                     * @param message DiskInstantiationConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskInstantiationConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskInstantiationConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskInstantiationConfig.verify|verify} messages.
                     * @param message DiskInstantiationConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskInstantiationConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskInstantiationConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskInstantiationConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskInstantiationConfig;

                    /**
                     * Decodes a DiskInstantiationConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskInstantiationConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskInstantiationConfig;

                    /**
                     * Verifies a DiskInstantiationConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskInstantiationConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskInstantiationConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskInstantiationConfig;

                    /**
                     * Creates a plain object from a DiskInstantiationConfig message. Also converts values to other types if specified.
                     * @param message DiskInstantiationConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskInstantiationConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskInstantiationConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskInstantiationConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DiskInstantiationConfig {

                    /** InstantiateFrom enum. */
                    enum InstantiateFrom {
                        UNDEFINED_INSTANTIATE_FROM = 0,
                        ATTACH_READ_ONLY = 513775419,
                        BLANK = 63281460,
                        CUSTOM_IMAGE = 196311789,
                        DEFAULT = 115302945,
                        DO_NOT_INCLUDE = 104218952,
                        SOURCE_IMAGE = 62631959,
                        SOURCE_IMAGE_FAMILY = 76850316
                    }
                }

                /** Properties of a DiskList. */
                interface IDiskList {

                    /** DiskList id */
                    id?: (string|null);

                    /** DiskList items */
                    items?: (google.cloud.compute.v1.IDisk[]|null);

                    /** DiskList kind */
                    kind?: (string|null);

                    /** DiskList nextPageToken */
                    nextPageToken?: (string|null);

                    /** DiskList selfLink */
                    selfLink?: (string|null);

                    /** DiskList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a DiskList. */
                class DiskList implements IDiskList {

                    /**
                     * Constructs a new DiskList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskList);

                    /** DiskList id. */
                    public id?: (string|null);

                    /** DiskList items. */
                    public items: google.cloud.compute.v1.IDisk[];

                    /** DiskList kind. */
                    public kind?: (string|null);

                    /** DiskList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** DiskList selfLink. */
                    public selfLink?: (string|null);

                    /** DiskList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** DiskList _id. */
                    public _id?: "id";

                    /** DiskList _kind. */
                    public _kind?: "kind";

                    /** DiskList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** DiskList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** DiskList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new DiskList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskList): google.cloud.compute.v1.DiskList;

                    /**
                     * Encodes the specified DiskList message. Does not implicitly {@link google.cloud.compute.v1.DiskList.verify|verify} messages.
                     * @param message DiskList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskList.verify|verify} messages.
                     * @param message DiskList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskList;

                    /**
                     * Decodes a DiskList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskList;

                    /**
                     * Verifies a DiskList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskList;

                    /**
                     * Creates a plain object from a DiskList message. Also converts values to other types if specified.
                     * @param message DiskList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskMoveRequest. */
                interface IDiskMoveRequest {

                    /** DiskMoveRequest destinationZone */
                    destinationZone?: (string|null);

                    /** DiskMoveRequest targetDisk */
                    targetDisk?: (string|null);
                }

                /** Represents a DiskMoveRequest. */
                class DiskMoveRequest implements IDiskMoveRequest {

                    /**
                     * Constructs a new DiskMoveRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskMoveRequest);

                    /** DiskMoveRequest destinationZone. */
                    public destinationZone?: (string|null);

                    /** DiskMoveRequest targetDisk. */
                    public targetDisk?: (string|null);

                    /** DiskMoveRequest _destinationZone. */
                    public _destinationZone?: "destinationZone";

                    /** DiskMoveRequest _targetDisk. */
                    public _targetDisk?: "targetDisk";

                    /**
                     * Creates a new DiskMoveRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskMoveRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskMoveRequest): google.cloud.compute.v1.DiskMoveRequest;

                    /**
                     * Encodes the specified DiskMoveRequest message. Does not implicitly {@link google.cloud.compute.v1.DiskMoveRequest.verify|verify} messages.
                     * @param message DiskMoveRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskMoveRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskMoveRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskMoveRequest.verify|verify} messages.
                     * @param message DiskMoveRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskMoveRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskMoveRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskMoveRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskMoveRequest;

                    /**
                     * Decodes a DiskMoveRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskMoveRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskMoveRequest;

                    /**
                     * Verifies a DiskMoveRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskMoveRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskMoveRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskMoveRequest;

                    /**
                     * Creates a plain object from a DiskMoveRequest message. Also converts values to other types if specified.
                     * @param message DiskMoveRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskMoveRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskMoveRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskMoveRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskParams. */
                interface IDiskParams {

                    /** DiskParams resourceManagerTags */
                    resourceManagerTags?: ({ [k: string]: string }|null);
                }

                /** Represents a DiskParams. */
                class DiskParams implements IDiskParams {

                    /**
                     * Constructs a new DiskParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskParams);

                    /** DiskParams resourceManagerTags. */
                    public resourceManagerTags: { [k: string]: string };

                    /**
                     * Creates a new DiskParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskParams instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskParams): google.cloud.compute.v1.DiskParams;

                    /**
                     * Encodes the specified DiskParams message. Does not implicitly {@link google.cloud.compute.v1.DiskParams.verify|verify} messages.
                     * @param message DiskParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskParams message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskParams.verify|verify} messages.
                     * @param message DiskParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskParams;

                    /**
                     * Decodes a DiskParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskParams;

                    /**
                     * Verifies a DiskParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskParams;

                    /**
                     * Creates a plain object from a DiskParams message. Also converts values to other types if specified.
                     * @param message DiskParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskType. */
                interface IDiskType {

                    /** DiskType creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** DiskType defaultDiskSizeGb */
                    defaultDiskSizeGb?: (number|Long|string|null);

                    /** DiskType deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** DiskType description */
                    description?: (string|null);

                    /** DiskType id */
                    id?: (number|Long|string|null);

                    /** DiskType kind */
                    kind?: (string|null);

                    /** DiskType name */
                    name?: (string|null);

                    /** DiskType region */
                    region?: (string|null);

                    /** DiskType selfLink */
                    selfLink?: (string|null);

                    /** DiskType validDiskSize */
                    validDiskSize?: (string|null);

                    /** DiskType zone */
                    zone?: (string|null);
                }

                /** Represents a DiskType. */
                class DiskType implements IDiskType {

                    /**
                     * Constructs a new DiskType.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskType);

                    /** DiskType creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** DiskType defaultDiskSizeGb. */
                    public defaultDiskSizeGb?: (number|Long|string|null);

                    /** DiskType deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** DiskType description. */
                    public description?: (string|null);

                    /** DiskType id. */
                    public id?: (number|Long|string|null);

                    /** DiskType kind. */
                    public kind?: (string|null);

                    /** DiskType name. */
                    public name?: (string|null);

                    /** DiskType region. */
                    public region?: (string|null);

                    /** DiskType selfLink. */
                    public selfLink?: (string|null);

                    /** DiskType validDiskSize. */
                    public validDiskSize?: (string|null);

                    /** DiskType zone. */
                    public zone?: (string|null);

                    /** DiskType _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** DiskType _defaultDiskSizeGb. */
                    public _defaultDiskSizeGb?: "defaultDiskSizeGb";

                    /** DiskType _deprecated. */
                    public _deprecated?: "deprecated";

                    /** DiskType _description. */
                    public _description?: "description";

                    /** DiskType _id. */
                    public _id?: "id";

                    /** DiskType _kind. */
                    public _kind?: "kind";

                    /** DiskType _name. */
                    public _name?: "name";

                    /** DiskType _region. */
                    public _region?: "region";

                    /** DiskType _selfLink. */
                    public _selfLink?: "selfLink";

                    /** DiskType _validDiskSize. */
                    public _validDiskSize?: "validDiskSize";

                    /** DiskType _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new DiskType instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskType instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskType): google.cloud.compute.v1.DiskType;

                    /**
                     * Encodes the specified DiskType message. Does not implicitly {@link google.cloud.compute.v1.DiskType.verify|verify} messages.
                     * @param message DiskType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskType message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskType.verify|verify} messages.
                     * @param message DiskType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskType message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskType;

                    /**
                     * Decodes a DiskType message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskType;

                    /**
                     * Verifies a DiskType message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskType message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskType
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskType;

                    /**
                     * Creates a plain object from a DiskType message. Also converts values to other types if specified.
                     * @param message DiskType
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskType to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskType
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskTypeAggregatedList. */
                interface IDiskTypeAggregatedList {

                    /** DiskTypeAggregatedList id */
                    id?: (string|null);

                    /** DiskTypeAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IDiskTypesScopedList }|null);

                    /** DiskTypeAggregatedList kind */
                    kind?: (string|null);

                    /** DiskTypeAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** DiskTypeAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** DiskTypeAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** DiskTypeAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a DiskTypeAggregatedList. */
                class DiskTypeAggregatedList implements IDiskTypeAggregatedList {

                    /**
                     * Constructs a new DiskTypeAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskTypeAggregatedList);

                    /** DiskTypeAggregatedList id. */
                    public id?: (string|null);

                    /** DiskTypeAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IDiskTypesScopedList };

                    /** DiskTypeAggregatedList kind. */
                    public kind?: (string|null);

                    /** DiskTypeAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** DiskTypeAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** DiskTypeAggregatedList unreachables. */
                    public unreachables: string[];

                    /** DiskTypeAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** DiskTypeAggregatedList _id. */
                    public _id?: "id";

                    /** DiskTypeAggregatedList _kind. */
                    public _kind?: "kind";

                    /** DiskTypeAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** DiskTypeAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** DiskTypeAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new DiskTypeAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskTypeAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskTypeAggregatedList): google.cloud.compute.v1.DiskTypeAggregatedList;

                    /**
                     * Encodes the specified DiskTypeAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.DiskTypeAggregatedList.verify|verify} messages.
                     * @param message DiskTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskTypeAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskTypeAggregatedList.verify|verify} messages.
                     * @param message DiskTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskTypeAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskTypeAggregatedList;

                    /**
                     * Decodes a DiskTypeAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskTypeAggregatedList;

                    /**
                     * Verifies a DiskTypeAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskTypeAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskTypeAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskTypeAggregatedList;

                    /**
                     * Creates a plain object from a DiskTypeAggregatedList message. Also converts values to other types if specified.
                     * @param message DiskTypeAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskTypeAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskTypeAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskTypeAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskTypeList. */
                interface IDiskTypeList {

                    /** DiskTypeList id */
                    id?: (string|null);

                    /** DiskTypeList items */
                    items?: (google.cloud.compute.v1.IDiskType[]|null);

                    /** DiskTypeList kind */
                    kind?: (string|null);

                    /** DiskTypeList nextPageToken */
                    nextPageToken?: (string|null);

                    /** DiskTypeList selfLink */
                    selfLink?: (string|null);

                    /** DiskTypeList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a DiskTypeList. */
                class DiskTypeList implements IDiskTypeList {

                    /**
                     * Constructs a new DiskTypeList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskTypeList);

                    /** DiskTypeList id. */
                    public id?: (string|null);

                    /** DiskTypeList items. */
                    public items: google.cloud.compute.v1.IDiskType[];

                    /** DiskTypeList kind. */
                    public kind?: (string|null);

                    /** DiskTypeList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** DiskTypeList selfLink. */
                    public selfLink?: (string|null);

                    /** DiskTypeList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** DiskTypeList _id. */
                    public _id?: "id";

                    /** DiskTypeList _kind. */
                    public _kind?: "kind";

                    /** DiskTypeList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** DiskTypeList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** DiskTypeList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new DiskTypeList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskTypeList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskTypeList): google.cloud.compute.v1.DiskTypeList;

                    /**
                     * Encodes the specified DiskTypeList message. Does not implicitly {@link google.cloud.compute.v1.DiskTypeList.verify|verify} messages.
                     * @param message DiskTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskTypeList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskTypeList.verify|verify} messages.
                     * @param message DiskTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskTypeList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskTypeList;

                    /**
                     * Decodes a DiskTypeList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskTypeList;

                    /**
                     * Verifies a DiskTypeList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskTypeList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskTypeList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskTypeList;

                    /**
                     * Creates a plain object from a DiskTypeList message. Also converts values to other types if specified.
                     * @param message DiskTypeList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskTypeList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskTypeList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskTypeList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DiskTypesScopedList. */
                interface IDiskTypesScopedList {

                    /** DiskTypesScopedList diskTypes */
                    diskTypes?: (google.cloud.compute.v1.IDiskType[]|null);

                    /** DiskTypesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a DiskTypesScopedList. */
                class DiskTypesScopedList implements IDiskTypesScopedList {

                    /**
                     * Constructs a new DiskTypesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDiskTypesScopedList);

                    /** DiskTypesScopedList diskTypes. */
                    public diskTypes: google.cloud.compute.v1.IDiskType[];

                    /** DiskTypesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** DiskTypesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new DiskTypesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DiskTypesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDiskTypesScopedList): google.cloud.compute.v1.DiskTypesScopedList;

                    /**
                     * Encodes the specified DiskTypesScopedList message. Does not implicitly {@link google.cloud.compute.v1.DiskTypesScopedList.verify|verify} messages.
                     * @param message DiskTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDiskTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DiskTypesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DiskTypesScopedList.verify|verify} messages.
                     * @param message DiskTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDiskTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DiskTypesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DiskTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DiskTypesScopedList;

                    /**
                     * Decodes a DiskTypesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DiskTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DiskTypesScopedList;

                    /**
                     * Verifies a DiskTypesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DiskTypesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DiskTypesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DiskTypesScopedList;

                    /**
                     * Creates a plain object from a DiskTypesScopedList message. Also converts values to other types if specified.
                     * @param message DiskTypesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DiskTypesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DiskTypesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DiskTypesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisksAddResourcePoliciesRequest. */
                interface IDisksAddResourcePoliciesRequest {

                    /** DisksAddResourcePoliciesRequest resourcePolicies */
                    resourcePolicies?: (string[]|null);
                }

                /** Represents a DisksAddResourcePoliciesRequest. */
                class DisksAddResourcePoliciesRequest implements IDisksAddResourcePoliciesRequest {

                    /**
                     * Constructs a new DisksAddResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisksAddResourcePoliciesRequest);

                    /** DisksAddResourcePoliciesRequest resourcePolicies. */
                    public resourcePolicies: string[];

                    /**
                     * Creates a new DisksAddResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisksAddResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisksAddResourcePoliciesRequest): google.cloud.compute.v1.DisksAddResourcePoliciesRequest;

                    /**
                     * Encodes the specified DisksAddResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.DisksAddResourcePoliciesRequest.verify|verify} messages.
                     * @param message DisksAddResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisksAddResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisksAddResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisksAddResourcePoliciesRequest.verify|verify} messages.
                     * @param message DisksAddResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisksAddResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisksAddResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisksAddResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisksAddResourcePoliciesRequest;

                    /**
                     * Decodes a DisksAddResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisksAddResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisksAddResourcePoliciesRequest;

                    /**
                     * Verifies a DisksAddResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisksAddResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisksAddResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisksAddResourcePoliciesRequest;

                    /**
                     * Creates a plain object from a DisksAddResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message DisksAddResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisksAddResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisksAddResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisksAddResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisksRemoveResourcePoliciesRequest. */
                interface IDisksRemoveResourcePoliciesRequest {

                    /** DisksRemoveResourcePoliciesRequest resourcePolicies */
                    resourcePolicies?: (string[]|null);
                }

                /** Represents a DisksRemoveResourcePoliciesRequest. */
                class DisksRemoveResourcePoliciesRequest implements IDisksRemoveResourcePoliciesRequest {

                    /**
                     * Constructs a new DisksRemoveResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisksRemoveResourcePoliciesRequest);

                    /** DisksRemoveResourcePoliciesRequest resourcePolicies. */
                    public resourcePolicies: string[];

                    /**
                     * Creates a new DisksRemoveResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisksRemoveResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisksRemoveResourcePoliciesRequest): google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest;

                    /**
                     * Encodes the specified DisksRemoveResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest.verify|verify} messages.
                     * @param message DisksRemoveResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisksRemoveResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisksRemoveResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest.verify|verify} messages.
                     * @param message DisksRemoveResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisksRemoveResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisksRemoveResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisksRemoveResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest;

                    /**
                     * Decodes a DisksRemoveResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisksRemoveResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest;

                    /**
                     * Verifies a DisksRemoveResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisksRemoveResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisksRemoveResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest;

                    /**
                     * Creates a plain object from a DisksRemoveResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message DisksRemoveResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisksRemoveResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisksRemoveResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisksRemoveResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisksResizeRequest. */
                interface IDisksResizeRequest {

                    /** DisksResizeRequest sizeGb */
                    sizeGb?: (number|Long|string|null);
                }

                /** Represents a DisksResizeRequest. */
                class DisksResizeRequest implements IDisksResizeRequest {

                    /**
                     * Constructs a new DisksResizeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisksResizeRequest);

                    /** DisksResizeRequest sizeGb. */
                    public sizeGb?: (number|Long|string|null);

                    /** DisksResizeRequest _sizeGb. */
                    public _sizeGb?: "sizeGb";

                    /**
                     * Creates a new DisksResizeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisksResizeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisksResizeRequest): google.cloud.compute.v1.DisksResizeRequest;

                    /**
                     * Encodes the specified DisksResizeRequest message. Does not implicitly {@link google.cloud.compute.v1.DisksResizeRequest.verify|verify} messages.
                     * @param message DisksResizeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisksResizeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisksResizeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisksResizeRequest.verify|verify} messages.
                     * @param message DisksResizeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisksResizeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisksResizeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisksResizeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisksResizeRequest;

                    /**
                     * Decodes a DisksResizeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisksResizeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisksResizeRequest;

                    /**
                     * Verifies a DisksResizeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisksResizeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisksResizeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisksResizeRequest;

                    /**
                     * Creates a plain object from a DisksResizeRequest message. Also converts values to other types if specified.
                     * @param message DisksResizeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisksResizeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisksResizeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisksResizeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisksScopedList. */
                interface IDisksScopedList {

                    /** DisksScopedList disks */
                    disks?: (google.cloud.compute.v1.IDisk[]|null);

                    /** DisksScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a DisksScopedList. */
                class DisksScopedList implements IDisksScopedList {

                    /**
                     * Constructs a new DisksScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisksScopedList);

                    /** DisksScopedList disks. */
                    public disks: google.cloud.compute.v1.IDisk[];

                    /** DisksScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** DisksScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new DisksScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisksScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisksScopedList): google.cloud.compute.v1.DisksScopedList;

                    /**
                     * Encodes the specified DisksScopedList message. Does not implicitly {@link google.cloud.compute.v1.DisksScopedList.verify|verify} messages.
                     * @param message DisksScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisksScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisksScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisksScopedList.verify|verify} messages.
                     * @param message DisksScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisksScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisksScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisksScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisksScopedList;

                    /**
                     * Decodes a DisksScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisksScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisksScopedList;

                    /**
                     * Verifies a DisksScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisksScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisksScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisksScopedList;

                    /**
                     * Creates a plain object from a DisksScopedList message. Also converts values to other types if specified.
                     * @param message DisksScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisksScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisksScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisksScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisplayDevice. */
                interface IDisplayDevice {

                    /** DisplayDevice enableDisplay */
                    enableDisplay?: (boolean|null);
                }

                /** Represents a DisplayDevice. */
                class DisplayDevice implements IDisplayDevice {

                    /**
                     * Constructs a new DisplayDevice.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDisplayDevice);

                    /** DisplayDevice enableDisplay. */
                    public enableDisplay?: (boolean|null);

                    /** DisplayDevice _enableDisplay. */
                    public _enableDisplay?: "enableDisplay";

                    /**
                     * Creates a new DisplayDevice instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisplayDevice instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDisplayDevice): google.cloud.compute.v1.DisplayDevice;

                    /**
                     * Encodes the specified DisplayDevice message. Does not implicitly {@link google.cloud.compute.v1.DisplayDevice.verify|verify} messages.
                     * @param message DisplayDevice message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDisplayDevice, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisplayDevice message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DisplayDevice.verify|verify} messages.
                     * @param message DisplayDevice message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDisplayDevice, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisplayDevice message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisplayDevice
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DisplayDevice;

                    /**
                     * Decodes a DisplayDevice message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisplayDevice
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DisplayDevice;

                    /**
                     * Verifies a DisplayDevice message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisplayDevice message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisplayDevice
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DisplayDevice;

                    /**
                     * Creates a plain object from a DisplayDevice message. Also converts values to other types if specified.
                     * @param message DisplayDevice
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DisplayDevice, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisplayDevice to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisplayDevice
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DistributionPolicy. */
                interface IDistributionPolicy {

                    /** DistributionPolicy targetShape */
                    targetShape?: (string|null);

                    /** DistributionPolicy zones */
                    zones?: (google.cloud.compute.v1.IDistributionPolicyZoneConfiguration[]|null);
                }

                /** Represents a DistributionPolicy. */
                class DistributionPolicy implements IDistributionPolicy {

                    /**
                     * Constructs a new DistributionPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDistributionPolicy);

                    /** DistributionPolicy targetShape. */
                    public targetShape?: (string|null);

                    /** DistributionPolicy zones. */
                    public zones: google.cloud.compute.v1.IDistributionPolicyZoneConfiguration[];

                    /** DistributionPolicy _targetShape. */
                    public _targetShape?: "targetShape";

                    /**
                     * Creates a new DistributionPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DistributionPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDistributionPolicy): google.cloud.compute.v1.DistributionPolicy;

                    /**
                     * Encodes the specified DistributionPolicy message. Does not implicitly {@link google.cloud.compute.v1.DistributionPolicy.verify|verify} messages.
                     * @param message DistributionPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDistributionPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DistributionPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DistributionPolicy.verify|verify} messages.
                     * @param message DistributionPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDistributionPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DistributionPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DistributionPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DistributionPolicy;

                    /**
                     * Decodes a DistributionPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DistributionPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DistributionPolicy;

                    /**
                     * Verifies a DistributionPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DistributionPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DistributionPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DistributionPolicy;

                    /**
                     * Creates a plain object from a DistributionPolicy message. Also converts values to other types if specified.
                     * @param message DistributionPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DistributionPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DistributionPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DistributionPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DistributionPolicy {

                    /** TargetShape enum. */
                    enum TargetShape {
                        UNDEFINED_TARGET_SHAPE = 0,
                        ANY = 64972,
                        BALANCED = 468409608,
                        EVEN = 2140442
                    }
                }

                /** Properties of a DistributionPolicyZoneConfiguration. */
                interface IDistributionPolicyZoneConfiguration {

                    /** DistributionPolicyZoneConfiguration zone */
                    zone?: (string|null);
                }

                /** Represents a DistributionPolicyZoneConfiguration. */
                class DistributionPolicyZoneConfiguration implements IDistributionPolicyZoneConfiguration {

                    /**
                     * Constructs a new DistributionPolicyZoneConfiguration.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDistributionPolicyZoneConfiguration);

                    /** DistributionPolicyZoneConfiguration zone. */
                    public zone?: (string|null);

                    /** DistributionPolicyZoneConfiguration _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new DistributionPolicyZoneConfiguration instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DistributionPolicyZoneConfiguration instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDistributionPolicyZoneConfiguration): google.cloud.compute.v1.DistributionPolicyZoneConfiguration;

                    /**
                     * Encodes the specified DistributionPolicyZoneConfiguration message. Does not implicitly {@link google.cloud.compute.v1.DistributionPolicyZoneConfiguration.verify|verify} messages.
                     * @param message DistributionPolicyZoneConfiguration message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDistributionPolicyZoneConfiguration, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DistributionPolicyZoneConfiguration message, length delimited. Does not implicitly {@link google.cloud.compute.v1.DistributionPolicyZoneConfiguration.verify|verify} messages.
                     * @param message DistributionPolicyZoneConfiguration message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDistributionPolicyZoneConfiguration, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DistributionPolicyZoneConfiguration message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DistributionPolicyZoneConfiguration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.DistributionPolicyZoneConfiguration;

                    /**
                     * Decodes a DistributionPolicyZoneConfiguration message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DistributionPolicyZoneConfiguration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.DistributionPolicyZoneConfiguration;

                    /**
                     * Verifies a DistributionPolicyZoneConfiguration message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DistributionPolicyZoneConfiguration message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DistributionPolicyZoneConfiguration
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.DistributionPolicyZoneConfiguration;

                    /**
                     * Creates a plain object from a DistributionPolicyZoneConfiguration message. Also converts values to other types if specified.
                     * @param message DistributionPolicyZoneConfiguration
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.DistributionPolicyZoneConfiguration, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DistributionPolicyZoneConfiguration to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DistributionPolicyZoneConfiguration
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Duration. */
                interface IDuration {

                    /** Duration nanos */
                    nanos?: (number|null);

                    /** Duration seconds */
                    seconds?: (number|Long|string|null);
                }

                /** Represents a Duration. */
                class Duration implements IDuration {

                    /**
                     * Constructs a new Duration.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IDuration);

                    /** Duration nanos. */
                    public nanos?: (number|null);

                    /** Duration seconds. */
                    public seconds?: (number|Long|string|null);

                    /** Duration _nanos. */
                    public _nanos?: "nanos";

                    /** Duration _seconds. */
                    public _seconds?: "seconds";

                    /**
                     * Creates a new Duration instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Duration instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IDuration): google.cloud.compute.v1.Duration;

                    /**
                     * Encodes the specified Duration message. Does not implicitly {@link google.cloud.compute.v1.Duration.verify|verify} messages.
                     * @param message Duration message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IDuration, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Duration message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Duration.verify|verify} messages.
                     * @param message Duration message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IDuration, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Duration message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Duration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Duration;

                    /**
                     * Decodes a Duration message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Duration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Duration;

                    /**
                     * Verifies a Duration message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Duration message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Duration
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Duration;

                    /**
                     * Creates a plain object from a Duration message. Also converts values to other types if specified.
                     * @param message Duration
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Duration, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Duration to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Duration
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableXpnHostProjectRequest. */
                interface IEnableXpnHostProjectRequest {

                    /** EnableXpnHostProjectRequest project */
                    project?: (string|null);

                    /** EnableXpnHostProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an EnableXpnHostProjectRequest. */
                class EnableXpnHostProjectRequest implements IEnableXpnHostProjectRequest {

                    /**
                     * Constructs a new EnableXpnHostProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IEnableXpnHostProjectRequest);

                    /** EnableXpnHostProjectRequest project. */
                    public project: string;

                    /** EnableXpnHostProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** EnableXpnHostProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new EnableXpnHostProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableXpnHostProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IEnableXpnHostProjectRequest): google.cloud.compute.v1.EnableXpnHostProjectRequest;

                    /**
                     * Encodes the specified EnableXpnHostProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.EnableXpnHostProjectRequest.verify|verify} messages.
                     * @param message EnableXpnHostProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IEnableXpnHostProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableXpnHostProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.EnableXpnHostProjectRequest.verify|verify} messages.
                     * @param message EnableXpnHostProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IEnableXpnHostProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableXpnHostProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableXpnHostProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.EnableXpnHostProjectRequest;

                    /**
                     * Decodes an EnableXpnHostProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableXpnHostProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.EnableXpnHostProjectRequest;

                    /**
                     * Verifies an EnableXpnHostProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableXpnHostProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableXpnHostProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.EnableXpnHostProjectRequest;

                    /**
                     * Creates a plain object from an EnableXpnHostProjectRequest message. Also converts values to other types if specified.
                     * @param message EnableXpnHostProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.EnableXpnHostProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableXpnHostProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableXpnHostProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableXpnResourceProjectRequest. */
                interface IEnableXpnResourceProjectRequest {

                    /** EnableXpnResourceProjectRequest project */
                    project?: (string|null);

                    /** EnableXpnResourceProjectRequest projectsEnableXpnResourceRequestResource */
                    projectsEnableXpnResourceRequestResource?: (google.cloud.compute.v1.IProjectsEnableXpnResourceRequest|null);

                    /** EnableXpnResourceProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an EnableXpnResourceProjectRequest. */
                class EnableXpnResourceProjectRequest implements IEnableXpnResourceProjectRequest {

                    /**
                     * Constructs a new EnableXpnResourceProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IEnableXpnResourceProjectRequest);

                    /** EnableXpnResourceProjectRequest project. */
                    public project: string;

                    /** EnableXpnResourceProjectRequest projectsEnableXpnResourceRequestResource. */
                    public projectsEnableXpnResourceRequestResource?: (google.cloud.compute.v1.IProjectsEnableXpnResourceRequest|null);

                    /** EnableXpnResourceProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** EnableXpnResourceProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new EnableXpnResourceProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableXpnResourceProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IEnableXpnResourceProjectRequest): google.cloud.compute.v1.EnableXpnResourceProjectRequest;

                    /**
                     * Encodes the specified EnableXpnResourceProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.EnableXpnResourceProjectRequest.verify|verify} messages.
                     * @param message EnableXpnResourceProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IEnableXpnResourceProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableXpnResourceProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.EnableXpnResourceProjectRequest.verify|verify} messages.
                     * @param message EnableXpnResourceProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IEnableXpnResourceProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableXpnResourceProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableXpnResourceProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.EnableXpnResourceProjectRequest;

                    /**
                     * Decodes an EnableXpnResourceProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableXpnResourceProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.EnableXpnResourceProjectRequest;

                    /**
                     * Verifies an EnableXpnResourceProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableXpnResourceProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableXpnResourceProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.EnableXpnResourceProjectRequest;

                    /**
                     * Creates a plain object from an EnableXpnResourceProjectRequest message. Also converts values to other types if specified.
                     * @param message EnableXpnResourceProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.EnableXpnResourceProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableXpnResourceProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableXpnResourceProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Error. */
                interface IError {

                    /** Error errors */
                    errors?: (google.cloud.compute.v1.IErrors[]|null);
                }

                /** Represents an Error. */
                class Error implements IError {

                    /**
                     * Constructs a new Error.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IError);

                    /** Error errors. */
                    public errors: google.cloud.compute.v1.IErrors[];

                    /**
                     * Creates a new Error instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Error instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IError): google.cloud.compute.v1.Error;

                    /**
                     * Encodes the specified Error message. Does not implicitly {@link google.cloud.compute.v1.Error.verify|verify} messages.
                     * @param message Error message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Error message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Error.verify|verify} messages.
                     * @param message Error message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Error message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Error
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Error;

                    /**
                     * Decodes an Error message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Error
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Error;

                    /**
                     * Verifies an Error message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Error message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Error
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Error;

                    /**
                     * Creates a plain object from an Error message. Also converts values to other types if specified.
                     * @param message Error
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Error, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Error to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Error
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ErrorDetails. */
                interface IErrorDetails {

                    /** ErrorDetails errorInfo */
                    errorInfo?: (google.cloud.compute.v1.IErrorInfo|null);

                    /** ErrorDetails help */
                    help?: (google.cloud.compute.v1.IHelp|null);

                    /** ErrorDetails localizedMessage */
                    localizedMessage?: (google.cloud.compute.v1.ILocalizedMessage|null);

                    /** ErrorDetails quotaInfo */
                    quotaInfo?: (google.cloud.compute.v1.IQuotaExceededInfo|null);
                }

                /** Represents an ErrorDetails. */
                class ErrorDetails implements IErrorDetails {

                    /**
                     * Constructs a new ErrorDetails.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IErrorDetails);

                    /** ErrorDetails errorInfo. */
                    public errorInfo?: (google.cloud.compute.v1.IErrorInfo|null);

                    /** ErrorDetails help. */
                    public help?: (google.cloud.compute.v1.IHelp|null);

                    /** ErrorDetails localizedMessage. */
                    public localizedMessage?: (google.cloud.compute.v1.ILocalizedMessage|null);

                    /** ErrorDetails quotaInfo. */
                    public quotaInfo?: (google.cloud.compute.v1.IQuotaExceededInfo|null);

                    /** ErrorDetails _errorInfo. */
                    public _errorInfo?: "errorInfo";

                    /** ErrorDetails _help. */
                    public _help?: "help";

                    /** ErrorDetails _localizedMessage. */
                    public _localizedMessage?: "localizedMessage";

                    /** ErrorDetails _quotaInfo. */
                    public _quotaInfo?: "quotaInfo";

                    /**
                     * Creates a new ErrorDetails instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ErrorDetails instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IErrorDetails): google.cloud.compute.v1.ErrorDetails;

                    /**
                     * Encodes the specified ErrorDetails message. Does not implicitly {@link google.cloud.compute.v1.ErrorDetails.verify|verify} messages.
                     * @param message ErrorDetails message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IErrorDetails, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ErrorDetails message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ErrorDetails.verify|verify} messages.
                     * @param message ErrorDetails message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IErrorDetails, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ErrorDetails message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ErrorDetails
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ErrorDetails;

                    /**
                     * Decodes an ErrorDetails message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ErrorDetails
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ErrorDetails;

                    /**
                     * Verifies an ErrorDetails message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ErrorDetails message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ErrorDetails
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ErrorDetails;

                    /**
                     * Creates a plain object from an ErrorDetails message. Also converts values to other types if specified.
                     * @param message ErrorDetails
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ErrorDetails, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ErrorDetails to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ErrorDetails
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ErrorInfo. */
                interface IErrorInfo {

                    /** ErrorInfo domain */
                    domain?: (string|null);

                    /** ErrorInfo metadatas */
                    metadatas?: ({ [k: string]: string }|null);

                    /** ErrorInfo reason */
                    reason?: (string|null);
                }

                /** Represents an ErrorInfo. */
                class ErrorInfo implements IErrorInfo {

                    /**
                     * Constructs a new ErrorInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IErrorInfo);

                    /** ErrorInfo domain. */
                    public domain?: (string|null);

                    /** ErrorInfo metadatas. */
                    public metadatas: { [k: string]: string };

                    /** ErrorInfo reason. */
                    public reason?: (string|null);

                    /** ErrorInfo _domain. */
                    public _domain?: "domain";

                    /** ErrorInfo _reason. */
                    public _reason?: "reason";

                    /**
                     * Creates a new ErrorInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ErrorInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IErrorInfo): google.cloud.compute.v1.ErrorInfo;

                    /**
                     * Encodes the specified ErrorInfo message. Does not implicitly {@link google.cloud.compute.v1.ErrorInfo.verify|verify} messages.
                     * @param message ErrorInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IErrorInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ErrorInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ErrorInfo.verify|verify} messages.
                     * @param message ErrorInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IErrorInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ErrorInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ErrorInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ErrorInfo;

                    /**
                     * Decodes an ErrorInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ErrorInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ErrorInfo;

                    /**
                     * Verifies an ErrorInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ErrorInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ErrorInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ErrorInfo;

                    /**
                     * Creates a plain object from an ErrorInfo message. Also converts values to other types if specified.
                     * @param message ErrorInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ErrorInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ErrorInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ErrorInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Errors. */
                interface IErrors {

                    /** Errors code */
                    code?: (string|null);

                    /** Errors errorDetails */
                    errorDetails?: (google.cloud.compute.v1.IErrorDetails[]|null);

                    /** Errors location */
                    location?: (string|null);

                    /** Errors message */
                    message?: (string|null);
                }

                /** Represents an Errors. */
                class Errors implements IErrors {

                    /**
                     * Constructs a new Errors.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IErrors);

                    /** Errors code. */
                    public code?: (string|null);

                    /** Errors errorDetails. */
                    public errorDetails: google.cloud.compute.v1.IErrorDetails[];

                    /** Errors location. */
                    public location?: (string|null);

                    /** Errors message. */
                    public message?: (string|null);

                    /** Errors _code. */
                    public _code?: "code";

                    /** Errors _location. */
                    public _location?: "location";

                    /** Errors _message. */
                    public _message?: "message";

                    /**
                     * Creates a new Errors instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Errors instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IErrors): google.cloud.compute.v1.Errors;

                    /**
                     * Encodes the specified Errors message. Does not implicitly {@link google.cloud.compute.v1.Errors.verify|verify} messages.
                     * @param message Errors message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IErrors, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Errors message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Errors.verify|verify} messages.
                     * @param message Errors message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IErrors, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Errors message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Errors
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Errors;

                    /**
                     * Decodes an Errors message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Errors
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Errors;

                    /**
                     * Verifies an Errors message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Errors message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Errors
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Errors;

                    /**
                     * Creates a plain object from an Errors message. Also converts values to other types if specified.
                     * @param message Errors
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Errors, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Errors to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Errors
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ExchangedPeeringRoute. */
                interface IExchangedPeeringRoute {

                    /** ExchangedPeeringRoute destRange */
                    destRange?: (string|null);

                    /** ExchangedPeeringRoute imported */
                    imported?: (boolean|null);

                    /** ExchangedPeeringRoute nextHopRegion */
                    nextHopRegion?: (string|null);

                    /** ExchangedPeeringRoute priority */
                    priority?: (number|null);

                    /** ExchangedPeeringRoute type */
                    type?: (string|null);
                }

                /** Represents an ExchangedPeeringRoute. */
                class ExchangedPeeringRoute implements IExchangedPeeringRoute {

                    /**
                     * Constructs a new ExchangedPeeringRoute.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExchangedPeeringRoute);

                    /** ExchangedPeeringRoute destRange. */
                    public destRange?: (string|null);

                    /** ExchangedPeeringRoute imported. */
                    public imported?: (boolean|null);

                    /** ExchangedPeeringRoute nextHopRegion. */
                    public nextHopRegion?: (string|null);

                    /** ExchangedPeeringRoute priority. */
                    public priority?: (number|null);

                    /** ExchangedPeeringRoute type. */
                    public type?: (string|null);

                    /** ExchangedPeeringRoute _destRange. */
                    public _destRange?: "destRange";

                    /** ExchangedPeeringRoute _imported. */
                    public _imported?: "imported";

                    /** ExchangedPeeringRoute _nextHopRegion. */
                    public _nextHopRegion?: "nextHopRegion";

                    /** ExchangedPeeringRoute _priority. */
                    public _priority?: "priority";

                    /** ExchangedPeeringRoute _type. */
                    public _type?: "type";

                    /**
                     * Creates a new ExchangedPeeringRoute instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ExchangedPeeringRoute instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExchangedPeeringRoute): google.cloud.compute.v1.ExchangedPeeringRoute;

                    /**
                     * Encodes the specified ExchangedPeeringRoute message. Does not implicitly {@link google.cloud.compute.v1.ExchangedPeeringRoute.verify|verify} messages.
                     * @param message ExchangedPeeringRoute message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExchangedPeeringRoute, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ExchangedPeeringRoute message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ExchangedPeeringRoute.verify|verify} messages.
                     * @param message ExchangedPeeringRoute message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExchangedPeeringRoute, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ExchangedPeeringRoute message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ExchangedPeeringRoute
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ExchangedPeeringRoute;

                    /**
                     * Decodes an ExchangedPeeringRoute message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ExchangedPeeringRoute
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ExchangedPeeringRoute;

                    /**
                     * Verifies an ExchangedPeeringRoute message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ExchangedPeeringRoute message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ExchangedPeeringRoute
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ExchangedPeeringRoute;

                    /**
                     * Creates a plain object from an ExchangedPeeringRoute message. Also converts values to other types if specified.
                     * @param message ExchangedPeeringRoute
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ExchangedPeeringRoute, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ExchangedPeeringRoute to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ExchangedPeeringRoute
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ExchangedPeeringRoute {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        DYNAMIC_PEERING_ROUTE = 469794858,
                        STATIC_PEERING_ROUTE = 473407545,
                        SUBNET_PEERING_ROUTE = 465782504
                    }
                }

                /** Properties of an ExchangedPeeringRoutesList. */
                interface IExchangedPeeringRoutesList {

                    /** ExchangedPeeringRoutesList id */
                    id?: (string|null);

                    /** ExchangedPeeringRoutesList items */
                    items?: (google.cloud.compute.v1.IExchangedPeeringRoute[]|null);

                    /** ExchangedPeeringRoutesList kind */
                    kind?: (string|null);

                    /** ExchangedPeeringRoutesList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ExchangedPeeringRoutesList selfLink */
                    selfLink?: (string|null);

                    /** ExchangedPeeringRoutesList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an ExchangedPeeringRoutesList. */
                class ExchangedPeeringRoutesList implements IExchangedPeeringRoutesList {

                    /**
                     * Constructs a new ExchangedPeeringRoutesList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExchangedPeeringRoutesList);

                    /** ExchangedPeeringRoutesList id. */
                    public id?: (string|null);

                    /** ExchangedPeeringRoutesList items. */
                    public items: google.cloud.compute.v1.IExchangedPeeringRoute[];

                    /** ExchangedPeeringRoutesList kind. */
                    public kind?: (string|null);

                    /** ExchangedPeeringRoutesList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ExchangedPeeringRoutesList selfLink. */
                    public selfLink?: (string|null);

                    /** ExchangedPeeringRoutesList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ExchangedPeeringRoutesList _id. */
                    public _id?: "id";

                    /** ExchangedPeeringRoutesList _kind. */
                    public _kind?: "kind";

                    /** ExchangedPeeringRoutesList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ExchangedPeeringRoutesList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ExchangedPeeringRoutesList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ExchangedPeeringRoutesList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ExchangedPeeringRoutesList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExchangedPeeringRoutesList): google.cloud.compute.v1.ExchangedPeeringRoutesList;

                    /**
                     * Encodes the specified ExchangedPeeringRoutesList message. Does not implicitly {@link google.cloud.compute.v1.ExchangedPeeringRoutesList.verify|verify} messages.
                     * @param message ExchangedPeeringRoutesList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExchangedPeeringRoutesList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ExchangedPeeringRoutesList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ExchangedPeeringRoutesList.verify|verify} messages.
                     * @param message ExchangedPeeringRoutesList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExchangedPeeringRoutesList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ExchangedPeeringRoutesList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ExchangedPeeringRoutesList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ExchangedPeeringRoutesList;

                    /**
                     * Decodes an ExchangedPeeringRoutesList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ExchangedPeeringRoutesList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ExchangedPeeringRoutesList;

                    /**
                     * Verifies an ExchangedPeeringRoutesList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ExchangedPeeringRoutesList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ExchangedPeeringRoutesList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ExchangedPeeringRoutesList;

                    /**
                     * Creates a plain object from an ExchangedPeeringRoutesList message. Also converts values to other types if specified.
                     * @param message ExchangedPeeringRoutesList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ExchangedPeeringRoutesList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ExchangedPeeringRoutesList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ExchangedPeeringRoutesList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ExpandIpCidrRangeSubnetworkRequest. */
                interface IExpandIpCidrRangeSubnetworkRequest {

                    /** ExpandIpCidrRangeSubnetworkRequest project */
                    project?: (string|null);

                    /** ExpandIpCidrRangeSubnetworkRequest region */
                    region?: (string|null);

                    /** ExpandIpCidrRangeSubnetworkRequest requestId */
                    requestId?: (string|null);

                    /** ExpandIpCidrRangeSubnetworkRequest subnetwork */
                    subnetwork?: (string|null);

                    /** ExpandIpCidrRangeSubnetworkRequest subnetworksExpandIpCidrRangeRequestResource */
                    subnetworksExpandIpCidrRangeRequestResource?: (google.cloud.compute.v1.ISubnetworksExpandIpCidrRangeRequest|null);
                }

                /** Represents an ExpandIpCidrRangeSubnetworkRequest. */
                class ExpandIpCidrRangeSubnetworkRequest implements IExpandIpCidrRangeSubnetworkRequest {

                    /**
                     * Constructs a new ExpandIpCidrRangeSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest);

                    /** ExpandIpCidrRangeSubnetworkRequest project. */
                    public project: string;

                    /** ExpandIpCidrRangeSubnetworkRequest region. */
                    public region: string;

                    /** ExpandIpCidrRangeSubnetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** ExpandIpCidrRangeSubnetworkRequest subnetwork. */
                    public subnetwork: string;

                    /** ExpandIpCidrRangeSubnetworkRequest subnetworksExpandIpCidrRangeRequestResource. */
                    public subnetworksExpandIpCidrRangeRequestResource?: (google.cloud.compute.v1.ISubnetworksExpandIpCidrRangeRequest|null);

                    /** ExpandIpCidrRangeSubnetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ExpandIpCidrRangeSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ExpandIpCidrRangeSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest): google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest;

                    /**
                     * Encodes the specified ExpandIpCidrRangeSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest.verify|verify} messages.
                     * @param message ExpandIpCidrRangeSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ExpandIpCidrRangeSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest.verify|verify} messages.
                     * @param message ExpandIpCidrRangeSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ExpandIpCidrRangeSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ExpandIpCidrRangeSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest;

                    /**
                     * Decodes an ExpandIpCidrRangeSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ExpandIpCidrRangeSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest;

                    /**
                     * Verifies an ExpandIpCidrRangeSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ExpandIpCidrRangeSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ExpandIpCidrRangeSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest;

                    /**
                     * Creates a plain object from an ExpandIpCidrRangeSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message ExpandIpCidrRangeSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ExpandIpCidrRangeSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ExpandIpCidrRangeSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ExpandIpCidrRangeSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Expr. */
                interface IExpr {

                    /** Expr description */
                    description?: (string|null);

                    /** Expr expression */
                    expression?: (string|null);

                    /** Expr location */
                    location?: (string|null);

                    /** Expr title */
                    title?: (string|null);
                }

                /** Represents an Expr. */
                class Expr implements IExpr {

                    /**
                     * Constructs a new Expr.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExpr);

                    /** Expr description. */
                    public description?: (string|null);

                    /** Expr expression. */
                    public expression?: (string|null);

                    /** Expr location. */
                    public location?: (string|null);

                    /** Expr title. */
                    public title?: (string|null);

                    /** Expr _description. */
                    public _description?: "description";

                    /** Expr _expression. */
                    public _expression?: "expression";

                    /** Expr _location. */
                    public _location?: "location";

                    /** Expr _title. */
                    public _title?: "title";

                    /**
                     * Creates a new Expr instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Expr instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExpr): google.cloud.compute.v1.Expr;

                    /**
                     * Encodes the specified Expr message. Does not implicitly {@link google.cloud.compute.v1.Expr.verify|verify} messages.
                     * @param message Expr message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExpr, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Expr message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Expr.verify|verify} messages.
                     * @param message Expr message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExpr, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Expr message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Expr
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Expr;

                    /**
                     * Decodes an Expr message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Expr
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Expr;

                    /**
                     * Verifies an Expr message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Expr message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Expr
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Expr;

                    /**
                     * Creates a plain object from an Expr message. Also converts values to other types if specified.
                     * @param message Expr
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Expr, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Expr to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Expr
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ExternalVpnGateway. */
                interface IExternalVpnGateway {

                    /** ExternalVpnGateway creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** ExternalVpnGateway description */
                    description?: (string|null);

                    /** ExternalVpnGateway id */
                    id?: (number|Long|string|null);

                    /** ExternalVpnGateway interfaces */
                    interfaces?: (google.cloud.compute.v1.IExternalVpnGatewayInterface[]|null);

                    /** ExternalVpnGateway kind */
                    kind?: (string|null);

                    /** ExternalVpnGateway labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** ExternalVpnGateway labels */
                    labels?: ({ [k: string]: string }|null);

                    /** ExternalVpnGateway name */
                    name?: (string|null);

                    /** ExternalVpnGateway redundancyType */
                    redundancyType?: (string|null);

                    /** ExternalVpnGateway selfLink */
                    selfLink?: (string|null);
                }

                /** Represents an ExternalVpnGateway. */
                class ExternalVpnGateway implements IExternalVpnGateway {

                    /**
                     * Constructs a new ExternalVpnGateway.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExternalVpnGateway);

                    /** ExternalVpnGateway creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** ExternalVpnGateway description. */
                    public description?: (string|null);

                    /** ExternalVpnGateway id. */
                    public id?: (number|Long|string|null);

                    /** ExternalVpnGateway interfaces. */
                    public interfaces: google.cloud.compute.v1.IExternalVpnGatewayInterface[];

                    /** ExternalVpnGateway kind. */
                    public kind?: (string|null);

                    /** ExternalVpnGateway labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** ExternalVpnGateway labels. */
                    public labels: { [k: string]: string };

                    /** ExternalVpnGateway name. */
                    public name?: (string|null);

                    /** ExternalVpnGateway redundancyType. */
                    public redundancyType?: (string|null);

                    /** ExternalVpnGateway selfLink. */
                    public selfLink?: (string|null);

                    /** ExternalVpnGateway _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** ExternalVpnGateway _description. */
                    public _description?: "description";

                    /** ExternalVpnGateway _id. */
                    public _id?: "id";

                    /** ExternalVpnGateway _kind. */
                    public _kind?: "kind";

                    /** ExternalVpnGateway _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** ExternalVpnGateway _name. */
                    public _name?: "name";

                    /** ExternalVpnGateway _redundancyType. */
                    public _redundancyType?: "redundancyType";

                    /** ExternalVpnGateway _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new ExternalVpnGateway instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ExternalVpnGateway instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExternalVpnGateway): google.cloud.compute.v1.ExternalVpnGateway;

                    /**
                     * Encodes the specified ExternalVpnGateway message. Does not implicitly {@link google.cloud.compute.v1.ExternalVpnGateway.verify|verify} messages.
                     * @param message ExternalVpnGateway message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExternalVpnGateway, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ExternalVpnGateway message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ExternalVpnGateway.verify|verify} messages.
                     * @param message ExternalVpnGateway message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExternalVpnGateway, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ExternalVpnGateway message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ExternalVpnGateway
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ExternalVpnGateway;

                    /**
                     * Decodes an ExternalVpnGateway message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ExternalVpnGateway
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ExternalVpnGateway;

                    /**
                     * Verifies an ExternalVpnGateway message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ExternalVpnGateway message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ExternalVpnGateway
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ExternalVpnGateway;

                    /**
                     * Creates a plain object from an ExternalVpnGateway message. Also converts values to other types if specified.
                     * @param message ExternalVpnGateway
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ExternalVpnGateway, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ExternalVpnGateway to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ExternalVpnGateway
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ExternalVpnGateway {

                    /** RedundancyType enum. */
                    enum RedundancyType {
                        UNDEFINED_REDUNDANCY_TYPE = 0,
                        FOUR_IPS_REDUNDANCY = 520087913,
                        SINGLE_IP_INTERNALLY_REDUNDANT = 133914873,
                        TWO_IPS_REDUNDANCY = 367049635
                    }
                }

                /** Properties of an ExternalVpnGatewayInterface. */
                interface IExternalVpnGatewayInterface {

                    /** ExternalVpnGatewayInterface id */
                    id?: (number|null);

                    /** ExternalVpnGatewayInterface ipAddress */
                    ipAddress?: (string|null);
                }

                /** Represents an ExternalVpnGatewayInterface. */
                class ExternalVpnGatewayInterface implements IExternalVpnGatewayInterface {

                    /**
                     * Constructs a new ExternalVpnGatewayInterface.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExternalVpnGatewayInterface);

                    /** ExternalVpnGatewayInterface id. */
                    public id?: (number|null);

                    /** ExternalVpnGatewayInterface ipAddress. */
                    public ipAddress?: (string|null);

                    /** ExternalVpnGatewayInterface _id. */
                    public _id?: "id";

                    /** ExternalVpnGatewayInterface _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /**
                     * Creates a new ExternalVpnGatewayInterface instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ExternalVpnGatewayInterface instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExternalVpnGatewayInterface): google.cloud.compute.v1.ExternalVpnGatewayInterface;

                    /**
                     * Encodes the specified ExternalVpnGatewayInterface message. Does not implicitly {@link google.cloud.compute.v1.ExternalVpnGatewayInterface.verify|verify} messages.
                     * @param message ExternalVpnGatewayInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExternalVpnGatewayInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ExternalVpnGatewayInterface message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ExternalVpnGatewayInterface.verify|verify} messages.
                     * @param message ExternalVpnGatewayInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExternalVpnGatewayInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ExternalVpnGatewayInterface message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ExternalVpnGatewayInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ExternalVpnGatewayInterface;

                    /**
                     * Decodes an ExternalVpnGatewayInterface message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ExternalVpnGatewayInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ExternalVpnGatewayInterface;

                    /**
                     * Verifies an ExternalVpnGatewayInterface message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ExternalVpnGatewayInterface message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ExternalVpnGatewayInterface
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ExternalVpnGatewayInterface;

                    /**
                     * Creates a plain object from an ExternalVpnGatewayInterface message. Also converts values to other types if specified.
                     * @param message ExternalVpnGatewayInterface
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ExternalVpnGatewayInterface, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ExternalVpnGatewayInterface to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ExternalVpnGatewayInterface
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ExternalVpnGatewayList. */
                interface IExternalVpnGatewayList {

                    /** ExternalVpnGatewayList etag */
                    etag?: (string|null);

                    /** ExternalVpnGatewayList id */
                    id?: (string|null);

                    /** ExternalVpnGatewayList items */
                    items?: (google.cloud.compute.v1.IExternalVpnGateway[]|null);

                    /** ExternalVpnGatewayList kind */
                    kind?: (string|null);

                    /** ExternalVpnGatewayList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ExternalVpnGatewayList selfLink */
                    selfLink?: (string|null);

                    /** ExternalVpnGatewayList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an ExternalVpnGatewayList. */
                class ExternalVpnGatewayList implements IExternalVpnGatewayList {

                    /**
                     * Constructs a new ExternalVpnGatewayList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IExternalVpnGatewayList);

                    /** ExternalVpnGatewayList etag. */
                    public etag?: (string|null);

                    /** ExternalVpnGatewayList id. */
                    public id?: (string|null);

                    /** ExternalVpnGatewayList items. */
                    public items: google.cloud.compute.v1.IExternalVpnGateway[];

                    /** ExternalVpnGatewayList kind. */
                    public kind?: (string|null);

                    /** ExternalVpnGatewayList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ExternalVpnGatewayList selfLink. */
                    public selfLink?: (string|null);

                    /** ExternalVpnGatewayList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ExternalVpnGatewayList _etag. */
                    public _etag?: "etag";

                    /** ExternalVpnGatewayList _id. */
                    public _id?: "id";

                    /** ExternalVpnGatewayList _kind. */
                    public _kind?: "kind";

                    /** ExternalVpnGatewayList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ExternalVpnGatewayList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ExternalVpnGatewayList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ExternalVpnGatewayList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ExternalVpnGatewayList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IExternalVpnGatewayList): google.cloud.compute.v1.ExternalVpnGatewayList;

                    /**
                     * Encodes the specified ExternalVpnGatewayList message. Does not implicitly {@link google.cloud.compute.v1.ExternalVpnGatewayList.verify|verify} messages.
                     * @param message ExternalVpnGatewayList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IExternalVpnGatewayList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ExternalVpnGatewayList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ExternalVpnGatewayList.verify|verify} messages.
                     * @param message ExternalVpnGatewayList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IExternalVpnGatewayList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ExternalVpnGatewayList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ExternalVpnGatewayList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ExternalVpnGatewayList;

                    /**
                     * Decodes an ExternalVpnGatewayList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ExternalVpnGatewayList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ExternalVpnGatewayList;

                    /**
                     * Verifies an ExternalVpnGatewayList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ExternalVpnGatewayList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ExternalVpnGatewayList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ExternalVpnGatewayList;

                    /**
                     * Creates a plain object from an ExternalVpnGatewayList message. Also converts values to other types if specified.
                     * @param message ExternalVpnGatewayList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ExternalVpnGatewayList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ExternalVpnGatewayList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ExternalVpnGatewayList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FileContentBuffer. */
                interface IFileContentBuffer {

                    /** FileContentBuffer content */
                    content?: (string|null);

                    /** FileContentBuffer fileType */
                    fileType?: (string|null);
                }

                /** Represents a FileContentBuffer. */
                class FileContentBuffer implements IFileContentBuffer {

                    /**
                     * Constructs a new FileContentBuffer.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFileContentBuffer);

                    /** FileContentBuffer content. */
                    public content?: (string|null);

                    /** FileContentBuffer fileType. */
                    public fileType?: (string|null);

                    /** FileContentBuffer _content. */
                    public _content?: "content";

                    /** FileContentBuffer _fileType. */
                    public _fileType?: "fileType";

                    /**
                     * Creates a new FileContentBuffer instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FileContentBuffer instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFileContentBuffer): google.cloud.compute.v1.FileContentBuffer;

                    /**
                     * Encodes the specified FileContentBuffer message. Does not implicitly {@link google.cloud.compute.v1.FileContentBuffer.verify|verify} messages.
                     * @param message FileContentBuffer message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFileContentBuffer, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FileContentBuffer message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FileContentBuffer.verify|verify} messages.
                     * @param message FileContentBuffer message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFileContentBuffer, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FileContentBuffer message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FileContentBuffer
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FileContentBuffer;

                    /**
                     * Decodes a FileContentBuffer message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FileContentBuffer
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FileContentBuffer;

                    /**
                     * Verifies a FileContentBuffer message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FileContentBuffer message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FileContentBuffer
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FileContentBuffer;

                    /**
                     * Creates a plain object from a FileContentBuffer message. Also converts values to other types if specified.
                     * @param message FileContentBuffer
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FileContentBuffer, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FileContentBuffer to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FileContentBuffer
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace FileContentBuffer {

                    /** FileType enum. */
                    enum FileType {
                        UNDEFINED_FILE_TYPE = 0,
                        BIN = 65767,
                        UNDEFINED = 137851184,
                        X509 = 2674086
                    }
                }

                /** Properties of a Firewall. */
                interface IFirewall {

                    /** Firewall allowed */
                    allowed?: (google.cloud.compute.v1.IAllowed[]|null);

                    /** Firewall creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Firewall denied */
                    denied?: (google.cloud.compute.v1.IDenied[]|null);

                    /** Firewall description */
                    description?: (string|null);

                    /** Firewall destinationRanges */
                    destinationRanges?: (string[]|null);

                    /** Firewall direction */
                    direction?: (string|null);

                    /** Firewall disabled */
                    disabled?: (boolean|null);

                    /** Firewall id */
                    id?: (number|Long|string|null);

                    /** Firewall kind */
                    kind?: (string|null);

                    /** Firewall logConfig */
                    logConfig?: (google.cloud.compute.v1.IFirewallLogConfig|null);

                    /** Firewall name */
                    name?: (string|null);

                    /** Firewall network */
                    network?: (string|null);

                    /** Firewall priority */
                    priority?: (number|null);

                    /** Firewall selfLink */
                    selfLink?: (string|null);

                    /** Firewall sourceRanges */
                    sourceRanges?: (string[]|null);

                    /** Firewall sourceServiceAccounts */
                    sourceServiceAccounts?: (string[]|null);

                    /** Firewall sourceTags */
                    sourceTags?: (string[]|null);

                    /** Firewall targetServiceAccounts */
                    targetServiceAccounts?: (string[]|null);

                    /** Firewall targetTags */
                    targetTags?: (string[]|null);
                }

                /** Represents a Firewall. */
                class Firewall implements IFirewall {

                    /**
                     * Constructs a new Firewall.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewall);

                    /** Firewall allowed. */
                    public allowed: google.cloud.compute.v1.IAllowed[];

                    /** Firewall creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Firewall denied. */
                    public denied: google.cloud.compute.v1.IDenied[];

                    /** Firewall description. */
                    public description?: (string|null);

                    /** Firewall destinationRanges. */
                    public destinationRanges: string[];

                    /** Firewall direction. */
                    public direction?: (string|null);

                    /** Firewall disabled. */
                    public disabled?: (boolean|null);

                    /** Firewall id. */
                    public id?: (number|Long|string|null);

                    /** Firewall kind. */
                    public kind?: (string|null);

                    /** Firewall logConfig. */
                    public logConfig?: (google.cloud.compute.v1.IFirewallLogConfig|null);

                    /** Firewall name. */
                    public name?: (string|null);

                    /** Firewall network. */
                    public network?: (string|null);

                    /** Firewall priority. */
                    public priority?: (number|null);

                    /** Firewall selfLink. */
                    public selfLink?: (string|null);

                    /** Firewall sourceRanges. */
                    public sourceRanges: string[];

                    /** Firewall sourceServiceAccounts. */
                    public sourceServiceAccounts: string[];

                    /** Firewall sourceTags. */
                    public sourceTags: string[];

                    /** Firewall targetServiceAccounts. */
                    public targetServiceAccounts: string[];

                    /** Firewall targetTags. */
                    public targetTags: string[];

                    /** Firewall _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Firewall _description. */
                    public _description?: "description";

                    /** Firewall _direction. */
                    public _direction?: "direction";

                    /** Firewall _disabled. */
                    public _disabled?: "disabled";

                    /** Firewall _id. */
                    public _id?: "id";

                    /** Firewall _kind. */
                    public _kind?: "kind";

                    /** Firewall _logConfig. */
                    public _logConfig?: "logConfig";

                    /** Firewall _name. */
                    public _name?: "name";

                    /** Firewall _network. */
                    public _network?: "network";

                    /** Firewall _priority. */
                    public _priority?: "priority";

                    /** Firewall _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new Firewall instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Firewall instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewall): google.cloud.compute.v1.Firewall;

                    /**
                     * Encodes the specified Firewall message. Does not implicitly {@link google.cloud.compute.v1.Firewall.verify|verify} messages.
                     * @param message Firewall message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewall, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Firewall message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Firewall.verify|verify} messages.
                     * @param message Firewall message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewall, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Firewall message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Firewall
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Firewall;

                    /**
                     * Decodes a Firewall message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Firewall
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Firewall;

                    /**
                     * Verifies a Firewall message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Firewall message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Firewall
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Firewall;

                    /**
                     * Creates a plain object from a Firewall message. Also converts values to other types if specified.
                     * @param message Firewall
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Firewall, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Firewall to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Firewall
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Firewall {

                    /** Direction enum. */
                    enum Direction {
                        UNDEFINED_DIRECTION = 0,
                        EGRESS = 432880501,
                        INGRESS = 516931221
                    }
                }

                /** Properties of a FirewallList. */
                interface IFirewallList {

                    /** FirewallList id */
                    id?: (string|null);

                    /** FirewallList items */
                    items?: (google.cloud.compute.v1.IFirewall[]|null);

                    /** FirewallList kind */
                    kind?: (string|null);

                    /** FirewallList nextPageToken */
                    nextPageToken?: (string|null);

                    /** FirewallList selfLink */
                    selfLink?: (string|null);

                    /** FirewallList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a FirewallList. */
                class FirewallList implements IFirewallList {

                    /**
                     * Constructs a new FirewallList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallList);

                    /** FirewallList id. */
                    public id?: (string|null);

                    /** FirewallList items. */
                    public items: google.cloud.compute.v1.IFirewall[];

                    /** FirewallList kind. */
                    public kind?: (string|null);

                    /** FirewallList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** FirewallList selfLink. */
                    public selfLink?: (string|null);

                    /** FirewallList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** FirewallList _id. */
                    public _id?: "id";

                    /** FirewallList _kind. */
                    public _kind?: "kind";

                    /** FirewallList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** FirewallList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** FirewallList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new FirewallList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallList): google.cloud.compute.v1.FirewallList;

                    /**
                     * Encodes the specified FirewallList message. Does not implicitly {@link google.cloud.compute.v1.FirewallList.verify|verify} messages.
                     * @param message FirewallList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallList.verify|verify} messages.
                     * @param message FirewallList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallList;

                    /**
                     * Decodes a FirewallList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallList;

                    /**
                     * Verifies a FirewallList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallList;

                    /**
                     * Creates a plain object from a FirewallList message. Also converts values to other types if specified.
                     * @param message FirewallList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallLogConfig. */
                interface IFirewallLogConfig {

                    /** FirewallLogConfig enable */
                    enable?: (boolean|null);

                    /** FirewallLogConfig metadata */
                    metadata?: (string|null);
                }

                /** Represents a FirewallLogConfig. */
                class FirewallLogConfig implements IFirewallLogConfig {

                    /**
                     * Constructs a new FirewallLogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallLogConfig);

                    /** FirewallLogConfig enable. */
                    public enable?: (boolean|null);

                    /** FirewallLogConfig metadata. */
                    public metadata?: (string|null);

                    /** FirewallLogConfig _enable. */
                    public _enable?: "enable";

                    /** FirewallLogConfig _metadata. */
                    public _metadata?: "metadata";

                    /**
                     * Creates a new FirewallLogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallLogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallLogConfig): google.cloud.compute.v1.FirewallLogConfig;

                    /**
                     * Encodes the specified FirewallLogConfig message. Does not implicitly {@link google.cloud.compute.v1.FirewallLogConfig.verify|verify} messages.
                     * @param message FirewallLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallLogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallLogConfig.verify|verify} messages.
                     * @param message FirewallLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallLogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallLogConfig;

                    /**
                     * Decodes a FirewallLogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallLogConfig;

                    /**
                     * Verifies a FirewallLogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallLogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallLogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallLogConfig;

                    /**
                     * Creates a plain object from a FirewallLogConfig message. Also converts values to other types if specified.
                     * @param message FirewallLogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallLogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallLogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallLogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace FirewallLogConfig {

                    /** Metadata enum. */
                    enum Metadata {
                        UNDEFINED_METADATA = 0,
                        EXCLUDE_ALL_METADATA = 334519954,
                        INCLUDE_ALL_METADATA = 164619908
                    }
                }

                /** Properties of a FirewallPoliciesListAssociationsResponse. */
                interface IFirewallPoliciesListAssociationsResponse {

                    /** FirewallPoliciesListAssociationsResponse associations */
                    associations?: (google.cloud.compute.v1.IFirewallPolicyAssociation[]|null);

                    /** FirewallPoliciesListAssociationsResponse kind */
                    kind?: (string|null);
                }

                /** Represents a FirewallPoliciesListAssociationsResponse. */
                class FirewallPoliciesListAssociationsResponse implements IFirewallPoliciesListAssociationsResponse {

                    /**
                     * Constructs a new FirewallPoliciesListAssociationsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPoliciesListAssociationsResponse);

                    /** FirewallPoliciesListAssociationsResponse associations. */
                    public associations: google.cloud.compute.v1.IFirewallPolicyAssociation[];

                    /** FirewallPoliciesListAssociationsResponse kind. */
                    public kind?: (string|null);

                    /** FirewallPoliciesListAssociationsResponse _kind. */
                    public _kind?: "kind";

                    /**
                     * Creates a new FirewallPoliciesListAssociationsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPoliciesListAssociationsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPoliciesListAssociationsResponse): google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse;

                    /**
                     * Encodes the specified FirewallPoliciesListAssociationsResponse message. Does not implicitly {@link google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse.verify|verify} messages.
                     * @param message FirewallPoliciesListAssociationsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPoliciesListAssociationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPoliciesListAssociationsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse.verify|verify} messages.
                     * @param message FirewallPoliciesListAssociationsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPoliciesListAssociationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPoliciesListAssociationsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPoliciesListAssociationsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse;

                    /**
                     * Decodes a FirewallPoliciesListAssociationsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPoliciesListAssociationsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse;

                    /**
                     * Verifies a FirewallPoliciesListAssociationsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPoliciesListAssociationsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPoliciesListAssociationsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse;

                    /**
                     * Creates a plain object from a FirewallPoliciesListAssociationsResponse message. Also converts values to other types if specified.
                     * @param message FirewallPoliciesListAssociationsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPoliciesListAssociationsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPoliciesListAssociationsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallPolicy. */
                interface IFirewallPolicy {

                    /** FirewallPolicy associations */
                    associations?: (google.cloud.compute.v1.IFirewallPolicyAssociation[]|null);

                    /** FirewallPolicy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** FirewallPolicy description */
                    description?: (string|null);

                    /** FirewallPolicy displayName */
                    displayName?: (string|null);

                    /** FirewallPolicy fingerprint */
                    fingerprint?: (string|null);

                    /** FirewallPolicy id */
                    id?: (number|Long|string|null);

                    /** FirewallPolicy kind */
                    kind?: (string|null);

                    /** FirewallPolicy name */
                    name?: (string|null);

                    /** FirewallPolicy parent */
                    parent?: (string|null);

                    /** FirewallPolicy region */
                    region?: (string|null);

                    /** FirewallPolicy ruleTupleCount */
                    ruleTupleCount?: (number|null);

                    /** FirewallPolicy rules */
                    rules?: (google.cloud.compute.v1.IFirewallPolicyRule[]|null);

                    /** FirewallPolicy selfLink */
                    selfLink?: (string|null);

                    /** FirewallPolicy selfLinkWithId */
                    selfLinkWithId?: (string|null);

                    /** FirewallPolicy shortName */
                    shortName?: (string|null);
                }

                /** Represents a FirewallPolicy. */
                class FirewallPolicy implements IFirewallPolicy {

                    /**
                     * Constructs a new FirewallPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicy);

                    /** FirewallPolicy associations. */
                    public associations: google.cloud.compute.v1.IFirewallPolicyAssociation[];

                    /** FirewallPolicy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** FirewallPolicy description. */
                    public description?: (string|null);

                    /** FirewallPolicy displayName. */
                    public displayName?: (string|null);

                    /** FirewallPolicy fingerprint. */
                    public fingerprint?: (string|null);

                    /** FirewallPolicy id. */
                    public id?: (number|Long|string|null);

                    /** FirewallPolicy kind. */
                    public kind?: (string|null);

                    /** FirewallPolicy name. */
                    public name?: (string|null);

                    /** FirewallPolicy parent. */
                    public parent?: (string|null);

                    /** FirewallPolicy region. */
                    public region?: (string|null);

                    /** FirewallPolicy ruleTupleCount. */
                    public ruleTupleCount?: (number|null);

                    /** FirewallPolicy rules. */
                    public rules: google.cloud.compute.v1.IFirewallPolicyRule[];

                    /** FirewallPolicy selfLink. */
                    public selfLink?: (string|null);

                    /** FirewallPolicy selfLinkWithId. */
                    public selfLinkWithId?: (string|null);

                    /** FirewallPolicy shortName. */
                    public shortName?: (string|null);

                    /** FirewallPolicy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** FirewallPolicy _description. */
                    public _description?: "description";

                    /** FirewallPolicy _displayName. */
                    public _displayName?: "displayName";

                    /** FirewallPolicy _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** FirewallPolicy _id. */
                    public _id?: "id";

                    /** FirewallPolicy _kind. */
                    public _kind?: "kind";

                    /** FirewallPolicy _name. */
                    public _name?: "name";

                    /** FirewallPolicy _parent. */
                    public _parent?: "parent";

                    /** FirewallPolicy _region. */
                    public _region?: "region";

                    /** FirewallPolicy _ruleTupleCount. */
                    public _ruleTupleCount?: "ruleTupleCount";

                    /** FirewallPolicy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** FirewallPolicy _selfLinkWithId. */
                    public _selfLinkWithId?: "selfLinkWithId";

                    /** FirewallPolicy _shortName. */
                    public _shortName?: "shortName";

                    /**
                     * Creates a new FirewallPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicy): google.cloud.compute.v1.FirewallPolicy;

                    /**
                     * Encodes the specified FirewallPolicy message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicy.verify|verify} messages.
                     * @param message FirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicy.verify|verify} messages.
                     * @param message FirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicy;

                    /**
                     * Decodes a FirewallPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicy;

                    /**
                     * Verifies a FirewallPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicy;

                    /**
                     * Creates a plain object from a FirewallPolicy message. Also converts values to other types if specified.
                     * @param message FirewallPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallPolicyAssociation. */
                interface IFirewallPolicyAssociation {

                    /** FirewallPolicyAssociation attachmentTarget */
                    attachmentTarget?: (string|null);

                    /** FirewallPolicyAssociation displayName */
                    displayName?: (string|null);

                    /** FirewallPolicyAssociation firewallPolicyId */
                    firewallPolicyId?: (string|null);

                    /** FirewallPolicyAssociation name */
                    name?: (string|null);

                    /** FirewallPolicyAssociation shortName */
                    shortName?: (string|null);
                }

                /** Represents a FirewallPolicyAssociation. */
                class FirewallPolicyAssociation implements IFirewallPolicyAssociation {

                    /**
                     * Constructs a new FirewallPolicyAssociation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicyAssociation);

                    /** FirewallPolicyAssociation attachmentTarget. */
                    public attachmentTarget?: (string|null);

                    /** FirewallPolicyAssociation displayName. */
                    public displayName?: (string|null);

                    /** FirewallPolicyAssociation firewallPolicyId. */
                    public firewallPolicyId?: (string|null);

                    /** FirewallPolicyAssociation name. */
                    public name?: (string|null);

                    /** FirewallPolicyAssociation shortName. */
                    public shortName?: (string|null);

                    /** FirewallPolicyAssociation _attachmentTarget. */
                    public _attachmentTarget?: "attachmentTarget";

                    /** FirewallPolicyAssociation _displayName. */
                    public _displayName?: "displayName";

                    /** FirewallPolicyAssociation _firewallPolicyId. */
                    public _firewallPolicyId?: "firewallPolicyId";

                    /** FirewallPolicyAssociation _name. */
                    public _name?: "name";

                    /** FirewallPolicyAssociation _shortName. */
                    public _shortName?: "shortName";

                    /**
                     * Creates a new FirewallPolicyAssociation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicyAssociation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicyAssociation): google.cloud.compute.v1.FirewallPolicyAssociation;

                    /**
                     * Encodes the specified FirewallPolicyAssociation message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyAssociation.verify|verify} messages.
                     * @param message FirewallPolicyAssociation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicyAssociation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicyAssociation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyAssociation.verify|verify} messages.
                     * @param message FirewallPolicyAssociation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicyAssociation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicyAssociation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicyAssociation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicyAssociation;

                    /**
                     * Decodes a FirewallPolicyAssociation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicyAssociation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicyAssociation;

                    /**
                     * Verifies a FirewallPolicyAssociation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicyAssociation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicyAssociation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicyAssociation;

                    /**
                     * Creates a plain object from a FirewallPolicyAssociation message. Also converts values to other types if specified.
                     * @param message FirewallPolicyAssociation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicyAssociation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicyAssociation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicyAssociation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallPolicyList. */
                interface IFirewallPolicyList {

                    /** FirewallPolicyList id */
                    id?: (string|null);

                    /** FirewallPolicyList items */
                    items?: (google.cloud.compute.v1.IFirewallPolicy[]|null);

                    /** FirewallPolicyList kind */
                    kind?: (string|null);

                    /** FirewallPolicyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** FirewallPolicyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a FirewallPolicyList. */
                class FirewallPolicyList implements IFirewallPolicyList {

                    /**
                     * Constructs a new FirewallPolicyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicyList);

                    /** FirewallPolicyList id. */
                    public id?: (string|null);

                    /** FirewallPolicyList items. */
                    public items: google.cloud.compute.v1.IFirewallPolicy[];

                    /** FirewallPolicyList kind. */
                    public kind?: (string|null);

                    /** FirewallPolicyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** FirewallPolicyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** FirewallPolicyList _id. */
                    public _id?: "id";

                    /** FirewallPolicyList _kind. */
                    public _kind?: "kind";

                    /** FirewallPolicyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** FirewallPolicyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new FirewallPolicyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicyList): google.cloud.compute.v1.FirewallPolicyList;

                    /**
                     * Encodes the specified FirewallPolicyList message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyList.verify|verify} messages.
                     * @param message FirewallPolicyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyList.verify|verify} messages.
                     * @param message FirewallPolicyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicyList;

                    /**
                     * Decodes a FirewallPolicyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicyList;

                    /**
                     * Verifies a FirewallPolicyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicyList;

                    /**
                     * Creates a plain object from a FirewallPolicyList message. Also converts values to other types if specified.
                     * @param message FirewallPolicyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallPolicyRule. */
                interface IFirewallPolicyRule {

                    /** FirewallPolicyRule action */
                    action?: (string|null);

                    /** FirewallPolicyRule description */
                    description?: (string|null);

                    /** FirewallPolicyRule direction */
                    direction?: (string|null);

                    /** FirewallPolicyRule disabled */
                    disabled?: (boolean|null);

                    /** FirewallPolicyRule enableLogging */
                    enableLogging?: (boolean|null);

                    /** FirewallPolicyRule kind */
                    kind?: (string|null);

                    /** FirewallPolicyRule match */
                    match?: (google.cloud.compute.v1.IFirewallPolicyRuleMatcher|null);

                    /** FirewallPolicyRule priority */
                    priority?: (number|null);

                    /** FirewallPolicyRule ruleName */
                    ruleName?: (string|null);

                    /** FirewallPolicyRule ruleTupleCount */
                    ruleTupleCount?: (number|null);

                    /** FirewallPolicyRule targetResources */
                    targetResources?: (string[]|null);

                    /** FirewallPolicyRule targetSecureTags */
                    targetSecureTags?: (google.cloud.compute.v1.IFirewallPolicyRuleSecureTag[]|null);

                    /** FirewallPolicyRule targetServiceAccounts */
                    targetServiceAccounts?: (string[]|null);
                }

                /** Represents a FirewallPolicyRule. */
                class FirewallPolicyRule implements IFirewallPolicyRule {

                    /**
                     * Constructs a new FirewallPolicyRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicyRule);

                    /** FirewallPolicyRule action. */
                    public action?: (string|null);

                    /** FirewallPolicyRule description. */
                    public description?: (string|null);

                    /** FirewallPolicyRule direction. */
                    public direction?: (string|null);

                    /** FirewallPolicyRule disabled. */
                    public disabled?: (boolean|null);

                    /** FirewallPolicyRule enableLogging. */
                    public enableLogging?: (boolean|null);

                    /** FirewallPolicyRule kind. */
                    public kind?: (string|null);

                    /** FirewallPolicyRule match. */
                    public match?: (google.cloud.compute.v1.IFirewallPolicyRuleMatcher|null);

                    /** FirewallPolicyRule priority. */
                    public priority?: (number|null);

                    /** FirewallPolicyRule ruleName. */
                    public ruleName?: (string|null);

                    /** FirewallPolicyRule ruleTupleCount. */
                    public ruleTupleCount?: (number|null);

                    /** FirewallPolicyRule targetResources. */
                    public targetResources: string[];

                    /** FirewallPolicyRule targetSecureTags. */
                    public targetSecureTags: google.cloud.compute.v1.IFirewallPolicyRuleSecureTag[];

                    /** FirewallPolicyRule targetServiceAccounts. */
                    public targetServiceAccounts: string[];

                    /** FirewallPolicyRule _action. */
                    public _action?: "action";

                    /** FirewallPolicyRule _description. */
                    public _description?: "description";

                    /** FirewallPolicyRule _direction. */
                    public _direction?: "direction";

                    /** FirewallPolicyRule _disabled. */
                    public _disabled?: "disabled";

                    /** FirewallPolicyRule _enableLogging. */
                    public _enableLogging?: "enableLogging";

                    /** FirewallPolicyRule _kind. */
                    public _kind?: "kind";

                    /** FirewallPolicyRule _match. */
                    public _match?: "match";

                    /** FirewallPolicyRule _priority. */
                    public _priority?: "priority";

                    /** FirewallPolicyRule _ruleName. */
                    public _ruleName?: "ruleName";

                    /** FirewallPolicyRule _ruleTupleCount. */
                    public _ruleTupleCount?: "ruleTupleCount";

                    /**
                     * Creates a new FirewallPolicyRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicyRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicyRule): google.cloud.compute.v1.FirewallPolicyRule;

                    /**
                     * Encodes the specified FirewallPolicyRule message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRule.verify|verify} messages.
                     * @param message FirewallPolicyRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicyRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicyRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRule.verify|verify} messages.
                     * @param message FirewallPolicyRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicyRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicyRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicyRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicyRule;

                    /**
                     * Decodes a FirewallPolicyRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicyRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicyRule;

                    /**
                     * Verifies a FirewallPolicyRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicyRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicyRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicyRule;

                    /**
                     * Creates a plain object from a FirewallPolicyRule message. Also converts values to other types if specified.
                     * @param message FirewallPolicyRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicyRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicyRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicyRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace FirewallPolicyRule {

                    /** Direction enum. */
                    enum Direction {
                        UNDEFINED_DIRECTION = 0,
                        EGRESS = 432880501,
                        INGRESS = 516931221
                    }
                }

                /** Properties of a FirewallPolicyRuleMatcher. */
                interface IFirewallPolicyRuleMatcher {

                    /** FirewallPolicyRuleMatcher destIpRanges */
                    destIpRanges?: (string[]|null);

                    /** FirewallPolicyRuleMatcher layer4Configs */
                    layer4Configs?: (google.cloud.compute.v1.IFirewallPolicyRuleMatcherLayer4Config[]|null);

                    /** FirewallPolicyRuleMatcher srcIpRanges */
                    srcIpRanges?: (string[]|null);

                    /** FirewallPolicyRuleMatcher srcSecureTags */
                    srcSecureTags?: (google.cloud.compute.v1.IFirewallPolicyRuleSecureTag[]|null);
                }

                /** Represents a FirewallPolicyRuleMatcher. */
                class FirewallPolicyRuleMatcher implements IFirewallPolicyRuleMatcher {

                    /**
                     * Constructs a new FirewallPolicyRuleMatcher.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicyRuleMatcher);

                    /** FirewallPolicyRuleMatcher destIpRanges. */
                    public destIpRanges: string[];

                    /** FirewallPolicyRuleMatcher layer4Configs. */
                    public layer4Configs: google.cloud.compute.v1.IFirewallPolicyRuleMatcherLayer4Config[];

                    /** FirewallPolicyRuleMatcher srcIpRanges. */
                    public srcIpRanges: string[];

                    /** FirewallPolicyRuleMatcher srcSecureTags. */
                    public srcSecureTags: google.cloud.compute.v1.IFirewallPolicyRuleSecureTag[];

                    /**
                     * Creates a new FirewallPolicyRuleMatcher instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicyRuleMatcher instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicyRuleMatcher): google.cloud.compute.v1.FirewallPolicyRuleMatcher;

                    /**
                     * Encodes the specified FirewallPolicyRuleMatcher message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRuleMatcher.verify|verify} messages.
                     * @param message FirewallPolicyRuleMatcher message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicyRuleMatcher, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicyRuleMatcher message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRuleMatcher.verify|verify} messages.
                     * @param message FirewallPolicyRuleMatcher message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicyRuleMatcher, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicyRuleMatcher message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicyRuleMatcher
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicyRuleMatcher;

                    /**
                     * Decodes a FirewallPolicyRuleMatcher message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicyRuleMatcher
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicyRuleMatcher;

                    /**
                     * Verifies a FirewallPolicyRuleMatcher message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicyRuleMatcher message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicyRuleMatcher
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicyRuleMatcher;

                    /**
                     * Creates a plain object from a FirewallPolicyRuleMatcher message. Also converts values to other types if specified.
                     * @param message FirewallPolicyRuleMatcher
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicyRuleMatcher, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicyRuleMatcher to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicyRuleMatcher
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallPolicyRuleMatcherLayer4Config. */
                interface IFirewallPolicyRuleMatcherLayer4Config {

                    /** FirewallPolicyRuleMatcherLayer4Config ipProtocol */
                    ipProtocol?: (string|null);

                    /** FirewallPolicyRuleMatcherLayer4Config ports */
                    ports?: (string[]|null);
                }

                /** Represents a FirewallPolicyRuleMatcherLayer4Config. */
                class FirewallPolicyRuleMatcherLayer4Config implements IFirewallPolicyRuleMatcherLayer4Config {

                    /**
                     * Constructs a new FirewallPolicyRuleMatcherLayer4Config.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicyRuleMatcherLayer4Config);

                    /** FirewallPolicyRuleMatcherLayer4Config ipProtocol. */
                    public ipProtocol?: (string|null);

                    /** FirewallPolicyRuleMatcherLayer4Config ports. */
                    public ports: string[];

                    /** FirewallPolicyRuleMatcherLayer4Config _ipProtocol. */
                    public _ipProtocol?: "ipProtocol";

                    /**
                     * Creates a new FirewallPolicyRuleMatcherLayer4Config instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicyRuleMatcherLayer4Config instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicyRuleMatcherLayer4Config): google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config;

                    /**
                     * Encodes the specified FirewallPolicyRuleMatcherLayer4Config message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config.verify|verify} messages.
                     * @param message FirewallPolicyRuleMatcherLayer4Config message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicyRuleMatcherLayer4Config, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicyRuleMatcherLayer4Config message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config.verify|verify} messages.
                     * @param message FirewallPolicyRuleMatcherLayer4Config message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicyRuleMatcherLayer4Config, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicyRuleMatcherLayer4Config message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicyRuleMatcherLayer4Config
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config;

                    /**
                     * Decodes a FirewallPolicyRuleMatcherLayer4Config message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicyRuleMatcherLayer4Config
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config;

                    /**
                     * Verifies a FirewallPolicyRuleMatcherLayer4Config message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicyRuleMatcherLayer4Config message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicyRuleMatcherLayer4Config
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config;

                    /**
                     * Creates a plain object from a FirewallPolicyRuleMatcherLayer4Config message. Also converts values to other types if specified.
                     * @param message FirewallPolicyRuleMatcherLayer4Config
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicyRuleMatcherLayer4Config, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicyRuleMatcherLayer4Config to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicyRuleMatcherLayer4Config
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FirewallPolicyRuleSecureTag. */
                interface IFirewallPolicyRuleSecureTag {

                    /** FirewallPolicyRuleSecureTag name */
                    name?: (string|null);

                    /** FirewallPolicyRuleSecureTag state */
                    state?: (string|null);
                }

                /** Represents a FirewallPolicyRuleSecureTag. */
                class FirewallPolicyRuleSecureTag implements IFirewallPolicyRuleSecureTag {

                    /**
                     * Constructs a new FirewallPolicyRuleSecureTag.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFirewallPolicyRuleSecureTag);

                    /** FirewallPolicyRuleSecureTag name. */
                    public name?: (string|null);

                    /** FirewallPolicyRuleSecureTag state. */
                    public state?: (string|null);

                    /** FirewallPolicyRuleSecureTag _name. */
                    public _name?: "name";

                    /** FirewallPolicyRuleSecureTag _state. */
                    public _state?: "state";

                    /**
                     * Creates a new FirewallPolicyRuleSecureTag instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FirewallPolicyRuleSecureTag instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFirewallPolicyRuleSecureTag): google.cloud.compute.v1.FirewallPolicyRuleSecureTag;

                    /**
                     * Encodes the specified FirewallPolicyRuleSecureTag message. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRuleSecureTag.verify|verify} messages.
                     * @param message FirewallPolicyRuleSecureTag message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFirewallPolicyRuleSecureTag, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FirewallPolicyRuleSecureTag message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FirewallPolicyRuleSecureTag.verify|verify} messages.
                     * @param message FirewallPolicyRuleSecureTag message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFirewallPolicyRuleSecureTag, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FirewallPolicyRuleSecureTag message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FirewallPolicyRuleSecureTag
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FirewallPolicyRuleSecureTag;

                    /**
                     * Decodes a FirewallPolicyRuleSecureTag message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FirewallPolicyRuleSecureTag
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FirewallPolicyRuleSecureTag;

                    /**
                     * Verifies a FirewallPolicyRuleSecureTag message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FirewallPolicyRuleSecureTag message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FirewallPolicyRuleSecureTag
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FirewallPolicyRuleSecureTag;

                    /**
                     * Creates a plain object from a FirewallPolicyRuleSecureTag message. Also converts values to other types if specified.
                     * @param message FirewallPolicyRuleSecureTag
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FirewallPolicyRuleSecureTag, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FirewallPolicyRuleSecureTag to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FirewallPolicyRuleSecureTag
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace FirewallPolicyRuleSecureTag {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        EFFECTIVE = 244201863,
                        INEFFECTIVE = 304458242
                    }
                }

                /** Properties of a FixedOrPercent. */
                interface IFixedOrPercent {

                    /** FixedOrPercent calculated */
                    calculated?: (number|null);

                    /** FixedOrPercent fixed */
                    fixed?: (number|null);

                    /** FixedOrPercent percent */
                    percent?: (number|null);
                }

                /** Represents a FixedOrPercent. */
                class FixedOrPercent implements IFixedOrPercent {

                    /**
                     * Constructs a new FixedOrPercent.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IFixedOrPercent);

                    /** FixedOrPercent calculated. */
                    public calculated?: (number|null);

                    /** FixedOrPercent fixed. */
                    public fixed?: (number|null);

                    /** FixedOrPercent percent. */
                    public percent?: (number|null);

                    /** FixedOrPercent _calculated. */
                    public _calculated?: "calculated";

                    /** FixedOrPercent _fixed. */
                    public _fixed?: "fixed";

                    /** FixedOrPercent _percent. */
                    public _percent?: "percent";

                    /**
                     * Creates a new FixedOrPercent instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FixedOrPercent instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IFixedOrPercent): google.cloud.compute.v1.FixedOrPercent;

                    /**
                     * Encodes the specified FixedOrPercent message. Does not implicitly {@link google.cloud.compute.v1.FixedOrPercent.verify|verify} messages.
                     * @param message FixedOrPercent message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IFixedOrPercent, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FixedOrPercent message, length delimited. Does not implicitly {@link google.cloud.compute.v1.FixedOrPercent.verify|verify} messages.
                     * @param message FixedOrPercent message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IFixedOrPercent, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FixedOrPercent message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FixedOrPercent
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.FixedOrPercent;

                    /**
                     * Decodes a FixedOrPercent message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FixedOrPercent
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.FixedOrPercent;

                    /**
                     * Verifies a FixedOrPercent message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FixedOrPercent message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FixedOrPercent
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.FixedOrPercent;

                    /**
                     * Creates a plain object from a FixedOrPercent message. Also converts values to other types if specified.
                     * @param message FixedOrPercent
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.FixedOrPercent, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FixedOrPercent to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FixedOrPercent
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ForwardingRule. */
                interface IForwardingRule {

                    /** ForwardingRule IPAddress */
                    IPAddress?: (string|null);

                    /** ForwardingRule IPProtocol */
                    IPProtocol?: (string|null);

                    /** ForwardingRule allPorts */
                    allPorts?: (boolean|null);

                    /** ForwardingRule allowGlobalAccess */
                    allowGlobalAccess?: (boolean|null);

                    /** ForwardingRule backendService */
                    backendService?: (string|null);

                    /** ForwardingRule creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** ForwardingRule description */
                    description?: (string|null);

                    /** ForwardingRule fingerprint */
                    fingerprint?: (string|null);

                    /** ForwardingRule id */
                    id?: (number|Long|string|null);

                    /** ForwardingRule ipVersion */
                    ipVersion?: (string|null);

                    /** ForwardingRule isMirroringCollector */
                    isMirroringCollector?: (boolean|null);

                    /** ForwardingRule kind */
                    kind?: (string|null);

                    /** ForwardingRule labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** ForwardingRule labels */
                    labels?: ({ [k: string]: string }|null);

                    /** ForwardingRule loadBalancingScheme */
                    loadBalancingScheme?: (string|null);

                    /** ForwardingRule metadataFilters */
                    metadataFilters?: (google.cloud.compute.v1.IMetadataFilter[]|null);

                    /** ForwardingRule name */
                    name?: (string|null);

                    /** ForwardingRule network */
                    network?: (string|null);

                    /** ForwardingRule networkTier */
                    networkTier?: (string|null);

                    /** ForwardingRule noAutomateDnsZone */
                    noAutomateDnsZone?: (boolean|null);

                    /** ForwardingRule portRange */
                    portRange?: (string|null);

                    /** ForwardingRule ports */
                    ports?: (string[]|null);

                    /** ForwardingRule pscConnectionId */
                    pscConnectionId?: (number|Long|string|null);

                    /** ForwardingRule pscConnectionStatus */
                    pscConnectionStatus?: (string|null);

                    /** ForwardingRule region */
                    region?: (string|null);

                    /** ForwardingRule selfLink */
                    selfLink?: (string|null);

                    /** ForwardingRule serviceDirectoryRegistrations */
                    serviceDirectoryRegistrations?: (google.cloud.compute.v1.IForwardingRuleServiceDirectoryRegistration[]|null);

                    /** ForwardingRule serviceLabel */
                    serviceLabel?: (string|null);

                    /** ForwardingRule serviceName */
                    serviceName?: (string|null);

                    /** ForwardingRule subnetwork */
                    subnetwork?: (string|null);

                    /** ForwardingRule target */
                    target?: (string|null);
                }

                /** Represents a ForwardingRule. */
                class ForwardingRule implements IForwardingRule {

                    /**
                     * Constructs a new ForwardingRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IForwardingRule);

                    /** ForwardingRule IPAddress. */
                    public IPAddress?: (string|null);

                    /** ForwardingRule IPProtocol. */
                    public IPProtocol?: (string|null);

                    /** ForwardingRule allPorts. */
                    public allPorts?: (boolean|null);

                    /** ForwardingRule allowGlobalAccess. */
                    public allowGlobalAccess?: (boolean|null);

                    /** ForwardingRule backendService. */
                    public backendService?: (string|null);

                    /** ForwardingRule creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** ForwardingRule description. */
                    public description?: (string|null);

                    /** ForwardingRule fingerprint. */
                    public fingerprint?: (string|null);

                    /** ForwardingRule id. */
                    public id?: (number|Long|string|null);

                    /** ForwardingRule ipVersion. */
                    public ipVersion?: (string|null);

                    /** ForwardingRule isMirroringCollector. */
                    public isMirroringCollector?: (boolean|null);

                    /** ForwardingRule kind. */
                    public kind?: (string|null);

                    /** ForwardingRule labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** ForwardingRule labels. */
                    public labels: { [k: string]: string };

                    /** ForwardingRule loadBalancingScheme. */
                    public loadBalancingScheme?: (string|null);

                    /** ForwardingRule metadataFilters. */
                    public metadataFilters: google.cloud.compute.v1.IMetadataFilter[];

                    /** ForwardingRule name. */
                    public name?: (string|null);

                    /** ForwardingRule network. */
                    public network?: (string|null);

                    /** ForwardingRule networkTier. */
                    public networkTier?: (string|null);

                    /** ForwardingRule noAutomateDnsZone. */
                    public noAutomateDnsZone?: (boolean|null);

                    /** ForwardingRule portRange. */
                    public portRange?: (string|null);

                    /** ForwardingRule ports. */
                    public ports: string[];

                    /** ForwardingRule pscConnectionId. */
                    public pscConnectionId?: (number|Long|string|null);

                    /** ForwardingRule pscConnectionStatus. */
                    public pscConnectionStatus?: (string|null);

                    /** ForwardingRule region. */
                    public region?: (string|null);

                    /** ForwardingRule selfLink. */
                    public selfLink?: (string|null);

                    /** ForwardingRule serviceDirectoryRegistrations. */
                    public serviceDirectoryRegistrations: google.cloud.compute.v1.IForwardingRuleServiceDirectoryRegistration[];

                    /** ForwardingRule serviceLabel. */
                    public serviceLabel?: (string|null);

                    /** ForwardingRule serviceName. */
                    public serviceName?: (string|null);

                    /** ForwardingRule subnetwork. */
                    public subnetwork?: (string|null);

                    /** ForwardingRule target. */
                    public target?: (string|null);

                    /** ForwardingRule _IPAddress. */
                    public _IPAddress?: "IPAddress";

                    /** ForwardingRule _IPProtocol. */
                    public _IPProtocol?: "IPProtocol";

                    /** ForwardingRule _allPorts. */
                    public _allPorts?: "allPorts";

                    /** ForwardingRule _allowGlobalAccess. */
                    public _allowGlobalAccess?: "allowGlobalAccess";

                    /** ForwardingRule _backendService. */
                    public _backendService?: "backendService";

                    /** ForwardingRule _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** ForwardingRule _description. */
                    public _description?: "description";

                    /** ForwardingRule _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** ForwardingRule _id. */
                    public _id?: "id";

                    /** ForwardingRule _ipVersion. */
                    public _ipVersion?: "ipVersion";

                    /** ForwardingRule _isMirroringCollector. */
                    public _isMirroringCollector?: "isMirroringCollector";

                    /** ForwardingRule _kind. */
                    public _kind?: "kind";

                    /** ForwardingRule _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** ForwardingRule _loadBalancingScheme. */
                    public _loadBalancingScheme?: "loadBalancingScheme";

                    /** ForwardingRule _name. */
                    public _name?: "name";

                    /** ForwardingRule _network. */
                    public _network?: "network";

                    /** ForwardingRule _networkTier. */
                    public _networkTier?: "networkTier";

                    /** ForwardingRule _noAutomateDnsZone. */
                    public _noAutomateDnsZone?: "noAutomateDnsZone";

                    /** ForwardingRule _portRange. */
                    public _portRange?: "portRange";

                    /** ForwardingRule _pscConnectionId. */
                    public _pscConnectionId?: "pscConnectionId";

                    /** ForwardingRule _pscConnectionStatus. */
                    public _pscConnectionStatus?: "pscConnectionStatus";

                    /** ForwardingRule _region. */
                    public _region?: "region";

                    /** ForwardingRule _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ForwardingRule _serviceLabel. */
                    public _serviceLabel?: "serviceLabel";

                    /** ForwardingRule _serviceName. */
                    public _serviceName?: "serviceName";

                    /** ForwardingRule _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /** ForwardingRule _target. */
                    public _target?: "target";

                    /**
                     * Creates a new ForwardingRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ForwardingRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IForwardingRule): google.cloud.compute.v1.ForwardingRule;

                    /**
                     * Encodes the specified ForwardingRule message. Does not implicitly {@link google.cloud.compute.v1.ForwardingRule.verify|verify} messages.
                     * @param message ForwardingRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IForwardingRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ForwardingRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ForwardingRule.verify|verify} messages.
                     * @param message ForwardingRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IForwardingRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ForwardingRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ForwardingRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ForwardingRule;

                    /**
                     * Decodes a ForwardingRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ForwardingRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ForwardingRule;

                    /**
                     * Verifies a ForwardingRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ForwardingRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ForwardingRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ForwardingRule;

                    /**
                     * Creates a plain object from a ForwardingRule message. Also converts values to other types if specified.
                     * @param message ForwardingRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ForwardingRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ForwardingRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ForwardingRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ForwardingRule {

                    /** IPProtocolEnum enum. */
                    enum IPProtocolEnum {
                        UNDEFINED_I_P_PROTOCOL_ENUM = 0,
                        AH = 2087,
                        ESP = 68962,
                        ICMP = 2241597,
                        L3_DEFAULT = 48151369,
                        SCTP = 2539724,
                        TCP = 82881,
                        UDP = 83873
                    }

                    /** IpVersion enum. */
                    enum IpVersion {
                        UNDEFINED_IP_VERSION = 0,
                        IPV4 = 2254341,
                        IPV6 = 2254343,
                        UNSPECIFIED_VERSION = 21850000
                    }

                    /** LoadBalancingScheme enum. */
                    enum LoadBalancingScheme {
                        UNDEFINED_LOAD_BALANCING_SCHEME = 0,
                        EXTERNAL = 35607499,
                        EXTERNAL_MANAGED = 512006923,
                        INTERNAL = 279295677,
                        INTERNAL_MANAGED = 37350397,
                        INTERNAL_SELF_MANAGED = 236211150,
                        INVALID = 530283991
                    }

                    /** NetworkTier enum. */
                    enum NetworkTier {
                        UNDEFINED_NETWORK_TIER = 0,
                        FIXED_STANDARD = 310464328,
                        PREMIUM = 399530551,
                        STANDARD = 484642493,
                        STANDARD_OVERRIDES_FIXED_STANDARD = 465847234
                    }

                    /** PscConnectionStatus enum. */
                    enum PscConnectionStatus {
                        UNDEFINED_PSC_CONNECTION_STATUS = 0,
                        ACCEPTED = 246714279,
                        CLOSED = 380163436,
                        NEEDS_ATTENTION = 344491452,
                        PENDING = 35394935,
                        REJECTED = 174130302,
                        STATUS_UNSPECIFIED = 42133066
                    }
                }

                /** Properties of a ForwardingRuleAggregatedList. */
                interface IForwardingRuleAggregatedList {

                    /** ForwardingRuleAggregatedList id */
                    id?: (string|null);

                    /** ForwardingRuleAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IForwardingRulesScopedList }|null);

                    /** ForwardingRuleAggregatedList kind */
                    kind?: (string|null);

                    /** ForwardingRuleAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ForwardingRuleAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** ForwardingRuleAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** ForwardingRuleAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ForwardingRuleAggregatedList. */
                class ForwardingRuleAggregatedList implements IForwardingRuleAggregatedList {

                    /**
                     * Constructs a new ForwardingRuleAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IForwardingRuleAggregatedList);

                    /** ForwardingRuleAggregatedList id. */
                    public id?: (string|null);

                    /** ForwardingRuleAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IForwardingRulesScopedList };

                    /** ForwardingRuleAggregatedList kind. */
                    public kind?: (string|null);

                    /** ForwardingRuleAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ForwardingRuleAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** ForwardingRuleAggregatedList unreachables. */
                    public unreachables: string[];

                    /** ForwardingRuleAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ForwardingRuleAggregatedList _id. */
                    public _id?: "id";

                    /** ForwardingRuleAggregatedList _kind. */
                    public _kind?: "kind";

                    /** ForwardingRuleAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ForwardingRuleAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ForwardingRuleAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ForwardingRuleAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ForwardingRuleAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IForwardingRuleAggregatedList): google.cloud.compute.v1.ForwardingRuleAggregatedList;

                    /**
                     * Encodes the specified ForwardingRuleAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleAggregatedList.verify|verify} messages.
                     * @param message ForwardingRuleAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IForwardingRuleAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ForwardingRuleAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleAggregatedList.verify|verify} messages.
                     * @param message ForwardingRuleAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IForwardingRuleAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ForwardingRuleAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ForwardingRuleAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ForwardingRuleAggregatedList;

                    /**
                     * Decodes a ForwardingRuleAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ForwardingRuleAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ForwardingRuleAggregatedList;

                    /**
                     * Verifies a ForwardingRuleAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ForwardingRuleAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ForwardingRuleAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ForwardingRuleAggregatedList;

                    /**
                     * Creates a plain object from a ForwardingRuleAggregatedList message. Also converts values to other types if specified.
                     * @param message ForwardingRuleAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ForwardingRuleAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ForwardingRuleAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ForwardingRuleAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ForwardingRuleList. */
                interface IForwardingRuleList {

                    /** ForwardingRuleList id */
                    id?: (string|null);

                    /** ForwardingRuleList items */
                    items?: (google.cloud.compute.v1.IForwardingRule[]|null);

                    /** ForwardingRuleList kind */
                    kind?: (string|null);

                    /** ForwardingRuleList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ForwardingRuleList selfLink */
                    selfLink?: (string|null);

                    /** ForwardingRuleList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ForwardingRuleList. */
                class ForwardingRuleList implements IForwardingRuleList {

                    /**
                     * Constructs a new ForwardingRuleList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IForwardingRuleList);

                    /** ForwardingRuleList id. */
                    public id?: (string|null);

                    /** ForwardingRuleList items. */
                    public items: google.cloud.compute.v1.IForwardingRule[];

                    /** ForwardingRuleList kind. */
                    public kind?: (string|null);

                    /** ForwardingRuleList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ForwardingRuleList selfLink. */
                    public selfLink?: (string|null);

                    /** ForwardingRuleList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ForwardingRuleList _id. */
                    public _id?: "id";

                    /** ForwardingRuleList _kind. */
                    public _kind?: "kind";

                    /** ForwardingRuleList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ForwardingRuleList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ForwardingRuleList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ForwardingRuleList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ForwardingRuleList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IForwardingRuleList): google.cloud.compute.v1.ForwardingRuleList;

                    /**
                     * Encodes the specified ForwardingRuleList message. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleList.verify|verify} messages.
                     * @param message ForwardingRuleList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IForwardingRuleList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ForwardingRuleList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleList.verify|verify} messages.
                     * @param message ForwardingRuleList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IForwardingRuleList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ForwardingRuleList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ForwardingRuleList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ForwardingRuleList;

                    /**
                     * Decodes a ForwardingRuleList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ForwardingRuleList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ForwardingRuleList;

                    /**
                     * Verifies a ForwardingRuleList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ForwardingRuleList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ForwardingRuleList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ForwardingRuleList;

                    /**
                     * Creates a plain object from a ForwardingRuleList message. Also converts values to other types if specified.
                     * @param message ForwardingRuleList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ForwardingRuleList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ForwardingRuleList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ForwardingRuleList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ForwardingRuleReference. */
                interface IForwardingRuleReference {

                    /** ForwardingRuleReference forwardingRule */
                    forwardingRule?: (string|null);
                }

                /** Represents a ForwardingRuleReference. */
                class ForwardingRuleReference implements IForwardingRuleReference {

                    /**
                     * Constructs a new ForwardingRuleReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IForwardingRuleReference);

                    /** ForwardingRuleReference forwardingRule. */
                    public forwardingRule?: (string|null);

                    /** ForwardingRuleReference _forwardingRule. */
                    public _forwardingRule?: "forwardingRule";

                    /**
                     * Creates a new ForwardingRuleReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ForwardingRuleReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IForwardingRuleReference): google.cloud.compute.v1.ForwardingRuleReference;

                    /**
                     * Encodes the specified ForwardingRuleReference message. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleReference.verify|verify} messages.
                     * @param message ForwardingRuleReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IForwardingRuleReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ForwardingRuleReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleReference.verify|verify} messages.
                     * @param message ForwardingRuleReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IForwardingRuleReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ForwardingRuleReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ForwardingRuleReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ForwardingRuleReference;

                    /**
                     * Decodes a ForwardingRuleReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ForwardingRuleReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ForwardingRuleReference;

                    /**
                     * Verifies a ForwardingRuleReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ForwardingRuleReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ForwardingRuleReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ForwardingRuleReference;

                    /**
                     * Creates a plain object from a ForwardingRuleReference message. Also converts values to other types if specified.
                     * @param message ForwardingRuleReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ForwardingRuleReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ForwardingRuleReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ForwardingRuleReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ForwardingRuleServiceDirectoryRegistration. */
                interface IForwardingRuleServiceDirectoryRegistration {

                    /** ForwardingRuleServiceDirectoryRegistration namespace */
                    namespace?: (string|null);

                    /** ForwardingRuleServiceDirectoryRegistration service */
                    service?: (string|null);

                    /** ForwardingRuleServiceDirectoryRegistration serviceDirectoryRegion */
                    serviceDirectoryRegion?: (string|null);
                }

                /** Represents a ForwardingRuleServiceDirectoryRegistration. */
                class ForwardingRuleServiceDirectoryRegistration implements IForwardingRuleServiceDirectoryRegistration {

                    /**
                     * Constructs a new ForwardingRuleServiceDirectoryRegistration.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IForwardingRuleServiceDirectoryRegistration);

                    /** ForwardingRuleServiceDirectoryRegistration namespace. */
                    public namespace?: (string|null);

                    /** ForwardingRuleServiceDirectoryRegistration service. */
                    public service?: (string|null);

                    /** ForwardingRuleServiceDirectoryRegistration serviceDirectoryRegion. */
                    public serviceDirectoryRegion?: (string|null);

                    /** ForwardingRuleServiceDirectoryRegistration _namespace. */
                    public _namespace?: "namespace";

                    /** ForwardingRuleServiceDirectoryRegistration _service. */
                    public _service?: "service";

                    /** ForwardingRuleServiceDirectoryRegistration _serviceDirectoryRegion. */
                    public _serviceDirectoryRegion?: "serviceDirectoryRegion";

                    /**
                     * Creates a new ForwardingRuleServiceDirectoryRegistration instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ForwardingRuleServiceDirectoryRegistration instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IForwardingRuleServiceDirectoryRegistration): google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration;

                    /**
                     * Encodes the specified ForwardingRuleServiceDirectoryRegistration message. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration.verify|verify} messages.
                     * @param message ForwardingRuleServiceDirectoryRegistration message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IForwardingRuleServiceDirectoryRegistration, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ForwardingRuleServiceDirectoryRegistration message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration.verify|verify} messages.
                     * @param message ForwardingRuleServiceDirectoryRegistration message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IForwardingRuleServiceDirectoryRegistration, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ForwardingRuleServiceDirectoryRegistration message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ForwardingRuleServiceDirectoryRegistration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration;

                    /**
                     * Decodes a ForwardingRuleServiceDirectoryRegistration message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ForwardingRuleServiceDirectoryRegistration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration;

                    /**
                     * Verifies a ForwardingRuleServiceDirectoryRegistration message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ForwardingRuleServiceDirectoryRegistration message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ForwardingRuleServiceDirectoryRegistration
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration;

                    /**
                     * Creates a plain object from a ForwardingRuleServiceDirectoryRegistration message. Also converts values to other types if specified.
                     * @param message ForwardingRuleServiceDirectoryRegistration
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ForwardingRuleServiceDirectoryRegistration, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ForwardingRuleServiceDirectoryRegistration to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ForwardingRuleServiceDirectoryRegistration
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ForwardingRulesScopedList. */
                interface IForwardingRulesScopedList {

                    /** ForwardingRulesScopedList forwardingRules */
                    forwardingRules?: (google.cloud.compute.v1.IForwardingRule[]|null);

                    /** ForwardingRulesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ForwardingRulesScopedList. */
                class ForwardingRulesScopedList implements IForwardingRulesScopedList {

                    /**
                     * Constructs a new ForwardingRulesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IForwardingRulesScopedList);

                    /** ForwardingRulesScopedList forwardingRules. */
                    public forwardingRules: google.cloud.compute.v1.IForwardingRule[];

                    /** ForwardingRulesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ForwardingRulesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ForwardingRulesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ForwardingRulesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IForwardingRulesScopedList): google.cloud.compute.v1.ForwardingRulesScopedList;

                    /**
                     * Encodes the specified ForwardingRulesScopedList message. Does not implicitly {@link google.cloud.compute.v1.ForwardingRulesScopedList.verify|verify} messages.
                     * @param message ForwardingRulesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IForwardingRulesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ForwardingRulesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ForwardingRulesScopedList.verify|verify} messages.
                     * @param message ForwardingRulesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IForwardingRulesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ForwardingRulesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ForwardingRulesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ForwardingRulesScopedList;

                    /**
                     * Decodes a ForwardingRulesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ForwardingRulesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ForwardingRulesScopedList;

                    /**
                     * Verifies a ForwardingRulesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ForwardingRulesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ForwardingRulesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ForwardingRulesScopedList;

                    /**
                     * Creates a plain object from a ForwardingRulesScopedList message. Also converts values to other types if specified.
                     * @param message ForwardingRulesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ForwardingRulesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ForwardingRulesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ForwardingRulesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GRPCHealthCheck. */
                interface IGRPCHealthCheck {

                    /** GRPCHealthCheck grpcServiceName */
                    grpcServiceName?: (string|null);

                    /** GRPCHealthCheck port */
                    port?: (number|null);

                    /** GRPCHealthCheck portName */
                    portName?: (string|null);

                    /** GRPCHealthCheck portSpecification */
                    portSpecification?: (string|null);
                }

                /** Represents a GRPCHealthCheck. */
                class GRPCHealthCheck implements IGRPCHealthCheck {

                    /**
                     * Constructs a new GRPCHealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGRPCHealthCheck);

                    /** GRPCHealthCheck grpcServiceName. */
                    public grpcServiceName?: (string|null);

                    /** GRPCHealthCheck port. */
                    public port?: (number|null);

                    /** GRPCHealthCheck portName. */
                    public portName?: (string|null);

                    /** GRPCHealthCheck portSpecification. */
                    public portSpecification?: (string|null);

                    /** GRPCHealthCheck _grpcServiceName. */
                    public _grpcServiceName?: "grpcServiceName";

                    /** GRPCHealthCheck _port. */
                    public _port?: "port";

                    /** GRPCHealthCheck _portName. */
                    public _portName?: "portName";

                    /** GRPCHealthCheck _portSpecification. */
                    public _portSpecification?: "portSpecification";

                    /**
                     * Creates a new GRPCHealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GRPCHealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGRPCHealthCheck): google.cloud.compute.v1.GRPCHealthCheck;

                    /**
                     * Encodes the specified GRPCHealthCheck message. Does not implicitly {@link google.cloud.compute.v1.GRPCHealthCheck.verify|verify} messages.
                     * @param message GRPCHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGRPCHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GRPCHealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GRPCHealthCheck.verify|verify} messages.
                     * @param message GRPCHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGRPCHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GRPCHealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GRPCHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GRPCHealthCheck;

                    /**
                     * Decodes a GRPCHealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GRPCHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GRPCHealthCheck;

                    /**
                     * Verifies a GRPCHealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GRPCHealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GRPCHealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GRPCHealthCheck;

                    /**
                     * Creates a plain object from a GRPCHealthCheck message. Also converts values to other types if specified.
                     * @param message GRPCHealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GRPCHealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GRPCHealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GRPCHealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace GRPCHealthCheck {

                    /** PortSpecification enum. */
                    enum PortSpecification {
                        UNDEFINED_PORT_SPECIFICATION = 0,
                        USE_FIXED_PORT = 190235748,
                        USE_NAMED_PORT = 349300671,
                        USE_SERVING_PORT = 362637516
                    }
                }

                /** Properties of a GetAcceleratorTypeRequest. */
                interface IGetAcceleratorTypeRequest {

                    /** GetAcceleratorTypeRequest acceleratorType */
                    acceleratorType?: (string|null);

                    /** GetAcceleratorTypeRequest project */
                    project?: (string|null);

                    /** GetAcceleratorTypeRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetAcceleratorTypeRequest. */
                class GetAcceleratorTypeRequest implements IGetAcceleratorTypeRequest {

                    /**
                     * Constructs a new GetAcceleratorTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetAcceleratorTypeRequest);

                    /** GetAcceleratorTypeRequest acceleratorType. */
                    public acceleratorType: string;

                    /** GetAcceleratorTypeRequest project. */
                    public project: string;

                    /** GetAcceleratorTypeRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetAcceleratorTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetAcceleratorTypeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetAcceleratorTypeRequest): google.cloud.compute.v1.GetAcceleratorTypeRequest;

                    /**
                     * Encodes the specified GetAcceleratorTypeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetAcceleratorTypeRequest.verify|verify} messages.
                     * @param message GetAcceleratorTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetAcceleratorTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetAcceleratorTypeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetAcceleratorTypeRequest.verify|verify} messages.
                     * @param message GetAcceleratorTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetAcceleratorTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetAcceleratorTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetAcceleratorTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetAcceleratorTypeRequest;

                    /**
                     * Decodes a GetAcceleratorTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetAcceleratorTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetAcceleratorTypeRequest;

                    /**
                     * Verifies a GetAcceleratorTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetAcceleratorTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetAcceleratorTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetAcceleratorTypeRequest;

                    /**
                     * Creates a plain object from a GetAcceleratorTypeRequest message. Also converts values to other types if specified.
                     * @param message GetAcceleratorTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetAcceleratorTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetAcceleratorTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetAcceleratorTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetAddressRequest. */
                interface IGetAddressRequest {

                    /** GetAddressRequest address */
                    address?: (string|null);

                    /** GetAddressRequest project */
                    project?: (string|null);

                    /** GetAddressRequest region */
                    region?: (string|null);
                }

                /** Represents a GetAddressRequest. */
                class GetAddressRequest implements IGetAddressRequest {

                    /**
                     * Constructs a new GetAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetAddressRequest);

                    /** GetAddressRequest address. */
                    public address: string;

                    /** GetAddressRequest project. */
                    public project: string;

                    /** GetAddressRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetAddressRequest): google.cloud.compute.v1.GetAddressRequest;

                    /**
                     * Encodes the specified GetAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.GetAddressRequest.verify|verify} messages.
                     * @param message GetAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetAddressRequest.verify|verify} messages.
                     * @param message GetAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetAddressRequest;

                    /**
                     * Decodes a GetAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetAddressRequest;

                    /**
                     * Verifies a GetAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetAddressRequest;

                    /**
                     * Creates a plain object from a GetAddressRequest message. Also converts values to other types if specified.
                     * @param message GetAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetAssociationFirewallPolicyRequest. */
                interface IGetAssociationFirewallPolicyRequest {

                    /** GetAssociationFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetAssociationFirewallPolicyRequest name */
                    name?: (string|null);
                }

                /** Represents a GetAssociationFirewallPolicyRequest. */
                class GetAssociationFirewallPolicyRequest implements IGetAssociationFirewallPolicyRequest {

                    /**
                     * Constructs a new GetAssociationFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetAssociationFirewallPolicyRequest);

                    /** GetAssociationFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetAssociationFirewallPolicyRequest name. */
                    public name?: (string|null);

                    /** GetAssociationFirewallPolicyRequest _name. */
                    public _name?: "name";

                    /**
                     * Creates a new GetAssociationFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetAssociationFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetAssociationFirewallPolicyRequest): google.cloud.compute.v1.GetAssociationFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetAssociationFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetAssociationFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetAssociationFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetAssociationFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetAssociationFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetAssociationFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetAssociationFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetAssociationFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetAssociationFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetAssociationFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetAssociationFirewallPolicyRequest;

                    /**
                     * Decodes a GetAssociationFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetAssociationFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetAssociationFirewallPolicyRequest;

                    /**
                     * Verifies a GetAssociationFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetAssociationFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetAssociationFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetAssociationFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetAssociationFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetAssociationFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetAssociationFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetAssociationFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetAssociationFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetAssociationNetworkFirewallPolicyRequest. */
                interface IGetAssociationNetworkFirewallPolicyRequest {

                    /** GetAssociationNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetAssociationNetworkFirewallPolicyRequest name */
                    name?: (string|null);

                    /** GetAssociationNetworkFirewallPolicyRequest project */
                    project?: (string|null);
                }

                /** Represents a GetAssociationNetworkFirewallPolicyRequest. */
                class GetAssociationNetworkFirewallPolicyRequest implements IGetAssociationNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetAssociationNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetAssociationNetworkFirewallPolicyRequest);

                    /** GetAssociationNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetAssociationNetworkFirewallPolicyRequest name. */
                    public name?: (string|null);

                    /** GetAssociationNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetAssociationNetworkFirewallPolicyRequest _name. */
                    public _name?: "name";

                    /**
                     * Creates a new GetAssociationNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetAssociationNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetAssociationNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetAssociationNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetAssociationNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetAssociationNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetAssociationNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetAssociationNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetAssociationNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetAssociationNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetAssociationNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetAssociationNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetAssociationNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetAssociationNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetAssociationNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetAssociationNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetAssociationNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetAssociationNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetAssociationNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetAssociationNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetAssociationNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetAssociationRegionNetworkFirewallPolicyRequest. */
                interface IGetAssociationRegionNetworkFirewallPolicyRequest {

                    /** GetAssociationRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetAssociationRegionNetworkFirewallPolicyRequest name */
                    name?: (string|null);

                    /** GetAssociationRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** GetAssociationRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);
                }

                /** Represents a GetAssociationRegionNetworkFirewallPolicyRequest. */
                class GetAssociationRegionNetworkFirewallPolicyRequest implements IGetAssociationRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetAssociationRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetAssociationRegionNetworkFirewallPolicyRequest);

                    /** GetAssociationRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetAssociationRegionNetworkFirewallPolicyRequest name. */
                    public name?: (string|null);

                    /** GetAssociationRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetAssociationRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** GetAssociationRegionNetworkFirewallPolicyRequest _name. */
                    public _name?: "name";

                    /**
                     * Creates a new GetAssociationRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetAssociationRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetAssociationRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetAssociationRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetAssociationRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetAssociationRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetAssociationRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetAssociationRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetAssociationRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetAssociationRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetAssociationRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetAssociationRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetAssociationRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetAssociationRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetAssociationRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetAssociationRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetAssociationRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetAssociationRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetAssociationRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetAssociationRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetAssociationRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetAutoscalerRequest. */
                interface IGetAutoscalerRequest {

                    /** GetAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** GetAutoscalerRequest project */
                    project?: (string|null);

                    /** GetAutoscalerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetAutoscalerRequest. */
                class GetAutoscalerRequest implements IGetAutoscalerRequest {

                    /**
                     * Constructs a new GetAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetAutoscalerRequest);

                    /** GetAutoscalerRequest autoscaler. */
                    public autoscaler: string;

                    /** GetAutoscalerRequest project. */
                    public project: string;

                    /** GetAutoscalerRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetAutoscalerRequest): google.cloud.compute.v1.GetAutoscalerRequest;

                    /**
                     * Encodes the specified GetAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.GetAutoscalerRequest.verify|verify} messages.
                     * @param message GetAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetAutoscalerRequest.verify|verify} messages.
                     * @param message GetAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetAutoscalerRequest;

                    /**
                     * Decodes a GetAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetAutoscalerRequest;

                    /**
                     * Verifies a GetAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetAutoscalerRequest;

                    /**
                     * Creates a plain object from a GetAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message GetAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetBackendBucketRequest. */
                interface IGetBackendBucketRequest {

                    /** GetBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** GetBackendBucketRequest project */
                    project?: (string|null);
                }

                /** Represents a GetBackendBucketRequest. */
                class GetBackendBucketRequest implements IGetBackendBucketRequest {

                    /**
                     * Constructs a new GetBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetBackendBucketRequest);

                    /** GetBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** GetBackendBucketRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetBackendBucketRequest): google.cloud.compute.v1.GetBackendBucketRequest;

                    /**
                     * Encodes the specified GetBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.GetBackendBucketRequest.verify|verify} messages.
                     * @param message GetBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetBackendBucketRequest.verify|verify} messages.
                     * @param message GetBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetBackendBucketRequest;

                    /**
                     * Decodes a GetBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetBackendBucketRequest;

                    /**
                     * Verifies a GetBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetBackendBucketRequest;

                    /**
                     * Creates a plain object from a GetBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message GetBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetBackendServiceRequest. */
                interface IGetBackendServiceRequest {

                    /** GetBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** GetBackendServiceRequest project */
                    project?: (string|null);
                }

                /** Represents a GetBackendServiceRequest. */
                class GetBackendServiceRequest implements IGetBackendServiceRequest {

                    /**
                     * Constructs a new GetBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetBackendServiceRequest);

                    /** GetBackendServiceRequest backendService. */
                    public backendService: string;

                    /** GetBackendServiceRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetBackendServiceRequest): google.cloud.compute.v1.GetBackendServiceRequest;

                    /**
                     * Encodes the specified GetBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetBackendServiceRequest.verify|verify} messages.
                     * @param message GetBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetBackendServiceRequest.verify|verify} messages.
                     * @param message GetBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetBackendServiceRequest;

                    /**
                     * Decodes a GetBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetBackendServiceRequest;

                    /**
                     * Verifies a GetBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetBackendServiceRequest;

                    /**
                     * Creates a plain object from a GetBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message GetBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetDiagnosticsInterconnectRequest. */
                interface IGetDiagnosticsInterconnectRequest {

                    /** GetDiagnosticsInterconnectRequest interconnect */
                    interconnect?: (string|null);

                    /** GetDiagnosticsInterconnectRequest project */
                    project?: (string|null);
                }

                /** Represents a GetDiagnosticsInterconnectRequest. */
                class GetDiagnosticsInterconnectRequest implements IGetDiagnosticsInterconnectRequest {

                    /**
                     * Constructs a new GetDiagnosticsInterconnectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetDiagnosticsInterconnectRequest);

                    /** GetDiagnosticsInterconnectRequest interconnect. */
                    public interconnect: string;

                    /** GetDiagnosticsInterconnectRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetDiagnosticsInterconnectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetDiagnosticsInterconnectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetDiagnosticsInterconnectRequest): google.cloud.compute.v1.GetDiagnosticsInterconnectRequest;

                    /**
                     * Encodes the specified GetDiagnosticsInterconnectRequest message. Does not implicitly {@link google.cloud.compute.v1.GetDiagnosticsInterconnectRequest.verify|verify} messages.
                     * @param message GetDiagnosticsInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetDiagnosticsInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetDiagnosticsInterconnectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetDiagnosticsInterconnectRequest.verify|verify} messages.
                     * @param message GetDiagnosticsInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetDiagnosticsInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetDiagnosticsInterconnectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetDiagnosticsInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetDiagnosticsInterconnectRequest;

                    /**
                     * Decodes a GetDiagnosticsInterconnectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetDiagnosticsInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetDiagnosticsInterconnectRequest;

                    /**
                     * Verifies a GetDiagnosticsInterconnectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetDiagnosticsInterconnectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetDiagnosticsInterconnectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetDiagnosticsInterconnectRequest;

                    /**
                     * Creates a plain object from a GetDiagnosticsInterconnectRequest message. Also converts values to other types if specified.
                     * @param message GetDiagnosticsInterconnectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetDiagnosticsInterconnectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetDiagnosticsInterconnectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetDiagnosticsInterconnectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetDiskRequest. */
                interface IGetDiskRequest {

                    /** GetDiskRequest disk */
                    disk?: (string|null);

                    /** GetDiskRequest project */
                    project?: (string|null);

                    /** GetDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetDiskRequest. */
                class GetDiskRequest implements IGetDiskRequest {

                    /**
                     * Constructs a new GetDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetDiskRequest);

                    /** GetDiskRequest disk. */
                    public disk: string;

                    /** GetDiskRequest project. */
                    public project: string;

                    /** GetDiskRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetDiskRequest): google.cloud.compute.v1.GetDiskRequest;

                    /**
                     * Encodes the specified GetDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.GetDiskRequest.verify|verify} messages.
                     * @param message GetDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetDiskRequest.verify|verify} messages.
                     * @param message GetDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetDiskRequest;

                    /**
                     * Decodes a GetDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetDiskRequest;

                    /**
                     * Verifies a GetDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetDiskRequest;

                    /**
                     * Creates a plain object from a GetDiskRequest message. Also converts values to other types if specified.
                     * @param message GetDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetDiskTypeRequest. */
                interface IGetDiskTypeRequest {

                    /** GetDiskTypeRequest diskType */
                    diskType?: (string|null);

                    /** GetDiskTypeRequest project */
                    project?: (string|null);

                    /** GetDiskTypeRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetDiskTypeRequest. */
                class GetDiskTypeRequest implements IGetDiskTypeRequest {

                    /**
                     * Constructs a new GetDiskTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetDiskTypeRequest);

                    /** GetDiskTypeRequest diskType. */
                    public diskType: string;

                    /** GetDiskTypeRequest project. */
                    public project: string;

                    /** GetDiskTypeRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetDiskTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetDiskTypeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetDiskTypeRequest): google.cloud.compute.v1.GetDiskTypeRequest;

                    /**
                     * Encodes the specified GetDiskTypeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetDiskTypeRequest.verify|verify} messages.
                     * @param message GetDiskTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetDiskTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetDiskTypeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetDiskTypeRequest.verify|verify} messages.
                     * @param message GetDiskTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetDiskTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetDiskTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetDiskTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetDiskTypeRequest;

                    /**
                     * Decodes a GetDiskTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetDiskTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetDiskTypeRequest;

                    /**
                     * Verifies a GetDiskTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetDiskTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetDiskTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetDiskTypeRequest;

                    /**
                     * Creates a plain object from a GetDiskTypeRequest message. Also converts values to other types if specified.
                     * @param message GetDiskTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetDiskTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetDiskTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetDiskTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetEffectiveFirewallsInstanceRequest. */
                interface IGetEffectiveFirewallsInstanceRequest {

                    /** GetEffectiveFirewallsInstanceRequest instance */
                    instance?: (string|null);

                    /** GetEffectiveFirewallsInstanceRequest networkInterface */
                    networkInterface?: (string|null);

                    /** GetEffectiveFirewallsInstanceRequest project */
                    project?: (string|null);

                    /** GetEffectiveFirewallsInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetEffectiveFirewallsInstanceRequest. */
                class GetEffectiveFirewallsInstanceRequest implements IGetEffectiveFirewallsInstanceRequest {

                    /**
                     * Constructs a new GetEffectiveFirewallsInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetEffectiveFirewallsInstanceRequest);

                    /** GetEffectiveFirewallsInstanceRequest instance. */
                    public instance: string;

                    /** GetEffectiveFirewallsInstanceRequest networkInterface. */
                    public networkInterface: string;

                    /** GetEffectiveFirewallsInstanceRequest project. */
                    public project: string;

                    /** GetEffectiveFirewallsInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetEffectiveFirewallsInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetEffectiveFirewallsInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetEffectiveFirewallsInstanceRequest): google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest;

                    /**
                     * Encodes the specified GetEffectiveFirewallsInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest.verify|verify} messages.
                     * @param message GetEffectiveFirewallsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetEffectiveFirewallsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetEffectiveFirewallsInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest.verify|verify} messages.
                     * @param message GetEffectiveFirewallsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetEffectiveFirewallsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetEffectiveFirewallsInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetEffectiveFirewallsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest;

                    /**
                     * Decodes a GetEffectiveFirewallsInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetEffectiveFirewallsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest;

                    /**
                     * Verifies a GetEffectiveFirewallsInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetEffectiveFirewallsInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetEffectiveFirewallsInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest;

                    /**
                     * Creates a plain object from a GetEffectiveFirewallsInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetEffectiveFirewallsInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetEffectiveFirewallsInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetEffectiveFirewallsInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetEffectiveFirewallsInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetEffectiveFirewallsNetworkRequest. */
                interface IGetEffectiveFirewallsNetworkRequest {

                    /** GetEffectiveFirewallsNetworkRequest network */
                    network?: (string|null);

                    /** GetEffectiveFirewallsNetworkRequest project */
                    project?: (string|null);
                }

                /** Represents a GetEffectiveFirewallsNetworkRequest. */
                class GetEffectiveFirewallsNetworkRequest implements IGetEffectiveFirewallsNetworkRequest {

                    /**
                     * Constructs a new GetEffectiveFirewallsNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetEffectiveFirewallsNetworkRequest);

                    /** GetEffectiveFirewallsNetworkRequest network. */
                    public network: string;

                    /** GetEffectiveFirewallsNetworkRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetEffectiveFirewallsNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetEffectiveFirewallsNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetEffectiveFirewallsNetworkRequest): google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest;

                    /**
                     * Encodes the specified GetEffectiveFirewallsNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest.verify|verify} messages.
                     * @param message GetEffectiveFirewallsNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetEffectiveFirewallsNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetEffectiveFirewallsNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest.verify|verify} messages.
                     * @param message GetEffectiveFirewallsNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetEffectiveFirewallsNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetEffectiveFirewallsNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetEffectiveFirewallsNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest;

                    /**
                     * Decodes a GetEffectiveFirewallsNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetEffectiveFirewallsNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest;

                    /**
                     * Verifies a GetEffectiveFirewallsNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetEffectiveFirewallsNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetEffectiveFirewallsNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest;

                    /**
                     * Creates a plain object from a GetEffectiveFirewallsNetworkRequest message. Also converts values to other types if specified.
                     * @param message GetEffectiveFirewallsNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetEffectiveFirewallsNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetEffectiveFirewallsNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetEffectiveFirewallsNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest. */
                interface IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest {

                    /** GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest network */
                    network?: (string|null);

                    /** GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);
                }

                /** Represents a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest. */
                class GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest implements IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest);

                    /** GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest network. */
                    public network: string;

                    /** GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetExternalVpnGatewayRequest. */
                interface IGetExternalVpnGatewayRequest {

                    /** GetExternalVpnGatewayRequest externalVpnGateway */
                    externalVpnGateway?: (string|null);

                    /** GetExternalVpnGatewayRequest project */
                    project?: (string|null);
                }

                /** Represents a GetExternalVpnGatewayRequest. */
                class GetExternalVpnGatewayRequest implements IGetExternalVpnGatewayRequest {

                    /**
                     * Constructs a new GetExternalVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetExternalVpnGatewayRequest);

                    /** GetExternalVpnGatewayRequest externalVpnGateway. */
                    public externalVpnGateway: string;

                    /** GetExternalVpnGatewayRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetExternalVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetExternalVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetExternalVpnGatewayRequest): google.cloud.compute.v1.GetExternalVpnGatewayRequest;

                    /**
                     * Encodes the specified GetExternalVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.GetExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message GetExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetExternalVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message GetExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetExternalVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetExternalVpnGatewayRequest;

                    /**
                     * Decodes a GetExternalVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetExternalVpnGatewayRequest;

                    /**
                     * Verifies a GetExternalVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetExternalVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetExternalVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetExternalVpnGatewayRequest;

                    /**
                     * Creates a plain object from a GetExternalVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message GetExternalVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetExternalVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetExternalVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetExternalVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetFirewallPolicyRequest. */
                interface IGetFirewallPolicyRequest {

                    /** GetFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);
                }

                /** Represents a GetFirewallPolicyRequest. */
                class GetFirewallPolicyRequest implements IGetFirewallPolicyRequest {

                    /**
                     * Constructs a new GetFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetFirewallPolicyRequest);

                    /** GetFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /**
                     * Creates a new GetFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetFirewallPolicyRequest): google.cloud.compute.v1.GetFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetFirewallPolicyRequest;

                    /**
                     * Decodes a GetFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetFirewallPolicyRequest;

                    /**
                     * Verifies a GetFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetFirewallRequest. */
                interface IGetFirewallRequest {

                    /** GetFirewallRequest firewall */
                    firewall?: (string|null);

                    /** GetFirewallRequest project */
                    project?: (string|null);
                }

                /** Represents a GetFirewallRequest. */
                class GetFirewallRequest implements IGetFirewallRequest {

                    /**
                     * Constructs a new GetFirewallRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetFirewallRequest);

                    /** GetFirewallRequest firewall. */
                    public firewall: string;

                    /** GetFirewallRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetFirewallRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetFirewallRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetFirewallRequest): google.cloud.compute.v1.GetFirewallRequest;

                    /**
                     * Encodes the specified GetFirewallRequest message. Does not implicitly {@link google.cloud.compute.v1.GetFirewallRequest.verify|verify} messages.
                     * @param message GetFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetFirewallRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetFirewallRequest.verify|verify} messages.
                     * @param message GetFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetFirewallRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetFirewallRequest;

                    /**
                     * Decodes a GetFirewallRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetFirewallRequest;

                    /**
                     * Verifies a GetFirewallRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetFirewallRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetFirewallRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetFirewallRequest;

                    /**
                     * Creates a plain object from a GetFirewallRequest message. Also converts values to other types if specified.
                     * @param message GetFirewallRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetFirewallRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetFirewallRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetFirewallRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetForwardingRuleRequest. */
                interface IGetForwardingRuleRequest {

                    /** GetForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** GetForwardingRuleRequest project */
                    project?: (string|null);

                    /** GetForwardingRuleRequest region */
                    region?: (string|null);
                }

                /** Represents a GetForwardingRuleRequest. */
                class GetForwardingRuleRequest implements IGetForwardingRuleRequest {

                    /**
                     * Constructs a new GetForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetForwardingRuleRequest);

                    /** GetForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** GetForwardingRuleRequest project. */
                    public project: string;

                    /** GetForwardingRuleRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetForwardingRuleRequest): google.cloud.compute.v1.GetForwardingRuleRequest;

                    /**
                     * Encodes the specified GetForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.GetForwardingRuleRequest.verify|verify} messages.
                     * @param message GetForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetForwardingRuleRequest.verify|verify} messages.
                     * @param message GetForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetForwardingRuleRequest;

                    /**
                     * Decodes a GetForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetForwardingRuleRequest;

                    /**
                     * Verifies a GetForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetForwardingRuleRequest;

                    /**
                     * Creates a plain object from a GetForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message GetForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetFromFamilyImageRequest. */
                interface IGetFromFamilyImageRequest {

                    /** GetFromFamilyImageRequest family */
                    family?: (string|null);

                    /** GetFromFamilyImageRequest project */
                    project?: (string|null);
                }

                /** Represents a GetFromFamilyImageRequest. */
                class GetFromFamilyImageRequest implements IGetFromFamilyImageRequest {

                    /**
                     * Constructs a new GetFromFamilyImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetFromFamilyImageRequest);

                    /** GetFromFamilyImageRequest family. */
                    public family: string;

                    /** GetFromFamilyImageRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetFromFamilyImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetFromFamilyImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetFromFamilyImageRequest): google.cloud.compute.v1.GetFromFamilyImageRequest;

                    /**
                     * Encodes the specified GetFromFamilyImageRequest message. Does not implicitly {@link google.cloud.compute.v1.GetFromFamilyImageRequest.verify|verify} messages.
                     * @param message GetFromFamilyImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetFromFamilyImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetFromFamilyImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetFromFamilyImageRequest.verify|verify} messages.
                     * @param message GetFromFamilyImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetFromFamilyImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetFromFamilyImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetFromFamilyImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetFromFamilyImageRequest;

                    /**
                     * Decodes a GetFromFamilyImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetFromFamilyImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetFromFamilyImageRequest;

                    /**
                     * Verifies a GetFromFamilyImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetFromFamilyImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetFromFamilyImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetFromFamilyImageRequest;

                    /**
                     * Creates a plain object from a GetFromFamilyImageRequest message. Also converts values to other types if specified.
                     * @param message GetFromFamilyImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetFromFamilyImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetFromFamilyImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetFromFamilyImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGlobalAddressRequest. */
                interface IGetGlobalAddressRequest {

                    /** GetGlobalAddressRequest address */
                    address?: (string|null);

                    /** GetGlobalAddressRequest project */
                    project?: (string|null);
                }

                /** Represents a GetGlobalAddressRequest. */
                class GetGlobalAddressRequest implements IGetGlobalAddressRequest {

                    /**
                     * Constructs a new GetGlobalAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGlobalAddressRequest);

                    /** GetGlobalAddressRequest address. */
                    public address: string;

                    /** GetGlobalAddressRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetGlobalAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGlobalAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGlobalAddressRequest): google.cloud.compute.v1.GetGlobalAddressRequest;

                    /**
                     * Encodes the specified GetGlobalAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGlobalAddressRequest.verify|verify} messages.
                     * @param message GetGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGlobalAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGlobalAddressRequest.verify|verify} messages.
                     * @param message GetGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGlobalAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGlobalAddressRequest;

                    /**
                     * Decodes a GetGlobalAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGlobalAddressRequest;

                    /**
                     * Verifies a GetGlobalAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGlobalAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGlobalAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGlobalAddressRequest;

                    /**
                     * Creates a plain object from a GetGlobalAddressRequest message. Also converts values to other types if specified.
                     * @param message GetGlobalAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGlobalAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGlobalAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGlobalAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGlobalForwardingRuleRequest. */
                interface IGetGlobalForwardingRuleRequest {

                    /** GetGlobalForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** GetGlobalForwardingRuleRequest project */
                    project?: (string|null);
                }

                /** Represents a GetGlobalForwardingRuleRequest. */
                class GetGlobalForwardingRuleRequest implements IGetGlobalForwardingRuleRequest {

                    /**
                     * Constructs a new GetGlobalForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGlobalForwardingRuleRequest);

                    /** GetGlobalForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** GetGlobalForwardingRuleRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetGlobalForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGlobalForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGlobalForwardingRuleRequest): google.cloud.compute.v1.GetGlobalForwardingRuleRequest;

                    /**
                     * Encodes the specified GetGlobalForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message GetGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGlobalForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message GetGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGlobalForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGlobalForwardingRuleRequest;

                    /**
                     * Decodes a GetGlobalForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGlobalForwardingRuleRequest;

                    /**
                     * Verifies a GetGlobalForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGlobalForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGlobalForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGlobalForwardingRuleRequest;

                    /**
                     * Creates a plain object from a GetGlobalForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message GetGlobalForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGlobalForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGlobalForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGlobalForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGlobalNetworkEndpointGroupRequest. */
                interface IGetGlobalNetworkEndpointGroupRequest {

                    /** GetGlobalNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** GetGlobalNetworkEndpointGroupRequest project */
                    project?: (string|null);
                }

                /** Represents a GetGlobalNetworkEndpointGroupRequest. */
                class GetGlobalNetworkEndpointGroupRequest implements IGetGlobalNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new GetGlobalNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest);

                    /** GetGlobalNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** GetGlobalNetworkEndpointGroupRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetGlobalNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGlobalNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest): google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified GetGlobalNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message GetGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGlobalNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message GetGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGlobalNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest;

                    /**
                     * Decodes a GetGlobalNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest;

                    /**
                     * Verifies a GetGlobalNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGlobalNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGlobalNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a GetGlobalNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message GetGlobalNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGlobalNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGlobalNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGlobalNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGlobalOperationRequest. */
                interface IGetGlobalOperationRequest {

                    /** GetGlobalOperationRequest operation */
                    operation?: (string|null);

                    /** GetGlobalOperationRequest project */
                    project?: (string|null);
                }

                /** Represents a GetGlobalOperationRequest. */
                class GetGlobalOperationRequest implements IGetGlobalOperationRequest {

                    /**
                     * Constructs a new GetGlobalOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGlobalOperationRequest);

                    /** GetGlobalOperationRequest operation. */
                    public operation: string;

                    /** GetGlobalOperationRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetGlobalOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGlobalOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGlobalOperationRequest): google.cloud.compute.v1.GetGlobalOperationRequest;

                    /**
                     * Encodes the specified GetGlobalOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGlobalOperationRequest.verify|verify} messages.
                     * @param message GetGlobalOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGlobalOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGlobalOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGlobalOperationRequest.verify|verify} messages.
                     * @param message GetGlobalOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGlobalOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGlobalOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGlobalOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGlobalOperationRequest;

                    /**
                     * Decodes a GetGlobalOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGlobalOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGlobalOperationRequest;

                    /**
                     * Verifies a GetGlobalOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGlobalOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGlobalOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGlobalOperationRequest;

                    /**
                     * Creates a plain object from a GetGlobalOperationRequest message. Also converts values to other types if specified.
                     * @param message GetGlobalOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGlobalOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGlobalOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGlobalOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGlobalOrganizationOperationRequest. */
                interface IGetGlobalOrganizationOperationRequest {

                    /** GetGlobalOrganizationOperationRequest operation */
                    operation?: (string|null);

                    /** GetGlobalOrganizationOperationRequest parentId */
                    parentId?: (string|null);
                }

                /** Represents a GetGlobalOrganizationOperationRequest. */
                class GetGlobalOrganizationOperationRequest implements IGetGlobalOrganizationOperationRequest {

                    /**
                     * Constructs a new GetGlobalOrganizationOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGlobalOrganizationOperationRequest);

                    /** GetGlobalOrganizationOperationRequest operation. */
                    public operation: string;

                    /** GetGlobalOrganizationOperationRequest parentId. */
                    public parentId?: (string|null);

                    /** GetGlobalOrganizationOperationRequest _parentId. */
                    public _parentId?: "parentId";

                    /**
                     * Creates a new GetGlobalOrganizationOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGlobalOrganizationOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGlobalOrganizationOperationRequest): google.cloud.compute.v1.GetGlobalOrganizationOperationRequest;

                    /**
                     * Encodes the specified GetGlobalOrganizationOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGlobalOrganizationOperationRequest.verify|verify} messages.
                     * @param message GetGlobalOrganizationOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGlobalOrganizationOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGlobalOrganizationOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGlobalOrganizationOperationRequest.verify|verify} messages.
                     * @param message GetGlobalOrganizationOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGlobalOrganizationOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGlobalOrganizationOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGlobalOrganizationOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGlobalOrganizationOperationRequest;

                    /**
                     * Decodes a GetGlobalOrganizationOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGlobalOrganizationOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGlobalOrganizationOperationRequest;

                    /**
                     * Verifies a GetGlobalOrganizationOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGlobalOrganizationOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGlobalOrganizationOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGlobalOrganizationOperationRequest;

                    /**
                     * Creates a plain object from a GetGlobalOrganizationOperationRequest message. Also converts values to other types if specified.
                     * @param message GetGlobalOrganizationOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGlobalOrganizationOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGlobalOrganizationOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGlobalOrganizationOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGlobalPublicDelegatedPrefixeRequest. */
                interface IGetGlobalPublicDelegatedPrefixeRequest {

                    /** GetGlobalPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** GetGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefix */
                    publicDelegatedPrefix?: (string|null);
                }

                /** Represents a GetGlobalPublicDelegatedPrefixeRequest. */
                class GetGlobalPublicDelegatedPrefixeRequest implements IGetGlobalPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new GetGlobalPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGlobalPublicDelegatedPrefixeRequest);

                    /** GetGlobalPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** GetGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefix. */
                    public publicDelegatedPrefix: string;

                    /**
                     * Creates a new GetGlobalPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGlobalPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGlobalPublicDelegatedPrefixeRequest): google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified GetGlobalPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message GetGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGlobalPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message GetGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes a GetGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies a GetGlobalPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGlobalPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGlobalPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from a GetGlobalPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message GetGlobalPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGlobalPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGlobalPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGlobalPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetGuestAttributesInstanceRequest. */
                interface IGetGuestAttributesInstanceRequest {

                    /** GetGuestAttributesInstanceRequest instance */
                    instance?: (string|null);

                    /** GetGuestAttributesInstanceRequest project */
                    project?: (string|null);

                    /** GetGuestAttributesInstanceRequest queryPath */
                    queryPath?: (string|null);

                    /** GetGuestAttributesInstanceRequest variableKey */
                    variableKey?: (string|null);

                    /** GetGuestAttributesInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetGuestAttributesInstanceRequest. */
                class GetGuestAttributesInstanceRequest implements IGetGuestAttributesInstanceRequest {

                    /**
                     * Constructs a new GetGuestAttributesInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetGuestAttributesInstanceRequest);

                    /** GetGuestAttributesInstanceRequest instance. */
                    public instance: string;

                    /** GetGuestAttributesInstanceRequest project. */
                    public project: string;

                    /** GetGuestAttributesInstanceRequest queryPath. */
                    public queryPath?: (string|null);

                    /** GetGuestAttributesInstanceRequest variableKey. */
                    public variableKey?: (string|null);

                    /** GetGuestAttributesInstanceRequest zone. */
                    public zone: string;

                    /** GetGuestAttributesInstanceRequest _queryPath. */
                    public _queryPath?: "queryPath";

                    /** GetGuestAttributesInstanceRequest _variableKey. */
                    public _variableKey?: "variableKey";

                    /**
                     * Creates a new GetGuestAttributesInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetGuestAttributesInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetGuestAttributesInstanceRequest): google.cloud.compute.v1.GetGuestAttributesInstanceRequest;

                    /**
                     * Encodes the specified GetGuestAttributesInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetGuestAttributesInstanceRequest.verify|verify} messages.
                     * @param message GetGuestAttributesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetGuestAttributesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetGuestAttributesInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetGuestAttributesInstanceRequest.verify|verify} messages.
                     * @param message GetGuestAttributesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetGuestAttributesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetGuestAttributesInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetGuestAttributesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetGuestAttributesInstanceRequest;

                    /**
                     * Decodes a GetGuestAttributesInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetGuestAttributesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetGuestAttributesInstanceRequest;

                    /**
                     * Verifies a GetGuestAttributesInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetGuestAttributesInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetGuestAttributesInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetGuestAttributesInstanceRequest;

                    /**
                     * Creates a plain object from a GetGuestAttributesInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetGuestAttributesInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetGuestAttributesInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetGuestAttributesInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetGuestAttributesInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetHealthBackendServiceRequest. */
                interface IGetHealthBackendServiceRequest {

                    /** GetHealthBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** GetHealthBackendServiceRequest project */
                    project?: (string|null);

                    /** GetHealthBackendServiceRequest resourceGroupReferenceResource */
                    resourceGroupReferenceResource?: (google.cloud.compute.v1.IResourceGroupReference|null);
                }

                /** Represents a GetHealthBackendServiceRequest. */
                class GetHealthBackendServiceRequest implements IGetHealthBackendServiceRequest {

                    /**
                     * Constructs a new GetHealthBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetHealthBackendServiceRequest);

                    /** GetHealthBackendServiceRequest backendService. */
                    public backendService: string;

                    /** GetHealthBackendServiceRequest project. */
                    public project: string;

                    /** GetHealthBackendServiceRequest resourceGroupReferenceResource. */
                    public resourceGroupReferenceResource?: (google.cloud.compute.v1.IResourceGroupReference|null);

                    /**
                     * Creates a new GetHealthBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetHealthBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetHealthBackendServiceRequest): google.cloud.compute.v1.GetHealthBackendServiceRequest;

                    /**
                     * Encodes the specified GetHealthBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetHealthBackendServiceRequest.verify|verify} messages.
                     * @param message GetHealthBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetHealthBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetHealthBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetHealthBackendServiceRequest.verify|verify} messages.
                     * @param message GetHealthBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetHealthBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetHealthBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetHealthBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetHealthBackendServiceRequest;

                    /**
                     * Decodes a GetHealthBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetHealthBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetHealthBackendServiceRequest;

                    /**
                     * Verifies a GetHealthBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetHealthBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetHealthBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetHealthBackendServiceRequest;

                    /**
                     * Creates a plain object from a GetHealthBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message GetHealthBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetHealthBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetHealthBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetHealthBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetHealthCheckRequest. */
                interface IGetHealthCheckRequest {

                    /** GetHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** GetHealthCheckRequest project */
                    project?: (string|null);
                }

                /** Represents a GetHealthCheckRequest. */
                class GetHealthCheckRequest implements IGetHealthCheckRequest {

                    /**
                     * Constructs a new GetHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetHealthCheckRequest);

                    /** GetHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** GetHealthCheckRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetHealthCheckRequest): google.cloud.compute.v1.GetHealthCheckRequest;

                    /**
                     * Encodes the specified GetHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.GetHealthCheckRequest.verify|verify} messages.
                     * @param message GetHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetHealthCheckRequest.verify|verify} messages.
                     * @param message GetHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetHealthCheckRequest;

                    /**
                     * Decodes a GetHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetHealthCheckRequest;

                    /**
                     * Verifies a GetHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetHealthCheckRequest;

                    /**
                     * Creates a plain object from a GetHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message GetHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetHealthRegionBackendServiceRequest. */
                interface IGetHealthRegionBackendServiceRequest {

                    /** GetHealthRegionBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** GetHealthRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** GetHealthRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** GetHealthRegionBackendServiceRequest resourceGroupReferenceResource */
                    resourceGroupReferenceResource?: (google.cloud.compute.v1.IResourceGroupReference|null);
                }

                /** Represents a GetHealthRegionBackendServiceRequest. */
                class GetHealthRegionBackendServiceRequest implements IGetHealthRegionBackendServiceRequest {

                    /**
                     * Constructs a new GetHealthRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetHealthRegionBackendServiceRequest);

                    /** GetHealthRegionBackendServiceRequest backendService. */
                    public backendService: string;

                    /** GetHealthRegionBackendServiceRequest project. */
                    public project: string;

                    /** GetHealthRegionBackendServiceRequest region. */
                    public region: string;

                    /** GetHealthRegionBackendServiceRequest resourceGroupReferenceResource. */
                    public resourceGroupReferenceResource?: (google.cloud.compute.v1.IResourceGroupReference|null);

                    /**
                     * Creates a new GetHealthRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetHealthRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetHealthRegionBackendServiceRequest): google.cloud.compute.v1.GetHealthRegionBackendServiceRequest;

                    /**
                     * Encodes the specified GetHealthRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetHealthRegionBackendServiceRequest.verify|verify} messages.
                     * @param message GetHealthRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetHealthRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetHealthRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetHealthRegionBackendServiceRequest.verify|verify} messages.
                     * @param message GetHealthRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetHealthRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetHealthRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetHealthRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetHealthRegionBackendServiceRequest;

                    /**
                     * Decodes a GetHealthRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetHealthRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetHealthRegionBackendServiceRequest;

                    /**
                     * Verifies a GetHealthRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetHealthRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetHealthRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetHealthRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from a GetHealthRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message GetHealthRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetHealthRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetHealthRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetHealthRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetHealthTargetPoolRequest. */
                interface IGetHealthTargetPoolRequest {

                    /** GetHealthTargetPoolRequest instanceReferenceResource */
                    instanceReferenceResource?: (google.cloud.compute.v1.IInstanceReference|null);

                    /** GetHealthTargetPoolRequest project */
                    project?: (string|null);

                    /** GetHealthTargetPoolRequest region */
                    region?: (string|null);

                    /** GetHealthTargetPoolRequest targetPool */
                    targetPool?: (string|null);
                }

                /** Represents a GetHealthTargetPoolRequest. */
                class GetHealthTargetPoolRequest implements IGetHealthTargetPoolRequest {

                    /**
                     * Constructs a new GetHealthTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetHealthTargetPoolRequest);

                    /** GetHealthTargetPoolRequest instanceReferenceResource. */
                    public instanceReferenceResource?: (google.cloud.compute.v1.IInstanceReference|null);

                    /** GetHealthTargetPoolRequest project. */
                    public project: string;

                    /** GetHealthTargetPoolRequest region. */
                    public region: string;

                    /** GetHealthTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /**
                     * Creates a new GetHealthTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetHealthTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetHealthTargetPoolRequest): google.cloud.compute.v1.GetHealthTargetPoolRequest;

                    /**
                     * Encodes the specified GetHealthTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.GetHealthTargetPoolRequest.verify|verify} messages.
                     * @param message GetHealthTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetHealthTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetHealthTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetHealthTargetPoolRequest.verify|verify} messages.
                     * @param message GetHealthTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetHealthTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetHealthTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetHealthTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetHealthTargetPoolRequest;

                    /**
                     * Decodes a GetHealthTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetHealthTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetHealthTargetPoolRequest;

                    /**
                     * Verifies a GetHealthTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetHealthTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetHealthTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetHealthTargetPoolRequest;

                    /**
                     * Creates a plain object from a GetHealthTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message GetHealthTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetHealthTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetHealthTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetHealthTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyBackendServiceRequest. */
                interface IGetIamPolicyBackendServiceRequest {

                    /** GetIamPolicyBackendServiceRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyBackendServiceRequest project */
                    project?: (string|null);

                    /** GetIamPolicyBackendServiceRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyBackendServiceRequest. */
                class GetIamPolicyBackendServiceRequest implements IGetIamPolicyBackendServiceRequest {

                    /**
                     * Constructs a new GetIamPolicyBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyBackendServiceRequest);

                    /** GetIamPolicyBackendServiceRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyBackendServiceRequest project. */
                    public project: string;

                    /** GetIamPolicyBackendServiceRequest resource. */
                    public resource: string;

                    /** GetIamPolicyBackendServiceRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyBackendServiceRequest): google.cloud.compute.v1.GetIamPolicyBackendServiceRequest;

                    /**
                     * Encodes the specified GetIamPolicyBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message GetIamPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message GetIamPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyBackendServiceRequest;

                    /**
                     * Decodes a GetIamPolicyBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyBackendServiceRequest;

                    /**
                     * Verifies a GetIamPolicyBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyBackendServiceRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyDiskRequest. */
                interface IGetIamPolicyDiskRequest {

                    /** GetIamPolicyDiskRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyDiskRequest project */
                    project?: (string|null);

                    /** GetIamPolicyDiskRequest resource */
                    resource?: (string|null);

                    /** GetIamPolicyDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetIamPolicyDiskRequest. */
                class GetIamPolicyDiskRequest implements IGetIamPolicyDiskRequest {

                    /**
                     * Constructs a new GetIamPolicyDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyDiskRequest);

                    /** GetIamPolicyDiskRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyDiskRequest project. */
                    public project: string;

                    /** GetIamPolicyDiskRequest resource. */
                    public resource: string;

                    /** GetIamPolicyDiskRequest zone. */
                    public zone: string;

                    /** GetIamPolicyDiskRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyDiskRequest): google.cloud.compute.v1.GetIamPolicyDiskRequest;

                    /**
                     * Encodes the specified GetIamPolicyDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyDiskRequest.verify|verify} messages.
                     * @param message GetIamPolicyDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyDiskRequest.verify|verify} messages.
                     * @param message GetIamPolicyDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyDiskRequest;

                    /**
                     * Decodes a GetIamPolicyDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyDiskRequest;

                    /**
                     * Verifies a GetIamPolicyDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyDiskRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyDiskRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyFirewallPolicyRequest. */
                interface IGetIamPolicyFirewallPolicyRequest {

                    /** GetIamPolicyFirewallPolicyRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyFirewallPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyFirewallPolicyRequest. */
                class GetIamPolicyFirewallPolicyRequest implements IGetIamPolicyFirewallPolicyRequest {

                    /**
                     * Constructs a new GetIamPolicyFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyFirewallPolicyRequest);

                    /** GetIamPolicyFirewallPolicyRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyFirewallPolicyRequest resource. */
                    public resource: string;

                    /** GetIamPolicyFirewallPolicyRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyFirewallPolicyRequest): google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetIamPolicyFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest;

                    /**
                     * Decodes a GetIamPolicyFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest;

                    /**
                     * Verifies a GetIamPolicyFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyImageRequest. */
                interface IGetIamPolicyImageRequest {

                    /** GetIamPolicyImageRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyImageRequest project */
                    project?: (string|null);

                    /** GetIamPolicyImageRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyImageRequest. */
                class GetIamPolicyImageRequest implements IGetIamPolicyImageRequest {

                    /**
                     * Constructs a new GetIamPolicyImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyImageRequest);

                    /** GetIamPolicyImageRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyImageRequest project. */
                    public project: string;

                    /** GetIamPolicyImageRequest resource. */
                    public resource: string;

                    /** GetIamPolicyImageRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyImageRequest): google.cloud.compute.v1.GetIamPolicyImageRequest;

                    /**
                     * Encodes the specified GetIamPolicyImageRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyImageRequest.verify|verify} messages.
                     * @param message GetIamPolicyImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyImageRequest.verify|verify} messages.
                     * @param message GetIamPolicyImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyImageRequest;

                    /**
                     * Decodes a GetIamPolicyImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyImageRequest;

                    /**
                     * Verifies a GetIamPolicyImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyImageRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyImageRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyInstanceRequest. */
                interface IGetIamPolicyInstanceRequest {

                    /** GetIamPolicyInstanceRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyInstanceRequest project */
                    project?: (string|null);

                    /** GetIamPolicyInstanceRequest resource */
                    resource?: (string|null);

                    /** GetIamPolicyInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetIamPolicyInstanceRequest. */
                class GetIamPolicyInstanceRequest implements IGetIamPolicyInstanceRequest {

                    /**
                     * Constructs a new GetIamPolicyInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyInstanceRequest);

                    /** GetIamPolicyInstanceRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyInstanceRequest project. */
                    public project: string;

                    /** GetIamPolicyInstanceRequest resource. */
                    public resource: string;

                    /** GetIamPolicyInstanceRequest zone. */
                    public zone: string;

                    /** GetIamPolicyInstanceRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyInstanceRequest): google.cloud.compute.v1.GetIamPolicyInstanceRequest;

                    /**
                     * Encodes the specified GetIamPolicyInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyInstanceRequest.verify|verify} messages.
                     * @param message GetIamPolicyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyInstanceRequest.verify|verify} messages.
                     * @param message GetIamPolicyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyInstanceRequest;

                    /**
                     * Decodes a GetIamPolicyInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyInstanceRequest;

                    /**
                     * Verifies a GetIamPolicyInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyInstanceRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyInstanceTemplateRequest. */
                interface IGetIamPolicyInstanceTemplateRequest {

                    /** GetIamPolicyInstanceTemplateRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyInstanceTemplateRequest project */
                    project?: (string|null);

                    /** GetIamPolicyInstanceTemplateRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyInstanceTemplateRequest. */
                class GetIamPolicyInstanceTemplateRequest implements IGetIamPolicyInstanceTemplateRequest {

                    /**
                     * Constructs a new GetIamPolicyInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyInstanceTemplateRequest);

                    /** GetIamPolicyInstanceTemplateRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyInstanceTemplateRequest project. */
                    public project: string;

                    /** GetIamPolicyInstanceTemplateRequest resource. */
                    public resource: string;

                    /** GetIamPolicyInstanceTemplateRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyInstanceTemplateRequest): google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest;

                    /**
                     * Encodes the specified GetIamPolicyInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest.verify|verify} messages.
                     * @param message GetIamPolicyInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest.verify|verify} messages.
                     * @param message GetIamPolicyInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest;

                    /**
                     * Decodes a GetIamPolicyInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest;

                    /**
                     * Verifies a GetIamPolicyInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyLicenseRequest. */
                interface IGetIamPolicyLicenseRequest {

                    /** GetIamPolicyLicenseRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyLicenseRequest project */
                    project?: (string|null);

                    /** GetIamPolicyLicenseRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyLicenseRequest. */
                class GetIamPolicyLicenseRequest implements IGetIamPolicyLicenseRequest {

                    /**
                     * Constructs a new GetIamPolicyLicenseRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyLicenseRequest);

                    /** GetIamPolicyLicenseRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyLicenseRequest project. */
                    public project: string;

                    /** GetIamPolicyLicenseRequest resource. */
                    public resource: string;

                    /** GetIamPolicyLicenseRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyLicenseRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyLicenseRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyLicenseRequest): google.cloud.compute.v1.GetIamPolicyLicenseRequest;

                    /**
                     * Encodes the specified GetIamPolicyLicenseRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyLicenseRequest.verify|verify} messages.
                     * @param message GetIamPolicyLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyLicenseRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyLicenseRequest.verify|verify} messages.
                     * @param message GetIamPolicyLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyLicenseRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyLicenseRequest;

                    /**
                     * Decodes a GetIamPolicyLicenseRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyLicenseRequest;

                    /**
                     * Verifies a GetIamPolicyLicenseRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyLicenseRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyLicenseRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyLicenseRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyLicenseRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyLicenseRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyLicenseRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyLicenseRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyLicenseRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyMachineImageRequest. */
                interface IGetIamPolicyMachineImageRequest {

                    /** GetIamPolicyMachineImageRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyMachineImageRequest project */
                    project?: (string|null);

                    /** GetIamPolicyMachineImageRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyMachineImageRequest. */
                class GetIamPolicyMachineImageRequest implements IGetIamPolicyMachineImageRequest {

                    /**
                     * Constructs a new GetIamPolicyMachineImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyMachineImageRequest);

                    /** GetIamPolicyMachineImageRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyMachineImageRequest project. */
                    public project: string;

                    /** GetIamPolicyMachineImageRequest resource. */
                    public resource: string;

                    /** GetIamPolicyMachineImageRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyMachineImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyMachineImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyMachineImageRequest): google.cloud.compute.v1.GetIamPolicyMachineImageRequest;

                    /**
                     * Encodes the specified GetIamPolicyMachineImageRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyMachineImageRequest.verify|verify} messages.
                     * @param message GetIamPolicyMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyMachineImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyMachineImageRequest.verify|verify} messages.
                     * @param message GetIamPolicyMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyMachineImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyMachineImageRequest;

                    /**
                     * Decodes a GetIamPolicyMachineImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyMachineImageRequest;

                    /**
                     * Verifies a GetIamPolicyMachineImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyMachineImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyMachineImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyMachineImageRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyMachineImageRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyMachineImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyMachineImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyMachineImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyMachineImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyNetworkFirewallPolicyRequest. */
                interface IGetIamPolicyNetworkFirewallPolicyRequest {

                    /** GetIamPolicyNetworkFirewallPolicyRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** GetIamPolicyNetworkFirewallPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyNetworkFirewallPolicyRequest. */
                class GetIamPolicyNetworkFirewallPolicyRequest implements IGetIamPolicyNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetIamPolicyNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyNetworkFirewallPolicyRequest);

                    /** GetIamPolicyNetworkFirewallPolicyRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetIamPolicyNetworkFirewallPolicyRequest resource. */
                    public resource: string;

                    /** GetIamPolicyNetworkFirewallPolicyRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetIamPolicyNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetIamPolicyNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetIamPolicyNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyNodeGroupRequest. */
                interface IGetIamPolicyNodeGroupRequest {

                    /** GetIamPolicyNodeGroupRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyNodeGroupRequest project */
                    project?: (string|null);

                    /** GetIamPolicyNodeGroupRequest resource */
                    resource?: (string|null);

                    /** GetIamPolicyNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetIamPolicyNodeGroupRequest. */
                class GetIamPolicyNodeGroupRequest implements IGetIamPolicyNodeGroupRequest {

                    /**
                     * Constructs a new GetIamPolicyNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest);

                    /** GetIamPolicyNodeGroupRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyNodeGroupRequest project. */
                    public project: string;

                    /** GetIamPolicyNodeGroupRequest resource. */
                    public resource: string;

                    /** GetIamPolicyNodeGroupRequest zone. */
                    public zone: string;

                    /** GetIamPolicyNodeGroupRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest): google.cloud.compute.v1.GetIamPolicyNodeGroupRequest;

                    /**
                     * Encodes the specified GetIamPolicyNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyNodeGroupRequest.verify|verify} messages.
                     * @param message GetIamPolicyNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyNodeGroupRequest.verify|verify} messages.
                     * @param message GetIamPolicyNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyNodeGroupRequest;

                    /**
                     * Decodes a GetIamPolicyNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyNodeGroupRequest;

                    /**
                     * Verifies a GetIamPolicyNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyNodeGroupRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyNodeTemplateRequest. */
                interface IGetIamPolicyNodeTemplateRequest {

                    /** GetIamPolicyNodeTemplateRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyNodeTemplateRequest project */
                    project?: (string|null);

                    /** GetIamPolicyNodeTemplateRequest region */
                    region?: (string|null);

                    /** GetIamPolicyNodeTemplateRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyNodeTemplateRequest. */
                class GetIamPolicyNodeTemplateRequest implements IGetIamPolicyNodeTemplateRequest {

                    /**
                     * Constructs a new GetIamPolicyNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyNodeTemplateRequest);

                    /** GetIamPolicyNodeTemplateRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyNodeTemplateRequest project. */
                    public project: string;

                    /** GetIamPolicyNodeTemplateRequest region. */
                    public region: string;

                    /** GetIamPolicyNodeTemplateRequest resource. */
                    public resource: string;

                    /** GetIamPolicyNodeTemplateRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyNodeTemplateRequest): google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest;

                    /**
                     * Encodes the specified GetIamPolicyNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest.verify|verify} messages.
                     * @param message GetIamPolicyNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest.verify|verify} messages.
                     * @param message GetIamPolicyNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest;

                    /**
                     * Decodes a GetIamPolicyNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest;

                    /**
                     * Verifies a GetIamPolicyNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyRegionBackendServiceRequest. */
                interface IGetIamPolicyRegionBackendServiceRequest {

                    /** GetIamPolicyRegionBackendServiceRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** GetIamPolicyRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** GetIamPolicyRegionBackendServiceRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyRegionBackendServiceRequest. */
                class GetIamPolicyRegionBackendServiceRequest implements IGetIamPolicyRegionBackendServiceRequest {

                    /**
                     * Constructs a new GetIamPolicyRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyRegionBackendServiceRequest);

                    /** GetIamPolicyRegionBackendServiceRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyRegionBackendServiceRequest project. */
                    public project: string;

                    /** GetIamPolicyRegionBackendServiceRequest region. */
                    public region: string;

                    /** GetIamPolicyRegionBackendServiceRequest resource. */
                    public resource: string;

                    /** GetIamPolicyRegionBackendServiceRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyRegionBackendServiceRequest): google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Encodes the specified GetIamPolicyRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest.verify|verify} messages.
                     * @param message GetIamPolicyRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest.verify|verify} messages.
                     * @param message GetIamPolicyRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Decodes a GetIamPolicyRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Verifies a GetIamPolicyRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyRegionDiskRequest. */
                interface IGetIamPolicyRegionDiskRequest {

                    /** GetIamPolicyRegionDiskRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyRegionDiskRequest project */
                    project?: (string|null);

                    /** GetIamPolicyRegionDiskRequest region */
                    region?: (string|null);

                    /** GetIamPolicyRegionDiskRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyRegionDiskRequest. */
                class GetIamPolicyRegionDiskRequest implements IGetIamPolicyRegionDiskRequest {

                    /**
                     * Constructs a new GetIamPolicyRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyRegionDiskRequest);

                    /** GetIamPolicyRegionDiskRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyRegionDiskRequest project. */
                    public project: string;

                    /** GetIamPolicyRegionDiskRequest region. */
                    public region: string;

                    /** GetIamPolicyRegionDiskRequest resource. */
                    public resource: string;

                    /** GetIamPolicyRegionDiskRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyRegionDiskRequest): google.cloud.compute.v1.GetIamPolicyRegionDiskRequest;

                    /**
                     * Encodes the specified GetIamPolicyRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyRegionDiskRequest.verify|verify} messages.
                     * @param message GetIamPolicyRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyRegionDiskRequest.verify|verify} messages.
                     * @param message GetIamPolicyRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyRegionDiskRequest;

                    /**
                     * Decodes a GetIamPolicyRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyRegionDiskRequest;

                    /**
                     * Verifies a GetIamPolicyRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyRegionDiskRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyRegionNetworkFirewallPolicyRequest. */
                interface IGetIamPolicyRegionNetworkFirewallPolicyRequest {

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyRegionNetworkFirewallPolicyRequest. */
                class GetIamPolicyRegionNetworkFirewallPolicyRequest implements IGetIamPolicyRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetIamPolicyRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyRegionNetworkFirewallPolicyRequest);

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest resource. */
                    public resource: string;

                    /** GetIamPolicyRegionNetworkFirewallPolicyRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetIamPolicyRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetIamPolicyRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetIamPolicyRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyReservationRequest. */
                interface IGetIamPolicyReservationRequest {

                    /** GetIamPolicyReservationRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyReservationRequest project */
                    project?: (string|null);

                    /** GetIamPolicyReservationRequest resource */
                    resource?: (string|null);

                    /** GetIamPolicyReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetIamPolicyReservationRequest. */
                class GetIamPolicyReservationRequest implements IGetIamPolicyReservationRequest {

                    /**
                     * Constructs a new GetIamPolicyReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyReservationRequest);

                    /** GetIamPolicyReservationRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyReservationRequest project. */
                    public project: string;

                    /** GetIamPolicyReservationRequest resource. */
                    public resource: string;

                    /** GetIamPolicyReservationRequest zone. */
                    public zone: string;

                    /** GetIamPolicyReservationRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyReservationRequest): google.cloud.compute.v1.GetIamPolicyReservationRequest;

                    /**
                     * Encodes the specified GetIamPolicyReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyReservationRequest.verify|verify} messages.
                     * @param message GetIamPolicyReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyReservationRequest.verify|verify} messages.
                     * @param message GetIamPolicyReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyReservationRequest;

                    /**
                     * Decodes a GetIamPolicyReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyReservationRequest;

                    /**
                     * Verifies a GetIamPolicyReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyReservationRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyReservationRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyResourcePolicyRequest. */
                interface IGetIamPolicyResourcePolicyRequest {

                    /** GetIamPolicyResourcePolicyRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyResourcePolicyRequest project */
                    project?: (string|null);

                    /** GetIamPolicyResourcePolicyRequest region */
                    region?: (string|null);

                    /** GetIamPolicyResourcePolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyResourcePolicyRequest. */
                class GetIamPolicyResourcePolicyRequest implements IGetIamPolicyResourcePolicyRequest {

                    /**
                     * Constructs a new GetIamPolicyResourcePolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyResourcePolicyRequest);

                    /** GetIamPolicyResourcePolicyRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyResourcePolicyRequest project. */
                    public project: string;

                    /** GetIamPolicyResourcePolicyRequest region. */
                    public region: string;

                    /** GetIamPolicyResourcePolicyRequest resource. */
                    public resource: string;

                    /** GetIamPolicyResourcePolicyRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyResourcePolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyResourcePolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyResourcePolicyRequest): google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest;

                    /**
                     * Encodes the specified GetIamPolicyResourcePolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyResourcePolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest.verify|verify} messages.
                     * @param message GetIamPolicyResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyResourcePolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest;

                    /**
                     * Decodes a GetIamPolicyResourcePolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest;

                    /**
                     * Verifies a GetIamPolicyResourcePolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyResourcePolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyResourcePolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyResourcePolicyRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyResourcePolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyResourcePolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyResourcePolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyResourcePolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicyServiceAttachmentRequest. */
                interface IGetIamPolicyServiceAttachmentRequest {

                    /** GetIamPolicyServiceAttachmentRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyServiceAttachmentRequest project */
                    project?: (string|null);

                    /** GetIamPolicyServiceAttachmentRequest region */
                    region?: (string|null);

                    /** GetIamPolicyServiceAttachmentRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicyServiceAttachmentRequest. */
                class GetIamPolicyServiceAttachmentRequest implements IGetIamPolicyServiceAttachmentRequest {

                    /**
                     * Constructs a new GetIamPolicyServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicyServiceAttachmentRequest);

                    /** GetIamPolicyServiceAttachmentRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicyServiceAttachmentRequest project. */
                    public project: string;

                    /** GetIamPolicyServiceAttachmentRequest region. */
                    public region: string;

                    /** GetIamPolicyServiceAttachmentRequest resource. */
                    public resource: string;

                    /** GetIamPolicyServiceAttachmentRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicyServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicyServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicyServiceAttachmentRequest): google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest;

                    /**
                     * Encodes the specified GetIamPolicyServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest.verify|verify} messages.
                     * @param message GetIamPolicyServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicyServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicyServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest.verify|verify} messages.
                     * @param message GetIamPolicyServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicyServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicyServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicyServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest;

                    /**
                     * Decodes a GetIamPolicyServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicyServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest;

                    /**
                     * Verifies a GetIamPolicyServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicyServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicyServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest;

                    /**
                     * Creates a plain object from a GetIamPolicyServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicyServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicyServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicyServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicyServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicySnapshotRequest. */
                interface IGetIamPolicySnapshotRequest {

                    /** GetIamPolicySnapshotRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicySnapshotRequest project */
                    project?: (string|null);

                    /** GetIamPolicySnapshotRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicySnapshotRequest. */
                class GetIamPolicySnapshotRequest implements IGetIamPolicySnapshotRequest {

                    /**
                     * Constructs a new GetIamPolicySnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicySnapshotRequest);

                    /** GetIamPolicySnapshotRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicySnapshotRequest project. */
                    public project: string;

                    /** GetIamPolicySnapshotRequest resource. */
                    public resource: string;

                    /** GetIamPolicySnapshotRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicySnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicySnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicySnapshotRequest): google.cloud.compute.v1.GetIamPolicySnapshotRequest;

                    /**
                     * Encodes the specified GetIamPolicySnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicySnapshotRequest.verify|verify} messages.
                     * @param message GetIamPolicySnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicySnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicySnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicySnapshotRequest.verify|verify} messages.
                     * @param message GetIamPolicySnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicySnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicySnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicySnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicySnapshotRequest;

                    /**
                     * Decodes a GetIamPolicySnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicySnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicySnapshotRequest;

                    /**
                     * Verifies a GetIamPolicySnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicySnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicySnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicySnapshotRequest;

                    /**
                     * Creates a plain object from a GetIamPolicySnapshotRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicySnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicySnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicySnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicySnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetIamPolicySubnetworkRequest. */
                interface IGetIamPolicySubnetworkRequest {

                    /** GetIamPolicySubnetworkRequest optionsRequestedPolicyVersion */
                    optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicySubnetworkRequest project */
                    project?: (string|null);

                    /** GetIamPolicySubnetworkRequest region */
                    region?: (string|null);

                    /** GetIamPolicySubnetworkRequest resource */
                    resource?: (string|null);
                }

                /** Represents a GetIamPolicySubnetworkRequest. */
                class GetIamPolicySubnetworkRequest implements IGetIamPolicySubnetworkRequest {

                    /**
                     * Constructs a new GetIamPolicySubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetIamPolicySubnetworkRequest);

                    /** GetIamPolicySubnetworkRequest optionsRequestedPolicyVersion. */
                    public optionsRequestedPolicyVersion?: (number|null);

                    /** GetIamPolicySubnetworkRequest project. */
                    public project: string;

                    /** GetIamPolicySubnetworkRequest region. */
                    public region: string;

                    /** GetIamPolicySubnetworkRequest resource. */
                    public resource: string;

                    /** GetIamPolicySubnetworkRequest _optionsRequestedPolicyVersion. */
                    public _optionsRequestedPolicyVersion?: "optionsRequestedPolicyVersion";

                    /**
                     * Creates a new GetIamPolicySubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetIamPolicySubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetIamPolicySubnetworkRequest): google.cloud.compute.v1.GetIamPolicySubnetworkRequest;

                    /**
                     * Encodes the specified GetIamPolicySubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicySubnetworkRequest.verify|verify} messages.
                     * @param message GetIamPolicySubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetIamPolicySubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetIamPolicySubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetIamPolicySubnetworkRequest.verify|verify} messages.
                     * @param message GetIamPolicySubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetIamPolicySubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetIamPolicySubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetIamPolicySubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetIamPolicySubnetworkRequest;

                    /**
                     * Decodes a GetIamPolicySubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetIamPolicySubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetIamPolicySubnetworkRequest;

                    /**
                     * Verifies a GetIamPolicySubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetIamPolicySubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetIamPolicySubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetIamPolicySubnetworkRequest;

                    /**
                     * Creates a plain object from a GetIamPolicySubnetworkRequest message. Also converts values to other types if specified.
                     * @param message GetIamPolicySubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetIamPolicySubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetIamPolicySubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetIamPolicySubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetImageFamilyViewRequest. */
                interface IGetImageFamilyViewRequest {

                    /** GetImageFamilyViewRequest family */
                    family?: (string|null);

                    /** GetImageFamilyViewRequest project */
                    project?: (string|null);

                    /** GetImageFamilyViewRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetImageFamilyViewRequest. */
                class GetImageFamilyViewRequest implements IGetImageFamilyViewRequest {

                    /**
                     * Constructs a new GetImageFamilyViewRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetImageFamilyViewRequest);

                    /** GetImageFamilyViewRequest family. */
                    public family: string;

                    /** GetImageFamilyViewRequest project. */
                    public project: string;

                    /** GetImageFamilyViewRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetImageFamilyViewRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetImageFamilyViewRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetImageFamilyViewRequest): google.cloud.compute.v1.GetImageFamilyViewRequest;

                    /**
                     * Encodes the specified GetImageFamilyViewRequest message. Does not implicitly {@link google.cloud.compute.v1.GetImageFamilyViewRequest.verify|verify} messages.
                     * @param message GetImageFamilyViewRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetImageFamilyViewRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetImageFamilyViewRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetImageFamilyViewRequest.verify|verify} messages.
                     * @param message GetImageFamilyViewRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetImageFamilyViewRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetImageFamilyViewRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetImageFamilyViewRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetImageFamilyViewRequest;

                    /**
                     * Decodes a GetImageFamilyViewRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetImageFamilyViewRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetImageFamilyViewRequest;

                    /**
                     * Verifies a GetImageFamilyViewRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetImageFamilyViewRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetImageFamilyViewRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetImageFamilyViewRequest;

                    /**
                     * Creates a plain object from a GetImageFamilyViewRequest message. Also converts values to other types if specified.
                     * @param message GetImageFamilyViewRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetImageFamilyViewRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetImageFamilyViewRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetImageFamilyViewRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetImageRequest. */
                interface IGetImageRequest {

                    /** GetImageRequest image */
                    image?: (string|null);

                    /** GetImageRequest project */
                    project?: (string|null);
                }

                /** Represents a GetImageRequest. */
                class GetImageRequest implements IGetImageRequest {

                    /**
                     * Constructs a new GetImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetImageRequest);

                    /** GetImageRequest image. */
                    public image: string;

                    /** GetImageRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetImageRequest): google.cloud.compute.v1.GetImageRequest;

                    /**
                     * Encodes the specified GetImageRequest message. Does not implicitly {@link google.cloud.compute.v1.GetImageRequest.verify|verify} messages.
                     * @param message GetImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetImageRequest.verify|verify} messages.
                     * @param message GetImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetImageRequest;

                    /**
                     * Decodes a GetImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetImageRequest;

                    /**
                     * Verifies a GetImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetImageRequest;

                    /**
                     * Creates a plain object from a GetImageRequest message. Also converts values to other types if specified.
                     * @param message GetImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInstanceGroupManagerRequest. */
                interface IGetInstanceGroupManagerRequest {

                    /** GetInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** GetInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** GetInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetInstanceGroupManagerRequest. */
                class GetInstanceGroupManagerRequest implements IGetInstanceGroupManagerRequest {

                    /**
                     * Constructs a new GetInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInstanceGroupManagerRequest);

                    /** GetInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** GetInstanceGroupManagerRequest project. */
                    public project: string;

                    /** GetInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInstanceGroupManagerRequest): google.cloud.compute.v1.GetInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified GetInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message GetInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message GetInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInstanceGroupManagerRequest;

                    /**
                     * Decodes a GetInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInstanceGroupManagerRequest;

                    /**
                     * Verifies a GetInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a GetInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message GetInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInstanceGroupRequest. */
                interface IGetInstanceGroupRequest {

                    /** GetInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** GetInstanceGroupRequest project */
                    project?: (string|null);

                    /** GetInstanceGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetInstanceGroupRequest. */
                class GetInstanceGroupRequest implements IGetInstanceGroupRequest {

                    /**
                     * Constructs a new GetInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInstanceGroupRequest);

                    /** GetInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** GetInstanceGroupRequest project. */
                    public project: string;

                    /** GetInstanceGroupRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInstanceGroupRequest): google.cloud.compute.v1.GetInstanceGroupRequest;

                    /**
                     * Encodes the specified GetInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInstanceGroupRequest.verify|verify} messages.
                     * @param message GetInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInstanceGroupRequest.verify|verify} messages.
                     * @param message GetInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInstanceGroupRequest;

                    /**
                     * Decodes a GetInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInstanceGroupRequest;

                    /**
                     * Verifies a GetInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInstanceGroupRequest;

                    /**
                     * Creates a plain object from a GetInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message GetInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInstanceRequest. */
                interface IGetInstanceRequest {

                    /** GetInstanceRequest instance */
                    instance?: (string|null);

                    /** GetInstanceRequest project */
                    project?: (string|null);

                    /** GetInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetInstanceRequest. */
                class GetInstanceRequest implements IGetInstanceRequest {

                    /**
                     * Constructs a new GetInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInstanceRequest);

                    /** GetInstanceRequest instance. */
                    public instance: string;

                    /** GetInstanceRequest project. */
                    public project: string;

                    /** GetInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInstanceRequest): google.cloud.compute.v1.GetInstanceRequest;

                    /**
                     * Encodes the specified GetInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInstanceRequest.verify|verify} messages.
                     * @param message GetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInstanceRequest.verify|verify} messages.
                     * @param message GetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInstanceRequest;

                    /**
                     * Decodes a GetInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInstanceRequest;

                    /**
                     * Verifies a GetInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInstanceRequest;

                    /**
                     * Creates a plain object from a GetInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInstanceTemplateRequest. */
                interface IGetInstanceTemplateRequest {

                    /** GetInstanceTemplateRequest instanceTemplate */
                    instanceTemplate?: (string|null);

                    /** GetInstanceTemplateRequest project */
                    project?: (string|null);
                }

                /** Represents a GetInstanceTemplateRequest. */
                class GetInstanceTemplateRequest implements IGetInstanceTemplateRequest {

                    /**
                     * Constructs a new GetInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInstanceTemplateRequest);

                    /** GetInstanceTemplateRequest instanceTemplate. */
                    public instanceTemplate: string;

                    /** GetInstanceTemplateRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInstanceTemplateRequest): google.cloud.compute.v1.GetInstanceTemplateRequest;

                    /**
                     * Encodes the specified GetInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInstanceTemplateRequest.verify|verify} messages.
                     * @param message GetInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInstanceTemplateRequest.verify|verify} messages.
                     * @param message GetInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInstanceTemplateRequest;

                    /**
                     * Decodes a GetInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInstanceTemplateRequest;

                    /**
                     * Verifies a GetInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInstanceTemplateRequest;

                    /**
                     * Creates a plain object from a GetInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message GetInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInterconnectAttachmentRequest. */
                interface IGetInterconnectAttachmentRequest {

                    /** GetInterconnectAttachmentRequest interconnectAttachment */
                    interconnectAttachment?: (string|null);

                    /** GetInterconnectAttachmentRequest project */
                    project?: (string|null);

                    /** GetInterconnectAttachmentRequest region */
                    region?: (string|null);
                }

                /** Represents a GetInterconnectAttachmentRequest. */
                class GetInterconnectAttachmentRequest implements IGetInterconnectAttachmentRequest {

                    /**
                     * Constructs a new GetInterconnectAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInterconnectAttachmentRequest);

                    /** GetInterconnectAttachmentRequest interconnectAttachment. */
                    public interconnectAttachment: string;

                    /** GetInterconnectAttachmentRequest project. */
                    public project: string;

                    /** GetInterconnectAttachmentRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetInterconnectAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInterconnectAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInterconnectAttachmentRequest): google.cloud.compute.v1.GetInterconnectAttachmentRequest;

                    /**
                     * Encodes the specified GetInterconnectAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message GetInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInterconnectAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message GetInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInterconnectAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInterconnectAttachmentRequest;

                    /**
                     * Decodes a GetInterconnectAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInterconnectAttachmentRequest;

                    /**
                     * Verifies a GetInterconnectAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInterconnectAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInterconnectAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInterconnectAttachmentRequest;

                    /**
                     * Creates a plain object from a GetInterconnectAttachmentRequest message. Also converts values to other types if specified.
                     * @param message GetInterconnectAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInterconnectAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInterconnectAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInterconnectAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInterconnectLocationRequest. */
                interface IGetInterconnectLocationRequest {

                    /** GetInterconnectLocationRequest interconnectLocation */
                    interconnectLocation?: (string|null);

                    /** GetInterconnectLocationRequest project */
                    project?: (string|null);
                }

                /** Represents a GetInterconnectLocationRequest. */
                class GetInterconnectLocationRequest implements IGetInterconnectLocationRequest {

                    /**
                     * Constructs a new GetInterconnectLocationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInterconnectLocationRequest);

                    /** GetInterconnectLocationRequest interconnectLocation. */
                    public interconnectLocation: string;

                    /** GetInterconnectLocationRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetInterconnectLocationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInterconnectLocationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInterconnectLocationRequest): google.cloud.compute.v1.GetInterconnectLocationRequest;

                    /**
                     * Encodes the specified GetInterconnectLocationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInterconnectLocationRequest.verify|verify} messages.
                     * @param message GetInterconnectLocationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInterconnectLocationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInterconnectLocationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInterconnectLocationRequest.verify|verify} messages.
                     * @param message GetInterconnectLocationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInterconnectLocationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInterconnectLocationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInterconnectLocationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInterconnectLocationRequest;

                    /**
                     * Decodes a GetInterconnectLocationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInterconnectLocationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInterconnectLocationRequest;

                    /**
                     * Verifies a GetInterconnectLocationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInterconnectLocationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInterconnectLocationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInterconnectLocationRequest;

                    /**
                     * Creates a plain object from a GetInterconnectLocationRequest message. Also converts values to other types if specified.
                     * @param message GetInterconnectLocationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInterconnectLocationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInterconnectLocationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInterconnectLocationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetInterconnectRequest. */
                interface IGetInterconnectRequest {

                    /** GetInterconnectRequest interconnect */
                    interconnect?: (string|null);

                    /** GetInterconnectRequest project */
                    project?: (string|null);
                }

                /** Represents a GetInterconnectRequest. */
                class GetInterconnectRequest implements IGetInterconnectRequest {

                    /**
                     * Constructs a new GetInterconnectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetInterconnectRequest);

                    /** GetInterconnectRequest interconnect. */
                    public interconnect: string;

                    /** GetInterconnectRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetInterconnectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetInterconnectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetInterconnectRequest): google.cloud.compute.v1.GetInterconnectRequest;

                    /**
                     * Encodes the specified GetInterconnectRequest message. Does not implicitly {@link google.cloud.compute.v1.GetInterconnectRequest.verify|verify} messages.
                     * @param message GetInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetInterconnectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetInterconnectRequest.verify|verify} messages.
                     * @param message GetInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetInterconnectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetInterconnectRequest;

                    /**
                     * Decodes a GetInterconnectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetInterconnectRequest;

                    /**
                     * Verifies a GetInterconnectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetInterconnectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetInterconnectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetInterconnectRequest;

                    /**
                     * Creates a plain object from a GetInterconnectRequest message. Also converts values to other types if specified.
                     * @param message GetInterconnectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetInterconnectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetInterconnectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetInterconnectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetLicenseCodeRequest. */
                interface IGetLicenseCodeRequest {

                    /** GetLicenseCodeRequest licenseCode */
                    licenseCode?: (string|null);

                    /** GetLicenseCodeRequest project */
                    project?: (string|null);
                }

                /** Represents a GetLicenseCodeRequest. */
                class GetLicenseCodeRequest implements IGetLicenseCodeRequest {

                    /**
                     * Constructs a new GetLicenseCodeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetLicenseCodeRequest);

                    /** GetLicenseCodeRequest licenseCode. */
                    public licenseCode: string;

                    /** GetLicenseCodeRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetLicenseCodeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetLicenseCodeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetLicenseCodeRequest): google.cloud.compute.v1.GetLicenseCodeRequest;

                    /**
                     * Encodes the specified GetLicenseCodeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetLicenseCodeRequest.verify|verify} messages.
                     * @param message GetLicenseCodeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetLicenseCodeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetLicenseCodeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetLicenseCodeRequest.verify|verify} messages.
                     * @param message GetLicenseCodeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetLicenseCodeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetLicenseCodeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetLicenseCodeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetLicenseCodeRequest;

                    /**
                     * Decodes a GetLicenseCodeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetLicenseCodeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetLicenseCodeRequest;

                    /**
                     * Verifies a GetLicenseCodeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetLicenseCodeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetLicenseCodeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetLicenseCodeRequest;

                    /**
                     * Creates a plain object from a GetLicenseCodeRequest message. Also converts values to other types if specified.
                     * @param message GetLicenseCodeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetLicenseCodeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetLicenseCodeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetLicenseCodeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetLicenseRequest. */
                interface IGetLicenseRequest {

                    /** GetLicenseRequest license */
                    license?: (string|null);

                    /** GetLicenseRequest project */
                    project?: (string|null);
                }

                /** Represents a GetLicenseRequest. */
                class GetLicenseRequest implements IGetLicenseRequest {

                    /**
                     * Constructs a new GetLicenseRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetLicenseRequest);

                    /** GetLicenseRequest license. */
                    public license: string;

                    /** GetLicenseRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetLicenseRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetLicenseRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetLicenseRequest): google.cloud.compute.v1.GetLicenseRequest;

                    /**
                     * Encodes the specified GetLicenseRequest message. Does not implicitly {@link google.cloud.compute.v1.GetLicenseRequest.verify|verify} messages.
                     * @param message GetLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetLicenseRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetLicenseRequest.verify|verify} messages.
                     * @param message GetLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetLicenseRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetLicenseRequest;

                    /**
                     * Decodes a GetLicenseRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetLicenseRequest;

                    /**
                     * Verifies a GetLicenseRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetLicenseRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetLicenseRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetLicenseRequest;

                    /**
                     * Creates a plain object from a GetLicenseRequest message. Also converts values to other types if specified.
                     * @param message GetLicenseRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetLicenseRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetLicenseRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetLicenseRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetMachineImageRequest. */
                interface IGetMachineImageRequest {

                    /** GetMachineImageRequest machineImage */
                    machineImage?: (string|null);

                    /** GetMachineImageRequest project */
                    project?: (string|null);
                }

                /** Represents a GetMachineImageRequest. */
                class GetMachineImageRequest implements IGetMachineImageRequest {

                    /**
                     * Constructs a new GetMachineImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetMachineImageRequest);

                    /** GetMachineImageRequest machineImage. */
                    public machineImage: string;

                    /** GetMachineImageRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetMachineImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetMachineImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetMachineImageRequest): google.cloud.compute.v1.GetMachineImageRequest;

                    /**
                     * Encodes the specified GetMachineImageRequest message. Does not implicitly {@link google.cloud.compute.v1.GetMachineImageRequest.verify|verify} messages.
                     * @param message GetMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetMachineImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetMachineImageRequest.verify|verify} messages.
                     * @param message GetMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetMachineImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetMachineImageRequest;

                    /**
                     * Decodes a GetMachineImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetMachineImageRequest;

                    /**
                     * Verifies a GetMachineImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetMachineImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetMachineImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetMachineImageRequest;

                    /**
                     * Creates a plain object from a GetMachineImageRequest message. Also converts values to other types if specified.
                     * @param message GetMachineImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetMachineImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetMachineImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetMachineImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetMachineTypeRequest. */
                interface IGetMachineTypeRequest {

                    /** GetMachineTypeRequest machineType */
                    machineType?: (string|null);

                    /** GetMachineTypeRequest project */
                    project?: (string|null);

                    /** GetMachineTypeRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetMachineTypeRequest. */
                class GetMachineTypeRequest implements IGetMachineTypeRequest {

                    /**
                     * Constructs a new GetMachineTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetMachineTypeRequest);

                    /** GetMachineTypeRequest machineType. */
                    public machineType: string;

                    /** GetMachineTypeRequest project. */
                    public project: string;

                    /** GetMachineTypeRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetMachineTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetMachineTypeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetMachineTypeRequest): google.cloud.compute.v1.GetMachineTypeRequest;

                    /**
                     * Encodes the specified GetMachineTypeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetMachineTypeRequest.verify|verify} messages.
                     * @param message GetMachineTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetMachineTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetMachineTypeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetMachineTypeRequest.verify|verify} messages.
                     * @param message GetMachineTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetMachineTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetMachineTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetMachineTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetMachineTypeRequest;

                    /**
                     * Decodes a GetMachineTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetMachineTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetMachineTypeRequest;

                    /**
                     * Verifies a GetMachineTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetMachineTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetMachineTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetMachineTypeRequest;

                    /**
                     * Creates a plain object from a GetMachineTypeRequest message. Also converts values to other types if specified.
                     * @param message GetMachineTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetMachineTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetMachineTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetMachineTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNatMappingInfoRoutersRequest. */
                interface IGetNatMappingInfoRoutersRequest {

                    /** GetNatMappingInfoRoutersRequest filter */
                    filter?: (string|null);

                    /** GetNatMappingInfoRoutersRequest maxResults */
                    maxResults?: (number|null);

                    /** GetNatMappingInfoRoutersRequest orderBy */
                    orderBy?: (string|null);

                    /** GetNatMappingInfoRoutersRequest pageToken */
                    pageToken?: (string|null);

                    /** GetNatMappingInfoRoutersRequest project */
                    project?: (string|null);

                    /** GetNatMappingInfoRoutersRequest region */
                    region?: (string|null);

                    /** GetNatMappingInfoRoutersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** GetNatMappingInfoRoutersRequest router */
                    router?: (string|null);
                }

                /** Represents a GetNatMappingInfoRoutersRequest. */
                class GetNatMappingInfoRoutersRequest implements IGetNatMappingInfoRoutersRequest {

                    /**
                     * Constructs a new GetNatMappingInfoRoutersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNatMappingInfoRoutersRequest);

                    /** GetNatMappingInfoRoutersRequest filter. */
                    public filter?: (string|null);

                    /** GetNatMappingInfoRoutersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** GetNatMappingInfoRoutersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** GetNatMappingInfoRoutersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** GetNatMappingInfoRoutersRequest project. */
                    public project: string;

                    /** GetNatMappingInfoRoutersRequest region. */
                    public region: string;

                    /** GetNatMappingInfoRoutersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** GetNatMappingInfoRoutersRequest router. */
                    public router: string;

                    /** GetNatMappingInfoRoutersRequest _filter. */
                    public _filter?: "filter";

                    /** GetNatMappingInfoRoutersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** GetNatMappingInfoRoutersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** GetNatMappingInfoRoutersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** GetNatMappingInfoRoutersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new GetNatMappingInfoRoutersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNatMappingInfoRoutersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNatMappingInfoRoutersRequest): google.cloud.compute.v1.GetNatMappingInfoRoutersRequest;

                    /**
                     * Encodes the specified GetNatMappingInfoRoutersRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNatMappingInfoRoutersRequest.verify|verify} messages.
                     * @param message GetNatMappingInfoRoutersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNatMappingInfoRoutersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNatMappingInfoRoutersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNatMappingInfoRoutersRequest.verify|verify} messages.
                     * @param message GetNatMappingInfoRoutersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNatMappingInfoRoutersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNatMappingInfoRoutersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNatMappingInfoRoutersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNatMappingInfoRoutersRequest;

                    /**
                     * Decodes a GetNatMappingInfoRoutersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNatMappingInfoRoutersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNatMappingInfoRoutersRequest;

                    /**
                     * Verifies a GetNatMappingInfoRoutersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNatMappingInfoRoutersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNatMappingInfoRoutersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNatMappingInfoRoutersRequest;

                    /**
                     * Creates a plain object from a GetNatMappingInfoRoutersRequest message. Also converts values to other types if specified.
                     * @param message GetNatMappingInfoRoutersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNatMappingInfoRoutersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNatMappingInfoRoutersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNatMappingInfoRoutersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNetworkEdgeSecurityServiceRequest. */
                interface IGetNetworkEdgeSecurityServiceRequest {

                    /** GetNetworkEdgeSecurityServiceRequest networkEdgeSecurityService */
                    networkEdgeSecurityService?: (string|null);

                    /** GetNetworkEdgeSecurityServiceRequest project */
                    project?: (string|null);

                    /** GetNetworkEdgeSecurityServiceRequest region */
                    region?: (string|null);
                }

                /** Represents a GetNetworkEdgeSecurityServiceRequest. */
                class GetNetworkEdgeSecurityServiceRequest implements IGetNetworkEdgeSecurityServiceRequest {

                    /**
                     * Constructs a new GetNetworkEdgeSecurityServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNetworkEdgeSecurityServiceRequest);

                    /** GetNetworkEdgeSecurityServiceRequest networkEdgeSecurityService. */
                    public networkEdgeSecurityService: string;

                    /** GetNetworkEdgeSecurityServiceRequest project. */
                    public project: string;

                    /** GetNetworkEdgeSecurityServiceRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetNetworkEdgeSecurityServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNetworkEdgeSecurityServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNetworkEdgeSecurityServiceRequest): google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest;

                    /**
                     * Encodes the specified GetNetworkEdgeSecurityServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message GetNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNetworkEdgeSecurityServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message GetNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNetworkEdgeSecurityServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest;

                    /**
                     * Decodes a GetNetworkEdgeSecurityServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest;

                    /**
                     * Verifies a GetNetworkEdgeSecurityServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNetworkEdgeSecurityServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNetworkEdgeSecurityServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest;

                    /**
                     * Creates a plain object from a GetNetworkEdgeSecurityServiceRequest message. Also converts values to other types if specified.
                     * @param message GetNetworkEdgeSecurityServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNetworkEdgeSecurityServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNetworkEdgeSecurityServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNetworkEdgeSecurityServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNetworkEndpointGroupRequest. */
                interface IGetNetworkEndpointGroupRequest {

                    /** GetNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** GetNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** GetNetworkEndpointGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetNetworkEndpointGroupRequest. */
                class GetNetworkEndpointGroupRequest implements IGetNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new GetNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNetworkEndpointGroupRequest);

                    /** GetNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** GetNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** GetNetworkEndpointGroupRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNetworkEndpointGroupRequest): google.cloud.compute.v1.GetNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified GetNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message GetNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message GetNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNetworkEndpointGroupRequest;

                    /**
                     * Decodes a GetNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNetworkEndpointGroupRequest;

                    /**
                     * Verifies a GetNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a GetNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message GetNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNetworkFirewallPolicyRequest. */
                interface IGetNetworkFirewallPolicyRequest {

                    /** GetNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetNetworkFirewallPolicyRequest project */
                    project?: (string|null);
                }

                /** Represents a GetNetworkFirewallPolicyRequest. */
                class GetNetworkFirewallPolicyRequest implements IGetNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNetworkFirewallPolicyRequest);

                    /** GetNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNetworkRequest. */
                interface IGetNetworkRequest {

                    /** GetNetworkRequest network */
                    network?: (string|null);

                    /** GetNetworkRequest project */
                    project?: (string|null);
                }

                /** Represents a GetNetworkRequest. */
                class GetNetworkRequest implements IGetNetworkRequest {

                    /**
                     * Constructs a new GetNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNetworkRequest);

                    /** GetNetworkRequest network. */
                    public network: string;

                    /** GetNetworkRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNetworkRequest): google.cloud.compute.v1.GetNetworkRequest;

                    /**
                     * Encodes the specified GetNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNetworkRequest.verify|verify} messages.
                     * @param message GetNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNetworkRequest.verify|verify} messages.
                     * @param message GetNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNetworkRequest;

                    /**
                     * Decodes a GetNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNetworkRequest;

                    /**
                     * Verifies a GetNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNetworkRequest;

                    /**
                     * Creates a plain object from a GetNetworkRequest message. Also converts values to other types if specified.
                     * @param message GetNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNodeGroupRequest. */
                interface IGetNodeGroupRequest {

                    /** GetNodeGroupRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** GetNodeGroupRequest project */
                    project?: (string|null);

                    /** GetNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetNodeGroupRequest. */
                class GetNodeGroupRequest implements IGetNodeGroupRequest {

                    /**
                     * Constructs a new GetNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNodeGroupRequest);

                    /** GetNodeGroupRequest nodeGroup. */
                    public nodeGroup: string;

                    /** GetNodeGroupRequest project. */
                    public project: string;

                    /** GetNodeGroupRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNodeGroupRequest): google.cloud.compute.v1.GetNodeGroupRequest;

                    /**
                     * Encodes the specified GetNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNodeGroupRequest.verify|verify} messages.
                     * @param message GetNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNodeGroupRequest.verify|verify} messages.
                     * @param message GetNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNodeGroupRequest;

                    /**
                     * Decodes a GetNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNodeGroupRequest;

                    /**
                     * Verifies a GetNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNodeGroupRequest;

                    /**
                     * Creates a plain object from a GetNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message GetNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNodeTemplateRequest. */
                interface IGetNodeTemplateRequest {

                    /** GetNodeTemplateRequest nodeTemplate */
                    nodeTemplate?: (string|null);

                    /** GetNodeTemplateRequest project */
                    project?: (string|null);

                    /** GetNodeTemplateRequest region */
                    region?: (string|null);
                }

                /** Represents a GetNodeTemplateRequest. */
                class GetNodeTemplateRequest implements IGetNodeTemplateRequest {

                    /**
                     * Constructs a new GetNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNodeTemplateRequest);

                    /** GetNodeTemplateRequest nodeTemplate. */
                    public nodeTemplate: string;

                    /** GetNodeTemplateRequest project. */
                    public project: string;

                    /** GetNodeTemplateRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNodeTemplateRequest): google.cloud.compute.v1.GetNodeTemplateRequest;

                    /**
                     * Encodes the specified GetNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNodeTemplateRequest.verify|verify} messages.
                     * @param message GetNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNodeTemplateRequest.verify|verify} messages.
                     * @param message GetNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNodeTemplateRequest;

                    /**
                     * Decodes a GetNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNodeTemplateRequest;

                    /**
                     * Verifies a GetNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNodeTemplateRequest;

                    /**
                     * Creates a plain object from a GetNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message GetNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetNodeTypeRequest. */
                interface IGetNodeTypeRequest {

                    /** GetNodeTypeRequest nodeType */
                    nodeType?: (string|null);

                    /** GetNodeTypeRequest project */
                    project?: (string|null);

                    /** GetNodeTypeRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetNodeTypeRequest. */
                class GetNodeTypeRequest implements IGetNodeTypeRequest {

                    /**
                     * Constructs a new GetNodeTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetNodeTypeRequest);

                    /** GetNodeTypeRequest nodeType. */
                    public nodeType: string;

                    /** GetNodeTypeRequest project. */
                    public project: string;

                    /** GetNodeTypeRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetNodeTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetNodeTypeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetNodeTypeRequest): google.cloud.compute.v1.GetNodeTypeRequest;

                    /**
                     * Encodes the specified GetNodeTypeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetNodeTypeRequest.verify|verify} messages.
                     * @param message GetNodeTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetNodeTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetNodeTypeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetNodeTypeRequest.verify|verify} messages.
                     * @param message GetNodeTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetNodeTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetNodeTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetNodeTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetNodeTypeRequest;

                    /**
                     * Decodes a GetNodeTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetNodeTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetNodeTypeRequest;

                    /**
                     * Verifies a GetNodeTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetNodeTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetNodeTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetNodeTypeRequest;

                    /**
                     * Creates a plain object from a GetNodeTypeRequest message. Also converts values to other types if specified.
                     * @param message GetNodeTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetNodeTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetNodeTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetNodeTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetPacketMirroringRequest. */
                interface IGetPacketMirroringRequest {

                    /** GetPacketMirroringRequest packetMirroring */
                    packetMirroring?: (string|null);

                    /** GetPacketMirroringRequest project */
                    project?: (string|null);

                    /** GetPacketMirroringRequest region */
                    region?: (string|null);
                }

                /** Represents a GetPacketMirroringRequest. */
                class GetPacketMirroringRequest implements IGetPacketMirroringRequest {

                    /**
                     * Constructs a new GetPacketMirroringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetPacketMirroringRequest);

                    /** GetPacketMirroringRequest packetMirroring. */
                    public packetMirroring: string;

                    /** GetPacketMirroringRequest project. */
                    public project: string;

                    /** GetPacketMirroringRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetPacketMirroringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetPacketMirroringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetPacketMirroringRequest): google.cloud.compute.v1.GetPacketMirroringRequest;

                    /**
                     * Encodes the specified GetPacketMirroringRequest message. Does not implicitly {@link google.cloud.compute.v1.GetPacketMirroringRequest.verify|verify} messages.
                     * @param message GetPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetPacketMirroringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetPacketMirroringRequest.verify|verify} messages.
                     * @param message GetPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetPacketMirroringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetPacketMirroringRequest;

                    /**
                     * Decodes a GetPacketMirroringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetPacketMirroringRequest;

                    /**
                     * Verifies a GetPacketMirroringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetPacketMirroringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetPacketMirroringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetPacketMirroringRequest;

                    /**
                     * Creates a plain object from a GetPacketMirroringRequest message. Also converts values to other types if specified.
                     * @param message GetPacketMirroringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetPacketMirroringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetPacketMirroringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetPacketMirroringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProjectRequest. */
                interface IGetProjectRequest {

                    /** GetProjectRequest project */
                    project?: (string|null);
                }

                /** Represents a GetProjectRequest. */
                class GetProjectRequest implements IGetProjectRequest {

                    /**
                     * Constructs a new GetProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetProjectRequest);

                    /** GetProjectRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetProjectRequest): google.cloud.compute.v1.GetProjectRequest;

                    /**
                     * Encodes the specified GetProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.GetProjectRequest.verify|verify} messages.
                     * @param message GetProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetProjectRequest.verify|verify} messages.
                     * @param message GetProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetProjectRequest;

                    /**
                     * Decodes a GetProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetProjectRequest;

                    /**
                     * Verifies a GetProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetProjectRequest;

                    /**
                     * Creates a plain object from a GetProjectRequest message. Also converts values to other types if specified.
                     * @param message GetProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetPublicAdvertisedPrefixeRequest. */
                interface IGetPublicAdvertisedPrefixeRequest {

                    /** GetPublicAdvertisedPrefixeRequest project */
                    project?: (string|null);

                    /** GetPublicAdvertisedPrefixeRequest publicAdvertisedPrefix */
                    publicAdvertisedPrefix?: (string|null);
                }

                /** Represents a GetPublicAdvertisedPrefixeRequest. */
                class GetPublicAdvertisedPrefixeRequest implements IGetPublicAdvertisedPrefixeRequest {

                    /**
                     * Constructs a new GetPublicAdvertisedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetPublicAdvertisedPrefixeRequest);

                    /** GetPublicAdvertisedPrefixeRequest project. */
                    public project: string;

                    /** GetPublicAdvertisedPrefixeRequest publicAdvertisedPrefix. */
                    public publicAdvertisedPrefix: string;

                    /**
                     * Creates a new GetPublicAdvertisedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetPublicAdvertisedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetPublicAdvertisedPrefixeRequest): google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest;

                    /**
                     * Encodes the specified GetPublicAdvertisedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message GetPublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetPublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetPublicAdvertisedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message GetPublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetPublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetPublicAdvertisedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetPublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest;

                    /**
                     * Decodes a GetPublicAdvertisedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetPublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest;

                    /**
                     * Verifies a GetPublicAdvertisedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetPublicAdvertisedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetPublicAdvertisedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest;

                    /**
                     * Creates a plain object from a GetPublicAdvertisedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message GetPublicAdvertisedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetPublicAdvertisedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetPublicAdvertisedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetPublicAdvertisedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetPublicDelegatedPrefixeRequest. */
                interface IGetPublicDelegatedPrefixeRequest {

                    /** GetPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** GetPublicDelegatedPrefixeRequest publicDelegatedPrefix */
                    publicDelegatedPrefix?: (string|null);

                    /** GetPublicDelegatedPrefixeRequest region */
                    region?: (string|null);
                }

                /** Represents a GetPublicDelegatedPrefixeRequest. */
                class GetPublicDelegatedPrefixeRequest implements IGetPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new GetPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetPublicDelegatedPrefixeRequest);

                    /** GetPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** GetPublicDelegatedPrefixeRequest publicDelegatedPrefix. */
                    public publicDelegatedPrefix: string;

                    /** GetPublicDelegatedPrefixeRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetPublicDelegatedPrefixeRequest): google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified GetPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message GetPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message GetPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes a GetPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies a GetPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from a GetPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message GetPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionAutoscalerRequest. */
                interface IGetRegionAutoscalerRequest {

                    /** GetRegionAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** GetRegionAutoscalerRequest project */
                    project?: (string|null);

                    /** GetRegionAutoscalerRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionAutoscalerRequest. */
                class GetRegionAutoscalerRequest implements IGetRegionAutoscalerRequest {

                    /**
                     * Constructs a new GetRegionAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionAutoscalerRequest);

                    /** GetRegionAutoscalerRequest autoscaler. */
                    public autoscaler: string;

                    /** GetRegionAutoscalerRequest project. */
                    public project: string;

                    /** GetRegionAutoscalerRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionAutoscalerRequest): google.cloud.compute.v1.GetRegionAutoscalerRequest;

                    /**
                     * Encodes the specified GetRegionAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionAutoscalerRequest.verify|verify} messages.
                     * @param message GetRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionAutoscalerRequest.verify|verify} messages.
                     * @param message GetRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionAutoscalerRequest;

                    /**
                     * Decodes a GetRegionAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionAutoscalerRequest;

                    /**
                     * Verifies a GetRegionAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionAutoscalerRequest;

                    /**
                     * Creates a plain object from a GetRegionAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message GetRegionAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionBackendServiceRequest. */
                interface IGetRegionBackendServiceRequest {

                    /** GetRegionBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** GetRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** GetRegionBackendServiceRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionBackendServiceRequest. */
                class GetRegionBackendServiceRequest implements IGetRegionBackendServiceRequest {

                    /**
                     * Constructs a new GetRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionBackendServiceRequest);

                    /** GetRegionBackendServiceRequest backendService. */
                    public backendService: string;

                    /** GetRegionBackendServiceRequest project. */
                    public project: string;

                    /** GetRegionBackendServiceRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionBackendServiceRequest): google.cloud.compute.v1.GetRegionBackendServiceRequest;

                    /**
                     * Encodes the specified GetRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionBackendServiceRequest.verify|verify} messages.
                     * @param message GetRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionBackendServiceRequest.verify|verify} messages.
                     * @param message GetRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionBackendServiceRequest;

                    /**
                     * Decodes a GetRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionBackendServiceRequest;

                    /**
                     * Verifies a GetRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from a GetRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message GetRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionCommitmentRequest. */
                interface IGetRegionCommitmentRequest {

                    /** GetRegionCommitmentRequest commitment */
                    commitment?: (string|null);

                    /** GetRegionCommitmentRequest project */
                    project?: (string|null);

                    /** GetRegionCommitmentRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionCommitmentRequest. */
                class GetRegionCommitmentRequest implements IGetRegionCommitmentRequest {

                    /**
                     * Constructs a new GetRegionCommitmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionCommitmentRequest);

                    /** GetRegionCommitmentRequest commitment. */
                    public commitment: string;

                    /** GetRegionCommitmentRequest project. */
                    public project: string;

                    /** GetRegionCommitmentRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionCommitmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionCommitmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionCommitmentRequest): google.cloud.compute.v1.GetRegionCommitmentRequest;

                    /**
                     * Encodes the specified GetRegionCommitmentRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionCommitmentRequest.verify|verify} messages.
                     * @param message GetRegionCommitmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionCommitmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionCommitmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionCommitmentRequest.verify|verify} messages.
                     * @param message GetRegionCommitmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionCommitmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionCommitmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionCommitmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionCommitmentRequest;

                    /**
                     * Decodes a GetRegionCommitmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionCommitmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionCommitmentRequest;

                    /**
                     * Verifies a GetRegionCommitmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionCommitmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionCommitmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionCommitmentRequest;

                    /**
                     * Creates a plain object from a GetRegionCommitmentRequest message. Also converts values to other types if specified.
                     * @param message GetRegionCommitmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionCommitmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionCommitmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionCommitmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionDiskRequest. */
                interface IGetRegionDiskRequest {

                    /** GetRegionDiskRequest disk */
                    disk?: (string|null);

                    /** GetRegionDiskRequest project */
                    project?: (string|null);

                    /** GetRegionDiskRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionDiskRequest. */
                class GetRegionDiskRequest implements IGetRegionDiskRequest {

                    /**
                     * Constructs a new GetRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionDiskRequest);

                    /** GetRegionDiskRequest disk. */
                    public disk: string;

                    /** GetRegionDiskRequest project. */
                    public project: string;

                    /** GetRegionDiskRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionDiskRequest): google.cloud.compute.v1.GetRegionDiskRequest;

                    /**
                     * Encodes the specified GetRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionDiskRequest.verify|verify} messages.
                     * @param message GetRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionDiskRequest.verify|verify} messages.
                     * @param message GetRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionDiskRequest;

                    /**
                     * Decodes a GetRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionDiskRequest;

                    /**
                     * Verifies a GetRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionDiskRequest;

                    /**
                     * Creates a plain object from a GetRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message GetRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionDiskTypeRequest. */
                interface IGetRegionDiskTypeRequest {

                    /** GetRegionDiskTypeRequest diskType */
                    diskType?: (string|null);

                    /** GetRegionDiskTypeRequest project */
                    project?: (string|null);

                    /** GetRegionDiskTypeRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionDiskTypeRequest. */
                class GetRegionDiskTypeRequest implements IGetRegionDiskTypeRequest {

                    /**
                     * Constructs a new GetRegionDiskTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionDiskTypeRequest);

                    /** GetRegionDiskTypeRequest diskType. */
                    public diskType: string;

                    /** GetRegionDiskTypeRequest project. */
                    public project: string;

                    /** GetRegionDiskTypeRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionDiskTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionDiskTypeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionDiskTypeRequest): google.cloud.compute.v1.GetRegionDiskTypeRequest;

                    /**
                     * Encodes the specified GetRegionDiskTypeRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionDiskTypeRequest.verify|verify} messages.
                     * @param message GetRegionDiskTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionDiskTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionDiskTypeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionDiskTypeRequest.verify|verify} messages.
                     * @param message GetRegionDiskTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionDiskTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionDiskTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionDiskTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionDiskTypeRequest;

                    /**
                     * Decodes a GetRegionDiskTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionDiskTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionDiskTypeRequest;

                    /**
                     * Verifies a GetRegionDiskTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionDiskTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionDiskTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionDiskTypeRequest;

                    /**
                     * Creates a plain object from a GetRegionDiskTypeRequest message. Also converts values to other types if specified.
                     * @param message GetRegionDiskTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionDiskTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionDiskTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionDiskTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionHealthCheckRequest. */
                interface IGetRegionHealthCheckRequest {

                    /** GetRegionHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** GetRegionHealthCheckRequest project */
                    project?: (string|null);

                    /** GetRegionHealthCheckRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionHealthCheckRequest. */
                class GetRegionHealthCheckRequest implements IGetRegionHealthCheckRequest {

                    /**
                     * Constructs a new GetRegionHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionHealthCheckRequest);

                    /** GetRegionHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** GetRegionHealthCheckRequest project. */
                    public project: string;

                    /** GetRegionHealthCheckRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionHealthCheckRequest): google.cloud.compute.v1.GetRegionHealthCheckRequest;

                    /**
                     * Encodes the specified GetRegionHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionHealthCheckRequest.verify|verify} messages.
                     * @param message GetRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionHealthCheckRequest.verify|verify} messages.
                     * @param message GetRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionHealthCheckRequest;

                    /**
                     * Decodes a GetRegionHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionHealthCheckRequest;

                    /**
                     * Verifies a GetRegionHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionHealthCheckRequest;

                    /**
                     * Creates a plain object from a GetRegionHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message GetRegionHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionHealthCheckServiceRequest. */
                interface IGetRegionHealthCheckServiceRequest {

                    /** GetRegionHealthCheckServiceRequest healthCheckService */
                    healthCheckService?: (string|null);

                    /** GetRegionHealthCheckServiceRequest project */
                    project?: (string|null);

                    /** GetRegionHealthCheckServiceRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionHealthCheckServiceRequest. */
                class GetRegionHealthCheckServiceRequest implements IGetRegionHealthCheckServiceRequest {

                    /**
                     * Constructs a new GetRegionHealthCheckServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionHealthCheckServiceRequest);

                    /** GetRegionHealthCheckServiceRequest healthCheckService. */
                    public healthCheckService: string;

                    /** GetRegionHealthCheckServiceRequest project. */
                    public project: string;

                    /** GetRegionHealthCheckServiceRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionHealthCheckServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionHealthCheckServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionHealthCheckServiceRequest): google.cloud.compute.v1.GetRegionHealthCheckServiceRequest;

                    /**
                     * Encodes the specified GetRegionHealthCheckServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message GetRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionHealthCheckServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message GetRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionHealthCheckServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionHealthCheckServiceRequest;

                    /**
                     * Decodes a GetRegionHealthCheckServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionHealthCheckServiceRequest;

                    /**
                     * Verifies a GetRegionHealthCheckServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionHealthCheckServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionHealthCheckServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionHealthCheckServiceRequest;

                    /**
                     * Creates a plain object from a GetRegionHealthCheckServiceRequest message. Also converts values to other types if specified.
                     * @param message GetRegionHealthCheckServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionHealthCheckServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionHealthCheckServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionHealthCheckServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionInstanceGroupManagerRequest. */
                interface IGetRegionInstanceGroupManagerRequest {

                    /** GetRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** GetRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** GetRegionInstanceGroupManagerRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionInstanceGroupManagerRequest. */
                class GetRegionInstanceGroupManagerRequest implements IGetRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new GetRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest);

                    /** GetRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** GetRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** GetRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest): google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified GetRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message GetRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message GetRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a GetRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a GetRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a GetRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message GetRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionInstanceGroupRequest. */
                interface IGetRegionInstanceGroupRequest {

                    /** GetRegionInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** GetRegionInstanceGroupRequest project */
                    project?: (string|null);

                    /** GetRegionInstanceGroupRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionInstanceGroupRequest. */
                class GetRegionInstanceGroupRequest implements IGetRegionInstanceGroupRequest {

                    /**
                     * Constructs a new GetRegionInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionInstanceGroupRequest);

                    /** GetRegionInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** GetRegionInstanceGroupRequest project. */
                    public project: string;

                    /** GetRegionInstanceGroupRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionInstanceGroupRequest): google.cloud.compute.v1.GetRegionInstanceGroupRequest;

                    /**
                     * Encodes the specified GetRegionInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionInstanceGroupRequest.verify|verify} messages.
                     * @param message GetRegionInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionInstanceGroupRequest.verify|verify} messages.
                     * @param message GetRegionInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionInstanceGroupRequest;

                    /**
                     * Decodes a GetRegionInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionInstanceGroupRequest;

                    /**
                     * Verifies a GetRegionInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionInstanceGroupRequest;

                    /**
                     * Creates a plain object from a GetRegionInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message GetRegionInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionNetworkEndpointGroupRequest. */
                interface IGetRegionNetworkEndpointGroupRequest {

                    /** GetRegionNetworkEndpointGroupRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** GetRegionNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** GetRegionNetworkEndpointGroupRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionNetworkEndpointGroupRequest. */
                class GetRegionNetworkEndpointGroupRequest implements IGetRegionNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new GetRegionNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionNetworkEndpointGroupRequest);

                    /** GetRegionNetworkEndpointGroupRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** GetRegionNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** GetRegionNetworkEndpointGroupRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionNetworkEndpointGroupRequest): google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified GetRegionNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message GetRegionNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message GetRegionNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest;

                    /**
                     * Decodes a GetRegionNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest;

                    /**
                     * Verifies a GetRegionNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a GetRegionNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message GetRegionNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionNetworkFirewallPolicyRequest. */
                interface IGetRegionNetworkFirewallPolicyRequest {

                    /** GetRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** GetRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionNetworkFirewallPolicyRequest. */
                class GetRegionNetworkFirewallPolicyRequest implements IGetRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionNetworkFirewallPolicyRequest);

                    /** GetRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionNotificationEndpointRequest. */
                interface IGetRegionNotificationEndpointRequest {

                    /** GetRegionNotificationEndpointRequest notificationEndpoint */
                    notificationEndpoint?: (string|null);

                    /** GetRegionNotificationEndpointRequest project */
                    project?: (string|null);

                    /** GetRegionNotificationEndpointRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionNotificationEndpointRequest. */
                class GetRegionNotificationEndpointRequest implements IGetRegionNotificationEndpointRequest {

                    /**
                     * Constructs a new GetRegionNotificationEndpointRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionNotificationEndpointRequest);

                    /** GetRegionNotificationEndpointRequest notificationEndpoint. */
                    public notificationEndpoint: string;

                    /** GetRegionNotificationEndpointRequest project. */
                    public project: string;

                    /** GetRegionNotificationEndpointRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionNotificationEndpointRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionNotificationEndpointRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionNotificationEndpointRequest): google.cloud.compute.v1.GetRegionNotificationEndpointRequest;

                    /**
                     * Encodes the specified GetRegionNotificationEndpointRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionNotificationEndpointRequest.verify|verify} messages.
                     * @param message GetRegionNotificationEndpointRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionNotificationEndpointRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionNotificationEndpointRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionNotificationEndpointRequest.verify|verify} messages.
                     * @param message GetRegionNotificationEndpointRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionNotificationEndpointRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionNotificationEndpointRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionNotificationEndpointRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionNotificationEndpointRequest;

                    /**
                     * Decodes a GetRegionNotificationEndpointRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionNotificationEndpointRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionNotificationEndpointRequest;

                    /**
                     * Verifies a GetRegionNotificationEndpointRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionNotificationEndpointRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionNotificationEndpointRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionNotificationEndpointRequest;

                    /**
                     * Creates a plain object from a GetRegionNotificationEndpointRequest message. Also converts values to other types if specified.
                     * @param message GetRegionNotificationEndpointRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionNotificationEndpointRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionNotificationEndpointRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionNotificationEndpointRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionOperationRequest. */
                interface IGetRegionOperationRequest {

                    /** GetRegionOperationRequest operation */
                    operation?: (string|null);

                    /** GetRegionOperationRequest project */
                    project?: (string|null);

                    /** GetRegionOperationRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionOperationRequest. */
                class GetRegionOperationRequest implements IGetRegionOperationRequest {

                    /**
                     * Constructs a new GetRegionOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionOperationRequest);

                    /** GetRegionOperationRequest operation. */
                    public operation: string;

                    /** GetRegionOperationRequest project. */
                    public project: string;

                    /** GetRegionOperationRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionOperationRequest): google.cloud.compute.v1.GetRegionOperationRequest;

                    /**
                     * Encodes the specified GetRegionOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionOperationRequest.verify|verify} messages.
                     * @param message GetRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionOperationRequest.verify|verify} messages.
                     * @param message GetRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionOperationRequest;

                    /**
                     * Decodes a GetRegionOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionOperationRequest;

                    /**
                     * Verifies a GetRegionOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionOperationRequest;

                    /**
                     * Creates a plain object from a GetRegionOperationRequest message. Also converts values to other types if specified.
                     * @param message GetRegionOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionRequest. */
                interface IGetRegionRequest {

                    /** GetRegionRequest project */
                    project?: (string|null);

                    /** GetRegionRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionRequest. */
                class GetRegionRequest implements IGetRegionRequest {

                    /**
                     * Constructs a new GetRegionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionRequest);

                    /** GetRegionRequest project. */
                    public project: string;

                    /** GetRegionRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionRequest): google.cloud.compute.v1.GetRegionRequest;

                    /**
                     * Encodes the specified GetRegionRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionRequest.verify|verify} messages.
                     * @param message GetRegionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionRequest.verify|verify} messages.
                     * @param message GetRegionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionRequest;

                    /**
                     * Decodes a GetRegionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionRequest;

                    /**
                     * Verifies a GetRegionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionRequest;

                    /**
                     * Creates a plain object from a GetRegionRequest message. Also converts values to other types if specified.
                     * @param message GetRegionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionSecurityPolicyRequest. */
                interface IGetRegionSecurityPolicyRequest {

                    /** GetRegionSecurityPolicyRequest project */
                    project?: (string|null);

                    /** GetRegionSecurityPolicyRequest region */
                    region?: (string|null);

                    /** GetRegionSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a GetRegionSecurityPolicyRequest. */
                class GetRegionSecurityPolicyRequest implements IGetRegionSecurityPolicyRequest {

                    /**
                     * Constructs a new GetRegionSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionSecurityPolicyRequest);

                    /** GetRegionSecurityPolicyRequest project. */
                    public project: string;

                    /** GetRegionSecurityPolicyRequest region. */
                    public region: string;

                    /** GetRegionSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /**
                     * Creates a new GetRegionSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionSecurityPolicyRequest): google.cloud.compute.v1.GetRegionSecurityPolicyRequest;

                    /**
                     * Encodes the specified GetRegionSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message GetRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message GetRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionSecurityPolicyRequest;

                    /**
                     * Decodes a GetRegionSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionSecurityPolicyRequest;

                    /**
                     * Verifies a GetRegionSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a GetRegionSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRegionSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionSslCertificateRequest. */
                interface IGetRegionSslCertificateRequest {

                    /** GetRegionSslCertificateRequest project */
                    project?: (string|null);

                    /** GetRegionSslCertificateRequest region */
                    region?: (string|null);

                    /** GetRegionSslCertificateRequest sslCertificate */
                    sslCertificate?: (string|null);
                }

                /** Represents a GetRegionSslCertificateRequest. */
                class GetRegionSslCertificateRequest implements IGetRegionSslCertificateRequest {

                    /**
                     * Constructs a new GetRegionSslCertificateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionSslCertificateRequest);

                    /** GetRegionSslCertificateRequest project. */
                    public project: string;

                    /** GetRegionSslCertificateRequest region. */
                    public region: string;

                    /** GetRegionSslCertificateRequest sslCertificate. */
                    public sslCertificate: string;

                    /**
                     * Creates a new GetRegionSslCertificateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionSslCertificateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionSslCertificateRequest): google.cloud.compute.v1.GetRegionSslCertificateRequest;

                    /**
                     * Encodes the specified GetRegionSslCertificateRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionSslCertificateRequest.verify|verify} messages.
                     * @param message GetRegionSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionSslCertificateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionSslCertificateRequest.verify|verify} messages.
                     * @param message GetRegionSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionSslCertificateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionSslCertificateRequest;

                    /**
                     * Decodes a GetRegionSslCertificateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionSslCertificateRequest;

                    /**
                     * Verifies a GetRegionSslCertificateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionSslCertificateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionSslCertificateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionSslCertificateRequest;

                    /**
                     * Creates a plain object from a GetRegionSslCertificateRequest message. Also converts values to other types if specified.
                     * @param message GetRegionSslCertificateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionSslCertificateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionSslCertificateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionSslCertificateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionSslPolicyRequest. */
                interface IGetRegionSslPolicyRequest {

                    /** GetRegionSslPolicyRequest project */
                    project?: (string|null);

                    /** GetRegionSslPolicyRequest region */
                    region?: (string|null);

                    /** GetRegionSslPolicyRequest sslPolicy */
                    sslPolicy?: (string|null);
                }

                /** Represents a GetRegionSslPolicyRequest. */
                class GetRegionSslPolicyRequest implements IGetRegionSslPolicyRequest {

                    /**
                     * Constructs a new GetRegionSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionSslPolicyRequest);

                    /** GetRegionSslPolicyRequest project. */
                    public project: string;

                    /** GetRegionSslPolicyRequest region. */
                    public region: string;

                    /** GetRegionSslPolicyRequest sslPolicy. */
                    public sslPolicy: string;

                    /**
                     * Creates a new GetRegionSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionSslPolicyRequest): google.cloud.compute.v1.GetRegionSslPolicyRequest;

                    /**
                     * Encodes the specified GetRegionSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionSslPolicyRequest.verify|verify} messages.
                     * @param message GetRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionSslPolicyRequest.verify|verify} messages.
                     * @param message GetRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionSslPolicyRequest;

                    /**
                     * Decodes a GetRegionSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionSslPolicyRequest;

                    /**
                     * Verifies a GetRegionSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionSslPolicyRequest;

                    /**
                     * Creates a plain object from a GetRegionSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRegionSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionTargetHttpProxyRequest. */
                interface IGetRegionTargetHttpProxyRequest {

                    /** GetRegionTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** GetRegionTargetHttpProxyRequest region */
                    region?: (string|null);

                    /** GetRegionTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);
                }

                /** Represents a GetRegionTargetHttpProxyRequest. */
                class GetRegionTargetHttpProxyRequest implements IGetRegionTargetHttpProxyRequest {

                    /**
                     * Constructs a new GetRegionTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionTargetHttpProxyRequest);

                    /** GetRegionTargetHttpProxyRequest project. */
                    public project: string;

                    /** GetRegionTargetHttpProxyRequest region. */
                    public region: string;

                    /** GetRegionTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /**
                     * Creates a new GetRegionTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionTargetHttpProxyRequest): google.cloud.compute.v1.GetRegionTargetHttpProxyRequest;

                    /**
                     * Encodes the specified GetRegionTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message GetRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message GetRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionTargetHttpProxyRequest;

                    /**
                     * Decodes a GetRegionTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionTargetHttpProxyRequest;

                    /**
                     * Verifies a GetRegionTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a GetRegionTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message GetRegionTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionTargetHttpsProxyRequest. */
                interface IGetRegionTargetHttpsProxyRequest {

                    /** GetRegionTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** GetRegionTargetHttpsProxyRequest region */
                    region?: (string|null);

                    /** GetRegionTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a GetRegionTargetHttpsProxyRequest. */
                class GetRegionTargetHttpsProxyRequest implements IGetRegionTargetHttpsProxyRequest {

                    /**
                     * Constructs a new GetRegionTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionTargetHttpsProxyRequest);

                    /** GetRegionTargetHttpsProxyRequest project. */
                    public project: string;

                    /** GetRegionTargetHttpsProxyRequest region. */
                    public region: string;

                    /** GetRegionTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /**
                     * Creates a new GetRegionTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionTargetHttpsProxyRequest): google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified GetRegionTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message GetRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message GetRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest;

                    /**
                     * Decodes a GetRegionTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest;

                    /**
                     * Verifies a GetRegionTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a GetRegionTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message GetRegionTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionTargetTcpProxyRequest. */
                interface IGetRegionTargetTcpProxyRequest {

                    /** GetRegionTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** GetRegionTargetTcpProxyRequest region */
                    region?: (string|null);

                    /** GetRegionTargetTcpProxyRequest targetTcpProxy */
                    targetTcpProxy?: (string|null);
                }

                /** Represents a GetRegionTargetTcpProxyRequest. */
                class GetRegionTargetTcpProxyRequest implements IGetRegionTargetTcpProxyRequest {

                    /**
                     * Constructs a new GetRegionTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionTargetTcpProxyRequest);

                    /** GetRegionTargetTcpProxyRequest project. */
                    public project: string;

                    /** GetRegionTargetTcpProxyRequest region. */
                    public region: string;

                    /** GetRegionTargetTcpProxyRequest targetTcpProxy. */
                    public targetTcpProxy: string;

                    /**
                     * Creates a new GetRegionTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionTargetTcpProxyRequest): google.cloud.compute.v1.GetRegionTargetTcpProxyRequest;

                    /**
                     * Encodes the specified GetRegionTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionTargetTcpProxyRequest.verify|verify} messages.
                     * @param message GetRegionTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionTargetTcpProxyRequest.verify|verify} messages.
                     * @param message GetRegionTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionTargetTcpProxyRequest;

                    /**
                     * Decodes a GetRegionTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionTargetTcpProxyRequest;

                    /**
                     * Verifies a GetRegionTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from a GetRegionTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message GetRegionTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionUrlMapRequest. */
                interface IGetRegionUrlMapRequest {

                    /** GetRegionUrlMapRequest project */
                    project?: (string|null);

                    /** GetRegionUrlMapRequest region */
                    region?: (string|null);

                    /** GetRegionUrlMapRequest urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a GetRegionUrlMapRequest. */
                class GetRegionUrlMapRequest implements IGetRegionUrlMapRequest {

                    /**
                     * Constructs a new GetRegionUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRegionUrlMapRequest);

                    /** GetRegionUrlMapRequest project. */
                    public project: string;

                    /** GetRegionUrlMapRequest region. */
                    public region: string;

                    /** GetRegionUrlMapRequest urlMap. */
                    public urlMap: string;

                    /**
                     * Creates a new GetRegionUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRegionUrlMapRequest): google.cloud.compute.v1.GetRegionUrlMapRequest;

                    /**
                     * Encodes the specified GetRegionUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRegionUrlMapRequest.verify|verify} messages.
                     * @param message GetRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRegionUrlMapRequest.verify|verify} messages.
                     * @param message GetRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRegionUrlMapRequest;

                    /**
                     * Decodes a GetRegionUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRegionUrlMapRequest;

                    /**
                     * Verifies a GetRegionUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRegionUrlMapRequest;

                    /**
                     * Creates a plain object from a GetRegionUrlMapRequest message. Also converts values to other types if specified.
                     * @param message GetRegionUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRegionUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetReservationRequest. */
                interface IGetReservationRequest {

                    /** GetReservationRequest project */
                    project?: (string|null);

                    /** GetReservationRequest reservation */
                    reservation?: (string|null);

                    /** GetReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetReservationRequest. */
                class GetReservationRequest implements IGetReservationRequest {

                    /**
                     * Constructs a new GetReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetReservationRequest);

                    /** GetReservationRequest project. */
                    public project: string;

                    /** GetReservationRequest reservation. */
                    public reservation: string;

                    /** GetReservationRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetReservationRequest): google.cloud.compute.v1.GetReservationRequest;

                    /**
                     * Encodes the specified GetReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetReservationRequest.verify|verify} messages.
                     * @param message GetReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetReservationRequest.verify|verify} messages.
                     * @param message GetReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetReservationRequest;

                    /**
                     * Decodes a GetReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetReservationRequest;

                    /**
                     * Verifies a GetReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetReservationRequest;

                    /**
                     * Creates a plain object from a GetReservationRequest message. Also converts values to other types if specified.
                     * @param message GetReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetResourcePolicyRequest. */
                interface IGetResourcePolicyRequest {

                    /** GetResourcePolicyRequest project */
                    project?: (string|null);

                    /** GetResourcePolicyRequest region */
                    region?: (string|null);

                    /** GetResourcePolicyRequest resourcePolicy */
                    resourcePolicy?: (string|null);
                }

                /** Represents a GetResourcePolicyRequest. */
                class GetResourcePolicyRequest implements IGetResourcePolicyRequest {

                    /**
                     * Constructs a new GetResourcePolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetResourcePolicyRequest);

                    /** GetResourcePolicyRequest project. */
                    public project: string;

                    /** GetResourcePolicyRequest region. */
                    public region: string;

                    /** GetResourcePolicyRequest resourcePolicy. */
                    public resourcePolicy: string;

                    /**
                     * Creates a new GetResourcePolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetResourcePolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetResourcePolicyRequest): google.cloud.compute.v1.GetResourcePolicyRequest;

                    /**
                     * Encodes the specified GetResourcePolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetResourcePolicyRequest.verify|verify} messages.
                     * @param message GetResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetResourcePolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetResourcePolicyRequest.verify|verify} messages.
                     * @param message GetResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetResourcePolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetResourcePolicyRequest;

                    /**
                     * Decodes a GetResourcePolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetResourcePolicyRequest;

                    /**
                     * Verifies a GetResourcePolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetResourcePolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetResourcePolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetResourcePolicyRequest;

                    /**
                     * Creates a plain object from a GetResourcePolicyRequest message. Also converts values to other types if specified.
                     * @param message GetResourcePolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetResourcePolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetResourcePolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetResourcePolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRouteRequest. */
                interface IGetRouteRequest {

                    /** GetRouteRequest project */
                    project?: (string|null);

                    /** GetRouteRequest route */
                    route?: (string|null);
                }

                /** Represents a GetRouteRequest. */
                class GetRouteRequest implements IGetRouteRequest {

                    /**
                     * Constructs a new GetRouteRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRouteRequest);

                    /** GetRouteRequest project. */
                    public project: string;

                    /** GetRouteRequest route. */
                    public route: string;

                    /**
                     * Creates a new GetRouteRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRouteRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRouteRequest): google.cloud.compute.v1.GetRouteRequest;

                    /**
                     * Encodes the specified GetRouteRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRouteRequest.verify|verify} messages.
                     * @param message GetRouteRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRouteRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRouteRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRouteRequest.verify|verify} messages.
                     * @param message GetRouteRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRouteRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRouteRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRouteRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRouteRequest;

                    /**
                     * Decodes a GetRouteRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRouteRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRouteRequest;

                    /**
                     * Verifies a GetRouteRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRouteRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRouteRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRouteRequest;

                    /**
                     * Creates a plain object from a GetRouteRequest message. Also converts values to other types if specified.
                     * @param message GetRouteRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRouteRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRouteRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRouteRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRouterRequest. */
                interface IGetRouterRequest {

                    /** GetRouterRequest project */
                    project?: (string|null);

                    /** GetRouterRequest region */
                    region?: (string|null);

                    /** GetRouterRequest router */
                    router?: (string|null);
                }

                /** Represents a GetRouterRequest. */
                class GetRouterRequest implements IGetRouterRequest {

                    /**
                     * Constructs a new GetRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRouterRequest);

                    /** GetRouterRequest project. */
                    public project: string;

                    /** GetRouterRequest region. */
                    public region: string;

                    /** GetRouterRequest router. */
                    public router: string;

                    /**
                     * Creates a new GetRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRouterRequest): google.cloud.compute.v1.GetRouterRequest;

                    /**
                     * Encodes the specified GetRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRouterRequest.verify|verify} messages.
                     * @param message GetRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRouterRequest.verify|verify} messages.
                     * @param message GetRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRouterRequest;

                    /**
                     * Decodes a GetRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRouterRequest;

                    /**
                     * Verifies a GetRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRouterRequest;

                    /**
                     * Creates a plain object from a GetRouterRequest message. Also converts values to other types if specified.
                     * @param message GetRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRouterStatusRouterRequest. */
                interface IGetRouterStatusRouterRequest {

                    /** GetRouterStatusRouterRequest project */
                    project?: (string|null);

                    /** GetRouterStatusRouterRequest region */
                    region?: (string|null);

                    /** GetRouterStatusRouterRequest router */
                    router?: (string|null);
                }

                /** Represents a GetRouterStatusRouterRequest. */
                class GetRouterStatusRouterRequest implements IGetRouterStatusRouterRequest {

                    /**
                     * Constructs a new GetRouterStatusRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRouterStatusRouterRequest);

                    /** GetRouterStatusRouterRequest project. */
                    public project: string;

                    /** GetRouterStatusRouterRequest region. */
                    public region: string;

                    /** GetRouterStatusRouterRequest router. */
                    public router: string;

                    /**
                     * Creates a new GetRouterStatusRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRouterStatusRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRouterStatusRouterRequest): google.cloud.compute.v1.GetRouterStatusRouterRequest;

                    /**
                     * Encodes the specified GetRouterStatusRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRouterStatusRouterRequest.verify|verify} messages.
                     * @param message GetRouterStatusRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRouterStatusRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRouterStatusRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRouterStatusRouterRequest.verify|verify} messages.
                     * @param message GetRouterStatusRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRouterStatusRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRouterStatusRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRouterStatusRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRouterStatusRouterRequest;

                    /**
                     * Decodes a GetRouterStatusRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRouterStatusRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRouterStatusRouterRequest;

                    /**
                     * Verifies a GetRouterStatusRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRouterStatusRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRouterStatusRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRouterStatusRouterRequest;

                    /**
                     * Creates a plain object from a GetRouterStatusRouterRequest message. Also converts values to other types if specified.
                     * @param message GetRouterStatusRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRouterStatusRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRouterStatusRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRouterStatusRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRuleFirewallPolicyRequest. */
                interface IGetRuleFirewallPolicyRequest {

                    /** GetRuleFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetRuleFirewallPolicyRequest priority */
                    priority?: (number|null);
                }

                /** Represents a GetRuleFirewallPolicyRequest. */
                class GetRuleFirewallPolicyRequest implements IGetRuleFirewallPolicyRequest {

                    /**
                     * Constructs a new GetRuleFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRuleFirewallPolicyRequest);

                    /** GetRuleFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetRuleFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** GetRuleFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /**
                     * Creates a new GetRuleFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRuleFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRuleFirewallPolicyRequest): google.cloud.compute.v1.GetRuleFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetRuleFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRuleFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRuleFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRuleFirewallPolicyRequest;

                    /**
                     * Decodes a GetRuleFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRuleFirewallPolicyRequest;

                    /**
                     * Verifies a GetRuleFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRuleFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRuleFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRuleFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetRuleFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRuleFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRuleFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRuleFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRuleFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRuleNetworkFirewallPolicyRequest. */
                interface IGetRuleNetworkFirewallPolicyRequest {

                    /** GetRuleNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetRuleNetworkFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** GetRuleNetworkFirewallPolicyRequest project */
                    project?: (string|null);
                }

                /** Represents a GetRuleNetworkFirewallPolicyRequest. */
                class GetRuleNetworkFirewallPolicyRequest implements IGetRuleNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetRuleNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRuleNetworkFirewallPolicyRequest);

                    /** GetRuleNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetRuleNetworkFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** GetRuleNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetRuleNetworkFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /**
                     * Creates a new GetRuleNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRuleNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRuleNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetRuleNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRuleNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRuleNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetRuleNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetRuleNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRuleNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRuleNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetRuleNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRuleNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRuleNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRuleNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRuleNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRuleRegionNetworkFirewallPolicyRequest. */
                interface IGetRuleRegionNetworkFirewallPolicyRequest {

                    /** GetRuleRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** GetRuleRegionNetworkFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** GetRuleRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** GetRuleRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRuleRegionNetworkFirewallPolicyRequest. */
                class GetRuleRegionNetworkFirewallPolicyRequest implements IGetRuleRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new GetRuleRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRuleRegionNetworkFirewallPolicyRequest);

                    /** GetRuleRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** GetRuleRegionNetworkFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** GetRuleRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** GetRuleRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** GetRuleRegionNetworkFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /**
                     * Creates a new GetRuleRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRuleRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRuleRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified GetRuleRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRuleRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message GetRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a GetRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a GetRuleRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRuleRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRuleRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a GetRuleRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRuleRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRuleRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRuleRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRuleRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRuleSecurityPolicyRequest. */
                interface IGetRuleSecurityPolicyRequest {

                    /** GetRuleSecurityPolicyRequest priority */
                    priority?: (number|null);

                    /** GetRuleSecurityPolicyRequest project */
                    project?: (string|null);

                    /** GetRuleSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a GetRuleSecurityPolicyRequest. */
                class GetRuleSecurityPolicyRequest implements IGetRuleSecurityPolicyRequest {

                    /**
                     * Constructs a new GetRuleSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetRuleSecurityPolicyRequest);

                    /** GetRuleSecurityPolicyRequest priority. */
                    public priority?: (number|null);

                    /** GetRuleSecurityPolicyRequest project. */
                    public project: string;

                    /** GetRuleSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** GetRuleSecurityPolicyRequest _priority. */
                    public _priority?: "priority";

                    /**
                     * Creates a new GetRuleSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRuleSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetRuleSecurityPolicyRequest): google.cloud.compute.v1.GetRuleSecurityPolicyRequest;

                    /**
                     * Encodes the specified GetRuleSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message GetRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRuleSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message GetRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRuleSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetRuleSecurityPolicyRequest;

                    /**
                     * Decodes a GetRuleSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetRuleSecurityPolicyRequest;

                    /**
                     * Verifies a GetRuleSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRuleSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRuleSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetRuleSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a GetRuleSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetRuleSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetRuleSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRuleSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRuleSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetScreenshotInstanceRequest. */
                interface IGetScreenshotInstanceRequest {

                    /** GetScreenshotInstanceRequest instance */
                    instance?: (string|null);

                    /** GetScreenshotInstanceRequest project */
                    project?: (string|null);

                    /** GetScreenshotInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetScreenshotInstanceRequest. */
                class GetScreenshotInstanceRequest implements IGetScreenshotInstanceRequest {

                    /**
                     * Constructs a new GetScreenshotInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetScreenshotInstanceRequest);

                    /** GetScreenshotInstanceRequest instance. */
                    public instance: string;

                    /** GetScreenshotInstanceRequest project. */
                    public project: string;

                    /** GetScreenshotInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetScreenshotInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetScreenshotInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetScreenshotInstanceRequest): google.cloud.compute.v1.GetScreenshotInstanceRequest;

                    /**
                     * Encodes the specified GetScreenshotInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetScreenshotInstanceRequest.verify|verify} messages.
                     * @param message GetScreenshotInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetScreenshotInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetScreenshotInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetScreenshotInstanceRequest.verify|verify} messages.
                     * @param message GetScreenshotInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetScreenshotInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetScreenshotInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetScreenshotInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetScreenshotInstanceRequest;

                    /**
                     * Decodes a GetScreenshotInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetScreenshotInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetScreenshotInstanceRequest;

                    /**
                     * Verifies a GetScreenshotInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetScreenshotInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetScreenshotInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetScreenshotInstanceRequest;

                    /**
                     * Creates a plain object from a GetScreenshotInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetScreenshotInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetScreenshotInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetScreenshotInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetScreenshotInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetSecurityPolicyRequest. */
                interface IGetSecurityPolicyRequest {

                    /** GetSecurityPolicyRequest project */
                    project?: (string|null);

                    /** GetSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a GetSecurityPolicyRequest. */
                class GetSecurityPolicyRequest implements IGetSecurityPolicyRequest {

                    /**
                     * Constructs a new GetSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetSecurityPolicyRequest);

                    /** GetSecurityPolicyRequest project. */
                    public project: string;

                    /** GetSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /**
                     * Creates a new GetSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetSecurityPolicyRequest): google.cloud.compute.v1.GetSecurityPolicyRequest;

                    /**
                     * Encodes the specified GetSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetSecurityPolicyRequest.verify|verify} messages.
                     * @param message GetSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetSecurityPolicyRequest.verify|verify} messages.
                     * @param message GetSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetSecurityPolicyRequest;

                    /**
                     * Decodes a GetSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetSecurityPolicyRequest;

                    /**
                     * Verifies a GetSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a GetSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetSerialPortOutputInstanceRequest. */
                interface IGetSerialPortOutputInstanceRequest {

                    /** GetSerialPortOutputInstanceRequest instance */
                    instance?: (string|null);

                    /** GetSerialPortOutputInstanceRequest port */
                    port?: (number|null);

                    /** GetSerialPortOutputInstanceRequest project */
                    project?: (string|null);

                    /** GetSerialPortOutputInstanceRequest start */
                    start?: (number|Long|string|null);

                    /** GetSerialPortOutputInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetSerialPortOutputInstanceRequest. */
                class GetSerialPortOutputInstanceRequest implements IGetSerialPortOutputInstanceRequest {

                    /**
                     * Constructs a new GetSerialPortOutputInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetSerialPortOutputInstanceRequest);

                    /** GetSerialPortOutputInstanceRequest instance. */
                    public instance: string;

                    /** GetSerialPortOutputInstanceRequest port. */
                    public port?: (number|null);

                    /** GetSerialPortOutputInstanceRequest project. */
                    public project: string;

                    /** GetSerialPortOutputInstanceRequest start. */
                    public start?: (number|Long|string|null);

                    /** GetSerialPortOutputInstanceRequest zone. */
                    public zone: string;

                    /** GetSerialPortOutputInstanceRequest _port. */
                    public _port?: "port";

                    /** GetSerialPortOutputInstanceRequest _start. */
                    public _start?: "start";

                    /**
                     * Creates a new GetSerialPortOutputInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetSerialPortOutputInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetSerialPortOutputInstanceRequest): google.cloud.compute.v1.GetSerialPortOutputInstanceRequest;

                    /**
                     * Encodes the specified GetSerialPortOutputInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetSerialPortOutputInstanceRequest.verify|verify} messages.
                     * @param message GetSerialPortOutputInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetSerialPortOutputInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetSerialPortOutputInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetSerialPortOutputInstanceRequest.verify|verify} messages.
                     * @param message GetSerialPortOutputInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetSerialPortOutputInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetSerialPortOutputInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetSerialPortOutputInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetSerialPortOutputInstanceRequest;

                    /**
                     * Decodes a GetSerialPortOutputInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetSerialPortOutputInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetSerialPortOutputInstanceRequest;

                    /**
                     * Verifies a GetSerialPortOutputInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetSerialPortOutputInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetSerialPortOutputInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetSerialPortOutputInstanceRequest;

                    /**
                     * Creates a plain object from a GetSerialPortOutputInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetSerialPortOutputInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetSerialPortOutputInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetSerialPortOutputInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetSerialPortOutputInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetServiceAttachmentRequest. */
                interface IGetServiceAttachmentRequest {

                    /** GetServiceAttachmentRequest project */
                    project?: (string|null);

                    /** GetServiceAttachmentRequest region */
                    region?: (string|null);

                    /** GetServiceAttachmentRequest serviceAttachment */
                    serviceAttachment?: (string|null);
                }

                /** Represents a GetServiceAttachmentRequest. */
                class GetServiceAttachmentRequest implements IGetServiceAttachmentRequest {

                    /**
                     * Constructs a new GetServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetServiceAttachmentRequest);

                    /** GetServiceAttachmentRequest project. */
                    public project: string;

                    /** GetServiceAttachmentRequest region. */
                    public region: string;

                    /** GetServiceAttachmentRequest serviceAttachment. */
                    public serviceAttachment: string;

                    /**
                     * Creates a new GetServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetServiceAttachmentRequest): google.cloud.compute.v1.GetServiceAttachmentRequest;

                    /**
                     * Encodes the specified GetServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.GetServiceAttachmentRequest.verify|verify} messages.
                     * @param message GetServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetServiceAttachmentRequest.verify|verify} messages.
                     * @param message GetServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetServiceAttachmentRequest;

                    /**
                     * Decodes a GetServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetServiceAttachmentRequest;

                    /**
                     * Verifies a GetServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetServiceAttachmentRequest;

                    /**
                     * Creates a plain object from a GetServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message GetServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetShieldedInstanceIdentityInstanceRequest. */
                interface IGetShieldedInstanceIdentityInstanceRequest {

                    /** GetShieldedInstanceIdentityInstanceRequest instance */
                    instance?: (string|null);

                    /** GetShieldedInstanceIdentityInstanceRequest project */
                    project?: (string|null);

                    /** GetShieldedInstanceIdentityInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetShieldedInstanceIdentityInstanceRequest. */
                class GetShieldedInstanceIdentityInstanceRequest implements IGetShieldedInstanceIdentityInstanceRequest {

                    /**
                     * Constructs a new GetShieldedInstanceIdentityInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetShieldedInstanceIdentityInstanceRequest);

                    /** GetShieldedInstanceIdentityInstanceRequest instance. */
                    public instance: string;

                    /** GetShieldedInstanceIdentityInstanceRequest project. */
                    public project: string;

                    /** GetShieldedInstanceIdentityInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetShieldedInstanceIdentityInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetShieldedInstanceIdentityInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetShieldedInstanceIdentityInstanceRequest): google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest;

                    /**
                     * Encodes the specified GetShieldedInstanceIdentityInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest.verify|verify} messages.
                     * @param message GetShieldedInstanceIdentityInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetShieldedInstanceIdentityInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetShieldedInstanceIdentityInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest.verify|verify} messages.
                     * @param message GetShieldedInstanceIdentityInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetShieldedInstanceIdentityInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetShieldedInstanceIdentityInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetShieldedInstanceIdentityInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest;

                    /**
                     * Decodes a GetShieldedInstanceIdentityInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetShieldedInstanceIdentityInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest;

                    /**
                     * Verifies a GetShieldedInstanceIdentityInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetShieldedInstanceIdentityInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetShieldedInstanceIdentityInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest;

                    /**
                     * Creates a plain object from a GetShieldedInstanceIdentityInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetShieldedInstanceIdentityInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetShieldedInstanceIdentityInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetShieldedInstanceIdentityInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetShieldedInstanceIdentityInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetSnapshotRequest. */
                interface IGetSnapshotRequest {

                    /** GetSnapshotRequest project */
                    project?: (string|null);

                    /** GetSnapshotRequest snapshot */
                    snapshot?: (string|null);
                }

                /** Represents a GetSnapshotRequest. */
                class GetSnapshotRequest implements IGetSnapshotRequest {

                    /**
                     * Constructs a new GetSnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetSnapshotRequest);

                    /** GetSnapshotRequest project. */
                    public project: string;

                    /** GetSnapshotRequest snapshot. */
                    public snapshot: string;

                    /**
                     * Creates a new GetSnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetSnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetSnapshotRequest): google.cloud.compute.v1.GetSnapshotRequest;

                    /**
                     * Encodes the specified GetSnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.GetSnapshotRequest.verify|verify} messages.
                     * @param message GetSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetSnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetSnapshotRequest.verify|verify} messages.
                     * @param message GetSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetSnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetSnapshotRequest;

                    /**
                     * Decodes a GetSnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetSnapshotRequest;

                    /**
                     * Verifies a GetSnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetSnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetSnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetSnapshotRequest;

                    /**
                     * Creates a plain object from a GetSnapshotRequest message. Also converts values to other types if specified.
                     * @param message GetSnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetSnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetSnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetSnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetSslCertificateRequest. */
                interface IGetSslCertificateRequest {

                    /** GetSslCertificateRequest project */
                    project?: (string|null);

                    /** GetSslCertificateRequest sslCertificate */
                    sslCertificate?: (string|null);
                }

                /** Represents a GetSslCertificateRequest. */
                class GetSslCertificateRequest implements IGetSslCertificateRequest {

                    /**
                     * Constructs a new GetSslCertificateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetSslCertificateRequest);

                    /** GetSslCertificateRequest project. */
                    public project: string;

                    /** GetSslCertificateRequest sslCertificate. */
                    public sslCertificate: string;

                    /**
                     * Creates a new GetSslCertificateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetSslCertificateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetSslCertificateRequest): google.cloud.compute.v1.GetSslCertificateRequest;

                    /**
                     * Encodes the specified GetSslCertificateRequest message. Does not implicitly {@link google.cloud.compute.v1.GetSslCertificateRequest.verify|verify} messages.
                     * @param message GetSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetSslCertificateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetSslCertificateRequest.verify|verify} messages.
                     * @param message GetSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetSslCertificateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetSslCertificateRequest;

                    /**
                     * Decodes a GetSslCertificateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetSslCertificateRequest;

                    /**
                     * Verifies a GetSslCertificateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetSslCertificateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetSslCertificateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetSslCertificateRequest;

                    /**
                     * Creates a plain object from a GetSslCertificateRequest message. Also converts values to other types if specified.
                     * @param message GetSslCertificateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetSslCertificateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetSslCertificateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetSslCertificateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetSslPolicyRequest. */
                interface IGetSslPolicyRequest {

                    /** GetSslPolicyRequest project */
                    project?: (string|null);

                    /** GetSslPolicyRequest sslPolicy */
                    sslPolicy?: (string|null);
                }

                /** Represents a GetSslPolicyRequest. */
                class GetSslPolicyRequest implements IGetSslPolicyRequest {

                    /**
                     * Constructs a new GetSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetSslPolicyRequest);

                    /** GetSslPolicyRequest project. */
                    public project: string;

                    /** GetSslPolicyRequest sslPolicy. */
                    public sslPolicy: string;

                    /**
                     * Creates a new GetSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetSslPolicyRequest): google.cloud.compute.v1.GetSslPolicyRequest;

                    /**
                     * Encodes the specified GetSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetSslPolicyRequest.verify|verify} messages.
                     * @param message GetSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetSslPolicyRequest.verify|verify} messages.
                     * @param message GetSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetSslPolicyRequest;

                    /**
                     * Decodes a GetSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetSslPolicyRequest;

                    /**
                     * Verifies a GetSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetSslPolicyRequest;

                    /**
                     * Creates a plain object from a GetSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message GetSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetStatusVpnGatewayRequest. */
                interface IGetStatusVpnGatewayRequest {

                    /** GetStatusVpnGatewayRequest project */
                    project?: (string|null);

                    /** GetStatusVpnGatewayRequest region */
                    region?: (string|null);

                    /** GetStatusVpnGatewayRequest vpnGateway */
                    vpnGateway?: (string|null);
                }

                /** Represents a GetStatusVpnGatewayRequest. */
                class GetStatusVpnGatewayRequest implements IGetStatusVpnGatewayRequest {

                    /**
                     * Constructs a new GetStatusVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetStatusVpnGatewayRequest);

                    /** GetStatusVpnGatewayRequest project. */
                    public project: string;

                    /** GetStatusVpnGatewayRequest region. */
                    public region: string;

                    /** GetStatusVpnGatewayRequest vpnGateway. */
                    public vpnGateway: string;

                    /**
                     * Creates a new GetStatusVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetStatusVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetStatusVpnGatewayRequest): google.cloud.compute.v1.GetStatusVpnGatewayRequest;

                    /**
                     * Encodes the specified GetStatusVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.GetStatusVpnGatewayRequest.verify|verify} messages.
                     * @param message GetStatusVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetStatusVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetStatusVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetStatusVpnGatewayRequest.verify|verify} messages.
                     * @param message GetStatusVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetStatusVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetStatusVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetStatusVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetStatusVpnGatewayRequest;

                    /**
                     * Decodes a GetStatusVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetStatusVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetStatusVpnGatewayRequest;

                    /**
                     * Verifies a GetStatusVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetStatusVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetStatusVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetStatusVpnGatewayRequest;

                    /**
                     * Creates a plain object from a GetStatusVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message GetStatusVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetStatusVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetStatusVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetStatusVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetSubnetworkRequest. */
                interface IGetSubnetworkRequest {

                    /** GetSubnetworkRequest project */
                    project?: (string|null);

                    /** GetSubnetworkRequest region */
                    region?: (string|null);

                    /** GetSubnetworkRequest subnetwork */
                    subnetwork?: (string|null);
                }

                /** Represents a GetSubnetworkRequest. */
                class GetSubnetworkRequest implements IGetSubnetworkRequest {

                    /**
                     * Constructs a new GetSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetSubnetworkRequest);

                    /** GetSubnetworkRequest project. */
                    public project: string;

                    /** GetSubnetworkRequest region. */
                    public region: string;

                    /** GetSubnetworkRequest subnetwork. */
                    public subnetwork: string;

                    /**
                     * Creates a new GetSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetSubnetworkRequest): google.cloud.compute.v1.GetSubnetworkRequest;

                    /**
                     * Encodes the specified GetSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.GetSubnetworkRequest.verify|verify} messages.
                     * @param message GetSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetSubnetworkRequest.verify|verify} messages.
                     * @param message GetSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetSubnetworkRequest;

                    /**
                     * Decodes a GetSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetSubnetworkRequest;

                    /**
                     * Verifies a GetSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetSubnetworkRequest;

                    /**
                     * Creates a plain object from a GetSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message GetSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetGrpcProxyRequest. */
                interface IGetTargetGrpcProxyRequest {

                    /** GetTargetGrpcProxyRequest project */
                    project?: (string|null);

                    /** GetTargetGrpcProxyRequest targetGrpcProxy */
                    targetGrpcProxy?: (string|null);
                }

                /** Represents a GetTargetGrpcProxyRequest. */
                class GetTargetGrpcProxyRequest implements IGetTargetGrpcProxyRequest {

                    /**
                     * Constructs a new GetTargetGrpcProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetGrpcProxyRequest);

                    /** GetTargetGrpcProxyRequest project. */
                    public project: string;

                    /** GetTargetGrpcProxyRequest targetGrpcProxy. */
                    public targetGrpcProxy: string;

                    /**
                     * Creates a new GetTargetGrpcProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetGrpcProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetGrpcProxyRequest): google.cloud.compute.v1.GetTargetGrpcProxyRequest;

                    /**
                     * Encodes the specified GetTargetGrpcProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message GetTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetGrpcProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message GetTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetGrpcProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetGrpcProxyRequest;

                    /**
                     * Decodes a GetTargetGrpcProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetGrpcProxyRequest;

                    /**
                     * Verifies a GetTargetGrpcProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetGrpcProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetGrpcProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetGrpcProxyRequest;

                    /**
                     * Creates a plain object from a GetTargetGrpcProxyRequest message. Also converts values to other types if specified.
                     * @param message GetTargetGrpcProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetGrpcProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetGrpcProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetGrpcProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetHttpProxyRequest. */
                interface IGetTargetHttpProxyRequest {

                    /** GetTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** GetTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);
                }

                /** Represents a GetTargetHttpProxyRequest. */
                class GetTargetHttpProxyRequest implements IGetTargetHttpProxyRequest {

                    /**
                     * Constructs a new GetTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetHttpProxyRequest);

                    /** GetTargetHttpProxyRequest project. */
                    public project: string;

                    /** GetTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /**
                     * Creates a new GetTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetHttpProxyRequest): google.cloud.compute.v1.GetTargetHttpProxyRequest;

                    /**
                     * Encodes the specified GetTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetHttpProxyRequest.verify|verify} messages.
                     * @param message GetTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetHttpProxyRequest.verify|verify} messages.
                     * @param message GetTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetHttpProxyRequest;

                    /**
                     * Decodes a GetTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetHttpProxyRequest;

                    /**
                     * Verifies a GetTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a GetTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message GetTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetHttpsProxyRequest. */
                interface IGetTargetHttpsProxyRequest {

                    /** GetTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** GetTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a GetTargetHttpsProxyRequest. */
                class GetTargetHttpsProxyRequest implements IGetTargetHttpsProxyRequest {

                    /**
                     * Constructs a new GetTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetHttpsProxyRequest);

                    /** GetTargetHttpsProxyRequest project. */
                    public project: string;

                    /** GetTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /**
                     * Creates a new GetTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetHttpsProxyRequest): google.cloud.compute.v1.GetTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified GetTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message GetTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message GetTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetHttpsProxyRequest;

                    /**
                     * Decodes a GetTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetHttpsProxyRequest;

                    /**
                     * Verifies a GetTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a GetTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message GetTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetInstanceRequest. */
                interface IGetTargetInstanceRequest {

                    /** GetTargetInstanceRequest project */
                    project?: (string|null);

                    /** GetTargetInstanceRequest targetInstance */
                    targetInstance?: (string|null);

                    /** GetTargetInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetTargetInstanceRequest. */
                class GetTargetInstanceRequest implements IGetTargetInstanceRequest {

                    /**
                     * Constructs a new GetTargetInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetInstanceRequest);

                    /** GetTargetInstanceRequest project. */
                    public project: string;

                    /** GetTargetInstanceRequest targetInstance. */
                    public targetInstance: string;

                    /** GetTargetInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetTargetInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetInstanceRequest): google.cloud.compute.v1.GetTargetInstanceRequest;

                    /**
                     * Encodes the specified GetTargetInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetInstanceRequest.verify|verify} messages.
                     * @param message GetTargetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetInstanceRequest.verify|verify} messages.
                     * @param message GetTargetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetInstanceRequest;

                    /**
                     * Decodes a GetTargetInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetInstanceRequest;

                    /**
                     * Verifies a GetTargetInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetInstanceRequest;

                    /**
                     * Creates a plain object from a GetTargetInstanceRequest message. Also converts values to other types if specified.
                     * @param message GetTargetInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetPoolRequest. */
                interface IGetTargetPoolRequest {

                    /** GetTargetPoolRequest project */
                    project?: (string|null);

                    /** GetTargetPoolRequest region */
                    region?: (string|null);

                    /** GetTargetPoolRequest targetPool */
                    targetPool?: (string|null);
                }

                /** Represents a GetTargetPoolRequest. */
                class GetTargetPoolRequest implements IGetTargetPoolRequest {

                    /**
                     * Constructs a new GetTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetPoolRequest);

                    /** GetTargetPoolRequest project. */
                    public project: string;

                    /** GetTargetPoolRequest region. */
                    public region: string;

                    /** GetTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /**
                     * Creates a new GetTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetPoolRequest): google.cloud.compute.v1.GetTargetPoolRequest;

                    /**
                     * Encodes the specified GetTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetPoolRequest.verify|verify} messages.
                     * @param message GetTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetPoolRequest.verify|verify} messages.
                     * @param message GetTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetPoolRequest;

                    /**
                     * Decodes a GetTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetPoolRequest;

                    /**
                     * Verifies a GetTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetPoolRequest;

                    /**
                     * Creates a plain object from a GetTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message GetTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetSslProxyRequest. */
                interface IGetTargetSslProxyRequest {

                    /** GetTargetSslProxyRequest project */
                    project?: (string|null);

                    /** GetTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a GetTargetSslProxyRequest. */
                class GetTargetSslProxyRequest implements IGetTargetSslProxyRequest {

                    /**
                     * Constructs a new GetTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetSslProxyRequest);

                    /** GetTargetSslProxyRequest project. */
                    public project: string;

                    /** GetTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /**
                     * Creates a new GetTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetSslProxyRequest): google.cloud.compute.v1.GetTargetSslProxyRequest;

                    /**
                     * Encodes the specified GetTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetSslProxyRequest.verify|verify} messages.
                     * @param message GetTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetSslProxyRequest.verify|verify} messages.
                     * @param message GetTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetSslProxyRequest;

                    /**
                     * Decodes a GetTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetSslProxyRequest;

                    /**
                     * Verifies a GetTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a GetTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message GetTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetTcpProxyRequest. */
                interface IGetTargetTcpProxyRequest {

                    /** GetTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** GetTargetTcpProxyRequest targetTcpProxy */
                    targetTcpProxy?: (string|null);
                }

                /** Represents a GetTargetTcpProxyRequest. */
                class GetTargetTcpProxyRequest implements IGetTargetTcpProxyRequest {

                    /**
                     * Constructs a new GetTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetTcpProxyRequest);

                    /** GetTargetTcpProxyRequest project. */
                    public project: string;

                    /** GetTargetTcpProxyRequest targetTcpProxy. */
                    public targetTcpProxy: string;

                    /**
                     * Creates a new GetTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetTcpProxyRequest): google.cloud.compute.v1.GetTargetTcpProxyRequest;

                    /**
                     * Encodes the specified GetTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetTcpProxyRequest.verify|verify} messages.
                     * @param message GetTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetTcpProxyRequest.verify|verify} messages.
                     * @param message GetTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetTcpProxyRequest;

                    /**
                     * Decodes a GetTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetTcpProxyRequest;

                    /**
                     * Verifies a GetTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from a GetTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message GetTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetTargetVpnGatewayRequest. */
                interface IGetTargetVpnGatewayRequest {

                    /** GetTargetVpnGatewayRequest project */
                    project?: (string|null);

                    /** GetTargetVpnGatewayRequest region */
                    region?: (string|null);

                    /** GetTargetVpnGatewayRequest targetVpnGateway */
                    targetVpnGateway?: (string|null);
                }

                /** Represents a GetTargetVpnGatewayRequest. */
                class GetTargetVpnGatewayRequest implements IGetTargetVpnGatewayRequest {

                    /**
                     * Constructs a new GetTargetVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetTargetVpnGatewayRequest);

                    /** GetTargetVpnGatewayRequest project. */
                    public project: string;

                    /** GetTargetVpnGatewayRequest region. */
                    public region: string;

                    /** GetTargetVpnGatewayRequest targetVpnGateway. */
                    public targetVpnGateway: string;

                    /**
                     * Creates a new GetTargetVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetTargetVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetTargetVpnGatewayRequest): google.cloud.compute.v1.GetTargetVpnGatewayRequest;

                    /**
                     * Encodes the specified GetTargetVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.GetTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message GetTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetTargetVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message GetTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetTargetVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetTargetVpnGatewayRequest;

                    /**
                     * Decodes a GetTargetVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetTargetVpnGatewayRequest;

                    /**
                     * Verifies a GetTargetVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetTargetVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetTargetVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetTargetVpnGatewayRequest;

                    /**
                     * Creates a plain object from a GetTargetVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message GetTargetVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetTargetVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetTargetVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetTargetVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetUrlMapRequest. */
                interface IGetUrlMapRequest {

                    /** GetUrlMapRequest project */
                    project?: (string|null);

                    /** GetUrlMapRequest urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a GetUrlMapRequest. */
                class GetUrlMapRequest implements IGetUrlMapRequest {

                    /**
                     * Constructs a new GetUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetUrlMapRequest);

                    /** GetUrlMapRequest project. */
                    public project: string;

                    /** GetUrlMapRequest urlMap. */
                    public urlMap: string;

                    /**
                     * Creates a new GetUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetUrlMapRequest): google.cloud.compute.v1.GetUrlMapRequest;

                    /**
                     * Encodes the specified GetUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.GetUrlMapRequest.verify|verify} messages.
                     * @param message GetUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetUrlMapRequest.verify|verify} messages.
                     * @param message GetUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetUrlMapRequest;

                    /**
                     * Decodes a GetUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetUrlMapRequest;

                    /**
                     * Verifies a GetUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetUrlMapRequest;

                    /**
                     * Creates a plain object from a GetUrlMapRequest message. Also converts values to other types if specified.
                     * @param message GetUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetVpnGatewayRequest. */
                interface IGetVpnGatewayRequest {

                    /** GetVpnGatewayRequest project */
                    project?: (string|null);

                    /** GetVpnGatewayRequest region */
                    region?: (string|null);

                    /** GetVpnGatewayRequest vpnGateway */
                    vpnGateway?: (string|null);
                }

                /** Represents a GetVpnGatewayRequest. */
                class GetVpnGatewayRequest implements IGetVpnGatewayRequest {

                    /**
                     * Constructs a new GetVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetVpnGatewayRequest);

                    /** GetVpnGatewayRequest project. */
                    public project: string;

                    /** GetVpnGatewayRequest region. */
                    public region: string;

                    /** GetVpnGatewayRequest vpnGateway. */
                    public vpnGateway: string;

                    /**
                     * Creates a new GetVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetVpnGatewayRequest): google.cloud.compute.v1.GetVpnGatewayRequest;

                    /**
                     * Encodes the specified GetVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.GetVpnGatewayRequest.verify|verify} messages.
                     * @param message GetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetVpnGatewayRequest.verify|verify} messages.
                     * @param message GetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetVpnGatewayRequest;

                    /**
                     * Decodes a GetVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetVpnGatewayRequest;

                    /**
                     * Verifies a GetVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetVpnGatewayRequest;

                    /**
                     * Creates a plain object from a GetVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message GetVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetVpnTunnelRequest. */
                interface IGetVpnTunnelRequest {

                    /** GetVpnTunnelRequest project */
                    project?: (string|null);

                    /** GetVpnTunnelRequest region */
                    region?: (string|null);

                    /** GetVpnTunnelRequest vpnTunnel */
                    vpnTunnel?: (string|null);
                }

                /** Represents a GetVpnTunnelRequest. */
                class GetVpnTunnelRequest implements IGetVpnTunnelRequest {

                    /**
                     * Constructs a new GetVpnTunnelRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetVpnTunnelRequest);

                    /** GetVpnTunnelRequest project. */
                    public project: string;

                    /** GetVpnTunnelRequest region. */
                    public region: string;

                    /** GetVpnTunnelRequest vpnTunnel. */
                    public vpnTunnel: string;

                    /**
                     * Creates a new GetVpnTunnelRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetVpnTunnelRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetVpnTunnelRequest): google.cloud.compute.v1.GetVpnTunnelRequest;

                    /**
                     * Encodes the specified GetVpnTunnelRequest message. Does not implicitly {@link google.cloud.compute.v1.GetVpnTunnelRequest.verify|verify} messages.
                     * @param message GetVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetVpnTunnelRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetVpnTunnelRequest.verify|verify} messages.
                     * @param message GetVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetVpnTunnelRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetVpnTunnelRequest;

                    /**
                     * Decodes a GetVpnTunnelRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetVpnTunnelRequest;

                    /**
                     * Verifies a GetVpnTunnelRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetVpnTunnelRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetVpnTunnelRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetVpnTunnelRequest;

                    /**
                     * Creates a plain object from a GetVpnTunnelRequest message. Also converts values to other types if specified.
                     * @param message GetVpnTunnelRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetVpnTunnelRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetVpnTunnelRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetVpnTunnelRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetXpnHostProjectRequest. */
                interface IGetXpnHostProjectRequest {

                    /** GetXpnHostProjectRequest project */
                    project?: (string|null);
                }

                /** Represents a GetXpnHostProjectRequest. */
                class GetXpnHostProjectRequest implements IGetXpnHostProjectRequest {

                    /**
                     * Constructs a new GetXpnHostProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetXpnHostProjectRequest);

                    /** GetXpnHostProjectRequest project. */
                    public project: string;

                    /**
                     * Creates a new GetXpnHostProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetXpnHostProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetXpnHostProjectRequest): google.cloud.compute.v1.GetXpnHostProjectRequest;

                    /**
                     * Encodes the specified GetXpnHostProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.GetXpnHostProjectRequest.verify|verify} messages.
                     * @param message GetXpnHostProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetXpnHostProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetXpnHostProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetXpnHostProjectRequest.verify|verify} messages.
                     * @param message GetXpnHostProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetXpnHostProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetXpnHostProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetXpnHostProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetXpnHostProjectRequest;

                    /**
                     * Decodes a GetXpnHostProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetXpnHostProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetXpnHostProjectRequest;

                    /**
                     * Verifies a GetXpnHostProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetXpnHostProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetXpnHostProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetXpnHostProjectRequest;

                    /**
                     * Creates a plain object from a GetXpnHostProjectRequest message. Also converts values to other types if specified.
                     * @param message GetXpnHostProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetXpnHostProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetXpnHostProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetXpnHostProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetXpnResourcesProjectsRequest. */
                interface IGetXpnResourcesProjectsRequest {

                    /** GetXpnResourcesProjectsRequest filter */
                    filter?: (string|null);

                    /** GetXpnResourcesProjectsRequest maxResults */
                    maxResults?: (number|null);

                    /** GetXpnResourcesProjectsRequest orderBy */
                    orderBy?: (string|null);

                    /** GetXpnResourcesProjectsRequest pageToken */
                    pageToken?: (string|null);

                    /** GetXpnResourcesProjectsRequest project */
                    project?: (string|null);

                    /** GetXpnResourcesProjectsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a GetXpnResourcesProjectsRequest. */
                class GetXpnResourcesProjectsRequest implements IGetXpnResourcesProjectsRequest {

                    /**
                     * Constructs a new GetXpnResourcesProjectsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetXpnResourcesProjectsRequest);

                    /** GetXpnResourcesProjectsRequest filter. */
                    public filter?: (string|null);

                    /** GetXpnResourcesProjectsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** GetXpnResourcesProjectsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** GetXpnResourcesProjectsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** GetXpnResourcesProjectsRequest project. */
                    public project: string;

                    /** GetXpnResourcesProjectsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** GetXpnResourcesProjectsRequest _filter. */
                    public _filter?: "filter";

                    /** GetXpnResourcesProjectsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** GetXpnResourcesProjectsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** GetXpnResourcesProjectsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** GetXpnResourcesProjectsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new GetXpnResourcesProjectsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetXpnResourcesProjectsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetXpnResourcesProjectsRequest): google.cloud.compute.v1.GetXpnResourcesProjectsRequest;

                    /**
                     * Encodes the specified GetXpnResourcesProjectsRequest message. Does not implicitly {@link google.cloud.compute.v1.GetXpnResourcesProjectsRequest.verify|verify} messages.
                     * @param message GetXpnResourcesProjectsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetXpnResourcesProjectsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetXpnResourcesProjectsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetXpnResourcesProjectsRequest.verify|verify} messages.
                     * @param message GetXpnResourcesProjectsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetXpnResourcesProjectsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetXpnResourcesProjectsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetXpnResourcesProjectsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetXpnResourcesProjectsRequest;

                    /**
                     * Decodes a GetXpnResourcesProjectsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetXpnResourcesProjectsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetXpnResourcesProjectsRequest;

                    /**
                     * Verifies a GetXpnResourcesProjectsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetXpnResourcesProjectsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetXpnResourcesProjectsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetXpnResourcesProjectsRequest;

                    /**
                     * Creates a plain object from a GetXpnResourcesProjectsRequest message. Also converts values to other types if specified.
                     * @param message GetXpnResourcesProjectsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetXpnResourcesProjectsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetXpnResourcesProjectsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetXpnResourcesProjectsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetZoneOperationRequest. */
                interface IGetZoneOperationRequest {

                    /** GetZoneOperationRequest operation */
                    operation?: (string|null);

                    /** GetZoneOperationRequest project */
                    project?: (string|null);

                    /** GetZoneOperationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetZoneOperationRequest. */
                class GetZoneOperationRequest implements IGetZoneOperationRequest {

                    /**
                     * Constructs a new GetZoneOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetZoneOperationRequest);

                    /** GetZoneOperationRequest operation. */
                    public operation: string;

                    /** GetZoneOperationRequest project. */
                    public project: string;

                    /** GetZoneOperationRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetZoneOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetZoneOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetZoneOperationRequest): google.cloud.compute.v1.GetZoneOperationRequest;

                    /**
                     * Encodes the specified GetZoneOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.GetZoneOperationRequest.verify|verify} messages.
                     * @param message GetZoneOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetZoneOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetZoneOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetZoneOperationRequest.verify|verify} messages.
                     * @param message GetZoneOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetZoneOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetZoneOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetZoneOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetZoneOperationRequest;

                    /**
                     * Decodes a GetZoneOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetZoneOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetZoneOperationRequest;

                    /**
                     * Verifies a GetZoneOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetZoneOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetZoneOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetZoneOperationRequest;

                    /**
                     * Creates a plain object from a GetZoneOperationRequest message. Also converts values to other types if specified.
                     * @param message GetZoneOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetZoneOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetZoneOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetZoneOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetZoneRequest. */
                interface IGetZoneRequest {

                    /** GetZoneRequest project */
                    project?: (string|null);

                    /** GetZoneRequest zone */
                    zone?: (string|null);
                }

                /** Represents a GetZoneRequest. */
                class GetZoneRequest implements IGetZoneRequest {

                    /**
                     * Constructs a new GetZoneRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGetZoneRequest);

                    /** GetZoneRequest project. */
                    public project: string;

                    /** GetZoneRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new GetZoneRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetZoneRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGetZoneRequest): google.cloud.compute.v1.GetZoneRequest;

                    /**
                     * Encodes the specified GetZoneRequest message. Does not implicitly {@link google.cloud.compute.v1.GetZoneRequest.verify|verify} messages.
                     * @param message GetZoneRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGetZoneRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetZoneRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GetZoneRequest.verify|verify} messages.
                     * @param message GetZoneRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGetZoneRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetZoneRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetZoneRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GetZoneRequest;

                    /**
                     * Decodes a GetZoneRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetZoneRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GetZoneRequest;

                    /**
                     * Verifies a GetZoneRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetZoneRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetZoneRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GetZoneRequest;

                    /**
                     * Creates a plain object from a GetZoneRequest message. Also converts values to other types if specified.
                     * @param message GetZoneRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GetZoneRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetZoneRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetZoneRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GlobalNetworkEndpointGroupsAttachEndpointsRequest. */
                interface IGlobalNetworkEndpointGroupsAttachEndpointsRequest {

                    /** GlobalNetworkEndpointGroupsAttachEndpointsRequest networkEndpoints */
                    networkEndpoints?: (google.cloud.compute.v1.INetworkEndpoint[]|null);
                }

                /** Represents a GlobalNetworkEndpointGroupsAttachEndpointsRequest. */
                class GlobalNetworkEndpointGroupsAttachEndpointsRequest implements IGlobalNetworkEndpointGroupsAttachEndpointsRequest {

                    /**
                     * Constructs a new GlobalNetworkEndpointGroupsAttachEndpointsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsAttachEndpointsRequest);

                    /** GlobalNetworkEndpointGroupsAttachEndpointsRequest networkEndpoints. */
                    public networkEndpoints: google.cloud.compute.v1.INetworkEndpoint[];

                    /**
                     * Creates a new GlobalNetworkEndpointGroupsAttachEndpointsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GlobalNetworkEndpointGroupsAttachEndpointsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsAttachEndpointsRequest): google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Encodes the specified GlobalNetworkEndpointGroupsAttachEndpointsRequest message. Does not implicitly {@link google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest.verify|verify} messages.
                     * @param message GlobalNetworkEndpointGroupsAttachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsAttachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GlobalNetworkEndpointGroupsAttachEndpointsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest.verify|verify} messages.
                     * @param message GlobalNetworkEndpointGroupsAttachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsAttachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GlobalNetworkEndpointGroupsAttachEndpointsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GlobalNetworkEndpointGroupsAttachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Decodes a GlobalNetworkEndpointGroupsAttachEndpointsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GlobalNetworkEndpointGroupsAttachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Verifies a GlobalNetworkEndpointGroupsAttachEndpointsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GlobalNetworkEndpointGroupsAttachEndpointsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GlobalNetworkEndpointGroupsAttachEndpointsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Creates a plain object from a GlobalNetworkEndpointGroupsAttachEndpointsRequest message. Also converts values to other types if specified.
                     * @param message GlobalNetworkEndpointGroupsAttachEndpointsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GlobalNetworkEndpointGroupsAttachEndpointsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GlobalNetworkEndpointGroupsAttachEndpointsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GlobalNetworkEndpointGroupsAttachEndpointsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GlobalNetworkEndpointGroupsDetachEndpointsRequest. */
                interface IGlobalNetworkEndpointGroupsDetachEndpointsRequest {

                    /** GlobalNetworkEndpointGroupsDetachEndpointsRequest networkEndpoints */
                    networkEndpoints?: (google.cloud.compute.v1.INetworkEndpoint[]|null);
                }

                /** Represents a GlobalNetworkEndpointGroupsDetachEndpointsRequest. */
                class GlobalNetworkEndpointGroupsDetachEndpointsRequest implements IGlobalNetworkEndpointGroupsDetachEndpointsRequest {

                    /**
                     * Constructs a new GlobalNetworkEndpointGroupsDetachEndpointsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsDetachEndpointsRequest);

                    /** GlobalNetworkEndpointGroupsDetachEndpointsRequest networkEndpoints. */
                    public networkEndpoints: google.cloud.compute.v1.INetworkEndpoint[];

                    /**
                     * Creates a new GlobalNetworkEndpointGroupsDetachEndpointsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GlobalNetworkEndpointGroupsDetachEndpointsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsDetachEndpointsRequest): google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Encodes the specified GlobalNetworkEndpointGroupsDetachEndpointsRequest message. Does not implicitly {@link google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest.verify|verify} messages.
                     * @param message GlobalNetworkEndpointGroupsDetachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsDetachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GlobalNetworkEndpointGroupsDetachEndpointsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest.verify|verify} messages.
                     * @param message GlobalNetworkEndpointGroupsDetachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGlobalNetworkEndpointGroupsDetachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GlobalNetworkEndpointGroupsDetachEndpointsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GlobalNetworkEndpointGroupsDetachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Decodes a GlobalNetworkEndpointGroupsDetachEndpointsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GlobalNetworkEndpointGroupsDetachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Verifies a GlobalNetworkEndpointGroupsDetachEndpointsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GlobalNetworkEndpointGroupsDetachEndpointsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GlobalNetworkEndpointGroupsDetachEndpointsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Creates a plain object from a GlobalNetworkEndpointGroupsDetachEndpointsRequest message. Also converts values to other types if specified.
                     * @param message GlobalNetworkEndpointGroupsDetachEndpointsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GlobalNetworkEndpointGroupsDetachEndpointsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GlobalNetworkEndpointGroupsDetachEndpointsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GlobalNetworkEndpointGroupsDetachEndpointsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GlobalOrganizationSetPolicyRequest. */
                interface IGlobalOrganizationSetPolicyRequest {

                    /** GlobalOrganizationSetPolicyRequest bindings */
                    bindings?: (google.cloud.compute.v1.IBinding[]|null);

                    /** GlobalOrganizationSetPolicyRequest etag */
                    etag?: (string|null);

                    /** GlobalOrganizationSetPolicyRequest policy */
                    policy?: (google.cloud.compute.v1.IPolicy|null);
                }

                /** Represents a GlobalOrganizationSetPolicyRequest. */
                class GlobalOrganizationSetPolicyRequest implements IGlobalOrganizationSetPolicyRequest {

                    /**
                     * Constructs a new GlobalOrganizationSetPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGlobalOrganizationSetPolicyRequest);

                    /** GlobalOrganizationSetPolicyRequest bindings. */
                    public bindings: google.cloud.compute.v1.IBinding[];

                    /** GlobalOrganizationSetPolicyRequest etag. */
                    public etag?: (string|null);

                    /** GlobalOrganizationSetPolicyRequest policy. */
                    public policy?: (google.cloud.compute.v1.IPolicy|null);

                    /** GlobalOrganizationSetPolicyRequest _etag. */
                    public _etag?: "etag";

                    /** GlobalOrganizationSetPolicyRequest _policy. */
                    public _policy?: "policy";

                    /**
                     * Creates a new GlobalOrganizationSetPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GlobalOrganizationSetPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGlobalOrganizationSetPolicyRequest): google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest;

                    /**
                     * Encodes the specified GlobalOrganizationSetPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest.verify|verify} messages.
                     * @param message GlobalOrganizationSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGlobalOrganizationSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GlobalOrganizationSetPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest.verify|verify} messages.
                     * @param message GlobalOrganizationSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGlobalOrganizationSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GlobalOrganizationSetPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GlobalOrganizationSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest;

                    /**
                     * Decodes a GlobalOrganizationSetPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GlobalOrganizationSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest;

                    /**
                     * Verifies a GlobalOrganizationSetPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GlobalOrganizationSetPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GlobalOrganizationSetPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest;

                    /**
                     * Creates a plain object from a GlobalOrganizationSetPolicyRequest message. Also converts values to other types if specified.
                     * @param message GlobalOrganizationSetPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GlobalOrganizationSetPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GlobalOrganizationSetPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GlobalOrganizationSetPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GlobalSetLabelsRequest. */
                interface IGlobalSetLabelsRequest {

                    /** GlobalSetLabelsRequest labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** GlobalSetLabelsRequest labels */
                    labels?: ({ [k: string]: string }|null);
                }

                /** Represents a GlobalSetLabelsRequest. */
                class GlobalSetLabelsRequest implements IGlobalSetLabelsRequest {

                    /**
                     * Constructs a new GlobalSetLabelsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGlobalSetLabelsRequest);

                    /** GlobalSetLabelsRequest labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** GlobalSetLabelsRequest labels. */
                    public labels: { [k: string]: string };

                    /** GlobalSetLabelsRequest _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /**
                     * Creates a new GlobalSetLabelsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GlobalSetLabelsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGlobalSetLabelsRequest): google.cloud.compute.v1.GlobalSetLabelsRequest;

                    /**
                     * Encodes the specified GlobalSetLabelsRequest message. Does not implicitly {@link google.cloud.compute.v1.GlobalSetLabelsRequest.verify|verify} messages.
                     * @param message GlobalSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGlobalSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GlobalSetLabelsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GlobalSetLabelsRequest.verify|verify} messages.
                     * @param message GlobalSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGlobalSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GlobalSetLabelsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GlobalSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GlobalSetLabelsRequest;

                    /**
                     * Decodes a GlobalSetLabelsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GlobalSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GlobalSetLabelsRequest;

                    /**
                     * Verifies a GlobalSetLabelsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GlobalSetLabelsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GlobalSetLabelsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GlobalSetLabelsRequest;

                    /**
                     * Creates a plain object from a GlobalSetLabelsRequest message. Also converts values to other types if specified.
                     * @param message GlobalSetLabelsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GlobalSetLabelsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GlobalSetLabelsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GlobalSetLabelsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GlobalSetPolicyRequest. */
                interface IGlobalSetPolicyRequest {

                    /** GlobalSetPolicyRequest bindings */
                    bindings?: (google.cloud.compute.v1.IBinding[]|null);

                    /** GlobalSetPolicyRequest etag */
                    etag?: (string|null);

                    /** GlobalSetPolicyRequest policy */
                    policy?: (google.cloud.compute.v1.IPolicy|null);
                }

                /** Represents a GlobalSetPolicyRequest. */
                class GlobalSetPolicyRequest implements IGlobalSetPolicyRequest {

                    /**
                     * Constructs a new GlobalSetPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGlobalSetPolicyRequest);

                    /** GlobalSetPolicyRequest bindings. */
                    public bindings: google.cloud.compute.v1.IBinding[];

                    /** GlobalSetPolicyRequest etag. */
                    public etag?: (string|null);

                    /** GlobalSetPolicyRequest policy. */
                    public policy?: (google.cloud.compute.v1.IPolicy|null);

                    /** GlobalSetPolicyRequest _etag. */
                    public _etag?: "etag";

                    /** GlobalSetPolicyRequest _policy. */
                    public _policy?: "policy";

                    /**
                     * Creates a new GlobalSetPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GlobalSetPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGlobalSetPolicyRequest): google.cloud.compute.v1.GlobalSetPolicyRequest;

                    /**
                     * Encodes the specified GlobalSetPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.GlobalSetPolicyRequest.verify|verify} messages.
                     * @param message GlobalSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGlobalSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GlobalSetPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GlobalSetPolicyRequest.verify|verify} messages.
                     * @param message GlobalSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGlobalSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GlobalSetPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GlobalSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GlobalSetPolicyRequest;

                    /**
                     * Decodes a GlobalSetPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GlobalSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GlobalSetPolicyRequest;

                    /**
                     * Verifies a GlobalSetPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GlobalSetPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GlobalSetPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GlobalSetPolicyRequest;

                    /**
                     * Creates a plain object from a GlobalSetPolicyRequest message. Also converts values to other types if specified.
                     * @param message GlobalSetPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GlobalSetPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GlobalSetPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GlobalSetPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GuestAttributes. */
                interface IGuestAttributes {

                    /** GuestAttributes kind */
                    kind?: (string|null);

                    /** GuestAttributes queryPath */
                    queryPath?: (string|null);

                    /** GuestAttributes queryValue */
                    queryValue?: (google.cloud.compute.v1.IGuestAttributesValue|null);

                    /** GuestAttributes selfLink */
                    selfLink?: (string|null);

                    /** GuestAttributes variableKey */
                    variableKey?: (string|null);

                    /** GuestAttributes variableValue */
                    variableValue?: (string|null);
                }

                /** Represents a GuestAttributes. */
                class GuestAttributes implements IGuestAttributes {

                    /**
                     * Constructs a new GuestAttributes.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGuestAttributes);

                    /** GuestAttributes kind. */
                    public kind?: (string|null);

                    /** GuestAttributes queryPath. */
                    public queryPath?: (string|null);

                    /** GuestAttributes queryValue. */
                    public queryValue?: (google.cloud.compute.v1.IGuestAttributesValue|null);

                    /** GuestAttributes selfLink. */
                    public selfLink?: (string|null);

                    /** GuestAttributes variableKey. */
                    public variableKey?: (string|null);

                    /** GuestAttributes variableValue. */
                    public variableValue?: (string|null);

                    /** GuestAttributes _kind. */
                    public _kind?: "kind";

                    /** GuestAttributes _queryPath. */
                    public _queryPath?: "queryPath";

                    /** GuestAttributes _queryValue. */
                    public _queryValue?: "queryValue";

                    /** GuestAttributes _selfLink. */
                    public _selfLink?: "selfLink";

                    /** GuestAttributes _variableKey. */
                    public _variableKey?: "variableKey";

                    /** GuestAttributes _variableValue. */
                    public _variableValue?: "variableValue";

                    /**
                     * Creates a new GuestAttributes instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GuestAttributes instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGuestAttributes): google.cloud.compute.v1.GuestAttributes;

                    /**
                     * Encodes the specified GuestAttributes message. Does not implicitly {@link google.cloud.compute.v1.GuestAttributes.verify|verify} messages.
                     * @param message GuestAttributes message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGuestAttributes, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GuestAttributes message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GuestAttributes.verify|verify} messages.
                     * @param message GuestAttributes message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGuestAttributes, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GuestAttributes message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GuestAttributes
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GuestAttributes;

                    /**
                     * Decodes a GuestAttributes message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GuestAttributes
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GuestAttributes;

                    /**
                     * Verifies a GuestAttributes message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GuestAttributes message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GuestAttributes
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GuestAttributes;

                    /**
                     * Creates a plain object from a GuestAttributes message. Also converts values to other types if specified.
                     * @param message GuestAttributes
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GuestAttributes, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GuestAttributes to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GuestAttributes
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GuestAttributesEntry. */
                interface IGuestAttributesEntry {

                    /** GuestAttributesEntry key */
                    key?: (string|null);

                    /** GuestAttributesEntry namespace */
                    namespace?: (string|null);

                    /** GuestAttributesEntry value */
                    value?: (string|null);
                }

                /** Represents a GuestAttributesEntry. */
                class GuestAttributesEntry implements IGuestAttributesEntry {

                    /**
                     * Constructs a new GuestAttributesEntry.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGuestAttributesEntry);

                    /** GuestAttributesEntry key. */
                    public key?: (string|null);

                    /** GuestAttributesEntry namespace. */
                    public namespace?: (string|null);

                    /** GuestAttributesEntry value. */
                    public value?: (string|null);

                    /** GuestAttributesEntry _key. */
                    public _key?: "key";

                    /** GuestAttributesEntry _namespace. */
                    public _namespace?: "namespace";

                    /** GuestAttributesEntry _value. */
                    public _value?: "value";

                    /**
                     * Creates a new GuestAttributesEntry instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GuestAttributesEntry instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGuestAttributesEntry): google.cloud.compute.v1.GuestAttributesEntry;

                    /**
                     * Encodes the specified GuestAttributesEntry message. Does not implicitly {@link google.cloud.compute.v1.GuestAttributesEntry.verify|verify} messages.
                     * @param message GuestAttributesEntry message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGuestAttributesEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GuestAttributesEntry message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GuestAttributesEntry.verify|verify} messages.
                     * @param message GuestAttributesEntry message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGuestAttributesEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GuestAttributesEntry message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GuestAttributesEntry
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GuestAttributesEntry;

                    /**
                     * Decodes a GuestAttributesEntry message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GuestAttributesEntry
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GuestAttributesEntry;

                    /**
                     * Verifies a GuestAttributesEntry message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GuestAttributesEntry message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GuestAttributesEntry
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GuestAttributesEntry;

                    /**
                     * Creates a plain object from a GuestAttributesEntry message. Also converts values to other types if specified.
                     * @param message GuestAttributesEntry
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GuestAttributesEntry, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GuestAttributesEntry to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GuestAttributesEntry
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GuestAttributesValue. */
                interface IGuestAttributesValue {

                    /** GuestAttributesValue items */
                    items?: (google.cloud.compute.v1.IGuestAttributesEntry[]|null);
                }

                /** Represents a GuestAttributesValue. */
                class GuestAttributesValue implements IGuestAttributesValue {

                    /**
                     * Constructs a new GuestAttributesValue.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGuestAttributesValue);

                    /** GuestAttributesValue items. */
                    public items: google.cloud.compute.v1.IGuestAttributesEntry[];

                    /**
                     * Creates a new GuestAttributesValue instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GuestAttributesValue instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGuestAttributesValue): google.cloud.compute.v1.GuestAttributesValue;

                    /**
                     * Encodes the specified GuestAttributesValue message. Does not implicitly {@link google.cloud.compute.v1.GuestAttributesValue.verify|verify} messages.
                     * @param message GuestAttributesValue message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGuestAttributesValue, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GuestAttributesValue message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GuestAttributesValue.verify|verify} messages.
                     * @param message GuestAttributesValue message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGuestAttributesValue, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GuestAttributesValue message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GuestAttributesValue
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GuestAttributesValue;

                    /**
                     * Decodes a GuestAttributesValue message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GuestAttributesValue
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GuestAttributesValue;

                    /**
                     * Verifies a GuestAttributesValue message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GuestAttributesValue message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GuestAttributesValue
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GuestAttributesValue;

                    /**
                     * Creates a plain object from a GuestAttributesValue message. Also converts values to other types if specified.
                     * @param message GuestAttributesValue
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GuestAttributesValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GuestAttributesValue to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GuestAttributesValue
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GuestOsFeature. */
                interface IGuestOsFeature {

                    /** GuestOsFeature type */
                    type?: (string|null);
                }

                /** Represents a GuestOsFeature. */
                class GuestOsFeature implements IGuestOsFeature {

                    /**
                     * Constructs a new GuestOsFeature.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IGuestOsFeature);

                    /** GuestOsFeature type. */
                    public type?: (string|null);

                    /** GuestOsFeature _type. */
                    public _type?: "type";

                    /**
                     * Creates a new GuestOsFeature instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GuestOsFeature instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IGuestOsFeature): google.cloud.compute.v1.GuestOsFeature;

                    /**
                     * Encodes the specified GuestOsFeature message. Does not implicitly {@link google.cloud.compute.v1.GuestOsFeature.verify|verify} messages.
                     * @param message GuestOsFeature message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IGuestOsFeature, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GuestOsFeature message, length delimited. Does not implicitly {@link google.cloud.compute.v1.GuestOsFeature.verify|verify} messages.
                     * @param message GuestOsFeature message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IGuestOsFeature, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GuestOsFeature message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GuestOsFeature
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.GuestOsFeature;

                    /**
                     * Decodes a GuestOsFeature message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GuestOsFeature
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.GuestOsFeature;

                    /**
                     * Verifies a GuestOsFeature message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GuestOsFeature message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GuestOsFeature
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.GuestOsFeature;

                    /**
                     * Creates a plain object from a GuestOsFeature message. Also converts values to other types if specified.
                     * @param message GuestOsFeature
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.GuestOsFeature, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GuestOsFeature to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GuestOsFeature
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace GuestOsFeature {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        FEATURE_TYPE_UNSPECIFIED = 531767259,
                        GVNIC = 68209305,
                        MULTI_IP_SUBNET = 151776719,
                        SECURE_BOOT = 376811194,
                        SEV_CAPABLE = 87083793,
                        UEFI_COMPATIBLE = 195865408,
                        VIRTIO_SCSI_MULTIQUEUE = 201597069,
                        WINDOWS = 456863331
                    }
                }

                /** Properties of a HTTP2HealthCheck. */
                interface IHTTP2HealthCheck {

                    /** HTTP2HealthCheck host */
                    host?: (string|null);

                    /** HTTP2HealthCheck port */
                    port?: (number|null);

                    /** HTTP2HealthCheck portName */
                    portName?: (string|null);

                    /** HTTP2HealthCheck portSpecification */
                    portSpecification?: (string|null);

                    /** HTTP2HealthCheck proxyHeader */
                    proxyHeader?: (string|null);

                    /** HTTP2HealthCheck requestPath */
                    requestPath?: (string|null);

                    /** HTTP2HealthCheck response */
                    response?: (string|null);
                }

                /** Represents a HTTP2HealthCheck. */
                class HTTP2HealthCheck implements IHTTP2HealthCheck {

                    /**
                     * Constructs a new HTTP2HealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHTTP2HealthCheck);

                    /** HTTP2HealthCheck host. */
                    public host?: (string|null);

                    /** HTTP2HealthCheck port. */
                    public port?: (number|null);

                    /** HTTP2HealthCheck portName. */
                    public portName?: (string|null);

                    /** HTTP2HealthCheck portSpecification. */
                    public portSpecification?: (string|null);

                    /** HTTP2HealthCheck proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** HTTP2HealthCheck requestPath. */
                    public requestPath?: (string|null);

                    /** HTTP2HealthCheck response. */
                    public response?: (string|null);

                    /** HTTP2HealthCheck _host. */
                    public _host?: "host";

                    /** HTTP2HealthCheck _port. */
                    public _port?: "port";

                    /** HTTP2HealthCheck _portName. */
                    public _portName?: "portName";

                    /** HTTP2HealthCheck _portSpecification. */
                    public _portSpecification?: "portSpecification";

                    /** HTTP2HealthCheck _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** HTTP2HealthCheck _requestPath. */
                    public _requestPath?: "requestPath";

                    /** HTTP2HealthCheck _response. */
                    public _response?: "response";

                    /**
                     * Creates a new HTTP2HealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HTTP2HealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHTTP2HealthCheck): google.cloud.compute.v1.HTTP2HealthCheck;

                    /**
                     * Encodes the specified HTTP2HealthCheck message. Does not implicitly {@link google.cloud.compute.v1.HTTP2HealthCheck.verify|verify} messages.
                     * @param message HTTP2HealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHTTP2HealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HTTP2HealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HTTP2HealthCheck.verify|verify} messages.
                     * @param message HTTP2HealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHTTP2HealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HTTP2HealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HTTP2HealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HTTP2HealthCheck;

                    /**
                     * Decodes a HTTP2HealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HTTP2HealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HTTP2HealthCheck;

                    /**
                     * Verifies a HTTP2HealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HTTP2HealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HTTP2HealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HTTP2HealthCheck;

                    /**
                     * Creates a plain object from a HTTP2HealthCheck message. Also converts values to other types if specified.
                     * @param message HTTP2HealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HTTP2HealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HTTP2HealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HTTP2HealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HTTP2HealthCheck {

                    /** PortSpecification enum. */
                    enum PortSpecification {
                        UNDEFINED_PORT_SPECIFICATION = 0,
                        USE_FIXED_PORT = 190235748,
                        USE_NAMED_PORT = 349300671,
                        USE_SERVING_PORT = 362637516
                    }

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a HTTPHealthCheck. */
                interface IHTTPHealthCheck {

                    /** HTTPHealthCheck host */
                    host?: (string|null);

                    /** HTTPHealthCheck port */
                    port?: (number|null);

                    /** HTTPHealthCheck portName */
                    portName?: (string|null);

                    /** HTTPHealthCheck portSpecification */
                    portSpecification?: (string|null);

                    /** HTTPHealthCheck proxyHeader */
                    proxyHeader?: (string|null);

                    /** HTTPHealthCheck requestPath */
                    requestPath?: (string|null);

                    /** HTTPHealthCheck response */
                    response?: (string|null);
                }

                /** Represents a HTTPHealthCheck. */
                class HTTPHealthCheck implements IHTTPHealthCheck {

                    /**
                     * Constructs a new HTTPHealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHTTPHealthCheck);

                    /** HTTPHealthCheck host. */
                    public host?: (string|null);

                    /** HTTPHealthCheck port. */
                    public port?: (number|null);

                    /** HTTPHealthCheck portName. */
                    public portName?: (string|null);

                    /** HTTPHealthCheck portSpecification. */
                    public portSpecification?: (string|null);

                    /** HTTPHealthCheck proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** HTTPHealthCheck requestPath. */
                    public requestPath?: (string|null);

                    /** HTTPHealthCheck response. */
                    public response?: (string|null);

                    /** HTTPHealthCheck _host. */
                    public _host?: "host";

                    /** HTTPHealthCheck _port. */
                    public _port?: "port";

                    /** HTTPHealthCheck _portName. */
                    public _portName?: "portName";

                    /** HTTPHealthCheck _portSpecification. */
                    public _portSpecification?: "portSpecification";

                    /** HTTPHealthCheck _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** HTTPHealthCheck _requestPath. */
                    public _requestPath?: "requestPath";

                    /** HTTPHealthCheck _response. */
                    public _response?: "response";

                    /**
                     * Creates a new HTTPHealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HTTPHealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHTTPHealthCheck): google.cloud.compute.v1.HTTPHealthCheck;

                    /**
                     * Encodes the specified HTTPHealthCheck message. Does not implicitly {@link google.cloud.compute.v1.HTTPHealthCheck.verify|verify} messages.
                     * @param message HTTPHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHTTPHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HTTPHealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HTTPHealthCheck.verify|verify} messages.
                     * @param message HTTPHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHTTPHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HTTPHealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HTTPHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HTTPHealthCheck;

                    /**
                     * Decodes a HTTPHealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HTTPHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HTTPHealthCheck;

                    /**
                     * Verifies a HTTPHealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HTTPHealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HTTPHealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HTTPHealthCheck;

                    /**
                     * Creates a plain object from a HTTPHealthCheck message. Also converts values to other types if specified.
                     * @param message HTTPHealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HTTPHealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HTTPHealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HTTPHealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HTTPHealthCheck {

                    /** PortSpecification enum. */
                    enum PortSpecification {
                        UNDEFINED_PORT_SPECIFICATION = 0,
                        USE_FIXED_PORT = 190235748,
                        USE_NAMED_PORT = 349300671,
                        USE_SERVING_PORT = 362637516
                    }

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a HTTPSHealthCheck. */
                interface IHTTPSHealthCheck {

                    /** HTTPSHealthCheck host */
                    host?: (string|null);

                    /** HTTPSHealthCheck port */
                    port?: (number|null);

                    /** HTTPSHealthCheck portName */
                    portName?: (string|null);

                    /** HTTPSHealthCheck portSpecification */
                    portSpecification?: (string|null);

                    /** HTTPSHealthCheck proxyHeader */
                    proxyHeader?: (string|null);

                    /** HTTPSHealthCheck requestPath */
                    requestPath?: (string|null);

                    /** HTTPSHealthCheck response */
                    response?: (string|null);
                }

                /** Represents a HTTPSHealthCheck. */
                class HTTPSHealthCheck implements IHTTPSHealthCheck {

                    /**
                     * Constructs a new HTTPSHealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHTTPSHealthCheck);

                    /** HTTPSHealthCheck host. */
                    public host?: (string|null);

                    /** HTTPSHealthCheck port. */
                    public port?: (number|null);

                    /** HTTPSHealthCheck portName. */
                    public portName?: (string|null);

                    /** HTTPSHealthCheck portSpecification. */
                    public portSpecification?: (string|null);

                    /** HTTPSHealthCheck proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** HTTPSHealthCheck requestPath. */
                    public requestPath?: (string|null);

                    /** HTTPSHealthCheck response. */
                    public response?: (string|null);

                    /** HTTPSHealthCheck _host. */
                    public _host?: "host";

                    /** HTTPSHealthCheck _port. */
                    public _port?: "port";

                    /** HTTPSHealthCheck _portName. */
                    public _portName?: "portName";

                    /** HTTPSHealthCheck _portSpecification. */
                    public _portSpecification?: "portSpecification";

                    /** HTTPSHealthCheck _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** HTTPSHealthCheck _requestPath. */
                    public _requestPath?: "requestPath";

                    /** HTTPSHealthCheck _response. */
                    public _response?: "response";

                    /**
                     * Creates a new HTTPSHealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HTTPSHealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHTTPSHealthCheck): google.cloud.compute.v1.HTTPSHealthCheck;

                    /**
                     * Encodes the specified HTTPSHealthCheck message. Does not implicitly {@link google.cloud.compute.v1.HTTPSHealthCheck.verify|verify} messages.
                     * @param message HTTPSHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHTTPSHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HTTPSHealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HTTPSHealthCheck.verify|verify} messages.
                     * @param message HTTPSHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHTTPSHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HTTPSHealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HTTPSHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HTTPSHealthCheck;

                    /**
                     * Decodes a HTTPSHealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HTTPSHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HTTPSHealthCheck;

                    /**
                     * Verifies a HTTPSHealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HTTPSHealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HTTPSHealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HTTPSHealthCheck;

                    /**
                     * Creates a plain object from a HTTPSHealthCheck message. Also converts values to other types if specified.
                     * @param message HTTPSHealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HTTPSHealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HTTPSHealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HTTPSHealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HTTPSHealthCheck {

                    /** PortSpecification enum. */
                    enum PortSpecification {
                        UNDEFINED_PORT_SPECIFICATION = 0,
                        USE_FIXED_PORT = 190235748,
                        USE_NAMED_PORT = 349300671,
                        USE_SERVING_PORT = 362637516
                    }

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a HealthCheck. */
                interface IHealthCheck {

                    /** HealthCheck checkIntervalSec */
                    checkIntervalSec?: (number|null);

                    /** HealthCheck creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** HealthCheck description */
                    description?: (string|null);

                    /** HealthCheck grpcHealthCheck */
                    grpcHealthCheck?: (google.cloud.compute.v1.IGRPCHealthCheck|null);

                    /** HealthCheck healthyThreshold */
                    healthyThreshold?: (number|null);

                    /** HealthCheck http2HealthCheck */
                    http2HealthCheck?: (google.cloud.compute.v1.IHTTP2HealthCheck|null);

                    /** HealthCheck httpHealthCheck */
                    httpHealthCheck?: (google.cloud.compute.v1.IHTTPHealthCheck|null);

                    /** HealthCheck httpsHealthCheck */
                    httpsHealthCheck?: (google.cloud.compute.v1.IHTTPSHealthCheck|null);

                    /** HealthCheck id */
                    id?: (number|Long|string|null);

                    /** HealthCheck kind */
                    kind?: (string|null);

                    /** HealthCheck logConfig */
                    logConfig?: (google.cloud.compute.v1.IHealthCheckLogConfig|null);

                    /** HealthCheck name */
                    name?: (string|null);

                    /** HealthCheck region */
                    region?: (string|null);

                    /** HealthCheck selfLink */
                    selfLink?: (string|null);

                    /** HealthCheck sslHealthCheck */
                    sslHealthCheck?: (google.cloud.compute.v1.ISSLHealthCheck|null);

                    /** HealthCheck tcpHealthCheck */
                    tcpHealthCheck?: (google.cloud.compute.v1.ITCPHealthCheck|null);

                    /** HealthCheck timeoutSec */
                    timeoutSec?: (number|null);

                    /** HealthCheck type */
                    type?: (string|null);

                    /** HealthCheck unhealthyThreshold */
                    unhealthyThreshold?: (number|null);
                }

                /** Represents a HealthCheck. */
                class HealthCheck implements IHealthCheck {

                    /**
                     * Constructs a new HealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheck);

                    /** HealthCheck checkIntervalSec. */
                    public checkIntervalSec?: (number|null);

                    /** HealthCheck creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** HealthCheck description. */
                    public description?: (string|null);

                    /** HealthCheck grpcHealthCheck. */
                    public grpcHealthCheck?: (google.cloud.compute.v1.IGRPCHealthCheck|null);

                    /** HealthCheck healthyThreshold. */
                    public healthyThreshold?: (number|null);

                    /** HealthCheck http2HealthCheck. */
                    public http2HealthCheck?: (google.cloud.compute.v1.IHTTP2HealthCheck|null);

                    /** HealthCheck httpHealthCheck. */
                    public httpHealthCheck?: (google.cloud.compute.v1.IHTTPHealthCheck|null);

                    /** HealthCheck httpsHealthCheck. */
                    public httpsHealthCheck?: (google.cloud.compute.v1.IHTTPSHealthCheck|null);

                    /** HealthCheck id. */
                    public id?: (number|Long|string|null);

                    /** HealthCheck kind. */
                    public kind?: (string|null);

                    /** HealthCheck logConfig. */
                    public logConfig?: (google.cloud.compute.v1.IHealthCheckLogConfig|null);

                    /** HealthCheck name. */
                    public name?: (string|null);

                    /** HealthCheck region. */
                    public region?: (string|null);

                    /** HealthCheck selfLink. */
                    public selfLink?: (string|null);

                    /** HealthCheck sslHealthCheck. */
                    public sslHealthCheck?: (google.cloud.compute.v1.ISSLHealthCheck|null);

                    /** HealthCheck tcpHealthCheck. */
                    public tcpHealthCheck?: (google.cloud.compute.v1.ITCPHealthCheck|null);

                    /** HealthCheck timeoutSec. */
                    public timeoutSec?: (number|null);

                    /** HealthCheck type. */
                    public type?: (string|null);

                    /** HealthCheck unhealthyThreshold. */
                    public unhealthyThreshold?: (number|null);

                    /** HealthCheck _checkIntervalSec. */
                    public _checkIntervalSec?: "checkIntervalSec";

                    /** HealthCheck _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** HealthCheck _description. */
                    public _description?: "description";

                    /** HealthCheck _grpcHealthCheck. */
                    public _grpcHealthCheck?: "grpcHealthCheck";

                    /** HealthCheck _healthyThreshold. */
                    public _healthyThreshold?: "healthyThreshold";

                    /** HealthCheck _http2HealthCheck. */
                    public _http2HealthCheck?: "http2HealthCheck";

                    /** HealthCheck _httpHealthCheck. */
                    public _httpHealthCheck?: "httpHealthCheck";

                    /** HealthCheck _httpsHealthCheck. */
                    public _httpsHealthCheck?: "httpsHealthCheck";

                    /** HealthCheck _id. */
                    public _id?: "id";

                    /** HealthCheck _kind. */
                    public _kind?: "kind";

                    /** HealthCheck _logConfig. */
                    public _logConfig?: "logConfig";

                    /** HealthCheck _name. */
                    public _name?: "name";

                    /** HealthCheck _region. */
                    public _region?: "region";

                    /** HealthCheck _selfLink. */
                    public _selfLink?: "selfLink";

                    /** HealthCheck _sslHealthCheck. */
                    public _sslHealthCheck?: "sslHealthCheck";

                    /** HealthCheck _tcpHealthCheck. */
                    public _tcpHealthCheck?: "tcpHealthCheck";

                    /** HealthCheck _timeoutSec. */
                    public _timeoutSec?: "timeoutSec";

                    /** HealthCheck _type. */
                    public _type?: "type";

                    /** HealthCheck _unhealthyThreshold. */
                    public _unhealthyThreshold?: "unhealthyThreshold";

                    /**
                     * Creates a new HealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheck): google.cloud.compute.v1.HealthCheck;

                    /**
                     * Encodes the specified HealthCheck message. Does not implicitly {@link google.cloud.compute.v1.HealthCheck.verify|verify} messages.
                     * @param message HealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheck.verify|verify} messages.
                     * @param message HealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheck;

                    /**
                     * Decodes a HealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheck;

                    /**
                     * Verifies a HealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheck;

                    /**
                     * Creates a plain object from a HealthCheck message. Also converts values to other types if specified.
                     * @param message HealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HealthCheck {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        GRPC = 2196510,
                        HTTP = 2228360,
                        HTTP2 = 69079210,
                        HTTPS = 69079243,
                        INVALID = 530283991,
                        SSL = 82412,
                        TCP = 82881
                    }
                }

                /** Properties of a HealthCheckList. */
                interface IHealthCheckList {

                    /** HealthCheckList id */
                    id?: (string|null);

                    /** HealthCheckList items */
                    items?: (google.cloud.compute.v1.IHealthCheck[]|null);

                    /** HealthCheckList kind */
                    kind?: (string|null);

                    /** HealthCheckList nextPageToken */
                    nextPageToken?: (string|null);

                    /** HealthCheckList selfLink */
                    selfLink?: (string|null);

                    /** HealthCheckList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a HealthCheckList. */
                class HealthCheckList implements IHealthCheckList {

                    /**
                     * Constructs a new HealthCheckList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheckList);

                    /** HealthCheckList id. */
                    public id?: (string|null);

                    /** HealthCheckList items. */
                    public items: google.cloud.compute.v1.IHealthCheck[];

                    /** HealthCheckList kind. */
                    public kind?: (string|null);

                    /** HealthCheckList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** HealthCheckList selfLink. */
                    public selfLink?: (string|null);

                    /** HealthCheckList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** HealthCheckList _id. */
                    public _id?: "id";

                    /** HealthCheckList _kind. */
                    public _kind?: "kind";

                    /** HealthCheckList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** HealthCheckList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** HealthCheckList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new HealthCheckList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheckList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheckList): google.cloud.compute.v1.HealthCheckList;

                    /**
                     * Encodes the specified HealthCheckList message. Does not implicitly {@link google.cloud.compute.v1.HealthCheckList.verify|verify} messages.
                     * @param message HealthCheckList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheckList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheckList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheckList.verify|verify} messages.
                     * @param message HealthCheckList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheckList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheckList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheckList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheckList;

                    /**
                     * Decodes a HealthCheckList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheckList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheckList;

                    /**
                     * Verifies a HealthCheckList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheckList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheckList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheckList;

                    /**
                     * Creates a plain object from a HealthCheckList message. Also converts values to other types if specified.
                     * @param message HealthCheckList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheckList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheckList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheckList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthCheckLogConfig. */
                interface IHealthCheckLogConfig {

                    /** HealthCheckLogConfig enable */
                    enable?: (boolean|null);
                }

                /** Represents a HealthCheckLogConfig. */
                class HealthCheckLogConfig implements IHealthCheckLogConfig {

                    /**
                     * Constructs a new HealthCheckLogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheckLogConfig);

                    /** HealthCheckLogConfig enable. */
                    public enable?: (boolean|null);

                    /** HealthCheckLogConfig _enable. */
                    public _enable?: "enable";

                    /**
                     * Creates a new HealthCheckLogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheckLogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheckLogConfig): google.cloud.compute.v1.HealthCheckLogConfig;

                    /**
                     * Encodes the specified HealthCheckLogConfig message. Does not implicitly {@link google.cloud.compute.v1.HealthCheckLogConfig.verify|verify} messages.
                     * @param message HealthCheckLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheckLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheckLogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheckLogConfig.verify|verify} messages.
                     * @param message HealthCheckLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheckLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheckLogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheckLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheckLogConfig;

                    /**
                     * Decodes a HealthCheckLogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheckLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheckLogConfig;

                    /**
                     * Verifies a HealthCheckLogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheckLogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheckLogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheckLogConfig;

                    /**
                     * Creates a plain object from a HealthCheckLogConfig message. Also converts values to other types if specified.
                     * @param message HealthCheckLogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheckLogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheckLogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheckLogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthCheckReference. */
                interface IHealthCheckReference {

                    /** HealthCheckReference healthCheck */
                    healthCheck?: (string|null);
                }

                /** Represents a HealthCheckReference. */
                class HealthCheckReference implements IHealthCheckReference {

                    /**
                     * Constructs a new HealthCheckReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheckReference);

                    /** HealthCheckReference healthCheck. */
                    public healthCheck?: (string|null);

                    /** HealthCheckReference _healthCheck. */
                    public _healthCheck?: "healthCheck";

                    /**
                     * Creates a new HealthCheckReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheckReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheckReference): google.cloud.compute.v1.HealthCheckReference;

                    /**
                     * Encodes the specified HealthCheckReference message. Does not implicitly {@link google.cloud.compute.v1.HealthCheckReference.verify|verify} messages.
                     * @param message HealthCheckReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheckReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheckReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheckReference.verify|verify} messages.
                     * @param message HealthCheckReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheckReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheckReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheckReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheckReference;

                    /**
                     * Decodes a HealthCheckReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheckReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheckReference;

                    /**
                     * Verifies a HealthCheckReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheckReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheckReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheckReference;

                    /**
                     * Creates a plain object from a HealthCheckReference message. Also converts values to other types if specified.
                     * @param message HealthCheckReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheckReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheckReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheckReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthCheckService. */
                interface IHealthCheckService {

                    /** HealthCheckService creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** HealthCheckService description */
                    description?: (string|null);

                    /** HealthCheckService fingerprint */
                    fingerprint?: (string|null);

                    /** HealthCheckService healthChecks */
                    healthChecks?: (string[]|null);

                    /** HealthCheckService healthStatusAggregationPolicy */
                    healthStatusAggregationPolicy?: (string|null);

                    /** HealthCheckService id */
                    id?: (number|Long|string|null);

                    /** HealthCheckService kind */
                    kind?: (string|null);

                    /** HealthCheckService name */
                    name?: (string|null);

                    /** HealthCheckService networkEndpointGroups */
                    networkEndpointGroups?: (string[]|null);

                    /** HealthCheckService notificationEndpoints */
                    notificationEndpoints?: (string[]|null);

                    /** HealthCheckService region */
                    region?: (string|null);

                    /** HealthCheckService selfLink */
                    selfLink?: (string|null);
                }

                /** Represents a HealthCheckService. */
                class HealthCheckService implements IHealthCheckService {

                    /**
                     * Constructs a new HealthCheckService.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheckService);

                    /** HealthCheckService creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** HealthCheckService description. */
                    public description?: (string|null);

                    /** HealthCheckService fingerprint. */
                    public fingerprint?: (string|null);

                    /** HealthCheckService healthChecks. */
                    public healthChecks: string[];

                    /** HealthCheckService healthStatusAggregationPolicy. */
                    public healthStatusAggregationPolicy?: (string|null);

                    /** HealthCheckService id. */
                    public id?: (number|Long|string|null);

                    /** HealthCheckService kind. */
                    public kind?: (string|null);

                    /** HealthCheckService name. */
                    public name?: (string|null);

                    /** HealthCheckService networkEndpointGroups. */
                    public networkEndpointGroups: string[];

                    /** HealthCheckService notificationEndpoints. */
                    public notificationEndpoints: string[];

                    /** HealthCheckService region. */
                    public region?: (string|null);

                    /** HealthCheckService selfLink. */
                    public selfLink?: (string|null);

                    /** HealthCheckService _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** HealthCheckService _description. */
                    public _description?: "description";

                    /** HealthCheckService _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** HealthCheckService _healthStatusAggregationPolicy. */
                    public _healthStatusAggregationPolicy?: "healthStatusAggregationPolicy";

                    /** HealthCheckService _id. */
                    public _id?: "id";

                    /** HealthCheckService _kind. */
                    public _kind?: "kind";

                    /** HealthCheckService _name. */
                    public _name?: "name";

                    /** HealthCheckService _region. */
                    public _region?: "region";

                    /** HealthCheckService _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new HealthCheckService instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheckService instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheckService): google.cloud.compute.v1.HealthCheckService;

                    /**
                     * Encodes the specified HealthCheckService message. Does not implicitly {@link google.cloud.compute.v1.HealthCheckService.verify|verify} messages.
                     * @param message HealthCheckService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheckService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheckService message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheckService.verify|verify} messages.
                     * @param message HealthCheckService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheckService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheckService message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheckService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheckService;

                    /**
                     * Decodes a HealthCheckService message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheckService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheckService;

                    /**
                     * Verifies a HealthCheckService message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheckService message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheckService
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheckService;

                    /**
                     * Creates a plain object from a HealthCheckService message. Also converts values to other types if specified.
                     * @param message HealthCheckService
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheckService, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheckService to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheckService
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HealthCheckService {

                    /** HealthStatusAggregationPolicy enum. */
                    enum HealthStatusAggregationPolicy {
                        UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0,
                        AND = 64951,
                        NO_AGGREGATION = 426445124
                    }
                }

                /** Properties of a HealthCheckServiceReference. */
                interface IHealthCheckServiceReference {

                    /** HealthCheckServiceReference healthCheckService */
                    healthCheckService?: (string|null);
                }

                /** Represents a HealthCheckServiceReference. */
                class HealthCheckServiceReference implements IHealthCheckServiceReference {

                    /**
                     * Constructs a new HealthCheckServiceReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheckServiceReference);

                    /** HealthCheckServiceReference healthCheckService. */
                    public healthCheckService?: (string|null);

                    /** HealthCheckServiceReference _healthCheckService. */
                    public _healthCheckService?: "healthCheckService";

                    /**
                     * Creates a new HealthCheckServiceReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheckServiceReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheckServiceReference): google.cloud.compute.v1.HealthCheckServiceReference;

                    /**
                     * Encodes the specified HealthCheckServiceReference message. Does not implicitly {@link google.cloud.compute.v1.HealthCheckServiceReference.verify|verify} messages.
                     * @param message HealthCheckServiceReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheckServiceReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheckServiceReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheckServiceReference.verify|verify} messages.
                     * @param message HealthCheckServiceReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheckServiceReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheckServiceReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheckServiceReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheckServiceReference;

                    /**
                     * Decodes a HealthCheckServiceReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheckServiceReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheckServiceReference;

                    /**
                     * Verifies a HealthCheckServiceReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheckServiceReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheckServiceReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheckServiceReference;

                    /**
                     * Creates a plain object from a HealthCheckServiceReference message. Also converts values to other types if specified.
                     * @param message HealthCheckServiceReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheckServiceReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheckServiceReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheckServiceReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthCheckServicesList. */
                interface IHealthCheckServicesList {

                    /** HealthCheckServicesList id */
                    id?: (string|null);

                    /** HealthCheckServicesList items */
                    items?: (google.cloud.compute.v1.IHealthCheckService[]|null);

                    /** HealthCheckServicesList kind */
                    kind?: (string|null);

                    /** HealthCheckServicesList nextPageToken */
                    nextPageToken?: (string|null);

                    /** HealthCheckServicesList selfLink */
                    selfLink?: (string|null);

                    /** HealthCheckServicesList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a HealthCheckServicesList. */
                class HealthCheckServicesList implements IHealthCheckServicesList {

                    /**
                     * Constructs a new HealthCheckServicesList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthCheckServicesList);

                    /** HealthCheckServicesList id. */
                    public id?: (string|null);

                    /** HealthCheckServicesList items. */
                    public items: google.cloud.compute.v1.IHealthCheckService[];

                    /** HealthCheckServicesList kind. */
                    public kind?: (string|null);

                    /** HealthCheckServicesList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** HealthCheckServicesList selfLink. */
                    public selfLink?: (string|null);

                    /** HealthCheckServicesList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** HealthCheckServicesList _id. */
                    public _id?: "id";

                    /** HealthCheckServicesList _kind. */
                    public _kind?: "kind";

                    /** HealthCheckServicesList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** HealthCheckServicesList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** HealthCheckServicesList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new HealthCheckServicesList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthCheckServicesList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthCheckServicesList): google.cloud.compute.v1.HealthCheckServicesList;

                    /**
                     * Encodes the specified HealthCheckServicesList message. Does not implicitly {@link google.cloud.compute.v1.HealthCheckServicesList.verify|verify} messages.
                     * @param message HealthCheckServicesList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthCheckServicesList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthCheckServicesList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthCheckServicesList.verify|verify} messages.
                     * @param message HealthCheckServicesList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthCheckServicesList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthCheckServicesList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthCheckServicesList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthCheckServicesList;

                    /**
                     * Decodes a HealthCheckServicesList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthCheckServicesList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthCheckServicesList;

                    /**
                     * Verifies a HealthCheckServicesList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthCheckServicesList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthCheckServicesList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthCheckServicesList;

                    /**
                     * Creates a plain object from a HealthCheckServicesList message. Also converts values to other types if specified.
                     * @param message HealthCheckServicesList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthCheckServicesList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthCheckServicesList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthCheckServicesList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthChecksAggregatedList. */
                interface IHealthChecksAggregatedList {

                    /** HealthChecksAggregatedList id */
                    id?: (string|null);

                    /** HealthChecksAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IHealthChecksScopedList }|null);

                    /** HealthChecksAggregatedList kind */
                    kind?: (string|null);

                    /** HealthChecksAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** HealthChecksAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** HealthChecksAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** HealthChecksAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a HealthChecksAggregatedList. */
                class HealthChecksAggregatedList implements IHealthChecksAggregatedList {

                    /**
                     * Constructs a new HealthChecksAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthChecksAggregatedList);

                    /** HealthChecksAggregatedList id. */
                    public id?: (string|null);

                    /** HealthChecksAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IHealthChecksScopedList };

                    /** HealthChecksAggregatedList kind. */
                    public kind?: (string|null);

                    /** HealthChecksAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** HealthChecksAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** HealthChecksAggregatedList unreachables. */
                    public unreachables: string[];

                    /** HealthChecksAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** HealthChecksAggregatedList _id. */
                    public _id?: "id";

                    /** HealthChecksAggregatedList _kind. */
                    public _kind?: "kind";

                    /** HealthChecksAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** HealthChecksAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** HealthChecksAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new HealthChecksAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthChecksAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthChecksAggregatedList): google.cloud.compute.v1.HealthChecksAggregatedList;

                    /**
                     * Encodes the specified HealthChecksAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.HealthChecksAggregatedList.verify|verify} messages.
                     * @param message HealthChecksAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthChecksAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthChecksAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthChecksAggregatedList.verify|verify} messages.
                     * @param message HealthChecksAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthChecksAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthChecksAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthChecksAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthChecksAggregatedList;

                    /**
                     * Decodes a HealthChecksAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthChecksAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthChecksAggregatedList;

                    /**
                     * Verifies a HealthChecksAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthChecksAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthChecksAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthChecksAggregatedList;

                    /**
                     * Creates a plain object from a HealthChecksAggregatedList message. Also converts values to other types if specified.
                     * @param message HealthChecksAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthChecksAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthChecksAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthChecksAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthChecksScopedList. */
                interface IHealthChecksScopedList {

                    /** HealthChecksScopedList healthChecks */
                    healthChecks?: (google.cloud.compute.v1.IHealthCheck[]|null);

                    /** HealthChecksScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a HealthChecksScopedList. */
                class HealthChecksScopedList implements IHealthChecksScopedList {

                    /**
                     * Constructs a new HealthChecksScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthChecksScopedList);

                    /** HealthChecksScopedList healthChecks. */
                    public healthChecks: google.cloud.compute.v1.IHealthCheck[];

                    /** HealthChecksScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** HealthChecksScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new HealthChecksScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthChecksScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthChecksScopedList): google.cloud.compute.v1.HealthChecksScopedList;

                    /**
                     * Encodes the specified HealthChecksScopedList message. Does not implicitly {@link google.cloud.compute.v1.HealthChecksScopedList.verify|verify} messages.
                     * @param message HealthChecksScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthChecksScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthChecksScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthChecksScopedList.verify|verify} messages.
                     * @param message HealthChecksScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthChecksScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthChecksScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthChecksScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthChecksScopedList;

                    /**
                     * Decodes a HealthChecksScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthChecksScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthChecksScopedList;

                    /**
                     * Verifies a HealthChecksScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthChecksScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthChecksScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthChecksScopedList;

                    /**
                     * Creates a plain object from a HealthChecksScopedList message. Also converts values to other types if specified.
                     * @param message HealthChecksScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthChecksScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthChecksScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthChecksScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HealthStatus. */
                interface IHealthStatus {

                    /** HealthStatus annotations */
                    annotations?: ({ [k: string]: string }|null);

                    /** HealthStatus forwardingRule */
                    forwardingRule?: (string|null);

                    /** HealthStatus forwardingRuleIp */
                    forwardingRuleIp?: (string|null);

                    /** HealthStatus healthState */
                    healthState?: (string|null);

                    /** HealthStatus instance */
                    instance?: (string|null);

                    /** HealthStatus ipAddress */
                    ipAddress?: (string|null);

                    /** HealthStatus port */
                    port?: (number|null);

                    /** HealthStatus weight */
                    weight?: (string|null);

                    /** HealthStatus weightError */
                    weightError?: (string|null);
                }

                /** Represents a HealthStatus. */
                class HealthStatus implements IHealthStatus {

                    /**
                     * Constructs a new HealthStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthStatus);

                    /** HealthStatus annotations. */
                    public annotations: { [k: string]: string };

                    /** HealthStatus forwardingRule. */
                    public forwardingRule?: (string|null);

                    /** HealthStatus forwardingRuleIp. */
                    public forwardingRuleIp?: (string|null);

                    /** HealthStatus healthState. */
                    public healthState?: (string|null);

                    /** HealthStatus instance. */
                    public instance?: (string|null);

                    /** HealthStatus ipAddress. */
                    public ipAddress?: (string|null);

                    /** HealthStatus port. */
                    public port?: (number|null);

                    /** HealthStatus weight. */
                    public weight?: (string|null);

                    /** HealthStatus weightError. */
                    public weightError?: (string|null);

                    /** HealthStatus _forwardingRule. */
                    public _forwardingRule?: "forwardingRule";

                    /** HealthStatus _forwardingRuleIp. */
                    public _forwardingRuleIp?: "forwardingRuleIp";

                    /** HealthStatus _healthState. */
                    public _healthState?: "healthState";

                    /** HealthStatus _instance. */
                    public _instance?: "instance";

                    /** HealthStatus _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /** HealthStatus _port. */
                    public _port?: "port";

                    /** HealthStatus _weight. */
                    public _weight?: "weight";

                    /** HealthStatus _weightError. */
                    public _weightError?: "weightError";

                    /**
                     * Creates a new HealthStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthStatus): google.cloud.compute.v1.HealthStatus;

                    /**
                     * Encodes the specified HealthStatus message. Does not implicitly {@link google.cloud.compute.v1.HealthStatus.verify|verify} messages.
                     * @param message HealthStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthStatus.verify|verify} messages.
                     * @param message HealthStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthStatus;

                    /**
                     * Decodes a HealthStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthStatus;

                    /**
                     * Verifies a HealthStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthStatus;

                    /**
                     * Creates a plain object from a HealthStatus message. Also converts values to other types if specified.
                     * @param message HealthStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HealthStatus {

                    /** HealthState enum. */
                    enum HealthState {
                        UNDEFINED_HEALTH_STATE = 0,
                        HEALTHY = 439801213,
                        UNHEALTHY = 462118084
                    }

                    /** WeightError enum. */
                    enum WeightError {
                        UNDEFINED_WEIGHT_ERROR = 0,
                        INVALID_WEIGHT = 383698400,
                        MISSING_WEIGHT = 384027537,
                        UNAVAILABLE_WEIGHT = 439464295,
                        WEIGHT_NONE = 502428831
                    }
                }

                /** Properties of a HealthStatusForNetworkEndpoint. */
                interface IHealthStatusForNetworkEndpoint {

                    /** HealthStatusForNetworkEndpoint backendService */
                    backendService?: (google.cloud.compute.v1.IBackendServiceReference|null);

                    /** HealthStatusForNetworkEndpoint forwardingRule */
                    forwardingRule?: (google.cloud.compute.v1.IForwardingRuleReference|null);

                    /** HealthStatusForNetworkEndpoint healthCheck */
                    healthCheck?: (google.cloud.compute.v1.IHealthCheckReference|null);

                    /** HealthStatusForNetworkEndpoint healthCheckService */
                    healthCheckService?: (google.cloud.compute.v1.IHealthCheckServiceReference|null);

                    /** HealthStatusForNetworkEndpoint healthState */
                    healthState?: (string|null);
                }

                /** Represents a HealthStatusForNetworkEndpoint. */
                class HealthStatusForNetworkEndpoint implements IHealthStatusForNetworkEndpoint {

                    /**
                     * Constructs a new HealthStatusForNetworkEndpoint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHealthStatusForNetworkEndpoint);

                    /** HealthStatusForNetworkEndpoint backendService. */
                    public backendService?: (google.cloud.compute.v1.IBackendServiceReference|null);

                    /** HealthStatusForNetworkEndpoint forwardingRule. */
                    public forwardingRule?: (google.cloud.compute.v1.IForwardingRuleReference|null);

                    /** HealthStatusForNetworkEndpoint healthCheck. */
                    public healthCheck?: (google.cloud.compute.v1.IHealthCheckReference|null);

                    /** HealthStatusForNetworkEndpoint healthCheckService. */
                    public healthCheckService?: (google.cloud.compute.v1.IHealthCheckServiceReference|null);

                    /** HealthStatusForNetworkEndpoint healthState. */
                    public healthState?: (string|null);

                    /** HealthStatusForNetworkEndpoint _backendService. */
                    public _backendService?: "backendService";

                    /** HealthStatusForNetworkEndpoint _forwardingRule. */
                    public _forwardingRule?: "forwardingRule";

                    /** HealthStatusForNetworkEndpoint _healthCheck. */
                    public _healthCheck?: "healthCheck";

                    /** HealthStatusForNetworkEndpoint _healthCheckService. */
                    public _healthCheckService?: "healthCheckService";

                    /** HealthStatusForNetworkEndpoint _healthState. */
                    public _healthState?: "healthState";

                    /**
                     * Creates a new HealthStatusForNetworkEndpoint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HealthStatusForNetworkEndpoint instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHealthStatusForNetworkEndpoint): google.cloud.compute.v1.HealthStatusForNetworkEndpoint;

                    /**
                     * Encodes the specified HealthStatusForNetworkEndpoint message. Does not implicitly {@link google.cloud.compute.v1.HealthStatusForNetworkEndpoint.verify|verify} messages.
                     * @param message HealthStatusForNetworkEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHealthStatusForNetworkEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HealthStatusForNetworkEndpoint message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HealthStatusForNetworkEndpoint.verify|verify} messages.
                     * @param message HealthStatusForNetworkEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHealthStatusForNetworkEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HealthStatusForNetworkEndpoint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HealthStatusForNetworkEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HealthStatusForNetworkEndpoint;

                    /**
                     * Decodes a HealthStatusForNetworkEndpoint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HealthStatusForNetworkEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HealthStatusForNetworkEndpoint;

                    /**
                     * Verifies a HealthStatusForNetworkEndpoint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HealthStatusForNetworkEndpoint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HealthStatusForNetworkEndpoint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HealthStatusForNetworkEndpoint;

                    /**
                     * Creates a plain object from a HealthStatusForNetworkEndpoint message. Also converts values to other types if specified.
                     * @param message HealthStatusForNetworkEndpoint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HealthStatusForNetworkEndpoint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HealthStatusForNetworkEndpoint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HealthStatusForNetworkEndpoint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HealthStatusForNetworkEndpoint {

                    /** HealthState enum. */
                    enum HealthState {
                        UNDEFINED_HEALTH_STATE = 0,
                        DRAINING = 480455402,
                        HEALTHY = 439801213,
                        UNHEALTHY = 462118084,
                        UNKNOWN = 433141802
                    }
                }

                /** Properties of a Help. */
                interface IHelp {

                    /** Help links */
                    links?: (google.cloud.compute.v1.IHelpLink[]|null);
                }

                /** Represents a Help. */
                class Help implements IHelp {

                    /**
                     * Constructs a new Help.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHelp);

                    /** Help links. */
                    public links: google.cloud.compute.v1.IHelpLink[];

                    /**
                     * Creates a new Help instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Help instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHelp): google.cloud.compute.v1.Help;

                    /**
                     * Encodes the specified Help message. Does not implicitly {@link google.cloud.compute.v1.Help.verify|verify} messages.
                     * @param message Help message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHelp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Help message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Help.verify|verify} messages.
                     * @param message Help message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHelp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Help message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Help
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Help;

                    /**
                     * Decodes a Help message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Help
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Help;

                    /**
                     * Verifies a Help message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Help message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Help
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Help;

                    /**
                     * Creates a plain object from a Help message. Also converts values to other types if specified.
                     * @param message Help
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Help, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Help to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Help
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HelpLink. */
                interface IHelpLink {

                    /** HelpLink description */
                    description?: (string|null);

                    /** HelpLink url */
                    url?: (string|null);
                }

                /** Represents a HelpLink. */
                class HelpLink implements IHelpLink {

                    /**
                     * Constructs a new HelpLink.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHelpLink);

                    /** HelpLink description. */
                    public description?: (string|null);

                    /** HelpLink url. */
                    public url?: (string|null);

                    /** HelpLink _description. */
                    public _description?: "description";

                    /** HelpLink _url. */
                    public _url?: "url";

                    /**
                     * Creates a new HelpLink instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HelpLink instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHelpLink): google.cloud.compute.v1.HelpLink;

                    /**
                     * Encodes the specified HelpLink message. Does not implicitly {@link google.cloud.compute.v1.HelpLink.verify|verify} messages.
                     * @param message HelpLink message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHelpLink, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HelpLink message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HelpLink.verify|verify} messages.
                     * @param message HelpLink message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHelpLink, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HelpLink message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HelpLink
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HelpLink;

                    /**
                     * Decodes a HelpLink message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HelpLink
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HelpLink;

                    /**
                     * Verifies a HelpLink message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HelpLink message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HelpLink
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HelpLink;

                    /**
                     * Creates a plain object from a HelpLink message. Also converts values to other types if specified.
                     * @param message HelpLink
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HelpLink, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HelpLink to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HelpLink
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HostRule. */
                interface IHostRule {

                    /** HostRule description */
                    description?: (string|null);

                    /** HostRule hosts */
                    hosts?: (string[]|null);

                    /** HostRule pathMatcher */
                    pathMatcher?: (string|null);
                }

                /** Represents a HostRule. */
                class HostRule implements IHostRule {

                    /**
                     * Constructs a new HostRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHostRule);

                    /** HostRule description. */
                    public description?: (string|null);

                    /** HostRule hosts. */
                    public hosts: string[];

                    /** HostRule pathMatcher. */
                    public pathMatcher?: (string|null);

                    /** HostRule _description. */
                    public _description?: "description";

                    /** HostRule _pathMatcher. */
                    public _pathMatcher?: "pathMatcher";

                    /**
                     * Creates a new HostRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HostRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHostRule): google.cloud.compute.v1.HostRule;

                    /**
                     * Encodes the specified HostRule message. Does not implicitly {@link google.cloud.compute.v1.HostRule.verify|verify} messages.
                     * @param message HostRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHostRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HostRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HostRule.verify|verify} messages.
                     * @param message HostRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHostRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HostRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HostRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HostRule;

                    /**
                     * Decodes a HostRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HostRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HostRule;

                    /**
                     * Verifies a HostRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HostRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HostRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HostRule;

                    /**
                     * Creates a plain object from a HostRule message. Also converts values to other types if specified.
                     * @param message HostRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HostRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HostRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HostRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpFaultAbort. */
                interface IHttpFaultAbort {

                    /** HttpFaultAbort httpStatus */
                    httpStatus?: (number|null);

                    /** HttpFaultAbort percentage */
                    percentage?: (number|null);
                }

                /** Represents a HttpFaultAbort. */
                class HttpFaultAbort implements IHttpFaultAbort {

                    /**
                     * Constructs a new HttpFaultAbort.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpFaultAbort);

                    /** HttpFaultAbort httpStatus. */
                    public httpStatus?: (number|null);

                    /** HttpFaultAbort percentage. */
                    public percentage?: (number|null);

                    /** HttpFaultAbort _httpStatus. */
                    public _httpStatus?: "httpStatus";

                    /** HttpFaultAbort _percentage. */
                    public _percentage?: "percentage";

                    /**
                     * Creates a new HttpFaultAbort instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpFaultAbort instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpFaultAbort): google.cloud.compute.v1.HttpFaultAbort;

                    /**
                     * Encodes the specified HttpFaultAbort message. Does not implicitly {@link google.cloud.compute.v1.HttpFaultAbort.verify|verify} messages.
                     * @param message HttpFaultAbort message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpFaultAbort, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpFaultAbort message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpFaultAbort.verify|verify} messages.
                     * @param message HttpFaultAbort message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpFaultAbort, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpFaultAbort message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpFaultAbort
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpFaultAbort;

                    /**
                     * Decodes a HttpFaultAbort message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpFaultAbort
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpFaultAbort;

                    /**
                     * Verifies a HttpFaultAbort message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpFaultAbort message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpFaultAbort
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpFaultAbort;

                    /**
                     * Creates a plain object from a HttpFaultAbort message. Also converts values to other types if specified.
                     * @param message HttpFaultAbort
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpFaultAbort, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpFaultAbort to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpFaultAbort
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpFaultDelay. */
                interface IHttpFaultDelay {

                    /** HttpFaultDelay fixedDelay */
                    fixedDelay?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpFaultDelay percentage */
                    percentage?: (number|null);
                }

                /** Represents a HttpFaultDelay. */
                class HttpFaultDelay implements IHttpFaultDelay {

                    /**
                     * Constructs a new HttpFaultDelay.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpFaultDelay);

                    /** HttpFaultDelay fixedDelay. */
                    public fixedDelay?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpFaultDelay percentage. */
                    public percentage?: (number|null);

                    /** HttpFaultDelay _fixedDelay. */
                    public _fixedDelay?: "fixedDelay";

                    /** HttpFaultDelay _percentage. */
                    public _percentage?: "percentage";

                    /**
                     * Creates a new HttpFaultDelay instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpFaultDelay instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpFaultDelay): google.cloud.compute.v1.HttpFaultDelay;

                    /**
                     * Encodes the specified HttpFaultDelay message. Does not implicitly {@link google.cloud.compute.v1.HttpFaultDelay.verify|verify} messages.
                     * @param message HttpFaultDelay message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpFaultDelay, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpFaultDelay message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpFaultDelay.verify|verify} messages.
                     * @param message HttpFaultDelay message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpFaultDelay, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpFaultDelay message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpFaultDelay
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpFaultDelay;

                    /**
                     * Decodes a HttpFaultDelay message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpFaultDelay
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpFaultDelay;

                    /**
                     * Verifies a HttpFaultDelay message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpFaultDelay message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpFaultDelay
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpFaultDelay;

                    /**
                     * Creates a plain object from a HttpFaultDelay message. Also converts values to other types if specified.
                     * @param message HttpFaultDelay
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpFaultDelay, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpFaultDelay to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpFaultDelay
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpFaultInjection. */
                interface IHttpFaultInjection {

                    /** HttpFaultInjection abort */
                    abort?: (google.cloud.compute.v1.IHttpFaultAbort|null);

                    /** HttpFaultInjection delay */
                    delay?: (google.cloud.compute.v1.IHttpFaultDelay|null);
                }

                /** Represents a HttpFaultInjection. */
                class HttpFaultInjection implements IHttpFaultInjection {

                    /**
                     * Constructs a new HttpFaultInjection.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpFaultInjection);

                    /** HttpFaultInjection abort. */
                    public abort?: (google.cloud.compute.v1.IHttpFaultAbort|null);

                    /** HttpFaultInjection delay. */
                    public delay?: (google.cloud.compute.v1.IHttpFaultDelay|null);

                    /** HttpFaultInjection _abort. */
                    public _abort?: "abort";

                    /** HttpFaultInjection _delay. */
                    public _delay?: "delay";

                    /**
                     * Creates a new HttpFaultInjection instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpFaultInjection instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpFaultInjection): google.cloud.compute.v1.HttpFaultInjection;

                    /**
                     * Encodes the specified HttpFaultInjection message. Does not implicitly {@link google.cloud.compute.v1.HttpFaultInjection.verify|verify} messages.
                     * @param message HttpFaultInjection message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpFaultInjection, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpFaultInjection message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpFaultInjection.verify|verify} messages.
                     * @param message HttpFaultInjection message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpFaultInjection, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpFaultInjection message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpFaultInjection
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpFaultInjection;

                    /**
                     * Decodes a HttpFaultInjection message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpFaultInjection
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpFaultInjection;

                    /**
                     * Verifies a HttpFaultInjection message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpFaultInjection message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpFaultInjection
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpFaultInjection;

                    /**
                     * Creates a plain object from a HttpFaultInjection message. Also converts values to other types if specified.
                     * @param message HttpFaultInjection
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpFaultInjection, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpFaultInjection to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpFaultInjection
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpHeaderAction. */
                interface IHttpHeaderAction {

                    /** HttpHeaderAction requestHeadersToAdd */
                    requestHeadersToAdd?: (google.cloud.compute.v1.IHttpHeaderOption[]|null);

                    /** HttpHeaderAction requestHeadersToRemove */
                    requestHeadersToRemove?: (string[]|null);

                    /** HttpHeaderAction responseHeadersToAdd */
                    responseHeadersToAdd?: (google.cloud.compute.v1.IHttpHeaderOption[]|null);

                    /** HttpHeaderAction responseHeadersToRemove */
                    responseHeadersToRemove?: (string[]|null);
                }

                /** Represents a HttpHeaderAction. */
                class HttpHeaderAction implements IHttpHeaderAction {

                    /**
                     * Constructs a new HttpHeaderAction.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpHeaderAction);

                    /** HttpHeaderAction requestHeadersToAdd. */
                    public requestHeadersToAdd: google.cloud.compute.v1.IHttpHeaderOption[];

                    /** HttpHeaderAction requestHeadersToRemove. */
                    public requestHeadersToRemove: string[];

                    /** HttpHeaderAction responseHeadersToAdd. */
                    public responseHeadersToAdd: google.cloud.compute.v1.IHttpHeaderOption[];

                    /** HttpHeaderAction responseHeadersToRemove. */
                    public responseHeadersToRemove: string[];

                    /**
                     * Creates a new HttpHeaderAction instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpHeaderAction instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpHeaderAction): google.cloud.compute.v1.HttpHeaderAction;

                    /**
                     * Encodes the specified HttpHeaderAction message. Does not implicitly {@link google.cloud.compute.v1.HttpHeaderAction.verify|verify} messages.
                     * @param message HttpHeaderAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpHeaderAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpHeaderAction message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpHeaderAction.verify|verify} messages.
                     * @param message HttpHeaderAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpHeaderAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpHeaderAction message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpHeaderAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpHeaderAction;

                    /**
                     * Decodes a HttpHeaderAction message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpHeaderAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpHeaderAction;

                    /**
                     * Verifies a HttpHeaderAction message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpHeaderAction message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpHeaderAction
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpHeaderAction;

                    /**
                     * Creates a plain object from a HttpHeaderAction message. Also converts values to other types if specified.
                     * @param message HttpHeaderAction
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpHeaderAction, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpHeaderAction to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpHeaderAction
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpHeaderMatch. */
                interface IHttpHeaderMatch {

                    /** HttpHeaderMatch exactMatch */
                    exactMatch?: (string|null);

                    /** HttpHeaderMatch headerName */
                    headerName?: (string|null);

                    /** HttpHeaderMatch invertMatch */
                    invertMatch?: (boolean|null);

                    /** HttpHeaderMatch prefixMatch */
                    prefixMatch?: (string|null);

                    /** HttpHeaderMatch presentMatch */
                    presentMatch?: (boolean|null);

                    /** HttpHeaderMatch rangeMatch */
                    rangeMatch?: (google.cloud.compute.v1.IInt64RangeMatch|null);

                    /** HttpHeaderMatch regexMatch */
                    regexMatch?: (string|null);

                    /** HttpHeaderMatch suffixMatch */
                    suffixMatch?: (string|null);
                }

                /** Represents a HttpHeaderMatch. */
                class HttpHeaderMatch implements IHttpHeaderMatch {

                    /**
                     * Constructs a new HttpHeaderMatch.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpHeaderMatch);

                    /** HttpHeaderMatch exactMatch. */
                    public exactMatch?: (string|null);

                    /** HttpHeaderMatch headerName. */
                    public headerName?: (string|null);

                    /** HttpHeaderMatch invertMatch. */
                    public invertMatch?: (boolean|null);

                    /** HttpHeaderMatch prefixMatch. */
                    public prefixMatch?: (string|null);

                    /** HttpHeaderMatch presentMatch. */
                    public presentMatch?: (boolean|null);

                    /** HttpHeaderMatch rangeMatch. */
                    public rangeMatch?: (google.cloud.compute.v1.IInt64RangeMatch|null);

                    /** HttpHeaderMatch regexMatch. */
                    public regexMatch?: (string|null);

                    /** HttpHeaderMatch suffixMatch. */
                    public suffixMatch?: (string|null);

                    /** HttpHeaderMatch _exactMatch. */
                    public _exactMatch?: "exactMatch";

                    /** HttpHeaderMatch _headerName. */
                    public _headerName?: "headerName";

                    /** HttpHeaderMatch _invertMatch. */
                    public _invertMatch?: "invertMatch";

                    /** HttpHeaderMatch _prefixMatch. */
                    public _prefixMatch?: "prefixMatch";

                    /** HttpHeaderMatch _presentMatch. */
                    public _presentMatch?: "presentMatch";

                    /** HttpHeaderMatch _rangeMatch. */
                    public _rangeMatch?: "rangeMatch";

                    /** HttpHeaderMatch _regexMatch. */
                    public _regexMatch?: "regexMatch";

                    /** HttpHeaderMatch _suffixMatch. */
                    public _suffixMatch?: "suffixMatch";

                    /**
                     * Creates a new HttpHeaderMatch instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpHeaderMatch instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpHeaderMatch): google.cloud.compute.v1.HttpHeaderMatch;

                    /**
                     * Encodes the specified HttpHeaderMatch message. Does not implicitly {@link google.cloud.compute.v1.HttpHeaderMatch.verify|verify} messages.
                     * @param message HttpHeaderMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpHeaderMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpHeaderMatch message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpHeaderMatch.verify|verify} messages.
                     * @param message HttpHeaderMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpHeaderMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpHeaderMatch message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpHeaderMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpHeaderMatch;

                    /**
                     * Decodes a HttpHeaderMatch message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpHeaderMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpHeaderMatch;

                    /**
                     * Verifies a HttpHeaderMatch message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpHeaderMatch message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpHeaderMatch
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpHeaderMatch;

                    /**
                     * Creates a plain object from a HttpHeaderMatch message. Also converts values to other types if specified.
                     * @param message HttpHeaderMatch
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpHeaderMatch, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpHeaderMatch to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpHeaderMatch
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpHeaderOption. */
                interface IHttpHeaderOption {

                    /** HttpHeaderOption headerName */
                    headerName?: (string|null);

                    /** HttpHeaderOption headerValue */
                    headerValue?: (string|null);

                    /** HttpHeaderOption replace */
                    replace?: (boolean|null);
                }

                /** Represents a HttpHeaderOption. */
                class HttpHeaderOption implements IHttpHeaderOption {

                    /**
                     * Constructs a new HttpHeaderOption.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpHeaderOption);

                    /** HttpHeaderOption headerName. */
                    public headerName?: (string|null);

                    /** HttpHeaderOption headerValue. */
                    public headerValue?: (string|null);

                    /** HttpHeaderOption replace. */
                    public replace?: (boolean|null);

                    /** HttpHeaderOption _headerName. */
                    public _headerName?: "headerName";

                    /** HttpHeaderOption _headerValue. */
                    public _headerValue?: "headerValue";

                    /** HttpHeaderOption _replace. */
                    public _replace?: "replace";

                    /**
                     * Creates a new HttpHeaderOption instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpHeaderOption instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpHeaderOption): google.cloud.compute.v1.HttpHeaderOption;

                    /**
                     * Encodes the specified HttpHeaderOption message. Does not implicitly {@link google.cloud.compute.v1.HttpHeaderOption.verify|verify} messages.
                     * @param message HttpHeaderOption message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpHeaderOption, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpHeaderOption message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpHeaderOption.verify|verify} messages.
                     * @param message HttpHeaderOption message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpHeaderOption, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpHeaderOption message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpHeaderOption
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpHeaderOption;

                    /**
                     * Decodes a HttpHeaderOption message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpHeaderOption
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpHeaderOption;

                    /**
                     * Verifies a HttpHeaderOption message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpHeaderOption message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpHeaderOption
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpHeaderOption;

                    /**
                     * Creates a plain object from a HttpHeaderOption message. Also converts values to other types if specified.
                     * @param message HttpHeaderOption
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpHeaderOption, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpHeaderOption to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpHeaderOption
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpQueryParameterMatch. */
                interface IHttpQueryParameterMatch {

                    /** HttpQueryParameterMatch exactMatch */
                    exactMatch?: (string|null);

                    /** HttpQueryParameterMatch name */
                    name?: (string|null);

                    /** HttpQueryParameterMatch presentMatch */
                    presentMatch?: (boolean|null);

                    /** HttpQueryParameterMatch regexMatch */
                    regexMatch?: (string|null);
                }

                /** Represents a HttpQueryParameterMatch. */
                class HttpQueryParameterMatch implements IHttpQueryParameterMatch {

                    /**
                     * Constructs a new HttpQueryParameterMatch.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpQueryParameterMatch);

                    /** HttpQueryParameterMatch exactMatch. */
                    public exactMatch?: (string|null);

                    /** HttpQueryParameterMatch name. */
                    public name?: (string|null);

                    /** HttpQueryParameterMatch presentMatch. */
                    public presentMatch?: (boolean|null);

                    /** HttpQueryParameterMatch regexMatch. */
                    public regexMatch?: (string|null);

                    /** HttpQueryParameterMatch _exactMatch. */
                    public _exactMatch?: "exactMatch";

                    /** HttpQueryParameterMatch _name. */
                    public _name?: "name";

                    /** HttpQueryParameterMatch _presentMatch. */
                    public _presentMatch?: "presentMatch";

                    /** HttpQueryParameterMatch _regexMatch. */
                    public _regexMatch?: "regexMatch";

                    /**
                     * Creates a new HttpQueryParameterMatch instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpQueryParameterMatch instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpQueryParameterMatch): google.cloud.compute.v1.HttpQueryParameterMatch;

                    /**
                     * Encodes the specified HttpQueryParameterMatch message. Does not implicitly {@link google.cloud.compute.v1.HttpQueryParameterMatch.verify|verify} messages.
                     * @param message HttpQueryParameterMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpQueryParameterMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpQueryParameterMatch message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpQueryParameterMatch.verify|verify} messages.
                     * @param message HttpQueryParameterMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpQueryParameterMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpQueryParameterMatch message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpQueryParameterMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpQueryParameterMatch;

                    /**
                     * Decodes a HttpQueryParameterMatch message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpQueryParameterMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpQueryParameterMatch;

                    /**
                     * Verifies a HttpQueryParameterMatch message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpQueryParameterMatch message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpQueryParameterMatch
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpQueryParameterMatch;

                    /**
                     * Creates a plain object from a HttpQueryParameterMatch message. Also converts values to other types if specified.
                     * @param message HttpQueryParameterMatch
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpQueryParameterMatch, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpQueryParameterMatch to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpQueryParameterMatch
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpRedirectAction. */
                interface IHttpRedirectAction {

                    /** HttpRedirectAction hostRedirect */
                    hostRedirect?: (string|null);

                    /** HttpRedirectAction httpsRedirect */
                    httpsRedirect?: (boolean|null);

                    /** HttpRedirectAction pathRedirect */
                    pathRedirect?: (string|null);

                    /** HttpRedirectAction prefixRedirect */
                    prefixRedirect?: (string|null);

                    /** HttpRedirectAction redirectResponseCode */
                    redirectResponseCode?: (string|null);

                    /** HttpRedirectAction stripQuery */
                    stripQuery?: (boolean|null);
                }

                /** Represents a HttpRedirectAction. */
                class HttpRedirectAction implements IHttpRedirectAction {

                    /**
                     * Constructs a new HttpRedirectAction.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpRedirectAction);

                    /** HttpRedirectAction hostRedirect. */
                    public hostRedirect?: (string|null);

                    /** HttpRedirectAction httpsRedirect. */
                    public httpsRedirect?: (boolean|null);

                    /** HttpRedirectAction pathRedirect. */
                    public pathRedirect?: (string|null);

                    /** HttpRedirectAction prefixRedirect. */
                    public prefixRedirect?: (string|null);

                    /** HttpRedirectAction redirectResponseCode. */
                    public redirectResponseCode?: (string|null);

                    /** HttpRedirectAction stripQuery. */
                    public stripQuery?: (boolean|null);

                    /** HttpRedirectAction _hostRedirect. */
                    public _hostRedirect?: "hostRedirect";

                    /** HttpRedirectAction _httpsRedirect. */
                    public _httpsRedirect?: "httpsRedirect";

                    /** HttpRedirectAction _pathRedirect. */
                    public _pathRedirect?: "pathRedirect";

                    /** HttpRedirectAction _prefixRedirect. */
                    public _prefixRedirect?: "prefixRedirect";

                    /** HttpRedirectAction _redirectResponseCode. */
                    public _redirectResponseCode?: "redirectResponseCode";

                    /** HttpRedirectAction _stripQuery. */
                    public _stripQuery?: "stripQuery";

                    /**
                     * Creates a new HttpRedirectAction instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpRedirectAction instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpRedirectAction): google.cloud.compute.v1.HttpRedirectAction;

                    /**
                     * Encodes the specified HttpRedirectAction message. Does not implicitly {@link google.cloud.compute.v1.HttpRedirectAction.verify|verify} messages.
                     * @param message HttpRedirectAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpRedirectAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpRedirectAction message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpRedirectAction.verify|verify} messages.
                     * @param message HttpRedirectAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpRedirectAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpRedirectAction message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpRedirectAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpRedirectAction;

                    /**
                     * Decodes a HttpRedirectAction message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpRedirectAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpRedirectAction;

                    /**
                     * Verifies a HttpRedirectAction message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpRedirectAction message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpRedirectAction
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpRedirectAction;

                    /**
                     * Creates a plain object from a HttpRedirectAction message. Also converts values to other types if specified.
                     * @param message HttpRedirectAction
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpRedirectAction, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpRedirectAction to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpRedirectAction
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HttpRedirectAction {

                    /** RedirectResponseCode enum. */
                    enum RedirectResponseCode {
                        UNDEFINED_REDIRECT_RESPONSE_CODE = 0,
                        FOUND = 67084130,
                        MOVED_PERMANENTLY_DEFAULT = 386698449,
                        PERMANENT_REDIRECT = 382006381,
                        SEE_OTHER = 445380580,
                        TEMPORARY_REDIRECT = 489550378
                    }
                }

                /** Properties of a HttpRetryPolicy. */
                interface IHttpRetryPolicy {

                    /** HttpRetryPolicy numRetries */
                    numRetries?: (number|null);

                    /** HttpRetryPolicy perTryTimeout */
                    perTryTimeout?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpRetryPolicy retryConditions */
                    retryConditions?: (string[]|null);
                }

                /** Represents a HttpRetryPolicy. */
                class HttpRetryPolicy implements IHttpRetryPolicy {

                    /**
                     * Constructs a new HttpRetryPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpRetryPolicy);

                    /** HttpRetryPolicy numRetries. */
                    public numRetries?: (number|null);

                    /** HttpRetryPolicy perTryTimeout. */
                    public perTryTimeout?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpRetryPolicy retryConditions. */
                    public retryConditions: string[];

                    /** HttpRetryPolicy _numRetries. */
                    public _numRetries?: "numRetries";

                    /** HttpRetryPolicy _perTryTimeout. */
                    public _perTryTimeout?: "perTryTimeout";

                    /**
                     * Creates a new HttpRetryPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpRetryPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpRetryPolicy): google.cloud.compute.v1.HttpRetryPolicy;

                    /**
                     * Encodes the specified HttpRetryPolicy message. Does not implicitly {@link google.cloud.compute.v1.HttpRetryPolicy.verify|verify} messages.
                     * @param message HttpRetryPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpRetryPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpRetryPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpRetryPolicy.verify|verify} messages.
                     * @param message HttpRetryPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpRetryPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpRetryPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpRetryPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpRetryPolicy;

                    /**
                     * Decodes a HttpRetryPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpRetryPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpRetryPolicy;

                    /**
                     * Verifies a HttpRetryPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpRetryPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpRetryPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpRetryPolicy;

                    /**
                     * Creates a plain object from a HttpRetryPolicy message. Also converts values to other types if specified.
                     * @param message HttpRetryPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpRetryPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpRetryPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpRetryPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpRouteAction. */
                interface IHttpRouteAction {

                    /** HttpRouteAction corsPolicy */
                    corsPolicy?: (google.cloud.compute.v1.ICorsPolicy|null);

                    /** HttpRouteAction faultInjectionPolicy */
                    faultInjectionPolicy?: (google.cloud.compute.v1.IHttpFaultInjection|null);

                    /** HttpRouteAction maxStreamDuration */
                    maxStreamDuration?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpRouteAction requestMirrorPolicy */
                    requestMirrorPolicy?: (google.cloud.compute.v1.IRequestMirrorPolicy|null);

                    /** HttpRouteAction retryPolicy */
                    retryPolicy?: (google.cloud.compute.v1.IHttpRetryPolicy|null);

                    /** HttpRouteAction timeout */
                    timeout?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpRouteAction urlRewrite */
                    urlRewrite?: (google.cloud.compute.v1.IUrlRewrite|null);

                    /** HttpRouteAction weightedBackendServices */
                    weightedBackendServices?: (google.cloud.compute.v1.IWeightedBackendService[]|null);
                }

                /** Represents a HttpRouteAction. */
                class HttpRouteAction implements IHttpRouteAction {

                    /**
                     * Constructs a new HttpRouteAction.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpRouteAction);

                    /** HttpRouteAction corsPolicy. */
                    public corsPolicy?: (google.cloud.compute.v1.ICorsPolicy|null);

                    /** HttpRouteAction faultInjectionPolicy. */
                    public faultInjectionPolicy?: (google.cloud.compute.v1.IHttpFaultInjection|null);

                    /** HttpRouteAction maxStreamDuration. */
                    public maxStreamDuration?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpRouteAction requestMirrorPolicy. */
                    public requestMirrorPolicy?: (google.cloud.compute.v1.IRequestMirrorPolicy|null);

                    /** HttpRouteAction retryPolicy. */
                    public retryPolicy?: (google.cloud.compute.v1.IHttpRetryPolicy|null);

                    /** HttpRouteAction timeout. */
                    public timeout?: (google.cloud.compute.v1.IDuration|null);

                    /** HttpRouteAction urlRewrite. */
                    public urlRewrite?: (google.cloud.compute.v1.IUrlRewrite|null);

                    /** HttpRouteAction weightedBackendServices. */
                    public weightedBackendServices: google.cloud.compute.v1.IWeightedBackendService[];

                    /** HttpRouteAction _corsPolicy. */
                    public _corsPolicy?: "corsPolicy";

                    /** HttpRouteAction _faultInjectionPolicy. */
                    public _faultInjectionPolicy?: "faultInjectionPolicy";

                    /** HttpRouteAction _maxStreamDuration. */
                    public _maxStreamDuration?: "maxStreamDuration";

                    /** HttpRouteAction _requestMirrorPolicy. */
                    public _requestMirrorPolicy?: "requestMirrorPolicy";

                    /** HttpRouteAction _retryPolicy. */
                    public _retryPolicy?: "retryPolicy";

                    /** HttpRouteAction _timeout. */
                    public _timeout?: "timeout";

                    /** HttpRouteAction _urlRewrite. */
                    public _urlRewrite?: "urlRewrite";

                    /**
                     * Creates a new HttpRouteAction instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpRouteAction instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpRouteAction): google.cloud.compute.v1.HttpRouteAction;

                    /**
                     * Encodes the specified HttpRouteAction message. Does not implicitly {@link google.cloud.compute.v1.HttpRouteAction.verify|verify} messages.
                     * @param message HttpRouteAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpRouteAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpRouteAction message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpRouteAction.verify|verify} messages.
                     * @param message HttpRouteAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpRouteAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpRouteAction message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpRouteAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpRouteAction;

                    /**
                     * Decodes a HttpRouteAction message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpRouteAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpRouteAction;

                    /**
                     * Verifies a HttpRouteAction message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpRouteAction message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpRouteAction
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpRouteAction;

                    /**
                     * Creates a plain object from a HttpRouteAction message. Also converts values to other types if specified.
                     * @param message HttpRouteAction
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpRouteAction, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpRouteAction to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpRouteAction
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpRouteRule. */
                interface IHttpRouteRule {

                    /** HttpRouteRule description */
                    description?: (string|null);

                    /** HttpRouteRule headerAction */
                    headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** HttpRouteRule matchRules */
                    matchRules?: (google.cloud.compute.v1.IHttpRouteRuleMatch[]|null);

                    /** HttpRouteRule priority */
                    priority?: (number|null);

                    /** HttpRouteRule routeAction */
                    routeAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** HttpRouteRule service */
                    service?: (string|null);

                    /** HttpRouteRule urlRedirect */
                    urlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);
                }

                /** Represents a HttpRouteRule. */
                class HttpRouteRule implements IHttpRouteRule {

                    /**
                     * Constructs a new HttpRouteRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpRouteRule);

                    /** HttpRouteRule description. */
                    public description?: (string|null);

                    /** HttpRouteRule headerAction. */
                    public headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** HttpRouteRule matchRules. */
                    public matchRules: google.cloud.compute.v1.IHttpRouteRuleMatch[];

                    /** HttpRouteRule priority. */
                    public priority?: (number|null);

                    /** HttpRouteRule routeAction. */
                    public routeAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** HttpRouteRule service. */
                    public service?: (string|null);

                    /** HttpRouteRule urlRedirect. */
                    public urlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);

                    /** HttpRouteRule _description. */
                    public _description?: "description";

                    /** HttpRouteRule _headerAction. */
                    public _headerAction?: "headerAction";

                    /** HttpRouteRule _priority. */
                    public _priority?: "priority";

                    /** HttpRouteRule _routeAction. */
                    public _routeAction?: "routeAction";

                    /** HttpRouteRule _service. */
                    public _service?: "service";

                    /** HttpRouteRule _urlRedirect. */
                    public _urlRedirect?: "urlRedirect";

                    /**
                     * Creates a new HttpRouteRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpRouteRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpRouteRule): google.cloud.compute.v1.HttpRouteRule;

                    /**
                     * Encodes the specified HttpRouteRule message. Does not implicitly {@link google.cloud.compute.v1.HttpRouteRule.verify|verify} messages.
                     * @param message HttpRouteRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpRouteRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpRouteRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpRouteRule.verify|verify} messages.
                     * @param message HttpRouteRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpRouteRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpRouteRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpRouteRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpRouteRule;

                    /**
                     * Decodes a HttpRouteRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpRouteRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpRouteRule;

                    /**
                     * Verifies a HttpRouteRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpRouteRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpRouteRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpRouteRule;

                    /**
                     * Creates a plain object from a HttpRouteRule message. Also converts values to other types if specified.
                     * @param message HttpRouteRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpRouteRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpRouteRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpRouteRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HttpRouteRuleMatch. */
                interface IHttpRouteRuleMatch {

                    /** HttpRouteRuleMatch fullPathMatch */
                    fullPathMatch?: (string|null);

                    /** HttpRouteRuleMatch headerMatches */
                    headerMatches?: (google.cloud.compute.v1.IHttpHeaderMatch[]|null);

                    /** HttpRouteRuleMatch ignoreCase */
                    ignoreCase?: (boolean|null);

                    /** HttpRouteRuleMatch metadataFilters */
                    metadataFilters?: (google.cloud.compute.v1.IMetadataFilter[]|null);

                    /** HttpRouteRuleMatch prefixMatch */
                    prefixMatch?: (string|null);

                    /** HttpRouteRuleMatch queryParameterMatches */
                    queryParameterMatches?: (google.cloud.compute.v1.IHttpQueryParameterMatch[]|null);

                    /** HttpRouteRuleMatch regexMatch */
                    regexMatch?: (string|null);
                }

                /** Represents a HttpRouteRuleMatch. */
                class HttpRouteRuleMatch implements IHttpRouteRuleMatch {

                    /**
                     * Constructs a new HttpRouteRuleMatch.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IHttpRouteRuleMatch);

                    /** HttpRouteRuleMatch fullPathMatch. */
                    public fullPathMatch?: (string|null);

                    /** HttpRouteRuleMatch headerMatches. */
                    public headerMatches: google.cloud.compute.v1.IHttpHeaderMatch[];

                    /** HttpRouteRuleMatch ignoreCase. */
                    public ignoreCase?: (boolean|null);

                    /** HttpRouteRuleMatch metadataFilters. */
                    public metadataFilters: google.cloud.compute.v1.IMetadataFilter[];

                    /** HttpRouteRuleMatch prefixMatch. */
                    public prefixMatch?: (string|null);

                    /** HttpRouteRuleMatch queryParameterMatches. */
                    public queryParameterMatches: google.cloud.compute.v1.IHttpQueryParameterMatch[];

                    /** HttpRouteRuleMatch regexMatch. */
                    public regexMatch?: (string|null);

                    /** HttpRouteRuleMatch _fullPathMatch. */
                    public _fullPathMatch?: "fullPathMatch";

                    /** HttpRouteRuleMatch _ignoreCase. */
                    public _ignoreCase?: "ignoreCase";

                    /** HttpRouteRuleMatch _prefixMatch. */
                    public _prefixMatch?: "prefixMatch";

                    /** HttpRouteRuleMatch _regexMatch. */
                    public _regexMatch?: "regexMatch";

                    /**
                     * Creates a new HttpRouteRuleMatch instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HttpRouteRuleMatch instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IHttpRouteRuleMatch): google.cloud.compute.v1.HttpRouteRuleMatch;

                    /**
                     * Encodes the specified HttpRouteRuleMatch message. Does not implicitly {@link google.cloud.compute.v1.HttpRouteRuleMatch.verify|verify} messages.
                     * @param message HttpRouteRuleMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IHttpRouteRuleMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HttpRouteRuleMatch message, length delimited. Does not implicitly {@link google.cloud.compute.v1.HttpRouteRuleMatch.verify|verify} messages.
                     * @param message HttpRouteRuleMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IHttpRouteRuleMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HttpRouteRuleMatch message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HttpRouteRuleMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.HttpRouteRuleMatch;

                    /**
                     * Decodes a HttpRouteRuleMatch message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HttpRouteRuleMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.HttpRouteRuleMatch;

                    /**
                     * Verifies a HttpRouteRuleMatch message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HttpRouteRuleMatch message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HttpRouteRuleMatch
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.HttpRouteRuleMatch;

                    /**
                     * Creates a plain object from a HttpRouteRuleMatch message. Also converts values to other types if specified.
                     * @param message HttpRouteRuleMatch
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.HttpRouteRuleMatch, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HttpRouteRuleMatch to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HttpRouteRuleMatch
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Image. */
                interface IImage {

                    /** Image architecture */
                    architecture?: (string|null);

                    /** Image archiveSizeBytes */
                    archiveSizeBytes?: (number|Long|string|null);

                    /** Image creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Image deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** Image description */
                    description?: (string|null);

                    /** Image diskSizeGb */
                    diskSizeGb?: (number|Long|string|null);

                    /** Image family */
                    family?: (string|null);

                    /** Image guestOsFeatures */
                    guestOsFeatures?: (google.cloud.compute.v1.IGuestOsFeature[]|null);

                    /** Image id */
                    id?: (number|Long|string|null);

                    /** Image imageEncryptionKey */
                    imageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image kind */
                    kind?: (string|null);

                    /** Image labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** Image labels */
                    labels?: ({ [k: string]: string }|null);

                    /** Image licenseCodes */
                    licenseCodes?: ((number|Long|string)[]|null);

                    /** Image licenses */
                    licenses?: (string[]|null);

                    /** Image name */
                    name?: (string|null);

                    /** Image rawDisk */
                    rawDisk?: (google.cloud.compute.v1.IRawDisk|null);

                    /** Image satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Image selfLink */
                    selfLink?: (string|null);

                    /** Image shieldedInstanceInitialState */
                    shieldedInstanceInitialState?: (google.cloud.compute.v1.IInitialStateConfig|null);

                    /** Image sourceDisk */
                    sourceDisk?: (string|null);

                    /** Image sourceDiskEncryptionKey */
                    sourceDiskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image sourceDiskId */
                    sourceDiskId?: (string|null);

                    /** Image sourceImage */
                    sourceImage?: (string|null);

                    /** Image sourceImageEncryptionKey */
                    sourceImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image sourceImageId */
                    sourceImageId?: (string|null);

                    /** Image sourceSnapshot */
                    sourceSnapshot?: (string|null);

                    /** Image sourceSnapshotEncryptionKey */
                    sourceSnapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image sourceSnapshotId */
                    sourceSnapshotId?: (string|null);

                    /** Image sourceType */
                    sourceType?: (string|null);

                    /** Image status */
                    status?: (string|null);

                    /** Image storageLocations */
                    storageLocations?: (string[]|null);
                }

                /** Represents an Image. */
                class Image implements IImage {

                    /**
                     * Constructs a new Image.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IImage);

                    /** Image architecture. */
                    public architecture?: (string|null);

                    /** Image archiveSizeBytes. */
                    public archiveSizeBytes?: (number|Long|string|null);

                    /** Image creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Image deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** Image description. */
                    public description?: (string|null);

                    /** Image diskSizeGb. */
                    public diskSizeGb?: (number|Long|string|null);

                    /** Image family. */
                    public family?: (string|null);

                    /** Image guestOsFeatures. */
                    public guestOsFeatures: google.cloud.compute.v1.IGuestOsFeature[];

                    /** Image id. */
                    public id?: (number|Long|string|null);

                    /** Image imageEncryptionKey. */
                    public imageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image kind. */
                    public kind?: (string|null);

                    /** Image labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** Image labels. */
                    public labels: { [k: string]: string };

                    /** Image licenseCodes. */
                    public licenseCodes: (number|Long|string)[];

                    /** Image licenses. */
                    public licenses: string[];

                    /** Image name. */
                    public name?: (string|null);

                    /** Image rawDisk. */
                    public rawDisk?: (google.cloud.compute.v1.IRawDisk|null);

                    /** Image satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** Image selfLink. */
                    public selfLink?: (string|null);

                    /** Image shieldedInstanceInitialState. */
                    public shieldedInstanceInitialState?: (google.cloud.compute.v1.IInitialStateConfig|null);

                    /** Image sourceDisk. */
                    public sourceDisk?: (string|null);

                    /** Image sourceDiskEncryptionKey. */
                    public sourceDiskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image sourceDiskId. */
                    public sourceDiskId?: (string|null);

                    /** Image sourceImage. */
                    public sourceImage?: (string|null);

                    /** Image sourceImageEncryptionKey. */
                    public sourceImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image sourceImageId. */
                    public sourceImageId?: (string|null);

                    /** Image sourceSnapshot. */
                    public sourceSnapshot?: (string|null);

                    /** Image sourceSnapshotEncryptionKey. */
                    public sourceSnapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Image sourceSnapshotId. */
                    public sourceSnapshotId?: (string|null);

                    /** Image sourceType. */
                    public sourceType?: (string|null);

                    /** Image status. */
                    public status?: (string|null);

                    /** Image storageLocations. */
                    public storageLocations: string[];

                    /** Image _architecture. */
                    public _architecture?: "architecture";

                    /** Image _archiveSizeBytes. */
                    public _archiveSizeBytes?: "archiveSizeBytes";

                    /** Image _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Image _deprecated. */
                    public _deprecated?: "deprecated";

                    /** Image _description. */
                    public _description?: "description";

                    /** Image _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** Image _family. */
                    public _family?: "family";

                    /** Image _id. */
                    public _id?: "id";

                    /** Image _imageEncryptionKey. */
                    public _imageEncryptionKey?: "imageEncryptionKey";

                    /** Image _kind. */
                    public _kind?: "kind";

                    /** Image _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** Image _name. */
                    public _name?: "name";

                    /** Image _rawDisk. */
                    public _rawDisk?: "rawDisk";

                    /** Image _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** Image _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Image _shieldedInstanceInitialState. */
                    public _shieldedInstanceInitialState?: "shieldedInstanceInitialState";

                    /** Image _sourceDisk. */
                    public _sourceDisk?: "sourceDisk";

                    /** Image _sourceDiskEncryptionKey. */
                    public _sourceDiskEncryptionKey?: "sourceDiskEncryptionKey";

                    /** Image _sourceDiskId. */
                    public _sourceDiskId?: "sourceDiskId";

                    /** Image _sourceImage. */
                    public _sourceImage?: "sourceImage";

                    /** Image _sourceImageEncryptionKey. */
                    public _sourceImageEncryptionKey?: "sourceImageEncryptionKey";

                    /** Image _sourceImageId. */
                    public _sourceImageId?: "sourceImageId";

                    /** Image _sourceSnapshot. */
                    public _sourceSnapshot?: "sourceSnapshot";

                    /** Image _sourceSnapshotEncryptionKey. */
                    public _sourceSnapshotEncryptionKey?: "sourceSnapshotEncryptionKey";

                    /** Image _sourceSnapshotId. */
                    public _sourceSnapshotId?: "sourceSnapshotId";

                    /** Image _sourceType. */
                    public _sourceType?: "sourceType";

                    /** Image _status. */
                    public _status?: "status";

                    /**
                     * Creates a new Image instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Image instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IImage): google.cloud.compute.v1.Image;

                    /**
                     * Encodes the specified Image message. Does not implicitly {@link google.cloud.compute.v1.Image.verify|verify} messages.
                     * @param message Image message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Image message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Image.verify|verify} messages.
                     * @param message Image message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Image message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Image
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Image;

                    /**
                     * Decodes an Image message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Image
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Image;

                    /**
                     * Verifies an Image message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Image message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Image
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Image;

                    /**
                     * Creates a plain object from an Image message. Also converts values to other types if specified.
                     * @param message Image
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Image, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Image to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Image
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Image {

                    /** Architecture enum. */
                    enum Architecture {
                        UNDEFINED_ARCHITECTURE = 0,
                        ARCHITECTURE_UNSPECIFIED = 394750507,
                        ARM64 = 62547450,
                        X86_64 = 425300551
                    }

                    /** SourceType enum. */
                    enum SourceType {
                        UNDEFINED_SOURCE_TYPE = 0,
                        RAW = 80904
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DELETING = 528602024,
                        FAILED = 455706685,
                        PENDING = 35394935,
                        READY = 77848963
                    }
                }

                /** Properties of an ImageFamilyView. */
                interface IImageFamilyView {

                    /** ImageFamilyView image */
                    image?: (google.cloud.compute.v1.IImage|null);
                }

                /** Represents an ImageFamilyView. */
                class ImageFamilyView implements IImageFamilyView {

                    /**
                     * Constructs a new ImageFamilyView.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IImageFamilyView);

                    /** ImageFamilyView image. */
                    public image?: (google.cloud.compute.v1.IImage|null);

                    /** ImageFamilyView _image. */
                    public _image?: "image";

                    /**
                     * Creates a new ImageFamilyView instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImageFamilyView instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IImageFamilyView): google.cloud.compute.v1.ImageFamilyView;

                    /**
                     * Encodes the specified ImageFamilyView message. Does not implicitly {@link google.cloud.compute.v1.ImageFamilyView.verify|verify} messages.
                     * @param message ImageFamilyView message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IImageFamilyView, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImageFamilyView message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ImageFamilyView.verify|verify} messages.
                     * @param message ImageFamilyView message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IImageFamilyView, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImageFamilyView message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImageFamilyView
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ImageFamilyView;

                    /**
                     * Decodes an ImageFamilyView message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImageFamilyView
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ImageFamilyView;

                    /**
                     * Verifies an ImageFamilyView message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImageFamilyView message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImageFamilyView
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ImageFamilyView;

                    /**
                     * Creates a plain object from an ImageFamilyView message. Also converts values to other types if specified.
                     * @param message ImageFamilyView
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ImageFamilyView, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImageFamilyView to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImageFamilyView
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ImageList. */
                interface IImageList {

                    /** ImageList id */
                    id?: (string|null);

                    /** ImageList items */
                    items?: (google.cloud.compute.v1.IImage[]|null);

                    /** ImageList kind */
                    kind?: (string|null);

                    /** ImageList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ImageList selfLink */
                    selfLink?: (string|null);

                    /** ImageList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an ImageList. */
                class ImageList implements IImageList {

                    /**
                     * Constructs a new ImageList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IImageList);

                    /** ImageList id. */
                    public id?: (string|null);

                    /** ImageList items. */
                    public items: google.cloud.compute.v1.IImage[];

                    /** ImageList kind. */
                    public kind?: (string|null);

                    /** ImageList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ImageList selfLink. */
                    public selfLink?: (string|null);

                    /** ImageList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ImageList _id. */
                    public _id?: "id";

                    /** ImageList _kind. */
                    public _kind?: "kind";

                    /** ImageList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ImageList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ImageList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ImageList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImageList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IImageList): google.cloud.compute.v1.ImageList;

                    /**
                     * Encodes the specified ImageList message. Does not implicitly {@link google.cloud.compute.v1.ImageList.verify|verify} messages.
                     * @param message ImageList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IImageList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImageList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ImageList.verify|verify} messages.
                     * @param message ImageList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IImageList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImageList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImageList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ImageList;

                    /**
                     * Decodes an ImageList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImageList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ImageList;

                    /**
                     * Verifies an ImageList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImageList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImageList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ImageList;

                    /**
                     * Creates a plain object from an ImageList message. Also converts values to other types if specified.
                     * @param message ImageList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ImageList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImageList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImageList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InitialStateConfig. */
                interface IInitialStateConfig {

                    /** InitialStateConfig dbs */
                    dbs?: (google.cloud.compute.v1.IFileContentBuffer[]|null);

                    /** InitialStateConfig dbxs */
                    dbxs?: (google.cloud.compute.v1.IFileContentBuffer[]|null);

                    /** InitialStateConfig keks */
                    keks?: (google.cloud.compute.v1.IFileContentBuffer[]|null);

                    /** InitialStateConfig pk */
                    pk?: (google.cloud.compute.v1.IFileContentBuffer|null);
                }

                /** Represents an InitialStateConfig. */
                class InitialStateConfig implements IInitialStateConfig {

                    /**
                     * Constructs a new InitialStateConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInitialStateConfig);

                    /** InitialStateConfig dbs. */
                    public dbs: google.cloud.compute.v1.IFileContentBuffer[];

                    /** InitialStateConfig dbxs. */
                    public dbxs: google.cloud.compute.v1.IFileContentBuffer[];

                    /** InitialStateConfig keks. */
                    public keks: google.cloud.compute.v1.IFileContentBuffer[];

                    /** InitialStateConfig pk. */
                    public pk?: (google.cloud.compute.v1.IFileContentBuffer|null);

                    /** InitialStateConfig _pk. */
                    public _pk?: "pk";

                    /**
                     * Creates a new InitialStateConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InitialStateConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInitialStateConfig): google.cloud.compute.v1.InitialStateConfig;

                    /**
                     * Encodes the specified InitialStateConfig message. Does not implicitly {@link google.cloud.compute.v1.InitialStateConfig.verify|verify} messages.
                     * @param message InitialStateConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInitialStateConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InitialStateConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InitialStateConfig.verify|verify} messages.
                     * @param message InitialStateConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInitialStateConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InitialStateConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InitialStateConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InitialStateConfig;

                    /**
                     * Decodes an InitialStateConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InitialStateConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InitialStateConfig;

                    /**
                     * Verifies an InitialStateConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InitialStateConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InitialStateConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InitialStateConfig;

                    /**
                     * Creates a plain object from an InitialStateConfig message. Also converts values to other types if specified.
                     * @param message InitialStateConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InitialStateConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InitialStateConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InitialStateConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertAddressRequest. */
                interface IInsertAddressRequest {

                    /** InsertAddressRequest addressResource */
                    addressResource?: (google.cloud.compute.v1.IAddress|null);

                    /** InsertAddressRequest project */
                    project?: (string|null);

                    /** InsertAddressRequest region */
                    region?: (string|null);

                    /** InsertAddressRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertAddressRequest. */
                class InsertAddressRequest implements IInsertAddressRequest {

                    /**
                     * Constructs a new InsertAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertAddressRequest);

                    /** InsertAddressRequest addressResource. */
                    public addressResource?: (google.cloud.compute.v1.IAddress|null);

                    /** InsertAddressRequest project. */
                    public project: string;

                    /** InsertAddressRequest region. */
                    public region: string;

                    /** InsertAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertAddressRequest): google.cloud.compute.v1.InsertAddressRequest;

                    /**
                     * Encodes the specified InsertAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertAddressRequest.verify|verify} messages.
                     * @param message InsertAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertAddressRequest.verify|verify} messages.
                     * @param message InsertAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertAddressRequest;

                    /**
                     * Decodes an InsertAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertAddressRequest;

                    /**
                     * Verifies an InsertAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertAddressRequest;

                    /**
                     * Creates a plain object from an InsertAddressRequest message. Also converts values to other types if specified.
                     * @param message InsertAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertAutoscalerRequest. */
                interface IInsertAutoscalerRequest {

                    /** InsertAutoscalerRequest autoscalerResource */
                    autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** InsertAutoscalerRequest project */
                    project?: (string|null);

                    /** InsertAutoscalerRequest requestId */
                    requestId?: (string|null);

                    /** InsertAutoscalerRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertAutoscalerRequest. */
                class InsertAutoscalerRequest implements IInsertAutoscalerRequest {

                    /**
                     * Constructs a new InsertAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertAutoscalerRequest);

                    /** InsertAutoscalerRequest autoscalerResource. */
                    public autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** InsertAutoscalerRequest project. */
                    public project: string;

                    /** InsertAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertAutoscalerRequest zone. */
                    public zone: string;

                    /** InsertAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertAutoscalerRequest): google.cloud.compute.v1.InsertAutoscalerRequest;

                    /**
                     * Encodes the specified InsertAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertAutoscalerRequest.verify|verify} messages.
                     * @param message InsertAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertAutoscalerRequest.verify|verify} messages.
                     * @param message InsertAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertAutoscalerRequest;

                    /**
                     * Decodes an InsertAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertAutoscalerRequest;

                    /**
                     * Verifies an InsertAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertAutoscalerRequest;

                    /**
                     * Creates a plain object from an InsertAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message InsertAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertBackendBucketRequest. */
                interface IInsertBackendBucketRequest {

                    /** InsertBackendBucketRequest backendBucketResource */
                    backendBucketResource?: (google.cloud.compute.v1.IBackendBucket|null);

                    /** InsertBackendBucketRequest project */
                    project?: (string|null);

                    /** InsertBackendBucketRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertBackendBucketRequest. */
                class InsertBackendBucketRequest implements IInsertBackendBucketRequest {

                    /**
                     * Constructs a new InsertBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertBackendBucketRequest);

                    /** InsertBackendBucketRequest backendBucketResource. */
                    public backendBucketResource?: (google.cloud.compute.v1.IBackendBucket|null);

                    /** InsertBackendBucketRequest project. */
                    public project: string;

                    /** InsertBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertBackendBucketRequest): google.cloud.compute.v1.InsertBackendBucketRequest;

                    /**
                     * Encodes the specified InsertBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertBackendBucketRequest.verify|verify} messages.
                     * @param message InsertBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertBackendBucketRequest.verify|verify} messages.
                     * @param message InsertBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertBackendBucketRequest;

                    /**
                     * Decodes an InsertBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertBackendBucketRequest;

                    /**
                     * Verifies an InsertBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertBackendBucketRequest;

                    /**
                     * Creates a plain object from an InsertBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message InsertBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertBackendServiceRequest. */
                interface IInsertBackendServiceRequest {

                    /** InsertBackendServiceRequest backendServiceResource */
                    backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** InsertBackendServiceRequest project */
                    project?: (string|null);

                    /** InsertBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertBackendServiceRequest. */
                class InsertBackendServiceRequest implements IInsertBackendServiceRequest {

                    /**
                     * Constructs a new InsertBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertBackendServiceRequest);

                    /** InsertBackendServiceRequest backendServiceResource. */
                    public backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** InsertBackendServiceRequest project. */
                    public project: string;

                    /** InsertBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertBackendServiceRequest): google.cloud.compute.v1.InsertBackendServiceRequest;

                    /**
                     * Encodes the specified InsertBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertBackendServiceRequest.verify|verify} messages.
                     * @param message InsertBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertBackendServiceRequest.verify|verify} messages.
                     * @param message InsertBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertBackendServiceRequest;

                    /**
                     * Decodes an InsertBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertBackendServiceRequest;

                    /**
                     * Verifies an InsertBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertBackendServiceRequest;

                    /**
                     * Creates a plain object from an InsertBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message InsertBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertDiskRequest. */
                interface IInsertDiskRequest {

                    /** InsertDiskRequest diskResource */
                    diskResource?: (google.cloud.compute.v1.IDisk|null);

                    /** InsertDiskRequest project */
                    project?: (string|null);

                    /** InsertDiskRequest requestId */
                    requestId?: (string|null);

                    /** InsertDiskRequest sourceImage */
                    sourceImage?: (string|null);

                    /** InsertDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertDiskRequest. */
                class InsertDiskRequest implements IInsertDiskRequest {

                    /**
                     * Constructs a new InsertDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertDiskRequest);

                    /** InsertDiskRequest diskResource. */
                    public diskResource?: (google.cloud.compute.v1.IDisk|null);

                    /** InsertDiskRequest project. */
                    public project: string;

                    /** InsertDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertDiskRequest sourceImage. */
                    public sourceImage?: (string|null);

                    /** InsertDiskRequest zone. */
                    public zone: string;

                    /** InsertDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertDiskRequest _sourceImage. */
                    public _sourceImage?: "sourceImage";

                    /**
                     * Creates a new InsertDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertDiskRequest): google.cloud.compute.v1.InsertDiskRequest;

                    /**
                     * Encodes the specified InsertDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertDiskRequest.verify|verify} messages.
                     * @param message InsertDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertDiskRequest.verify|verify} messages.
                     * @param message InsertDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertDiskRequest;

                    /**
                     * Decodes an InsertDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertDiskRequest;

                    /**
                     * Verifies an InsertDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertDiskRequest;

                    /**
                     * Creates a plain object from an InsertDiskRequest message. Also converts values to other types if specified.
                     * @param message InsertDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertExternalVpnGatewayRequest. */
                interface IInsertExternalVpnGatewayRequest {

                    /** InsertExternalVpnGatewayRequest externalVpnGatewayResource */
                    externalVpnGatewayResource?: (google.cloud.compute.v1.IExternalVpnGateway|null);

                    /** InsertExternalVpnGatewayRequest project */
                    project?: (string|null);

                    /** InsertExternalVpnGatewayRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertExternalVpnGatewayRequest. */
                class InsertExternalVpnGatewayRequest implements IInsertExternalVpnGatewayRequest {

                    /**
                     * Constructs a new InsertExternalVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertExternalVpnGatewayRequest);

                    /** InsertExternalVpnGatewayRequest externalVpnGatewayResource. */
                    public externalVpnGatewayResource?: (google.cloud.compute.v1.IExternalVpnGateway|null);

                    /** InsertExternalVpnGatewayRequest project. */
                    public project: string;

                    /** InsertExternalVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertExternalVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertExternalVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertExternalVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertExternalVpnGatewayRequest): google.cloud.compute.v1.InsertExternalVpnGatewayRequest;

                    /**
                     * Encodes the specified InsertExternalVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message InsertExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertExternalVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message InsertExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertExternalVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertExternalVpnGatewayRequest;

                    /**
                     * Decodes an InsertExternalVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertExternalVpnGatewayRequest;

                    /**
                     * Verifies an InsertExternalVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertExternalVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertExternalVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertExternalVpnGatewayRequest;

                    /**
                     * Creates a plain object from an InsertExternalVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message InsertExternalVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertExternalVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertExternalVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertExternalVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertFirewallPolicyRequest. */
                interface IInsertFirewallPolicyRequest {

                    /** InsertFirewallPolicyRequest firewallPolicyResource */
                    firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** InsertFirewallPolicyRequest parentId */
                    parentId?: (string|null);

                    /** InsertFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertFirewallPolicyRequest. */
                class InsertFirewallPolicyRequest implements IInsertFirewallPolicyRequest {

                    /**
                     * Constructs a new InsertFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertFirewallPolicyRequest);

                    /** InsertFirewallPolicyRequest firewallPolicyResource. */
                    public firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** InsertFirewallPolicyRequest parentId. */
                    public parentId: string;

                    /** InsertFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertFirewallPolicyRequest): google.cloud.compute.v1.InsertFirewallPolicyRequest;

                    /**
                     * Encodes the specified InsertFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertFirewallPolicyRequest.verify|verify} messages.
                     * @param message InsertFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertFirewallPolicyRequest.verify|verify} messages.
                     * @param message InsertFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertFirewallPolicyRequest;

                    /**
                     * Decodes an InsertFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertFirewallPolicyRequest;

                    /**
                     * Verifies an InsertFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an InsertFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertFirewallRequest. */
                interface IInsertFirewallRequest {

                    /** InsertFirewallRequest firewallResource */
                    firewallResource?: (google.cloud.compute.v1.IFirewall|null);

                    /** InsertFirewallRequest project */
                    project?: (string|null);

                    /** InsertFirewallRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertFirewallRequest. */
                class InsertFirewallRequest implements IInsertFirewallRequest {

                    /**
                     * Constructs a new InsertFirewallRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertFirewallRequest);

                    /** InsertFirewallRequest firewallResource. */
                    public firewallResource?: (google.cloud.compute.v1.IFirewall|null);

                    /** InsertFirewallRequest project. */
                    public project: string;

                    /** InsertFirewallRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertFirewallRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertFirewallRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertFirewallRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertFirewallRequest): google.cloud.compute.v1.InsertFirewallRequest;

                    /**
                     * Encodes the specified InsertFirewallRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertFirewallRequest.verify|verify} messages.
                     * @param message InsertFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertFirewallRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertFirewallRequest.verify|verify} messages.
                     * @param message InsertFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertFirewallRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertFirewallRequest;

                    /**
                     * Decodes an InsertFirewallRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertFirewallRequest;

                    /**
                     * Verifies an InsertFirewallRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertFirewallRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertFirewallRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertFirewallRequest;

                    /**
                     * Creates a plain object from an InsertFirewallRequest message. Also converts values to other types if specified.
                     * @param message InsertFirewallRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertFirewallRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertFirewallRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertFirewallRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertForwardingRuleRequest. */
                interface IInsertForwardingRuleRequest {

                    /** InsertForwardingRuleRequest forwardingRuleResource */
                    forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** InsertForwardingRuleRequest project */
                    project?: (string|null);

                    /** InsertForwardingRuleRequest region */
                    region?: (string|null);

                    /** InsertForwardingRuleRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertForwardingRuleRequest. */
                class InsertForwardingRuleRequest implements IInsertForwardingRuleRequest {

                    /**
                     * Constructs a new InsertForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertForwardingRuleRequest);

                    /** InsertForwardingRuleRequest forwardingRuleResource. */
                    public forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** InsertForwardingRuleRequest project. */
                    public project: string;

                    /** InsertForwardingRuleRequest region. */
                    public region: string;

                    /** InsertForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertForwardingRuleRequest): google.cloud.compute.v1.InsertForwardingRuleRequest;

                    /**
                     * Encodes the specified InsertForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertForwardingRuleRequest.verify|verify} messages.
                     * @param message InsertForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertForwardingRuleRequest.verify|verify} messages.
                     * @param message InsertForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertForwardingRuleRequest;

                    /**
                     * Decodes an InsertForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertForwardingRuleRequest;

                    /**
                     * Verifies an InsertForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertForwardingRuleRequest;

                    /**
                     * Creates a plain object from an InsertForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message InsertForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertGlobalAddressRequest. */
                interface IInsertGlobalAddressRequest {

                    /** InsertGlobalAddressRequest addressResource */
                    addressResource?: (google.cloud.compute.v1.IAddress|null);

                    /** InsertGlobalAddressRequest project */
                    project?: (string|null);

                    /** InsertGlobalAddressRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertGlobalAddressRequest. */
                class InsertGlobalAddressRequest implements IInsertGlobalAddressRequest {

                    /**
                     * Constructs a new InsertGlobalAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertGlobalAddressRequest);

                    /** InsertGlobalAddressRequest addressResource. */
                    public addressResource?: (google.cloud.compute.v1.IAddress|null);

                    /** InsertGlobalAddressRequest project. */
                    public project: string;

                    /** InsertGlobalAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertGlobalAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertGlobalAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertGlobalAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertGlobalAddressRequest): google.cloud.compute.v1.InsertGlobalAddressRequest;

                    /**
                     * Encodes the specified InsertGlobalAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalAddressRequest.verify|verify} messages.
                     * @param message InsertGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertGlobalAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalAddressRequest.verify|verify} messages.
                     * @param message InsertGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertGlobalAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertGlobalAddressRequest;

                    /**
                     * Decodes an InsertGlobalAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertGlobalAddressRequest;

                    /**
                     * Verifies an InsertGlobalAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertGlobalAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertGlobalAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertGlobalAddressRequest;

                    /**
                     * Creates a plain object from an InsertGlobalAddressRequest message. Also converts values to other types if specified.
                     * @param message InsertGlobalAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertGlobalAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertGlobalAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertGlobalAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertGlobalForwardingRuleRequest. */
                interface IInsertGlobalForwardingRuleRequest {

                    /** InsertGlobalForwardingRuleRequest forwardingRuleResource */
                    forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** InsertGlobalForwardingRuleRequest project */
                    project?: (string|null);

                    /** InsertGlobalForwardingRuleRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertGlobalForwardingRuleRequest. */
                class InsertGlobalForwardingRuleRequest implements IInsertGlobalForwardingRuleRequest {

                    /**
                     * Constructs a new InsertGlobalForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertGlobalForwardingRuleRequest);

                    /** InsertGlobalForwardingRuleRequest forwardingRuleResource. */
                    public forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** InsertGlobalForwardingRuleRequest project. */
                    public project: string;

                    /** InsertGlobalForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertGlobalForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertGlobalForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertGlobalForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertGlobalForwardingRuleRequest): google.cloud.compute.v1.InsertGlobalForwardingRuleRequest;

                    /**
                     * Encodes the specified InsertGlobalForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message InsertGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertGlobalForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message InsertGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertGlobalForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertGlobalForwardingRuleRequest;

                    /**
                     * Decodes an InsertGlobalForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertGlobalForwardingRuleRequest;

                    /**
                     * Verifies an InsertGlobalForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertGlobalForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertGlobalForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertGlobalForwardingRuleRequest;

                    /**
                     * Creates a plain object from an InsertGlobalForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message InsertGlobalForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertGlobalForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertGlobalForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertGlobalForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertGlobalNetworkEndpointGroupRequest. */
                interface IInsertGlobalNetworkEndpointGroupRequest {

                    /** InsertGlobalNetworkEndpointGroupRequest networkEndpointGroupResource */
                    networkEndpointGroupResource?: (google.cloud.compute.v1.INetworkEndpointGroup|null);

                    /** InsertGlobalNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** InsertGlobalNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertGlobalNetworkEndpointGroupRequest. */
                class InsertGlobalNetworkEndpointGroupRequest implements IInsertGlobalNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new InsertGlobalNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest);

                    /** InsertGlobalNetworkEndpointGroupRequest networkEndpointGroupResource. */
                    public networkEndpointGroupResource?: (google.cloud.compute.v1.INetworkEndpointGroup|null);

                    /** InsertGlobalNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** InsertGlobalNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertGlobalNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertGlobalNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertGlobalNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest): google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified InsertGlobalNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message InsertGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertGlobalNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message InsertGlobalNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertGlobalNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest;

                    /**
                     * Decodes an InsertGlobalNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertGlobalNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest;

                    /**
                     * Verifies an InsertGlobalNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertGlobalNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertGlobalNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from an InsertGlobalNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message InsertGlobalNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertGlobalNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertGlobalNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertGlobalNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertGlobalPublicDelegatedPrefixeRequest. */
                interface IInsertGlobalPublicDelegatedPrefixeRequest {

                    /** InsertGlobalPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** InsertGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefixResource */
                    publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** InsertGlobalPublicDelegatedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertGlobalPublicDelegatedPrefixeRequest. */
                class InsertGlobalPublicDelegatedPrefixeRequest implements IInsertGlobalPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new InsertGlobalPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertGlobalPublicDelegatedPrefixeRequest);

                    /** InsertGlobalPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** InsertGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefixResource. */
                    public publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** InsertGlobalPublicDelegatedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertGlobalPublicDelegatedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertGlobalPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertGlobalPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertGlobalPublicDelegatedPrefixeRequest): google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified InsertGlobalPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message InsertGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertGlobalPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message InsertGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes an InsertGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies an InsertGlobalPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertGlobalPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertGlobalPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from an InsertGlobalPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message InsertGlobalPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertGlobalPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertGlobalPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertGlobalPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertHealthCheckRequest. */
                interface IInsertHealthCheckRequest {

                    /** InsertHealthCheckRequest healthCheckResource */
                    healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** InsertHealthCheckRequest project */
                    project?: (string|null);

                    /** InsertHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertHealthCheckRequest. */
                class InsertHealthCheckRequest implements IInsertHealthCheckRequest {

                    /**
                     * Constructs a new InsertHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertHealthCheckRequest);

                    /** InsertHealthCheckRequest healthCheckResource. */
                    public healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** InsertHealthCheckRequest project. */
                    public project: string;

                    /** InsertHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertHealthCheckRequest): google.cloud.compute.v1.InsertHealthCheckRequest;

                    /**
                     * Encodes the specified InsertHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertHealthCheckRequest.verify|verify} messages.
                     * @param message InsertHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertHealthCheckRequest.verify|verify} messages.
                     * @param message InsertHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertHealthCheckRequest;

                    /**
                     * Decodes an InsertHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertHealthCheckRequest;

                    /**
                     * Verifies an InsertHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertHealthCheckRequest;

                    /**
                     * Creates a plain object from an InsertHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message InsertHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertImageRequest. */
                interface IInsertImageRequest {

                    /** InsertImageRequest forceCreate */
                    forceCreate?: (boolean|null);

                    /** InsertImageRequest imageResource */
                    imageResource?: (google.cloud.compute.v1.IImage|null);

                    /** InsertImageRequest project */
                    project?: (string|null);

                    /** InsertImageRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertImageRequest. */
                class InsertImageRequest implements IInsertImageRequest {

                    /**
                     * Constructs a new InsertImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertImageRequest);

                    /** InsertImageRequest forceCreate. */
                    public forceCreate?: (boolean|null);

                    /** InsertImageRequest imageResource. */
                    public imageResource?: (google.cloud.compute.v1.IImage|null);

                    /** InsertImageRequest project. */
                    public project: string;

                    /** InsertImageRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertImageRequest _forceCreate. */
                    public _forceCreate?: "forceCreate";

                    /** InsertImageRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertImageRequest): google.cloud.compute.v1.InsertImageRequest;

                    /**
                     * Encodes the specified InsertImageRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertImageRequest.verify|verify} messages.
                     * @param message InsertImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertImageRequest.verify|verify} messages.
                     * @param message InsertImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertImageRequest;

                    /**
                     * Decodes an InsertImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertImageRequest;

                    /**
                     * Verifies an InsertImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertImageRequest;

                    /**
                     * Creates a plain object from an InsertImageRequest message. Also converts values to other types if specified.
                     * @param message InsertImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertInstanceGroupManagerRequest. */
                interface IInsertInstanceGroupManagerRequest {

                    /** InsertInstanceGroupManagerRequest instanceGroupManagerResource */
                    instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** InsertInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** InsertInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** InsertInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertInstanceGroupManagerRequest. */
                class InsertInstanceGroupManagerRequest implements IInsertInstanceGroupManagerRequest {

                    /**
                     * Constructs a new InsertInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertInstanceGroupManagerRequest);

                    /** InsertInstanceGroupManagerRequest instanceGroupManagerResource. */
                    public instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** InsertInstanceGroupManagerRequest project. */
                    public project: string;

                    /** InsertInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** InsertInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertInstanceGroupManagerRequest): google.cloud.compute.v1.InsertInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified InsertInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message InsertInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message InsertInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertInstanceGroupManagerRequest;

                    /**
                     * Decodes an InsertInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertInstanceGroupManagerRequest;

                    /**
                     * Verifies an InsertInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an InsertInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message InsertInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertInstanceGroupRequest. */
                interface IInsertInstanceGroupRequest {

                    /** InsertInstanceGroupRequest instanceGroupResource */
                    instanceGroupResource?: (google.cloud.compute.v1.IInstanceGroup|null);

                    /** InsertInstanceGroupRequest project */
                    project?: (string|null);

                    /** InsertInstanceGroupRequest requestId */
                    requestId?: (string|null);

                    /** InsertInstanceGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertInstanceGroupRequest. */
                class InsertInstanceGroupRequest implements IInsertInstanceGroupRequest {

                    /**
                     * Constructs a new InsertInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertInstanceGroupRequest);

                    /** InsertInstanceGroupRequest instanceGroupResource. */
                    public instanceGroupResource?: (google.cloud.compute.v1.IInstanceGroup|null);

                    /** InsertInstanceGroupRequest project. */
                    public project: string;

                    /** InsertInstanceGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertInstanceGroupRequest zone. */
                    public zone: string;

                    /** InsertInstanceGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertInstanceGroupRequest): google.cloud.compute.v1.InsertInstanceGroupRequest;

                    /**
                     * Encodes the specified InsertInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceGroupRequest.verify|verify} messages.
                     * @param message InsertInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceGroupRequest.verify|verify} messages.
                     * @param message InsertInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertInstanceGroupRequest;

                    /**
                     * Decodes an InsertInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertInstanceGroupRequest;

                    /**
                     * Verifies an InsertInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertInstanceGroupRequest;

                    /**
                     * Creates a plain object from an InsertInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message InsertInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertInstanceRequest. */
                interface IInsertInstanceRequest {

                    /** InsertInstanceRequest instanceResource */
                    instanceResource?: (google.cloud.compute.v1.IInstance|null);

                    /** InsertInstanceRequest project */
                    project?: (string|null);

                    /** InsertInstanceRequest requestId */
                    requestId?: (string|null);

                    /** InsertInstanceRequest sourceInstanceTemplate */
                    sourceInstanceTemplate?: (string|null);

                    /** InsertInstanceRequest sourceMachineImage */
                    sourceMachineImage?: (string|null);

                    /** InsertInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertInstanceRequest. */
                class InsertInstanceRequest implements IInsertInstanceRequest {

                    /**
                     * Constructs a new InsertInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertInstanceRequest);

                    /** InsertInstanceRequest instanceResource. */
                    public instanceResource?: (google.cloud.compute.v1.IInstance|null);

                    /** InsertInstanceRequest project. */
                    public project: string;

                    /** InsertInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertInstanceRequest sourceInstanceTemplate. */
                    public sourceInstanceTemplate?: (string|null);

                    /** InsertInstanceRequest sourceMachineImage. */
                    public sourceMachineImage?: (string|null);

                    /** InsertInstanceRequest zone. */
                    public zone: string;

                    /** InsertInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertInstanceRequest _sourceInstanceTemplate. */
                    public _sourceInstanceTemplate?: "sourceInstanceTemplate";

                    /** InsertInstanceRequest _sourceMachineImage. */
                    public _sourceMachineImage?: "sourceMachineImage";

                    /**
                     * Creates a new InsertInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertInstanceRequest): google.cloud.compute.v1.InsertInstanceRequest;

                    /**
                     * Encodes the specified InsertInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceRequest.verify|verify} messages.
                     * @param message InsertInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceRequest.verify|verify} messages.
                     * @param message InsertInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertInstanceRequest;

                    /**
                     * Decodes an InsertInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertInstanceRequest;

                    /**
                     * Verifies an InsertInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertInstanceRequest;

                    /**
                     * Creates a plain object from an InsertInstanceRequest message. Also converts values to other types if specified.
                     * @param message InsertInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertInstanceTemplateRequest. */
                interface IInsertInstanceTemplateRequest {

                    /** InsertInstanceTemplateRequest instanceTemplateResource */
                    instanceTemplateResource?: (google.cloud.compute.v1.IInstanceTemplate|null);

                    /** InsertInstanceTemplateRequest project */
                    project?: (string|null);

                    /** InsertInstanceTemplateRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertInstanceTemplateRequest. */
                class InsertInstanceTemplateRequest implements IInsertInstanceTemplateRequest {

                    /**
                     * Constructs a new InsertInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertInstanceTemplateRequest);

                    /** InsertInstanceTemplateRequest instanceTemplateResource. */
                    public instanceTemplateResource?: (google.cloud.compute.v1.IInstanceTemplate|null);

                    /** InsertInstanceTemplateRequest project. */
                    public project: string;

                    /** InsertInstanceTemplateRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertInstanceTemplateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertInstanceTemplateRequest): google.cloud.compute.v1.InsertInstanceTemplateRequest;

                    /**
                     * Encodes the specified InsertInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceTemplateRequest.verify|verify} messages.
                     * @param message InsertInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertInstanceTemplateRequest.verify|verify} messages.
                     * @param message InsertInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertInstanceTemplateRequest;

                    /**
                     * Decodes an InsertInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertInstanceTemplateRequest;

                    /**
                     * Verifies an InsertInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertInstanceTemplateRequest;

                    /**
                     * Creates a plain object from an InsertInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message InsertInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertInterconnectAttachmentRequest. */
                interface IInsertInterconnectAttachmentRequest {

                    /** InsertInterconnectAttachmentRequest interconnectAttachmentResource */
                    interconnectAttachmentResource?: (google.cloud.compute.v1.IInterconnectAttachment|null);

                    /** InsertInterconnectAttachmentRequest project */
                    project?: (string|null);

                    /** InsertInterconnectAttachmentRequest region */
                    region?: (string|null);

                    /** InsertInterconnectAttachmentRequest requestId */
                    requestId?: (string|null);

                    /** InsertInterconnectAttachmentRequest validateOnly */
                    validateOnly?: (boolean|null);
                }

                /** Represents an InsertInterconnectAttachmentRequest. */
                class InsertInterconnectAttachmentRequest implements IInsertInterconnectAttachmentRequest {

                    /**
                     * Constructs a new InsertInterconnectAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertInterconnectAttachmentRequest);

                    /** InsertInterconnectAttachmentRequest interconnectAttachmentResource. */
                    public interconnectAttachmentResource?: (google.cloud.compute.v1.IInterconnectAttachment|null);

                    /** InsertInterconnectAttachmentRequest project. */
                    public project: string;

                    /** InsertInterconnectAttachmentRequest region. */
                    public region: string;

                    /** InsertInterconnectAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertInterconnectAttachmentRequest validateOnly. */
                    public validateOnly?: (boolean|null);

                    /** InsertInterconnectAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertInterconnectAttachmentRequest _validateOnly. */
                    public _validateOnly?: "validateOnly";

                    /**
                     * Creates a new InsertInterconnectAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertInterconnectAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertInterconnectAttachmentRequest): google.cloud.compute.v1.InsertInterconnectAttachmentRequest;

                    /**
                     * Encodes the specified InsertInterconnectAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message InsertInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertInterconnectAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message InsertInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertInterconnectAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertInterconnectAttachmentRequest;

                    /**
                     * Decodes an InsertInterconnectAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertInterconnectAttachmentRequest;

                    /**
                     * Verifies an InsertInterconnectAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertInterconnectAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertInterconnectAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertInterconnectAttachmentRequest;

                    /**
                     * Creates a plain object from an InsertInterconnectAttachmentRequest message. Also converts values to other types if specified.
                     * @param message InsertInterconnectAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertInterconnectAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertInterconnectAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertInterconnectAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertInterconnectRequest. */
                interface IInsertInterconnectRequest {

                    /** InsertInterconnectRequest interconnectResource */
                    interconnectResource?: (google.cloud.compute.v1.IInterconnect|null);

                    /** InsertInterconnectRequest project */
                    project?: (string|null);

                    /** InsertInterconnectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertInterconnectRequest. */
                class InsertInterconnectRequest implements IInsertInterconnectRequest {

                    /**
                     * Constructs a new InsertInterconnectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertInterconnectRequest);

                    /** InsertInterconnectRequest interconnectResource. */
                    public interconnectResource?: (google.cloud.compute.v1.IInterconnect|null);

                    /** InsertInterconnectRequest project. */
                    public project: string;

                    /** InsertInterconnectRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertInterconnectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertInterconnectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertInterconnectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertInterconnectRequest): google.cloud.compute.v1.InsertInterconnectRequest;

                    /**
                     * Encodes the specified InsertInterconnectRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertInterconnectRequest.verify|verify} messages.
                     * @param message InsertInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertInterconnectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertInterconnectRequest.verify|verify} messages.
                     * @param message InsertInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertInterconnectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertInterconnectRequest;

                    /**
                     * Decodes an InsertInterconnectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertInterconnectRequest;

                    /**
                     * Verifies an InsertInterconnectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertInterconnectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertInterconnectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertInterconnectRequest;

                    /**
                     * Creates a plain object from an InsertInterconnectRequest message. Also converts values to other types if specified.
                     * @param message InsertInterconnectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertInterconnectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertInterconnectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertInterconnectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertLicenseRequest. */
                interface IInsertLicenseRequest {

                    /** InsertLicenseRequest licenseResource */
                    licenseResource?: (google.cloud.compute.v1.ILicense|null);

                    /** InsertLicenseRequest project */
                    project?: (string|null);

                    /** InsertLicenseRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertLicenseRequest. */
                class InsertLicenseRequest implements IInsertLicenseRequest {

                    /**
                     * Constructs a new InsertLicenseRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertLicenseRequest);

                    /** InsertLicenseRequest licenseResource. */
                    public licenseResource?: (google.cloud.compute.v1.ILicense|null);

                    /** InsertLicenseRequest project. */
                    public project: string;

                    /** InsertLicenseRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertLicenseRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertLicenseRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertLicenseRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertLicenseRequest): google.cloud.compute.v1.InsertLicenseRequest;

                    /**
                     * Encodes the specified InsertLicenseRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertLicenseRequest.verify|verify} messages.
                     * @param message InsertLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertLicenseRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertLicenseRequest.verify|verify} messages.
                     * @param message InsertLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertLicenseRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertLicenseRequest;

                    /**
                     * Decodes an InsertLicenseRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertLicenseRequest;

                    /**
                     * Verifies an InsertLicenseRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertLicenseRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertLicenseRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertLicenseRequest;

                    /**
                     * Creates a plain object from an InsertLicenseRequest message. Also converts values to other types if specified.
                     * @param message InsertLicenseRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertLicenseRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertLicenseRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertLicenseRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertMachineImageRequest. */
                interface IInsertMachineImageRequest {

                    /** InsertMachineImageRequest machineImageResource */
                    machineImageResource?: (google.cloud.compute.v1.IMachineImage|null);

                    /** InsertMachineImageRequest project */
                    project?: (string|null);

                    /** InsertMachineImageRequest requestId */
                    requestId?: (string|null);

                    /** InsertMachineImageRequest sourceInstance */
                    sourceInstance?: (string|null);
                }

                /** Represents an InsertMachineImageRequest. */
                class InsertMachineImageRequest implements IInsertMachineImageRequest {

                    /**
                     * Constructs a new InsertMachineImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertMachineImageRequest);

                    /** InsertMachineImageRequest machineImageResource. */
                    public machineImageResource?: (google.cloud.compute.v1.IMachineImage|null);

                    /** InsertMachineImageRequest project. */
                    public project: string;

                    /** InsertMachineImageRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertMachineImageRequest sourceInstance. */
                    public sourceInstance?: (string|null);

                    /** InsertMachineImageRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertMachineImageRequest _sourceInstance. */
                    public _sourceInstance?: "sourceInstance";

                    /**
                     * Creates a new InsertMachineImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertMachineImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertMachineImageRequest): google.cloud.compute.v1.InsertMachineImageRequest;

                    /**
                     * Encodes the specified InsertMachineImageRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertMachineImageRequest.verify|verify} messages.
                     * @param message InsertMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertMachineImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertMachineImageRequest.verify|verify} messages.
                     * @param message InsertMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertMachineImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertMachineImageRequest;

                    /**
                     * Decodes an InsertMachineImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertMachineImageRequest;

                    /**
                     * Verifies an InsertMachineImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertMachineImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertMachineImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertMachineImageRequest;

                    /**
                     * Creates a plain object from an InsertMachineImageRequest message. Also converts values to other types if specified.
                     * @param message InsertMachineImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertMachineImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertMachineImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertMachineImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertNetworkEdgeSecurityServiceRequest. */
                interface IInsertNetworkEdgeSecurityServiceRequest {

                    /** InsertNetworkEdgeSecurityServiceRequest networkEdgeSecurityServiceResource */
                    networkEdgeSecurityServiceResource?: (google.cloud.compute.v1.INetworkEdgeSecurityService|null);

                    /** InsertNetworkEdgeSecurityServiceRequest project */
                    project?: (string|null);

                    /** InsertNetworkEdgeSecurityServiceRequest region */
                    region?: (string|null);

                    /** InsertNetworkEdgeSecurityServiceRequest requestId */
                    requestId?: (string|null);

                    /** InsertNetworkEdgeSecurityServiceRequest validateOnly */
                    validateOnly?: (boolean|null);
                }

                /** Represents an InsertNetworkEdgeSecurityServiceRequest. */
                class InsertNetworkEdgeSecurityServiceRequest implements IInsertNetworkEdgeSecurityServiceRequest {

                    /**
                     * Constructs a new InsertNetworkEdgeSecurityServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertNetworkEdgeSecurityServiceRequest);

                    /** InsertNetworkEdgeSecurityServiceRequest networkEdgeSecurityServiceResource. */
                    public networkEdgeSecurityServiceResource?: (google.cloud.compute.v1.INetworkEdgeSecurityService|null);

                    /** InsertNetworkEdgeSecurityServiceRequest project. */
                    public project: string;

                    /** InsertNetworkEdgeSecurityServiceRequest region. */
                    public region: string;

                    /** InsertNetworkEdgeSecurityServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertNetworkEdgeSecurityServiceRequest validateOnly. */
                    public validateOnly?: (boolean|null);

                    /** InsertNetworkEdgeSecurityServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertNetworkEdgeSecurityServiceRequest _validateOnly. */
                    public _validateOnly?: "validateOnly";

                    /**
                     * Creates a new InsertNetworkEdgeSecurityServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertNetworkEdgeSecurityServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertNetworkEdgeSecurityServiceRequest): google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest;

                    /**
                     * Encodes the specified InsertNetworkEdgeSecurityServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message InsertNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertNetworkEdgeSecurityServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message InsertNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertNetworkEdgeSecurityServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest;

                    /**
                     * Decodes an InsertNetworkEdgeSecurityServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest;

                    /**
                     * Verifies an InsertNetworkEdgeSecurityServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertNetworkEdgeSecurityServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertNetworkEdgeSecurityServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest;

                    /**
                     * Creates a plain object from an InsertNetworkEdgeSecurityServiceRequest message. Also converts values to other types if specified.
                     * @param message InsertNetworkEdgeSecurityServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertNetworkEdgeSecurityServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertNetworkEdgeSecurityServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertNetworkEdgeSecurityServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertNetworkEndpointGroupRequest. */
                interface IInsertNetworkEndpointGroupRequest {

                    /** InsertNetworkEndpointGroupRequest networkEndpointGroupResource */
                    networkEndpointGroupResource?: (google.cloud.compute.v1.INetworkEndpointGroup|null);

                    /** InsertNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** InsertNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);

                    /** InsertNetworkEndpointGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertNetworkEndpointGroupRequest. */
                class InsertNetworkEndpointGroupRequest implements IInsertNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new InsertNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertNetworkEndpointGroupRequest);

                    /** InsertNetworkEndpointGroupRequest networkEndpointGroupResource. */
                    public networkEndpointGroupResource?: (google.cloud.compute.v1.INetworkEndpointGroup|null);

                    /** InsertNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** InsertNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertNetworkEndpointGroupRequest zone. */
                    public zone: string;

                    /** InsertNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertNetworkEndpointGroupRequest): google.cloud.compute.v1.InsertNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified InsertNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message InsertNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message InsertNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertNetworkEndpointGroupRequest;

                    /**
                     * Decodes an InsertNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertNetworkEndpointGroupRequest;

                    /**
                     * Verifies an InsertNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from an InsertNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message InsertNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertNetworkFirewallPolicyRequest. */
                interface IInsertNetworkFirewallPolicyRequest {

                    /** InsertNetworkFirewallPolicyRequest firewallPolicyResource */
                    firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** InsertNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** InsertNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertNetworkFirewallPolicyRequest. */
                class InsertNetworkFirewallPolicyRequest implements IInsertNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new InsertNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertNetworkFirewallPolicyRequest);

                    /** InsertNetworkFirewallPolicyRequest firewallPolicyResource. */
                    public firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** InsertNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** InsertNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertNetworkFirewallPolicyRequest): google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified InsertNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message InsertNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message InsertNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest;

                    /**
                     * Decodes an InsertNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest;

                    /**
                     * Verifies an InsertNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an InsertNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertNetworkRequest. */
                interface IInsertNetworkRequest {

                    /** InsertNetworkRequest networkResource */
                    networkResource?: (google.cloud.compute.v1.INetwork|null);

                    /** InsertNetworkRequest project */
                    project?: (string|null);

                    /** InsertNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertNetworkRequest. */
                class InsertNetworkRequest implements IInsertNetworkRequest {

                    /**
                     * Constructs a new InsertNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertNetworkRequest);

                    /** InsertNetworkRequest networkResource. */
                    public networkResource?: (google.cloud.compute.v1.INetwork|null);

                    /** InsertNetworkRequest project. */
                    public project: string;

                    /** InsertNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertNetworkRequest): google.cloud.compute.v1.InsertNetworkRequest;

                    /**
                     * Encodes the specified InsertNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkRequest.verify|verify} messages.
                     * @param message InsertNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertNetworkRequest.verify|verify} messages.
                     * @param message InsertNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertNetworkRequest;

                    /**
                     * Decodes an InsertNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertNetworkRequest;

                    /**
                     * Verifies an InsertNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertNetworkRequest;

                    /**
                     * Creates a plain object from an InsertNetworkRequest message. Also converts values to other types if specified.
                     * @param message InsertNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertNodeGroupRequest. */
                interface IInsertNodeGroupRequest {

                    /** InsertNodeGroupRequest initialNodeCount */
                    initialNodeCount?: (number|null);

                    /** InsertNodeGroupRequest nodeGroupResource */
                    nodeGroupResource?: (google.cloud.compute.v1.INodeGroup|null);

                    /** InsertNodeGroupRequest project */
                    project?: (string|null);

                    /** InsertNodeGroupRequest requestId */
                    requestId?: (string|null);

                    /** InsertNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertNodeGroupRequest. */
                class InsertNodeGroupRequest implements IInsertNodeGroupRequest {

                    /**
                     * Constructs a new InsertNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertNodeGroupRequest);

                    /** InsertNodeGroupRequest initialNodeCount. */
                    public initialNodeCount: number;

                    /** InsertNodeGroupRequest nodeGroupResource. */
                    public nodeGroupResource?: (google.cloud.compute.v1.INodeGroup|null);

                    /** InsertNodeGroupRequest project. */
                    public project: string;

                    /** InsertNodeGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertNodeGroupRequest zone. */
                    public zone: string;

                    /** InsertNodeGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertNodeGroupRequest): google.cloud.compute.v1.InsertNodeGroupRequest;

                    /**
                     * Encodes the specified InsertNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertNodeGroupRequest.verify|verify} messages.
                     * @param message InsertNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertNodeGroupRequest.verify|verify} messages.
                     * @param message InsertNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertNodeGroupRequest;

                    /**
                     * Decodes an InsertNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertNodeGroupRequest;

                    /**
                     * Verifies an InsertNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertNodeGroupRequest;

                    /**
                     * Creates a plain object from an InsertNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message InsertNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertNodeTemplateRequest. */
                interface IInsertNodeTemplateRequest {

                    /** InsertNodeTemplateRequest nodeTemplateResource */
                    nodeTemplateResource?: (google.cloud.compute.v1.INodeTemplate|null);

                    /** InsertNodeTemplateRequest project */
                    project?: (string|null);

                    /** InsertNodeTemplateRequest region */
                    region?: (string|null);

                    /** InsertNodeTemplateRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertNodeTemplateRequest. */
                class InsertNodeTemplateRequest implements IInsertNodeTemplateRequest {

                    /**
                     * Constructs a new InsertNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertNodeTemplateRequest);

                    /** InsertNodeTemplateRequest nodeTemplateResource. */
                    public nodeTemplateResource?: (google.cloud.compute.v1.INodeTemplate|null);

                    /** InsertNodeTemplateRequest project. */
                    public project: string;

                    /** InsertNodeTemplateRequest region. */
                    public region: string;

                    /** InsertNodeTemplateRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertNodeTemplateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertNodeTemplateRequest): google.cloud.compute.v1.InsertNodeTemplateRequest;

                    /**
                     * Encodes the specified InsertNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertNodeTemplateRequest.verify|verify} messages.
                     * @param message InsertNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertNodeTemplateRequest.verify|verify} messages.
                     * @param message InsertNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertNodeTemplateRequest;

                    /**
                     * Decodes an InsertNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertNodeTemplateRequest;

                    /**
                     * Verifies an InsertNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertNodeTemplateRequest;

                    /**
                     * Creates a plain object from an InsertNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message InsertNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertPacketMirroringRequest. */
                interface IInsertPacketMirroringRequest {

                    /** InsertPacketMirroringRequest packetMirroringResource */
                    packetMirroringResource?: (google.cloud.compute.v1.IPacketMirroring|null);

                    /** InsertPacketMirroringRequest project */
                    project?: (string|null);

                    /** InsertPacketMirroringRequest region */
                    region?: (string|null);

                    /** InsertPacketMirroringRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertPacketMirroringRequest. */
                class InsertPacketMirroringRequest implements IInsertPacketMirroringRequest {

                    /**
                     * Constructs a new InsertPacketMirroringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertPacketMirroringRequest);

                    /** InsertPacketMirroringRequest packetMirroringResource. */
                    public packetMirroringResource?: (google.cloud.compute.v1.IPacketMirroring|null);

                    /** InsertPacketMirroringRequest project. */
                    public project: string;

                    /** InsertPacketMirroringRequest region. */
                    public region: string;

                    /** InsertPacketMirroringRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertPacketMirroringRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertPacketMirroringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertPacketMirroringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertPacketMirroringRequest): google.cloud.compute.v1.InsertPacketMirroringRequest;

                    /**
                     * Encodes the specified InsertPacketMirroringRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertPacketMirroringRequest.verify|verify} messages.
                     * @param message InsertPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertPacketMirroringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertPacketMirroringRequest.verify|verify} messages.
                     * @param message InsertPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertPacketMirroringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertPacketMirroringRequest;

                    /**
                     * Decodes an InsertPacketMirroringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertPacketMirroringRequest;

                    /**
                     * Verifies an InsertPacketMirroringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertPacketMirroringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertPacketMirroringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertPacketMirroringRequest;

                    /**
                     * Creates a plain object from an InsertPacketMirroringRequest message. Also converts values to other types if specified.
                     * @param message InsertPacketMirroringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertPacketMirroringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertPacketMirroringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertPacketMirroringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertPublicAdvertisedPrefixeRequest. */
                interface IInsertPublicAdvertisedPrefixeRequest {

                    /** InsertPublicAdvertisedPrefixeRequest project */
                    project?: (string|null);

                    /** InsertPublicAdvertisedPrefixeRequest publicAdvertisedPrefixResource */
                    publicAdvertisedPrefixResource?: (google.cloud.compute.v1.IPublicAdvertisedPrefix|null);

                    /** InsertPublicAdvertisedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertPublicAdvertisedPrefixeRequest. */
                class InsertPublicAdvertisedPrefixeRequest implements IInsertPublicAdvertisedPrefixeRequest {

                    /**
                     * Constructs a new InsertPublicAdvertisedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertPublicAdvertisedPrefixeRequest);

                    /** InsertPublicAdvertisedPrefixeRequest project. */
                    public project: string;

                    /** InsertPublicAdvertisedPrefixeRequest publicAdvertisedPrefixResource. */
                    public publicAdvertisedPrefixResource?: (google.cloud.compute.v1.IPublicAdvertisedPrefix|null);

                    /** InsertPublicAdvertisedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertPublicAdvertisedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertPublicAdvertisedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertPublicAdvertisedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertPublicAdvertisedPrefixeRequest): google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest;

                    /**
                     * Encodes the specified InsertPublicAdvertisedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message InsertPublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertPublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertPublicAdvertisedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message InsertPublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertPublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertPublicAdvertisedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertPublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest;

                    /**
                     * Decodes an InsertPublicAdvertisedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertPublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest;

                    /**
                     * Verifies an InsertPublicAdvertisedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertPublicAdvertisedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertPublicAdvertisedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest;

                    /**
                     * Creates a plain object from an InsertPublicAdvertisedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message InsertPublicAdvertisedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertPublicAdvertisedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertPublicAdvertisedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertPublicAdvertisedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertPublicDelegatedPrefixeRequest. */
                interface IInsertPublicDelegatedPrefixeRequest {

                    /** InsertPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** InsertPublicDelegatedPrefixeRequest publicDelegatedPrefixResource */
                    publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** InsertPublicDelegatedPrefixeRequest region */
                    region?: (string|null);

                    /** InsertPublicDelegatedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertPublicDelegatedPrefixeRequest. */
                class InsertPublicDelegatedPrefixeRequest implements IInsertPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new InsertPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertPublicDelegatedPrefixeRequest);

                    /** InsertPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** InsertPublicDelegatedPrefixeRequest publicDelegatedPrefixResource. */
                    public publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** InsertPublicDelegatedPrefixeRequest region. */
                    public region: string;

                    /** InsertPublicDelegatedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertPublicDelegatedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertPublicDelegatedPrefixeRequest): google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified InsertPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message InsertPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message InsertPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes an InsertPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies an InsertPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from an InsertPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message InsertPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionAutoscalerRequest. */
                interface IInsertRegionAutoscalerRequest {

                    /** InsertRegionAutoscalerRequest autoscalerResource */
                    autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** InsertRegionAutoscalerRequest project */
                    project?: (string|null);

                    /** InsertRegionAutoscalerRequest region */
                    region?: (string|null);

                    /** InsertRegionAutoscalerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionAutoscalerRequest. */
                class InsertRegionAutoscalerRequest implements IInsertRegionAutoscalerRequest {

                    /**
                     * Constructs a new InsertRegionAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionAutoscalerRequest);

                    /** InsertRegionAutoscalerRequest autoscalerResource. */
                    public autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** InsertRegionAutoscalerRequest project. */
                    public project: string;

                    /** InsertRegionAutoscalerRequest region. */
                    public region: string;

                    /** InsertRegionAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionAutoscalerRequest): google.cloud.compute.v1.InsertRegionAutoscalerRequest;

                    /**
                     * Encodes the specified InsertRegionAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionAutoscalerRequest.verify|verify} messages.
                     * @param message InsertRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionAutoscalerRequest.verify|verify} messages.
                     * @param message InsertRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionAutoscalerRequest;

                    /**
                     * Decodes an InsertRegionAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionAutoscalerRequest;

                    /**
                     * Verifies an InsertRegionAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionAutoscalerRequest;

                    /**
                     * Creates a plain object from an InsertRegionAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionBackendServiceRequest. */
                interface IInsertRegionBackendServiceRequest {

                    /** InsertRegionBackendServiceRequest backendServiceResource */
                    backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** InsertRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** InsertRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** InsertRegionBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionBackendServiceRequest. */
                class InsertRegionBackendServiceRequest implements IInsertRegionBackendServiceRequest {

                    /**
                     * Constructs a new InsertRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionBackendServiceRequest);

                    /** InsertRegionBackendServiceRequest backendServiceResource. */
                    public backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** InsertRegionBackendServiceRequest project. */
                    public project: string;

                    /** InsertRegionBackendServiceRequest region. */
                    public region: string;

                    /** InsertRegionBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionBackendServiceRequest): google.cloud.compute.v1.InsertRegionBackendServiceRequest;

                    /**
                     * Encodes the specified InsertRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionBackendServiceRequest.verify|verify} messages.
                     * @param message InsertRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionBackendServiceRequest.verify|verify} messages.
                     * @param message InsertRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionBackendServiceRequest;

                    /**
                     * Decodes an InsertRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionBackendServiceRequest;

                    /**
                     * Verifies an InsertRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from an InsertRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionCommitmentRequest. */
                interface IInsertRegionCommitmentRequest {

                    /** InsertRegionCommitmentRequest commitmentResource */
                    commitmentResource?: (google.cloud.compute.v1.ICommitment|null);

                    /** InsertRegionCommitmentRequest project */
                    project?: (string|null);

                    /** InsertRegionCommitmentRequest region */
                    region?: (string|null);

                    /** InsertRegionCommitmentRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionCommitmentRequest. */
                class InsertRegionCommitmentRequest implements IInsertRegionCommitmentRequest {

                    /**
                     * Constructs a new InsertRegionCommitmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionCommitmentRequest);

                    /** InsertRegionCommitmentRequest commitmentResource. */
                    public commitmentResource?: (google.cloud.compute.v1.ICommitment|null);

                    /** InsertRegionCommitmentRequest project. */
                    public project: string;

                    /** InsertRegionCommitmentRequest region. */
                    public region: string;

                    /** InsertRegionCommitmentRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionCommitmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionCommitmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionCommitmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionCommitmentRequest): google.cloud.compute.v1.InsertRegionCommitmentRequest;

                    /**
                     * Encodes the specified InsertRegionCommitmentRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionCommitmentRequest.verify|verify} messages.
                     * @param message InsertRegionCommitmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionCommitmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionCommitmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionCommitmentRequest.verify|verify} messages.
                     * @param message InsertRegionCommitmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionCommitmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionCommitmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionCommitmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionCommitmentRequest;

                    /**
                     * Decodes an InsertRegionCommitmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionCommitmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionCommitmentRequest;

                    /**
                     * Verifies an InsertRegionCommitmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionCommitmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionCommitmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionCommitmentRequest;

                    /**
                     * Creates a plain object from an InsertRegionCommitmentRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionCommitmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionCommitmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionCommitmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionCommitmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionDiskRequest. */
                interface IInsertRegionDiskRequest {

                    /** InsertRegionDiskRequest diskResource */
                    diskResource?: (google.cloud.compute.v1.IDisk|null);

                    /** InsertRegionDiskRequest project */
                    project?: (string|null);

                    /** InsertRegionDiskRequest region */
                    region?: (string|null);

                    /** InsertRegionDiskRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionDiskRequest sourceImage */
                    sourceImage?: (string|null);
                }

                /** Represents an InsertRegionDiskRequest. */
                class InsertRegionDiskRequest implements IInsertRegionDiskRequest {

                    /**
                     * Constructs a new InsertRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionDiskRequest);

                    /** InsertRegionDiskRequest diskResource. */
                    public diskResource?: (google.cloud.compute.v1.IDisk|null);

                    /** InsertRegionDiskRequest project. */
                    public project: string;

                    /** InsertRegionDiskRequest region. */
                    public region: string;

                    /** InsertRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionDiskRequest sourceImage. */
                    public sourceImage?: (string|null);

                    /** InsertRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertRegionDiskRequest _sourceImage. */
                    public _sourceImage?: "sourceImage";

                    /**
                     * Creates a new InsertRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionDiskRequest): google.cloud.compute.v1.InsertRegionDiskRequest;

                    /**
                     * Encodes the specified InsertRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionDiskRequest.verify|verify} messages.
                     * @param message InsertRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionDiskRequest.verify|verify} messages.
                     * @param message InsertRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionDiskRequest;

                    /**
                     * Decodes an InsertRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionDiskRequest;

                    /**
                     * Verifies an InsertRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionDiskRequest;

                    /**
                     * Creates a plain object from an InsertRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionHealthCheckRequest. */
                interface IInsertRegionHealthCheckRequest {

                    /** InsertRegionHealthCheckRequest healthCheckResource */
                    healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** InsertRegionHealthCheckRequest project */
                    project?: (string|null);

                    /** InsertRegionHealthCheckRequest region */
                    region?: (string|null);

                    /** InsertRegionHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionHealthCheckRequest. */
                class InsertRegionHealthCheckRequest implements IInsertRegionHealthCheckRequest {

                    /**
                     * Constructs a new InsertRegionHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionHealthCheckRequest);

                    /** InsertRegionHealthCheckRequest healthCheckResource. */
                    public healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** InsertRegionHealthCheckRequest project. */
                    public project: string;

                    /** InsertRegionHealthCheckRequest region. */
                    public region: string;

                    /** InsertRegionHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionHealthCheckRequest): google.cloud.compute.v1.InsertRegionHealthCheckRequest;

                    /**
                     * Encodes the specified InsertRegionHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionHealthCheckRequest.verify|verify} messages.
                     * @param message InsertRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionHealthCheckRequest.verify|verify} messages.
                     * @param message InsertRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionHealthCheckRequest;

                    /**
                     * Decodes an InsertRegionHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionHealthCheckRequest;

                    /**
                     * Verifies an InsertRegionHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionHealthCheckRequest;

                    /**
                     * Creates a plain object from an InsertRegionHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionHealthCheckServiceRequest. */
                interface IInsertRegionHealthCheckServiceRequest {

                    /** InsertRegionHealthCheckServiceRequest healthCheckServiceResource */
                    healthCheckServiceResource?: (google.cloud.compute.v1.IHealthCheckService|null);

                    /** InsertRegionHealthCheckServiceRequest project */
                    project?: (string|null);

                    /** InsertRegionHealthCheckServiceRequest region */
                    region?: (string|null);

                    /** InsertRegionHealthCheckServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionHealthCheckServiceRequest. */
                class InsertRegionHealthCheckServiceRequest implements IInsertRegionHealthCheckServiceRequest {

                    /**
                     * Constructs a new InsertRegionHealthCheckServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionHealthCheckServiceRequest);

                    /** InsertRegionHealthCheckServiceRequest healthCheckServiceResource. */
                    public healthCheckServiceResource?: (google.cloud.compute.v1.IHealthCheckService|null);

                    /** InsertRegionHealthCheckServiceRequest project. */
                    public project: string;

                    /** InsertRegionHealthCheckServiceRequest region. */
                    public region: string;

                    /** InsertRegionHealthCheckServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionHealthCheckServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionHealthCheckServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionHealthCheckServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionHealthCheckServiceRequest): google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest;

                    /**
                     * Encodes the specified InsertRegionHealthCheckServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message InsertRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionHealthCheckServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message InsertRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionHealthCheckServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest;

                    /**
                     * Decodes an InsertRegionHealthCheckServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest;

                    /**
                     * Verifies an InsertRegionHealthCheckServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionHealthCheckServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionHealthCheckServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest;

                    /**
                     * Creates a plain object from an InsertRegionHealthCheckServiceRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionHealthCheckServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionHealthCheckServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionHealthCheckServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionHealthCheckServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionInstanceGroupManagerRequest. */
                interface IInsertRegionInstanceGroupManagerRequest {

                    /** InsertRegionInstanceGroupManagerRequest instanceGroupManagerResource */
                    instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** InsertRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** InsertRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** InsertRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionInstanceGroupManagerRequest. */
                class InsertRegionInstanceGroupManagerRequest implements IInsertRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new InsertRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest);

                    /** InsertRegionInstanceGroupManagerRequest instanceGroupManagerResource. */
                    public instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** InsertRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** InsertRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** InsertRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest): google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified InsertRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message InsertRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message InsertRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes an InsertRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies an InsertRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an InsertRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionNetworkEndpointGroupRequest. */
                interface IInsertRegionNetworkEndpointGroupRequest {

                    /** InsertRegionNetworkEndpointGroupRequest networkEndpointGroupResource */
                    networkEndpointGroupResource?: (google.cloud.compute.v1.INetworkEndpointGroup|null);

                    /** InsertRegionNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** InsertRegionNetworkEndpointGroupRequest region */
                    region?: (string|null);

                    /** InsertRegionNetworkEndpointGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionNetworkEndpointGroupRequest. */
                class InsertRegionNetworkEndpointGroupRequest implements IInsertRegionNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new InsertRegionNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionNetworkEndpointGroupRequest);

                    /** InsertRegionNetworkEndpointGroupRequest networkEndpointGroupResource. */
                    public networkEndpointGroupResource?: (google.cloud.compute.v1.INetworkEndpointGroup|null);

                    /** InsertRegionNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** InsertRegionNetworkEndpointGroupRequest region. */
                    public region: string;

                    /** InsertRegionNetworkEndpointGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionNetworkEndpointGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionNetworkEndpointGroupRequest): google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified InsertRegionNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message InsertRegionNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message InsertRegionNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest;

                    /**
                     * Decodes an InsertRegionNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest;

                    /**
                     * Verifies an InsertRegionNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from an InsertRegionNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionNetworkFirewallPolicyRequest. */
                interface IInsertRegionNetworkFirewallPolicyRequest {

                    /** InsertRegionNetworkFirewallPolicyRequest firewallPolicyResource */
                    firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** InsertRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** InsertRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** InsertRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionNetworkFirewallPolicyRequest. */
                class InsertRegionNetworkFirewallPolicyRequest implements IInsertRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new InsertRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionNetworkFirewallPolicyRequest);

                    /** InsertRegionNetworkFirewallPolicyRequest firewallPolicyResource. */
                    public firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** InsertRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** InsertRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** InsertRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified InsertRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message InsertRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message InsertRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes an InsertRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies an InsertRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from an InsertRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionNotificationEndpointRequest. */
                interface IInsertRegionNotificationEndpointRequest {

                    /** InsertRegionNotificationEndpointRequest notificationEndpointResource */
                    notificationEndpointResource?: (google.cloud.compute.v1.INotificationEndpoint|null);

                    /** InsertRegionNotificationEndpointRequest project */
                    project?: (string|null);

                    /** InsertRegionNotificationEndpointRequest region */
                    region?: (string|null);

                    /** InsertRegionNotificationEndpointRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertRegionNotificationEndpointRequest. */
                class InsertRegionNotificationEndpointRequest implements IInsertRegionNotificationEndpointRequest {

                    /**
                     * Constructs a new InsertRegionNotificationEndpointRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionNotificationEndpointRequest);

                    /** InsertRegionNotificationEndpointRequest notificationEndpointResource. */
                    public notificationEndpointResource?: (google.cloud.compute.v1.INotificationEndpoint|null);

                    /** InsertRegionNotificationEndpointRequest project. */
                    public project: string;

                    /** InsertRegionNotificationEndpointRequest region. */
                    public region: string;

                    /** InsertRegionNotificationEndpointRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionNotificationEndpointRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionNotificationEndpointRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionNotificationEndpointRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionNotificationEndpointRequest): google.cloud.compute.v1.InsertRegionNotificationEndpointRequest;

                    /**
                     * Encodes the specified InsertRegionNotificationEndpointRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionNotificationEndpointRequest.verify|verify} messages.
                     * @param message InsertRegionNotificationEndpointRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionNotificationEndpointRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionNotificationEndpointRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionNotificationEndpointRequest.verify|verify} messages.
                     * @param message InsertRegionNotificationEndpointRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionNotificationEndpointRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionNotificationEndpointRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionNotificationEndpointRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionNotificationEndpointRequest;

                    /**
                     * Decodes an InsertRegionNotificationEndpointRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionNotificationEndpointRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionNotificationEndpointRequest;

                    /**
                     * Verifies an InsertRegionNotificationEndpointRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionNotificationEndpointRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionNotificationEndpointRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionNotificationEndpointRequest;

                    /**
                     * Creates a plain object from an InsertRegionNotificationEndpointRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionNotificationEndpointRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionNotificationEndpointRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionNotificationEndpointRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionNotificationEndpointRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionSecurityPolicyRequest. */
                interface IInsertRegionSecurityPolicyRequest {

                    /** InsertRegionSecurityPolicyRequest project */
                    project?: (string|null);

                    /** InsertRegionSecurityPolicyRequest region */
                    region?: (string|null);

                    /** InsertRegionSecurityPolicyRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionSecurityPolicyRequest securityPolicyResource */
                    securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);

                    /** InsertRegionSecurityPolicyRequest validateOnly */
                    validateOnly?: (boolean|null);
                }

                /** Represents an InsertRegionSecurityPolicyRequest. */
                class InsertRegionSecurityPolicyRequest implements IInsertRegionSecurityPolicyRequest {

                    /**
                     * Constructs a new InsertRegionSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionSecurityPolicyRequest);

                    /** InsertRegionSecurityPolicyRequest project. */
                    public project: string;

                    /** InsertRegionSecurityPolicyRequest region. */
                    public region: string;

                    /** InsertRegionSecurityPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionSecurityPolicyRequest securityPolicyResource. */
                    public securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);

                    /** InsertRegionSecurityPolicyRequest validateOnly. */
                    public validateOnly?: (boolean|null);

                    /** InsertRegionSecurityPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertRegionSecurityPolicyRequest _validateOnly. */
                    public _validateOnly?: "validateOnly";

                    /**
                     * Creates a new InsertRegionSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionSecurityPolicyRequest): google.cloud.compute.v1.InsertRegionSecurityPolicyRequest;

                    /**
                     * Encodes the specified InsertRegionSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message InsertRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message InsertRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionSecurityPolicyRequest;

                    /**
                     * Decodes an InsertRegionSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionSecurityPolicyRequest;

                    /**
                     * Verifies an InsertRegionSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionSecurityPolicyRequest;

                    /**
                     * Creates a plain object from an InsertRegionSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionSslCertificateRequest. */
                interface IInsertRegionSslCertificateRequest {

                    /** InsertRegionSslCertificateRequest project */
                    project?: (string|null);

                    /** InsertRegionSslCertificateRequest region */
                    region?: (string|null);

                    /** InsertRegionSslCertificateRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionSslCertificateRequest sslCertificateResource */
                    sslCertificateResource?: (google.cloud.compute.v1.ISslCertificate|null);
                }

                /** Represents an InsertRegionSslCertificateRequest. */
                class InsertRegionSslCertificateRequest implements IInsertRegionSslCertificateRequest {

                    /**
                     * Constructs a new InsertRegionSslCertificateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionSslCertificateRequest);

                    /** InsertRegionSslCertificateRequest project. */
                    public project: string;

                    /** InsertRegionSslCertificateRequest region. */
                    public region: string;

                    /** InsertRegionSslCertificateRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionSslCertificateRequest sslCertificateResource. */
                    public sslCertificateResource?: (google.cloud.compute.v1.ISslCertificate|null);

                    /** InsertRegionSslCertificateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionSslCertificateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionSslCertificateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionSslCertificateRequest): google.cloud.compute.v1.InsertRegionSslCertificateRequest;

                    /**
                     * Encodes the specified InsertRegionSslCertificateRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionSslCertificateRequest.verify|verify} messages.
                     * @param message InsertRegionSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionSslCertificateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionSslCertificateRequest.verify|verify} messages.
                     * @param message InsertRegionSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionSslCertificateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionSslCertificateRequest;

                    /**
                     * Decodes an InsertRegionSslCertificateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionSslCertificateRequest;

                    /**
                     * Verifies an InsertRegionSslCertificateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionSslCertificateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionSslCertificateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionSslCertificateRequest;

                    /**
                     * Creates a plain object from an InsertRegionSslCertificateRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionSslCertificateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionSslCertificateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionSslCertificateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionSslCertificateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionSslPolicyRequest. */
                interface IInsertRegionSslPolicyRequest {

                    /** InsertRegionSslPolicyRequest project */
                    project?: (string|null);

                    /** InsertRegionSslPolicyRequest region */
                    region?: (string|null);

                    /** InsertRegionSslPolicyRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionSslPolicyRequest sslPolicyResource */
                    sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);
                }

                /** Represents an InsertRegionSslPolicyRequest. */
                class InsertRegionSslPolicyRequest implements IInsertRegionSslPolicyRequest {

                    /**
                     * Constructs a new InsertRegionSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionSslPolicyRequest);

                    /** InsertRegionSslPolicyRequest project. */
                    public project: string;

                    /** InsertRegionSslPolicyRequest region. */
                    public region: string;

                    /** InsertRegionSslPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionSslPolicyRequest sslPolicyResource. */
                    public sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);

                    /** InsertRegionSslPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionSslPolicyRequest): google.cloud.compute.v1.InsertRegionSslPolicyRequest;

                    /**
                     * Encodes the specified InsertRegionSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionSslPolicyRequest.verify|verify} messages.
                     * @param message InsertRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionSslPolicyRequest.verify|verify} messages.
                     * @param message InsertRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionSslPolicyRequest;

                    /**
                     * Decodes an InsertRegionSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionSslPolicyRequest;

                    /**
                     * Verifies an InsertRegionSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionSslPolicyRequest;

                    /**
                     * Creates a plain object from an InsertRegionSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionTargetHttpProxyRequest. */
                interface IInsertRegionTargetHttpProxyRequest {

                    /** InsertRegionTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** InsertRegionTargetHttpProxyRequest region */
                    region?: (string|null);

                    /** InsertRegionTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionTargetHttpProxyRequest targetHttpProxyResource */
                    targetHttpProxyResource?: (google.cloud.compute.v1.ITargetHttpProxy|null);
                }

                /** Represents an InsertRegionTargetHttpProxyRequest. */
                class InsertRegionTargetHttpProxyRequest implements IInsertRegionTargetHttpProxyRequest {

                    /**
                     * Constructs a new InsertRegionTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionTargetHttpProxyRequest);

                    /** InsertRegionTargetHttpProxyRequest project. */
                    public project: string;

                    /** InsertRegionTargetHttpProxyRequest region. */
                    public region: string;

                    /** InsertRegionTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionTargetHttpProxyRequest targetHttpProxyResource. */
                    public targetHttpProxyResource?: (google.cloud.compute.v1.ITargetHttpProxy|null);

                    /** InsertRegionTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionTargetHttpProxyRequest): google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest;

                    /**
                     * Encodes the specified InsertRegionTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message InsertRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message InsertRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest;

                    /**
                     * Decodes an InsertRegionTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest;

                    /**
                     * Verifies an InsertRegionTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from an InsertRegionTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionTargetHttpsProxyRequest. */
                interface IInsertRegionTargetHttpsProxyRequest {

                    /** InsertRegionTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** InsertRegionTargetHttpsProxyRequest region */
                    region?: (string|null);

                    /** InsertRegionTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionTargetHttpsProxyRequest targetHttpsProxyResource */
                    targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);
                }

                /** Represents an InsertRegionTargetHttpsProxyRequest. */
                class InsertRegionTargetHttpsProxyRequest implements IInsertRegionTargetHttpsProxyRequest {

                    /**
                     * Constructs a new InsertRegionTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionTargetHttpsProxyRequest);

                    /** InsertRegionTargetHttpsProxyRequest project. */
                    public project: string;

                    /** InsertRegionTargetHttpsProxyRequest region. */
                    public region: string;

                    /** InsertRegionTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionTargetHttpsProxyRequest targetHttpsProxyResource. */
                    public targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);

                    /** InsertRegionTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionTargetHttpsProxyRequest): google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified InsertRegionTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message InsertRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message InsertRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest;

                    /**
                     * Decodes an InsertRegionTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest;

                    /**
                     * Verifies an InsertRegionTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from an InsertRegionTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionTargetTcpProxyRequest. */
                interface IInsertRegionTargetTcpProxyRequest {

                    /** InsertRegionTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** InsertRegionTargetTcpProxyRequest region */
                    region?: (string|null);

                    /** InsertRegionTargetTcpProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionTargetTcpProxyRequest targetTcpProxyResource */
                    targetTcpProxyResource?: (google.cloud.compute.v1.ITargetTcpProxy|null);
                }

                /** Represents an InsertRegionTargetTcpProxyRequest. */
                class InsertRegionTargetTcpProxyRequest implements IInsertRegionTargetTcpProxyRequest {

                    /**
                     * Constructs a new InsertRegionTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionTargetTcpProxyRequest);

                    /** InsertRegionTargetTcpProxyRequest project. */
                    public project: string;

                    /** InsertRegionTargetTcpProxyRequest region. */
                    public region: string;

                    /** InsertRegionTargetTcpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionTargetTcpProxyRequest targetTcpProxyResource. */
                    public targetTcpProxyResource?: (google.cloud.compute.v1.ITargetTcpProxy|null);

                    /** InsertRegionTargetTcpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionTargetTcpProxyRequest): google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest;

                    /**
                     * Encodes the specified InsertRegionTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest.verify|verify} messages.
                     * @param message InsertRegionTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest.verify|verify} messages.
                     * @param message InsertRegionTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest;

                    /**
                     * Decodes an InsertRegionTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest;

                    /**
                     * Verifies an InsertRegionTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from an InsertRegionTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRegionUrlMapRequest. */
                interface IInsertRegionUrlMapRequest {

                    /** InsertRegionUrlMapRequest project */
                    project?: (string|null);

                    /** InsertRegionUrlMapRequest region */
                    region?: (string|null);

                    /** InsertRegionUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** InsertRegionUrlMapRequest urlMapResource */
                    urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents an InsertRegionUrlMapRequest. */
                class InsertRegionUrlMapRequest implements IInsertRegionUrlMapRequest {

                    /**
                     * Constructs a new InsertRegionUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRegionUrlMapRequest);

                    /** InsertRegionUrlMapRequest project. */
                    public project: string;

                    /** InsertRegionUrlMapRequest region. */
                    public region: string;

                    /** InsertRegionUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRegionUrlMapRequest urlMapResource. */
                    public urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** InsertRegionUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRegionUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRegionUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRegionUrlMapRequest): google.cloud.compute.v1.InsertRegionUrlMapRequest;

                    /**
                     * Encodes the specified InsertRegionUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRegionUrlMapRequest.verify|verify} messages.
                     * @param message InsertRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRegionUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRegionUrlMapRequest.verify|verify} messages.
                     * @param message InsertRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRegionUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRegionUrlMapRequest;

                    /**
                     * Decodes an InsertRegionUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRegionUrlMapRequest;

                    /**
                     * Verifies an InsertRegionUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRegionUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRegionUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRegionUrlMapRequest;

                    /**
                     * Creates a plain object from an InsertRegionUrlMapRequest message. Also converts values to other types if specified.
                     * @param message InsertRegionUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRegionUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRegionUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRegionUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertReservationRequest. */
                interface IInsertReservationRequest {

                    /** InsertReservationRequest project */
                    project?: (string|null);

                    /** InsertReservationRequest requestId */
                    requestId?: (string|null);

                    /** InsertReservationRequest reservationResource */
                    reservationResource?: (google.cloud.compute.v1.IReservation|null);

                    /** InsertReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertReservationRequest. */
                class InsertReservationRequest implements IInsertReservationRequest {

                    /**
                     * Constructs a new InsertReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertReservationRequest);

                    /** InsertReservationRequest project. */
                    public project: string;

                    /** InsertReservationRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertReservationRequest reservationResource. */
                    public reservationResource?: (google.cloud.compute.v1.IReservation|null);

                    /** InsertReservationRequest zone. */
                    public zone: string;

                    /** InsertReservationRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertReservationRequest): google.cloud.compute.v1.InsertReservationRequest;

                    /**
                     * Encodes the specified InsertReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertReservationRequest.verify|verify} messages.
                     * @param message InsertReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertReservationRequest.verify|verify} messages.
                     * @param message InsertReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertReservationRequest;

                    /**
                     * Decodes an InsertReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertReservationRequest;

                    /**
                     * Verifies an InsertReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertReservationRequest;

                    /**
                     * Creates a plain object from an InsertReservationRequest message. Also converts values to other types if specified.
                     * @param message InsertReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertResourcePolicyRequest. */
                interface IInsertResourcePolicyRequest {

                    /** InsertResourcePolicyRequest project */
                    project?: (string|null);

                    /** InsertResourcePolicyRequest region */
                    region?: (string|null);

                    /** InsertResourcePolicyRequest requestId */
                    requestId?: (string|null);

                    /** InsertResourcePolicyRequest resourcePolicyResource */
                    resourcePolicyResource?: (google.cloud.compute.v1.IResourcePolicy|null);
                }

                /** Represents an InsertResourcePolicyRequest. */
                class InsertResourcePolicyRequest implements IInsertResourcePolicyRequest {

                    /**
                     * Constructs a new InsertResourcePolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertResourcePolicyRequest);

                    /** InsertResourcePolicyRequest project. */
                    public project: string;

                    /** InsertResourcePolicyRequest region. */
                    public region: string;

                    /** InsertResourcePolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertResourcePolicyRequest resourcePolicyResource. */
                    public resourcePolicyResource?: (google.cloud.compute.v1.IResourcePolicy|null);

                    /** InsertResourcePolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertResourcePolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertResourcePolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertResourcePolicyRequest): google.cloud.compute.v1.InsertResourcePolicyRequest;

                    /**
                     * Encodes the specified InsertResourcePolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertResourcePolicyRequest.verify|verify} messages.
                     * @param message InsertResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertResourcePolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertResourcePolicyRequest.verify|verify} messages.
                     * @param message InsertResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertResourcePolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertResourcePolicyRequest;

                    /**
                     * Decodes an InsertResourcePolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertResourcePolicyRequest;

                    /**
                     * Verifies an InsertResourcePolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertResourcePolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertResourcePolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertResourcePolicyRequest;

                    /**
                     * Creates a plain object from an InsertResourcePolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertResourcePolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertResourcePolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertResourcePolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertResourcePolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRouteRequest. */
                interface IInsertRouteRequest {

                    /** InsertRouteRequest project */
                    project?: (string|null);

                    /** InsertRouteRequest requestId */
                    requestId?: (string|null);

                    /** InsertRouteRequest routeResource */
                    routeResource?: (google.cloud.compute.v1.IRoute|null);
                }

                /** Represents an InsertRouteRequest. */
                class InsertRouteRequest implements IInsertRouteRequest {

                    /**
                     * Constructs a new InsertRouteRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRouteRequest);

                    /** InsertRouteRequest project. */
                    public project: string;

                    /** InsertRouteRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRouteRequest routeResource. */
                    public routeResource?: (google.cloud.compute.v1.IRoute|null);

                    /** InsertRouteRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRouteRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRouteRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRouteRequest): google.cloud.compute.v1.InsertRouteRequest;

                    /**
                     * Encodes the specified InsertRouteRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRouteRequest.verify|verify} messages.
                     * @param message InsertRouteRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRouteRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRouteRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRouteRequest.verify|verify} messages.
                     * @param message InsertRouteRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRouteRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRouteRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRouteRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRouteRequest;

                    /**
                     * Decodes an InsertRouteRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRouteRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRouteRequest;

                    /**
                     * Verifies an InsertRouteRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRouteRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRouteRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRouteRequest;

                    /**
                     * Creates a plain object from an InsertRouteRequest message. Also converts values to other types if specified.
                     * @param message InsertRouteRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRouteRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRouteRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRouteRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertRouterRequest. */
                interface IInsertRouterRequest {

                    /** InsertRouterRequest project */
                    project?: (string|null);

                    /** InsertRouterRequest region */
                    region?: (string|null);

                    /** InsertRouterRequest requestId */
                    requestId?: (string|null);

                    /** InsertRouterRequest routerResource */
                    routerResource?: (google.cloud.compute.v1.IRouter|null);
                }

                /** Represents an InsertRouterRequest. */
                class InsertRouterRequest implements IInsertRouterRequest {

                    /**
                     * Constructs a new InsertRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertRouterRequest);

                    /** InsertRouterRequest project. */
                    public project: string;

                    /** InsertRouterRequest region. */
                    public region: string;

                    /** InsertRouterRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertRouterRequest routerResource. */
                    public routerResource?: (google.cloud.compute.v1.IRouter|null);

                    /** InsertRouterRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertRouterRequest): google.cloud.compute.v1.InsertRouterRequest;

                    /**
                     * Encodes the specified InsertRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertRouterRequest.verify|verify} messages.
                     * @param message InsertRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertRouterRequest.verify|verify} messages.
                     * @param message InsertRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertRouterRequest;

                    /**
                     * Decodes an InsertRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertRouterRequest;

                    /**
                     * Verifies an InsertRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertRouterRequest;

                    /**
                     * Creates a plain object from an InsertRouterRequest message. Also converts values to other types if specified.
                     * @param message InsertRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertSecurityPolicyRequest. */
                interface IInsertSecurityPolicyRequest {

                    /** InsertSecurityPolicyRequest project */
                    project?: (string|null);

                    /** InsertSecurityPolicyRequest requestId */
                    requestId?: (string|null);

                    /** InsertSecurityPolicyRequest securityPolicyResource */
                    securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);

                    /** InsertSecurityPolicyRequest validateOnly */
                    validateOnly?: (boolean|null);
                }

                /** Represents an InsertSecurityPolicyRequest. */
                class InsertSecurityPolicyRequest implements IInsertSecurityPolicyRequest {

                    /**
                     * Constructs a new InsertSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertSecurityPolicyRequest);

                    /** InsertSecurityPolicyRequest project. */
                    public project: string;

                    /** InsertSecurityPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertSecurityPolicyRequest securityPolicyResource. */
                    public securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);

                    /** InsertSecurityPolicyRequest validateOnly. */
                    public validateOnly?: (boolean|null);

                    /** InsertSecurityPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /** InsertSecurityPolicyRequest _validateOnly. */
                    public _validateOnly?: "validateOnly";

                    /**
                     * Creates a new InsertSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertSecurityPolicyRequest): google.cloud.compute.v1.InsertSecurityPolicyRequest;

                    /**
                     * Encodes the specified InsertSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertSecurityPolicyRequest.verify|verify} messages.
                     * @param message InsertSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertSecurityPolicyRequest.verify|verify} messages.
                     * @param message InsertSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertSecurityPolicyRequest;

                    /**
                     * Decodes an InsertSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertSecurityPolicyRequest;

                    /**
                     * Verifies an InsertSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertSecurityPolicyRequest;

                    /**
                     * Creates a plain object from an InsertSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertServiceAttachmentRequest. */
                interface IInsertServiceAttachmentRequest {

                    /** InsertServiceAttachmentRequest project */
                    project?: (string|null);

                    /** InsertServiceAttachmentRequest region */
                    region?: (string|null);

                    /** InsertServiceAttachmentRequest requestId */
                    requestId?: (string|null);

                    /** InsertServiceAttachmentRequest serviceAttachmentResource */
                    serviceAttachmentResource?: (google.cloud.compute.v1.IServiceAttachment|null);
                }

                /** Represents an InsertServiceAttachmentRequest. */
                class InsertServiceAttachmentRequest implements IInsertServiceAttachmentRequest {

                    /**
                     * Constructs a new InsertServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertServiceAttachmentRequest);

                    /** InsertServiceAttachmentRequest project. */
                    public project: string;

                    /** InsertServiceAttachmentRequest region. */
                    public region: string;

                    /** InsertServiceAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertServiceAttachmentRequest serviceAttachmentResource. */
                    public serviceAttachmentResource?: (google.cloud.compute.v1.IServiceAttachment|null);

                    /** InsertServiceAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertServiceAttachmentRequest): google.cloud.compute.v1.InsertServiceAttachmentRequest;

                    /**
                     * Encodes the specified InsertServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertServiceAttachmentRequest.verify|verify} messages.
                     * @param message InsertServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertServiceAttachmentRequest.verify|verify} messages.
                     * @param message InsertServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertServiceAttachmentRequest;

                    /**
                     * Decodes an InsertServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertServiceAttachmentRequest;

                    /**
                     * Verifies an InsertServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertServiceAttachmentRequest;

                    /**
                     * Creates a plain object from an InsertServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message InsertServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertSnapshotRequest. */
                interface IInsertSnapshotRequest {

                    /** InsertSnapshotRequest project */
                    project?: (string|null);

                    /** InsertSnapshotRequest requestId */
                    requestId?: (string|null);

                    /** InsertSnapshotRequest snapshotResource */
                    snapshotResource?: (google.cloud.compute.v1.ISnapshot|null);
                }

                /** Represents an InsertSnapshotRequest. */
                class InsertSnapshotRequest implements IInsertSnapshotRequest {

                    /**
                     * Constructs a new InsertSnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertSnapshotRequest);

                    /** InsertSnapshotRequest project. */
                    public project: string;

                    /** InsertSnapshotRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertSnapshotRequest snapshotResource. */
                    public snapshotResource?: (google.cloud.compute.v1.ISnapshot|null);

                    /** InsertSnapshotRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertSnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertSnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertSnapshotRequest): google.cloud.compute.v1.InsertSnapshotRequest;

                    /**
                     * Encodes the specified InsertSnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertSnapshotRequest.verify|verify} messages.
                     * @param message InsertSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertSnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertSnapshotRequest.verify|verify} messages.
                     * @param message InsertSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertSnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertSnapshotRequest;

                    /**
                     * Decodes an InsertSnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertSnapshotRequest;

                    /**
                     * Verifies an InsertSnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertSnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertSnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertSnapshotRequest;

                    /**
                     * Creates a plain object from an InsertSnapshotRequest message. Also converts values to other types if specified.
                     * @param message InsertSnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertSnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertSnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertSnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertSslCertificateRequest. */
                interface IInsertSslCertificateRequest {

                    /** InsertSslCertificateRequest project */
                    project?: (string|null);

                    /** InsertSslCertificateRequest requestId */
                    requestId?: (string|null);

                    /** InsertSslCertificateRequest sslCertificateResource */
                    sslCertificateResource?: (google.cloud.compute.v1.ISslCertificate|null);
                }

                /** Represents an InsertSslCertificateRequest. */
                class InsertSslCertificateRequest implements IInsertSslCertificateRequest {

                    /**
                     * Constructs a new InsertSslCertificateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertSslCertificateRequest);

                    /** InsertSslCertificateRequest project. */
                    public project: string;

                    /** InsertSslCertificateRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertSslCertificateRequest sslCertificateResource. */
                    public sslCertificateResource?: (google.cloud.compute.v1.ISslCertificate|null);

                    /** InsertSslCertificateRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertSslCertificateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertSslCertificateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertSslCertificateRequest): google.cloud.compute.v1.InsertSslCertificateRequest;

                    /**
                     * Encodes the specified InsertSslCertificateRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertSslCertificateRequest.verify|verify} messages.
                     * @param message InsertSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertSslCertificateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertSslCertificateRequest.verify|verify} messages.
                     * @param message InsertSslCertificateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertSslCertificateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertSslCertificateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertSslCertificateRequest;

                    /**
                     * Decodes an InsertSslCertificateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertSslCertificateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertSslCertificateRequest;

                    /**
                     * Verifies an InsertSslCertificateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertSslCertificateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertSslCertificateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertSslCertificateRequest;

                    /**
                     * Creates a plain object from an InsertSslCertificateRequest message. Also converts values to other types if specified.
                     * @param message InsertSslCertificateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertSslCertificateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertSslCertificateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertSslCertificateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertSslPolicyRequest. */
                interface IInsertSslPolicyRequest {

                    /** InsertSslPolicyRequest project */
                    project?: (string|null);

                    /** InsertSslPolicyRequest requestId */
                    requestId?: (string|null);

                    /** InsertSslPolicyRequest sslPolicyResource */
                    sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);
                }

                /** Represents an InsertSslPolicyRequest. */
                class InsertSslPolicyRequest implements IInsertSslPolicyRequest {

                    /**
                     * Constructs a new InsertSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertSslPolicyRequest);

                    /** InsertSslPolicyRequest project. */
                    public project: string;

                    /** InsertSslPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertSslPolicyRequest sslPolicyResource. */
                    public sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);

                    /** InsertSslPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertSslPolicyRequest): google.cloud.compute.v1.InsertSslPolicyRequest;

                    /**
                     * Encodes the specified InsertSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertSslPolicyRequest.verify|verify} messages.
                     * @param message InsertSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertSslPolicyRequest.verify|verify} messages.
                     * @param message InsertSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertSslPolicyRequest;

                    /**
                     * Decodes an InsertSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertSslPolicyRequest;

                    /**
                     * Verifies an InsertSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertSslPolicyRequest;

                    /**
                     * Creates a plain object from an InsertSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message InsertSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertSubnetworkRequest. */
                interface IInsertSubnetworkRequest {

                    /** InsertSubnetworkRequest project */
                    project?: (string|null);

                    /** InsertSubnetworkRequest region */
                    region?: (string|null);

                    /** InsertSubnetworkRequest requestId */
                    requestId?: (string|null);

                    /** InsertSubnetworkRequest subnetworkResource */
                    subnetworkResource?: (google.cloud.compute.v1.ISubnetwork|null);
                }

                /** Represents an InsertSubnetworkRequest. */
                class InsertSubnetworkRequest implements IInsertSubnetworkRequest {

                    /**
                     * Constructs a new InsertSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertSubnetworkRequest);

                    /** InsertSubnetworkRequest project. */
                    public project: string;

                    /** InsertSubnetworkRequest region. */
                    public region: string;

                    /** InsertSubnetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertSubnetworkRequest subnetworkResource. */
                    public subnetworkResource?: (google.cloud.compute.v1.ISubnetwork|null);

                    /** InsertSubnetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertSubnetworkRequest): google.cloud.compute.v1.InsertSubnetworkRequest;

                    /**
                     * Encodes the specified InsertSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertSubnetworkRequest.verify|verify} messages.
                     * @param message InsertSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertSubnetworkRequest.verify|verify} messages.
                     * @param message InsertSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertSubnetworkRequest;

                    /**
                     * Decodes an InsertSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertSubnetworkRequest;

                    /**
                     * Verifies an InsertSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertSubnetworkRequest;

                    /**
                     * Creates a plain object from an InsertSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message InsertSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetGrpcProxyRequest. */
                interface IInsertTargetGrpcProxyRequest {

                    /** InsertTargetGrpcProxyRequest project */
                    project?: (string|null);

                    /** InsertTargetGrpcProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetGrpcProxyRequest targetGrpcProxyResource */
                    targetGrpcProxyResource?: (google.cloud.compute.v1.ITargetGrpcProxy|null);
                }

                /** Represents an InsertTargetGrpcProxyRequest. */
                class InsertTargetGrpcProxyRequest implements IInsertTargetGrpcProxyRequest {

                    /**
                     * Constructs a new InsertTargetGrpcProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetGrpcProxyRequest);

                    /** InsertTargetGrpcProxyRequest project. */
                    public project: string;

                    /** InsertTargetGrpcProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetGrpcProxyRequest targetGrpcProxyResource. */
                    public targetGrpcProxyResource?: (google.cloud.compute.v1.ITargetGrpcProxy|null);

                    /** InsertTargetGrpcProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetGrpcProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetGrpcProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetGrpcProxyRequest): google.cloud.compute.v1.InsertTargetGrpcProxyRequest;

                    /**
                     * Encodes the specified InsertTargetGrpcProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message InsertTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetGrpcProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message InsertTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetGrpcProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetGrpcProxyRequest;

                    /**
                     * Decodes an InsertTargetGrpcProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetGrpcProxyRequest;

                    /**
                     * Verifies an InsertTargetGrpcProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetGrpcProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetGrpcProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetGrpcProxyRequest;

                    /**
                     * Creates a plain object from an InsertTargetGrpcProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetGrpcProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetGrpcProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetGrpcProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetGrpcProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetHttpProxyRequest. */
                interface IInsertTargetHttpProxyRequest {

                    /** InsertTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** InsertTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetHttpProxyRequest targetHttpProxyResource */
                    targetHttpProxyResource?: (google.cloud.compute.v1.ITargetHttpProxy|null);
                }

                /** Represents an InsertTargetHttpProxyRequest. */
                class InsertTargetHttpProxyRequest implements IInsertTargetHttpProxyRequest {

                    /**
                     * Constructs a new InsertTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetHttpProxyRequest);

                    /** InsertTargetHttpProxyRequest project. */
                    public project: string;

                    /** InsertTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetHttpProxyRequest targetHttpProxyResource. */
                    public targetHttpProxyResource?: (google.cloud.compute.v1.ITargetHttpProxy|null);

                    /** InsertTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetHttpProxyRequest): google.cloud.compute.v1.InsertTargetHttpProxyRequest;

                    /**
                     * Encodes the specified InsertTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetHttpProxyRequest.verify|verify} messages.
                     * @param message InsertTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetHttpProxyRequest.verify|verify} messages.
                     * @param message InsertTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetHttpProxyRequest;

                    /**
                     * Decodes an InsertTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetHttpProxyRequest;

                    /**
                     * Verifies an InsertTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from an InsertTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetHttpsProxyRequest. */
                interface IInsertTargetHttpsProxyRequest {

                    /** InsertTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** InsertTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetHttpsProxyRequest targetHttpsProxyResource */
                    targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);
                }

                /** Represents an InsertTargetHttpsProxyRequest. */
                class InsertTargetHttpsProxyRequest implements IInsertTargetHttpsProxyRequest {

                    /**
                     * Constructs a new InsertTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetHttpsProxyRequest);

                    /** InsertTargetHttpsProxyRequest project. */
                    public project: string;

                    /** InsertTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetHttpsProxyRequest targetHttpsProxyResource. */
                    public targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);

                    /** InsertTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetHttpsProxyRequest): google.cloud.compute.v1.InsertTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified InsertTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message InsertTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message InsertTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetHttpsProxyRequest;

                    /**
                     * Decodes an InsertTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetHttpsProxyRequest;

                    /**
                     * Verifies an InsertTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from an InsertTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetInstanceRequest. */
                interface IInsertTargetInstanceRequest {

                    /** InsertTargetInstanceRequest project */
                    project?: (string|null);

                    /** InsertTargetInstanceRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetInstanceRequest targetInstanceResource */
                    targetInstanceResource?: (google.cloud.compute.v1.ITargetInstance|null);

                    /** InsertTargetInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an InsertTargetInstanceRequest. */
                class InsertTargetInstanceRequest implements IInsertTargetInstanceRequest {

                    /**
                     * Constructs a new InsertTargetInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetInstanceRequest);

                    /** InsertTargetInstanceRequest project. */
                    public project: string;

                    /** InsertTargetInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetInstanceRequest targetInstanceResource. */
                    public targetInstanceResource?: (google.cloud.compute.v1.ITargetInstance|null);

                    /** InsertTargetInstanceRequest zone. */
                    public zone: string;

                    /** InsertTargetInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetInstanceRequest): google.cloud.compute.v1.InsertTargetInstanceRequest;

                    /**
                     * Encodes the specified InsertTargetInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetInstanceRequest.verify|verify} messages.
                     * @param message InsertTargetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetInstanceRequest.verify|verify} messages.
                     * @param message InsertTargetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetInstanceRequest;

                    /**
                     * Decodes an InsertTargetInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetInstanceRequest;

                    /**
                     * Verifies an InsertTargetInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetInstanceRequest;

                    /**
                     * Creates a plain object from an InsertTargetInstanceRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetPoolRequest. */
                interface IInsertTargetPoolRequest {

                    /** InsertTargetPoolRequest project */
                    project?: (string|null);

                    /** InsertTargetPoolRequest region */
                    region?: (string|null);

                    /** InsertTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetPoolRequest targetPoolResource */
                    targetPoolResource?: (google.cloud.compute.v1.ITargetPool|null);
                }

                /** Represents an InsertTargetPoolRequest. */
                class InsertTargetPoolRequest implements IInsertTargetPoolRequest {

                    /**
                     * Constructs a new InsertTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetPoolRequest);

                    /** InsertTargetPoolRequest project. */
                    public project: string;

                    /** InsertTargetPoolRequest region. */
                    public region: string;

                    /** InsertTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetPoolRequest targetPoolResource. */
                    public targetPoolResource?: (google.cloud.compute.v1.ITargetPool|null);

                    /** InsertTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetPoolRequest): google.cloud.compute.v1.InsertTargetPoolRequest;

                    /**
                     * Encodes the specified InsertTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetPoolRequest.verify|verify} messages.
                     * @param message InsertTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetPoolRequest.verify|verify} messages.
                     * @param message InsertTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetPoolRequest;

                    /**
                     * Decodes an InsertTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetPoolRequest;

                    /**
                     * Verifies an InsertTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetPoolRequest;

                    /**
                     * Creates a plain object from an InsertTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetSslProxyRequest. */
                interface IInsertTargetSslProxyRequest {

                    /** InsertTargetSslProxyRequest project */
                    project?: (string|null);

                    /** InsertTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetSslProxyRequest targetSslProxyResource */
                    targetSslProxyResource?: (google.cloud.compute.v1.ITargetSslProxy|null);
                }

                /** Represents an InsertTargetSslProxyRequest. */
                class InsertTargetSslProxyRequest implements IInsertTargetSslProxyRequest {

                    /**
                     * Constructs a new InsertTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetSslProxyRequest);

                    /** InsertTargetSslProxyRequest project. */
                    public project: string;

                    /** InsertTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetSslProxyRequest targetSslProxyResource. */
                    public targetSslProxyResource?: (google.cloud.compute.v1.ITargetSslProxy|null);

                    /** InsertTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetSslProxyRequest): google.cloud.compute.v1.InsertTargetSslProxyRequest;

                    /**
                     * Encodes the specified InsertTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetSslProxyRequest.verify|verify} messages.
                     * @param message InsertTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetSslProxyRequest.verify|verify} messages.
                     * @param message InsertTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetSslProxyRequest;

                    /**
                     * Decodes an InsertTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetSslProxyRequest;

                    /**
                     * Verifies an InsertTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetSslProxyRequest;

                    /**
                     * Creates a plain object from an InsertTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetTcpProxyRequest. */
                interface IInsertTargetTcpProxyRequest {

                    /** InsertTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** InsertTargetTcpProxyRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetTcpProxyRequest targetTcpProxyResource */
                    targetTcpProxyResource?: (google.cloud.compute.v1.ITargetTcpProxy|null);
                }

                /** Represents an InsertTargetTcpProxyRequest. */
                class InsertTargetTcpProxyRequest implements IInsertTargetTcpProxyRequest {

                    /**
                     * Constructs a new InsertTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetTcpProxyRequest);

                    /** InsertTargetTcpProxyRequest project. */
                    public project: string;

                    /** InsertTargetTcpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetTcpProxyRequest targetTcpProxyResource. */
                    public targetTcpProxyResource?: (google.cloud.compute.v1.ITargetTcpProxy|null);

                    /** InsertTargetTcpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetTcpProxyRequest): google.cloud.compute.v1.InsertTargetTcpProxyRequest;

                    /**
                     * Encodes the specified InsertTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetTcpProxyRequest.verify|verify} messages.
                     * @param message InsertTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetTcpProxyRequest.verify|verify} messages.
                     * @param message InsertTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetTcpProxyRequest;

                    /**
                     * Decodes an InsertTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetTcpProxyRequest;

                    /**
                     * Verifies an InsertTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from an InsertTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertTargetVpnGatewayRequest. */
                interface IInsertTargetVpnGatewayRequest {

                    /** InsertTargetVpnGatewayRequest project */
                    project?: (string|null);

                    /** InsertTargetVpnGatewayRequest region */
                    region?: (string|null);

                    /** InsertTargetVpnGatewayRequest requestId */
                    requestId?: (string|null);

                    /** InsertTargetVpnGatewayRequest targetVpnGatewayResource */
                    targetVpnGatewayResource?: (google.cloud.compute.v1.ITargetVpnGateway|null);
                }

                /** Represents an InsertTargetVpnGatewayRequest. */
                class InsertTargetVpnGatewayRequest implements IInsertTargetVpnGatewayRequest {

                    /**
                     * Constructs a new InsertTargetVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertTargetVpnGatewayRequest);

                    /** InsertTargetVpnGatewayRequest project. */
                    public project: string;

                    /** InsertTargetVpnGatewayRequest region. */
                    public region: string;

                    /** InsertTargetVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertTargetVpnGatewayRequest targetVpnGatewayResource. */
                    public targetVpnGatewayResource?: (google.cloud.compute.v1.ITargetVpnGateway|null);

                    /** InsertTargetVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertTargetVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertTargetVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertTargetVpnGatewayRequest): google.cloud.compute.v1.InsertTargetVpnGatewayRequest;

                    /**
                     * Encodes the specified InsertTargetVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message InsertTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertTargetVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message InsertTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertTargetVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertTargetVpnGatewayRequest;

                    /**
                     * Decodes an InsertTargetVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertTargetVpnGatewayRequest;

                    /**
                     * Verifies an InsertTargetVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertTargetVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertTargetVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertTargetVpnGatewayRequest;

                    /**
                     * Creates a plain object from an InsertTargetVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message InsertTargetVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertTargetVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertTargetVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertTargetVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertUrlMapRequest. */
                interface IInsertUrlMapRequest {

                    /** InsertUrlMapRequest project */
                    project?: (string|null);

                    /** InsertUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** InsertUrlMapRequest urlMapResource */
                    urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents an InsertUrlMapRequest. */
                class InsertUrlMapRequest implements IInsertUrlMapRequest {

                    /**
                     * Constructs a new InsertUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertUrlMapRequest);

                    /** InsertUrlMapRequest project. */
                    public project: string;

                    /** InsertUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertUrlMapRequest urlMapResource. */
                    public urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** InsertUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertUrlMapRequest): google.cloud.compute.v1.InsertUrlMapRequest;

                    /**
                     * Encodes the specified InsertUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertUrlMapRequest.verify|verify} messages.
                     * @param message InsertUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertUrlMapRequest.verify|verify} messages.
                     * @param message InsertUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertUrlMapRequest;

                    /**
                     * Decodes an InsertUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertUrlMapRequest;

                    /**
                     * Verifies an InsertUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertUrlMapRequest;

                    /**
                     * Creates a plain object from an InsertUrlMapRequest message. Also converts values to other types if specified.
                     * @param message InsertUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertVpnGatewayRequest. */
                interface IInsertVpnGatewayRequest {

                    /** InsertVpnGatewayRequest project */
                    project?: (string|null);

                    /** InsertVpnGatewayRequest region */
                    region?: (string|null);

                    /** InsertVpnGatewayRequest requestId */
                    requestId?: (string|null);

                    /** InsertVpnGatewayRequest vpnGatewayResource */
                    vpnGatewayResource?: (google.cloud.compute.v1.IVpnGateway|null);
                }

                /** Represents an InsertVpnGatewayRequest. */
                class InsertVpnGatewayRequest implements IInsertVpnGatewayRequest {

                    /**
                     * Constructs a new InsertVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertVpnGatewayRequest);

                    /** InsertVpnGatewayRequest project. */
                    public project: string;

                    /** InsertVpnGatewayRequest region. */
                    public region: string;

                    /** InsertVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertVpnGatewayRequest vpnGatewayResource. */
                    public vpnGatewayResource?: (google.cloud.compute.v1.IVpnGateway|null);

                    /** InsertVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertVpnGatewayRequest): google.cloud.compute.v1.InsertVpnGatewayRequest;

                    /**
                     * Encodes the specified InsertVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertVpnGatewayRequest.verify|verify} messages.
                     * @param message InsertVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertVpnGatewayRequest.verify|verify} messages.
                     * @param message InsertVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertVpnGatewayRequest;

                    /**
                     * Decodes an InsertVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertVpnGatewayRequest;

                    /**
                     * Verifies an InsertVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertVpnGatewayRequest;

                    /**
                     * Creates a plain object from an InsertVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message InsertVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertVpnTunnelRequest. */
                interface IInsertVpnTunnelRequest {

                    /** InsertVpnTunnelRequest project */
                    project?: (string|null);

                    /** InsertVpnTunnelRequest region */
                    region?: (string|null);

                    /** InsertVpnTunnelRequest requestId */
                    requestId?: (string|null);

                    /** InsertVpnTunnelRequest vpnTunnelResource */
                    vpnTunnelResource?: (google.cloud.compute.v1.IVpnTunnel|null);
                }

                /** Represents an InsertVpnTunnelRequest. */
                class InsertVpnTunnelRequest implements IInsertVpnTunnelRequest {

                    /**
                     * Constructs a new InsertVpnTunnelRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInsertVpnTunnelRequest);

                    /** InsertVpnTunnelRequest project. */
                    public project: string;

                    /** InsertVpnTunnelRequest region. */
                    public region: string;

                    /** InsertVpnTunnelRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertVpnTunnelRequest vpnTunnelResource. */
                    public vpnTunnelResource?: (google.cloud.compute.v1.IVpnTunnel|null);

                    /** InsertVpnTunnelRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertVpnTunnelRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertVpnTunnelRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInsertVpnTunnelRequest): google.cloud.compute.v1.InsertVpnTunnelRequest;

                    /**
                     * Encodes the specified InsertVpnTunnelRequest message. Does not implicitly {@link google.cloud.compute.v1.InsertVpnTunnelRequest.verify|verify} messages.
                     * @param message InsertVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInsertVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertVpnTunnelRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InsertVpnTunnelRequest.verify|verify} messages.
                     * @param message InsertVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInsertVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertVpnTunnelRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InsertVpnTunnelRequest;

                    /**
                     * Decodes an InsertVpnTunnelRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InsertVpnTunnelRequest;

                    /**
                     * Verifies an InsertVpnTunnelRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertVpnTunnelRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertVpnTunnelRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InsertVpnTunnelRequest;

                    /**
                     * Creates a plain object from an InsertVpnTunnelRequest message. Also converts values to other types if specified.
                     * @param message InsertVpnTunnelRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InsertVpnTunnelRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertVpnTunnelRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertVpnTunnelRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Instance. */
                interface IInstance {

                    /** Instance advancedMachineFeatures */
                    advancedMachineFeatures?: (google.cloud.compute.v1.IAdvancedMachineFeatures|null);

                    /** Instance canIpForward */
                    canIpForward?: (boolean|null);

                    /** Instance confidentialInstanceConfig */
                    confidentialInstanceConfig?: (google.cloud.compute.v1.IConfidentialInstanceConfig|null);

                    /** Instance cpuPlatform */
                    cpuPlatform?: (string|null);

                    /** Instance creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Instance deletionProtection */
                    deletionProtection?: (boolean|null);

                    /** Instance description */
                    description?: (string|null);

                    /** Instance disks */
                    disks?: (google.cloud.compute.v1.IAttachedDisk[]|null);

                    /** Instance displayDevice */
                    displayDevice?: (google.cloud.compute.v1.IDisplayDevice|null);

                    /** Instance fingerprint */
                    fingerprint?: (string|null);

                    /** Instance guestAccelerators */
                    guestAccelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);

                    /** Instance hostname */
                    hostname?: (string|null);

                    /** Instance id */
                    id?: (number|Long|string|null);

                    /** Instance keyRevocationActionType */
                    keyRevocationActionType?: (string|null);

                    /** Instance kind */
                    kind?: (string|null);

                    /** Instance labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** Instance labels */
                    labels?: ({ [k: string]: string }|null);

                    /** Instance lastStartTimestamp */
                    lastStartTimestamp?: (string|null);

                    /** Instance lastStopTimestamp */
                    lastStopTimestamp?: (string|null);

                    /** Instance lastSuspendedTimestamp */
                    lastSuspendedTimestamp?: (string|null);

                    /** Instance machineType */
                    machineType?: (string|null);

                    /** Instance metadata */
                    metadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** Instance minCpuPlatform */
                    minCpuPlatform?: (string|null);

                    /** Instance name */
                    name?: (string|null);

                    /** Instance networkInterfaces */
                    networkInterfaces?: (google.cloud.compute.v1.INetworkInterface[]|null);

                    /** Instance networkPerformanceConfig */
                    networkPerformanceConfig?: (google.cloud.compute.v1.INetworkPerformanceConfig|null);

                    /** Instance params */
                    params?: (google.cloud.compute.v1.IInstanceParams|null);

                    /** Instance privateIpv6GoogleAccess */
                    privateIpv6GoogleAccess?: (string|null);

                    /** Instance reservationAffinity */
                    reservationAffinity?: (google.cloud.compute.v1.IReservationAffinity|null);

                    /** Instance resourcePolicies */
                    resourcePolicies?: (string[]|null);

                    /** Instance resourceStatus */
                    resourceStatus?: (google.cloud.compute.v1.IResourceStatus|null);

                    /** Instance satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Instance scheduling */
                    scheduling?: (google.cloud.compute.v1.IScheduling|null);

                    /** Instance selfLink */
                    selfLink?: (string|null);

                    /** Instance serviceAccounts */
                    serviceAccounts?: (google.cloud.compute.v1.IServiceAccount[]|null);

                    /** Instance shieldedInstanceConfig */
                    shieldedInstanceConfig?: (google.cloud.compute.v1.IShieldedInstanceConfig|null);

                    /** Instance shieldedInstanceIntegrityPolicy */
                    shieldedInstanceIntegrityPolicy?: (google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy|null);

                    /** Instance sourceMachineImage */
                    sourceMachineImage?: (string|null);

                    /** Instance sourceMachineImageEncryptionKey */
                    sourceMachineImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Instance startRestricted */
                    startRestricted?: (boolean|null);

                    /** Instance status */
                    status?: (string|null);

                    /** Instance statusMessage */
                    statusMessage?: (string|null);

                    /** Instance tags */
                    tags?: (google.cloud.compute.v1.ITags|null);

                    /** Instance zone */
                    zone?: (string|null);
                }

                /** Represents an Instance. */
                class Instance implements IInstance {

                    /**
                     * Constructs a new Instance.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstance);

                    /** Instance advancedMachineFeatures. */
                    public advancedMachineFeatures?: (google.cloud.compute.v1.IAdvancedMachineFeatures|null);

                    /** Instance canIpForward. */
                    public canIpForward?: (boolean|null);

                    /** Instance confidentialInstanceConfig. */
                    public confidentialInstanceConfig?: (google.cloud.compute.v1.IConfidentialInstanceConfig|null);

                    /** Instance cpuPlatform. */
                    public cpuPlatform?: (string|null);

                    /** Instance creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Instance deletionProtection. */
                    public deletionProtection?: (boolean|null);

                    /** Instance description. */
                    public description?: (string|null);

                    /** Instance disks. */
                    public disks: google.cloud.compute.v1.IAttachedDisk[];

                    /** Instance displayDevice. */
                    public displayDevice?: (google.cloud.compute.v1.IDisplayDevice|null);

                    /** Instance fingerprint. */
                    public fingerprint?: (string|null);

                    /** Instance guestAccelerators. */
                    public guestAccelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /** Instance hostname. */
                    public hostname?: (string|null);

                    /** Instance id. */
                    public id?: (number|Long|string|null);

                    /** Instance keyRevocationActionType. */
                    public keyRevocationActionType?: (string|null);

                    /** Instance kind. */
                    public kind?: (string|null);

                    /** Instance labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** Instance labels. */
                    public labels: { [k: string]: string };

                    /** Instance lastStartTimestamp. */
                    public lastStartTimestamp?: (string|null);

                    /** Instance lastStopTimestamp. */
                    public lastStopTimestamp?: (string|null);

                    /** Instance lastSuspendedTimestamp. */
                    public lastSuspendedTimestamp?: (string|null);

                    /** Instance machineType. */
                    public machineType?: (string|null);

                    /** Instance metadata. */
                    public metadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** Instance minCpuPlatform. */
                    public minCpuPlatform?: (string|null);

                    /** Instance name. */
                    public name?: (string|null);

                    /** Instance networkInterfaces. */
                    public networkInterfaces: google.cloud.compute.v1.INetworkInterface[];

                    /** Instance networkPerformanceConfig. */
                    public networkPerformanceConfig?: (google.cloud.compute.v1.INetworkPerformanceConfig|null);

                    /** Instance params. */
                    public params?: (google.cloud.compute.v1.IInstanceParams|null);

                    /** Instance privateIpv6GoogleAccess. */
                    public privateIpv6GoogleAccess?: (string|null);

                    /** Instance reservationAffinity. */
                    public reservationAffinity?: (google.cloud.compute.v1.IReservationAffinity|null);

                    /** Instance resourcePolicies. */
                    public resourcePolicies: string[];

                    /** Instance resourceStatus. */
                    public resourceStatus?: (google.cloud.compute.v1.IResourceStatus|null);

                    /** Instance satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** Instance scheduling. */
                    public scheduling?: (google.cloud.compute.v1.IScheduling|null);

                    /** Instance selfLink. */
                    public selfLink?: (string|null);

                    /** Instance serviceAccounts. */
                    public serviceAccounts: google.cloud.compute.v1.IServiceAccount[];

                    /** Instance shieldedInstanceConfig. */
                    public shieldedInstanceConfig?: (google.cloud.compute.v1.IShieldedInstanceConfig|null);

                    /** Instance shieldedInstanceIntegrityPolicy. */
                    public shieldedInstanceIntegrityPolicy?: (google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy|null);

                    /** Instance sourceMachineImage. */
                    public sourceMachineImage?: (string|null);

                    /** Instance sourceMachineImageEncryptionKey. */
                    public sourceMachineImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Instance startRestricted. */
                    public startRestricted?: (boolean|null);

                    /** Instance status. */
                    public status?: (string|null);

                    /** Instance statusMessage. */
                    public statusMessage?: (string|null);

                    /** Instance tags. */
                    public tags?: (google.cloud.compute.v1.ITags|null);

                    /** Instance zone. */
                    public zone?: (string|null);

                    /** Instance _advancedMachineFeatures. */
                    public _advancedMachineFeatures?: "advancedMachineFeatures";

                    /** Instance _canIpForward. */
                    public _canIpForward?: "canIpForward";

                    /** Instance _confidentialInstanceConfig. */
                    public _confidentialInstanceConfig?: "confidentialInstanceConfig";

                    /** Instance _cpuPlatform. */
                    public _cpuPlatform?: "cpuPlatform";

                    /** Instance _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Instance _deletionProtection. */
                    public _deletionProtection?: "deletionProtection";

                    /** Instance _description. */
                    public _description?: "description";

                    /** Instance _displayDevice. */
                    public _displayDevice?: "displayDevice";

                    /** Instance _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** Instance _hostname. */
                    public _hostname?: "hostname";

                    /** Instance _id. */
                    public _id?: "id";

                    /** Instance _keyRevocationActionType. */
                    public _keyRevocationActionType?: "keyRevocationActionType";

                    /** Instance _kind. */
                    public _kind?: "kind";

                    /** Instance _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** Instance _lastStartTimestamp. */
                    public _lastStartTimestamp?: "lastStartTimestamp";

                    /** Instance _lastStopTimestamp. */
                    public _lastStopTimestamp?: "lastStopTimestamp";

                    /** Instance _lastSuspendedTimestamp. */
                    public _lastSuspendedTimestamp?: "lastSuspendedTimestamp";

                    /** Instance _machineType. */
                    public _machineType?: "machineType";

                    /** Instance _metadata. */
                    public _metadata?: "metadata";

                    /** Instance _minCpuPlatform. */
                    public _minCpuPlatform?: "minCpuPlatform";

                    /** Instance _name. */
                    public _name?: "name";

                    /** Instance _networkPerformanceConfig. */
                    public _networkPerformanceConfig?: "networkPerformanceConfig";

                    /** Instance _params. */
                    public _params?: "params";

                    /** Instance _privateIpv6GoogleAccess. */
                    public _privateIpv6GoogleAccess?: "privateIpv6GoogleAccess";

                    /** Instance _reservationAffinity. */
                    public _reservationAffinity?: "reservationAffinity";

                    /** Instance _resourceStatus. */
                    public _resourceStatus?: "resourceStatus";

                    /** Instance _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** Instance _scheduling. */
                    public _scheduling?: "scheduling";

                    /** Instance _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Instance _shieldedInstanceConfig. */
                    public _shieldedInstanceConfig?: "shieldedInstanceConfig";

                    /** Instance _shieldedInstanceIntegrityPolicy. */
                    public _shieldedInstanceIntegrityPolicy?: "shieldedInstanceIntegrityPolicy";

                    /** Instance _sourceMachineImage. */
                    public _sourceMachineImage?: "sourceMachineImage";

                    /** Instance _sourceMachineImageEncryptionKey. */
                    public _sourceMachineImageEncryptionKey?: "sourceMachineImageEncryptionKey";

                    /** Instance _startRestricted. */
                    public _startRestricted?: "startRestricted";

                    /** Instance _status. */
                    public _status?: "status";

                    /** Instance _statusMessage. */
                    public _statusMessage?: "statusMessage";

                    /** Instance _tags. */
                    public _tags?: "tags";

                    /** Instance _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new Instance instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Instance instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstance): google.cloud.compute.v1.Instance;

                    /**
                     * Encodes the specified Instance message. Does not implicitly {@link google.cloud.compute.v1.Instance.verify|verify} messages.
                     * @param message Instance message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstance, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Instance message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Instance.verify|verify} messages.
                     * @param message Instance message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstance, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Instance message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Instance
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Instance;

                    /**
                     * Decodes an Instance message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Instance
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Instance;

                    /**
                     * Verifies an Instance message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Instance message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Instance
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Instance;

                    /**
                     * Creates a plain object from an Instance message. Also converts values to other types if specified.
                     * @param message Instance
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Instance, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Instance to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Instance
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Instance {

                    /** KeyRevocationActionType enum. */
                    enum KeyRevocationActionType {
                        UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0,
                        KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467110106,
                        NONE = 2402104,
                        STOP = 2555906
                    }

                    /** PrivateIpv6GoogleAccess enum. */
                    enum PrivateIpv6GoogleAccess {
                        UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS = 0,
                        ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 427975994,
                        ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 288210263,
                        INHERIT_FROM_SUBNETWORK = 530256959
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DEPROVISIONING = 428935662,
                        PROVISIONING = 290896621,
                        REPAIRING = 413483285,
                        RUNNING = 121282975,
                        STAGING = 431072283,
                        STOPPED = 444276141,
                        STOPPING = 350791796,
                        SUSPENDED = 51223995,
                        SUSPENDING = 514206246,
                        TERMINATED = 250018339
                    }
                }

                /** Properties of an InstanceAggregatedList. */
                interface IInstanceAggregatedList {

                    /** InstanceAggregatedList id */
                    id?: (string|null);

                    /** InstanceAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IInstancesScopedList }|null);

                    /** InstanceAggregatedList kind */
                    kind?: (string|null);

                    /** InstanceAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** InstanceAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** InstanceAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceAggregatedList. */
                class InstanceAggregatedList implements IInstanceAggregatedList {

                    /**
                     * Constructs a new InstanceAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceAggregatedList);

                    /** InstanceAggregatedList id. */
                    public id?: (string|null);

                    /** InstanceAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IInstancesScopedList };

                    /** InstanceAggregatedList kind. */
                    public kind?: (string|null);

                    /** InstanceAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceAggregatedList unreachables. */
                    public unreachables: string[];

                    /** InstanceAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceAggregatedList _id. */
                    public _id?: "id";

                    /** InstanceAggregatedList _kind. */
                    public _kind?: "kind";

                    /** InstanceAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceAggregatedList): google.cloud.compute.v1.InstanceAggregatedList;

                    /**
                     * Encodes the specified InstanceAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.InstanceAggregatedList.verify|verify} messages.
                     * @param message InstanceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceAggregatedList.verify|verify} messages.
                     * @param message InstanceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceAggregatedList;

                    /**
                     * Decodes an InstanceAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceAggregatedList;

                    /**
                     * Verifies an InstanceAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceAggregatedList;

                    /**
                     * Creates a plain object from an InstanceAggregatedList message. Also converts values to other types if specified.
                     * @param message InstanceAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceConsumptionData. */
                interface IInstanceConsumptionData {

                    /** InstanceConsumptionData consumptionInfo */
                    consumptionInfo?: (google.cloud.compute.v1.IInstanceConsumptionInfo|null);

                    /** InstanceConsumptionData instance */
                    instance?: (string|null);
                }

                /** Represents an InstanceConsumptionData. */
                class InstanceConsumptionData implements IInstanceConsumptionData {

                    /**
                     * Constructs a new InstanceConsumptionData.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceConsumptionData);

                    /** InstanceConsumptionData consumptionInfo. */
                    public consumptionInfo?: (google.cloud.compute.v1.IInstanceConsumptionInfo|null);

                    /** InstanceConsumptionData instance. */
                    public instance?: (string|null);

                    /** InstanceConsumptionData _consumptionInfo. */
                    public _consumptionInfo?: "consumptionInfo";

                    /** InstanceConsumptionData _instance. */
                    public _instance?: "instance";

                    /**
                     * Creates a new InstanceConsumptionData instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceConsumptionData instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceConsumptionData): google.cloud.compute.v1.InstanceConsumptionData;

                    /**
                     * Encodes the specified InstanceConsumptionData message. Does not implicitly {@link google.cloud.compute.v1.InstanceConsumptionData.verify|verify} messages.
                     * @param message InstanceConsumptionData message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceConsumptionData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceConsumptionData message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceConsumptionData.verify|verify} messages.
                     * @param message InstanceConsumptionData message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceConsumptionData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceConsumptionData message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceConsumptionData
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceConsumptionData;

                    /**
                     * Decodes an InstanceConsumptionData message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceConsumptionData
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceConsumptionData;

                    /**
                     * Verifies an InstanceConsumptionData message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceConsumptionData message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceConsumptionData
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceConsumptionData;

                    /**
                     * Creates a plain object from an InstanceConsumptionData message. Also converts values to other types if specified.
                     * @param message InstanceConsumptionData
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceConsumptionData, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceConsumptionData to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceConsumptionData
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceConsumptionInfo. */
                interface IInstanceConsumptionInfo {

                    /** InstanceConsumptionInfo guestCpus */
                    guestCpus?: (number|null);

                    /** InstanceConsumptionInfo localSsdGb */
                    localSsdGb?: (number|null);

                    /** InstanceConsumptionInfo memoryMb */
                    memoryMb?: (number|null);

                    /** InstanceConsumptionInfo minNodeCpus */
                    minNodeCpus?: (number|null);
                }

                /** Represents an InstanceConsumptionInfo. */
                class InstanceConsumptionInfo implements IInstanceConsumptionInfo {

                    /**
                     * Constructs a new InstanceConsumptionInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceConsumptionInfo);

                    /** InstanceConsumptionInfo guestCpus. */
                    public guestCpus?: (number|null);

                    /** InstanceConsumptionInfo localSsdGb. */
                    public localSsdGb?: (number|null);

                    /** InstanceConsumptionInfo memoryMb. */
                    public memoryMb?: (number|null);

                    /** InstanceConsumptionInfo minNodeCpus. */
                    public minNodeCpus?: (number|null);

                    /** InstanceConsumptionInfo _guestCpus. */
                    public _guestCpus?: "guestCpus";

                    /** InstanceConsumptionInfo _localSsdGb. */
                    public _localSsdGb?: "localSsdGb";

                    /** InstanceConsumptionInfo _memoryMb. */
                    public _memoryMb?: "memoryMb";

                    /** InstanceConsumptionInfo _minNodeCpus. */
                    public _minNodeCpus?: "minNodeCpus";

                    /**
                     * Creates a new InstanceConsumptionInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceConsumptionInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceConsumptionInfo): google.cloud.compute.v1.InstanceConsumptionInfo;

                    /**
                     * Encodes the specified InstanceConsumptionInfo message. Does not implicitly {@link google.cloud.compute.v1.InstanceConsumptionInfo.verify|verify} messages.
                     * @param message InstanceConsumptionInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceConsumptionInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceConsumptionInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceConsumptionInfo.verify|verify} messages.
                     * @param message InstanceConsumptionInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceConsumptionInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceConsumptionInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceConsumptionInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceConsumptionInfo;

                    /**
                     * Decodes an InstanceConsumptionInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceConsumptionInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceConsumptionInfo;

                    /**
                     * Verifies an InstanceConsumptionInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceConsumptionInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceConsumptionInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceConsumptionInfo;

                    /**
                     * Creates a plain object from an InstanceConsumptionInfo message. Also converts values to other types if specified.
                     * @param message InstanceConsumptionInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceConsumptionInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceConsumptionInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceConsumptionInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroup. */
                interface IInstanceGroup {

                    /** InstanceGroup creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** InstanceGroup description */
                    description?: (string|null);

                    /** InstanceGroup fingerprint */
                    fingerprint?: (string|null);

                    /** InstanceGroup id */
                    id?: (number|Long|string|null);

                    /** InstanceGroup kind */
                    kind?: (string|null);

                    /** InstanceGroup name */
                    name?: (string|null);

                    /** InstanceGroup namedPorts */
                    namedPorts?: (google.cloud.compute.v1.INamedPort[]|null);

                    /** InstanceGroup network */
                    network?: (string|null);

                    /** InstanceGroup region */
                    region?: (string|null);

                    /** InstanceGroup selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroup size */
                    size?: (number|null);

                    /** InstanceGroup subnetwork */
                    subnetwork?: (string|null);

                    /** InstanceGroup zone */
                    zone?: (string|null);
                }

                /** Represents an InstanceGroup. */
                class InstanceGroup implements IInstanceGroup {

                    /**
                     * Constructs a new InstanceGroup.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroup);

                    /** InstanceGroup creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** InstanceGroup description. */
                    public description?: (string|null);

                    /** InstanceGroup fingerprint. */
                    public fingerprint?: (string|null);

                    /** InstanceGroup id. */
                    public id?: (number|Long|string|null);

                    /** InstanceGroup kind. */
                    public kind?: (string|null);

                    /** InstanceGroup name. */
                    public name?: (string|null);

                    /** InstanceGroup namedPorts. */
                    public namedPorts: google.cloud.compute.v1.INamedPort[];

                    /** InstanceGroup network. */
                    public network?: (string|null);

                    /** InstanceGroup region. */
                    public region?: (string|null);

                    /** InstanceGroup selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroup size. */
                    public size?: (number|null);

                    /** InstanceGroup subnetwork. */
                    public subnetwork?: (string|null);

                    /** InstanceGroup zone. */
                    public zone?: (string|null);

                    /** InstanceGroup _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** InstanceGroup _description. */
                    public _description?: "description";

                    /** InstanceGroup _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** InstanceGroup _id. */
                    public _id?: "id";

                    /** InstanceGroup _kind. */
                    public _kind?: "kind";

                    /** InstanceGroup _name. */
                    public _name?: "name";

                    /** InstanceGroup _network. */
                    public _network?: "network";

                    /** InstanceGroup _region. */
                    public _region?: "region";

                    /** InstanceGroup _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroup _size. */
                    public _size?: "size";

                    /** InstanceGroup _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /** InstanceGroup _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new InstanceGroup instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroup instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroup): google.cloud.compute.v1.InstanceGroup;

                    /**
                     * Encodes the specified InstanceGroup message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroup.verify|verify} messages.
                     * @param message InstanceGroup message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroup, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroup message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroup.verify|verify} messages.
                     * @param message InstanceGroup message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroup, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroup message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroup
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroup;

                    /**
                     * Decodes an InstanceGroup message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroup
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroup;

                    /**
                     * Verifies an InstanceGroup message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroup message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroup
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroup;

                    /**
                     * Creates a plain object from an InstanceGroup message. Also converts values to other types if specified.
                     * @param message InstanceGroup
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroup, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroup to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroup
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupAggregatedList. */
                interface IInstanceGroupAggregatedList {

                    /** InstanceGroupAggregatedList id */
                    id?: (string|null);

                    /** InstanceGroupAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IInstanceGroupsScopedList }|null);

                    /** InstanceGroupAggregatedList kind */
                    kind?: (string|null);

                    /** InstanceGroupAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceGroupAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroupAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** InstanceGroupAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupAggregatedList. */
                class InstanceGroupAggregatedList implements IInstanceGroupAggregatedList {

                    /**
                     * Constructs a new InstanceGroupAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupAggregatedList);

                    /** InstanceGroupAggregatedList id. */
                    public id?: (string|null);

                    /** InstanceGroupAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IInstanceGroupsScopedList };

                    /** InstanceGroupAggregatedList kind. */
                    public kind?: (string|null);

                    /** InstanceGroupAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroupAggregatedList unreachables. */
                    public unreachables: string[];

                    /** InstanceGroupAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupAggregatedList _id. */
                    public _id?: "id";

                    /** InstanceGroupAggregatedList _kind. */
                    public _kind?: "kind";

                    /** InstanceGroupAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceGroupAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroupAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupAggregatedList): google.cloud.compute.v1.InstanceGroupAggregatedList;

                    /**
                     * Encodes the specified InstanceGroupAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupAggregatedList.verify|verify} messages.
                     * @param message InstanceGroupAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupAggregatedList.verify|verify} messages.
                     * @param message InstanceGroupAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupAggregatedList;

                    /**
                     * Decodes an InstanceGroupAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupAggregatedList;

                    /**
                     * Verifies an InstanceGroupAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupAggregatedList;

                    /**
                     * Creates a plain object from an InstanceGroupAggregatedList message. Also converts values to other types if specified.
                     * @param message InstanceGroupAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupList. */
                interface IInstanceGroupList {

                    /** InstanceGroupList id */
                    id?: (string|null);

                    /** InstanceGroupList items */
                    items?: (google.cloud.compute.v1.IInstanceGroup[]|null);

                    /** InstanceGroupList kind */
                    kind?: (string|null);

                    /** InstanceGroupList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceGroupList selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroupList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupList. */
                class InstanceGroupList implements IInstanceGroupList {

                    /**
                     * Constructs a new InstanceGroupList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupList);

                    /** InstanceGroupList id. */
                    public id?: (string|null);

                    /** InstanceGroupList items. */
                    public items: google.cloud.compute.v1.IInstanceGroup[];

                    /** InstanceGroupList kind. */
                    public kind?: (string|null);

                    /** InstanceGroupList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroupList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupList _id. */
                    public _id?: "id";

                    /** InstanceGroupList _kind. */
                    public _kind?: "kind";

                    /** InstanceGroupList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceGroupList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroupList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupList): google.cloud.compute.v1.InstanceGroupList;

                    /**
                     * Encodes the specified InstanceGroupList message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupList.verify|verify} messages.
                     * @param message InstanceGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupList.verify|verify} messages.
                     * @param message InstanceGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupList;

                    /**
                     * Decodes an InstanceGroupList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupList;

                    /**
                     * Verifies an InstanceGroupList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupList;

                    /**
                     * Creates a plain object from an InstanceGroupList message. Also converts values to other types if specified.
                     * @param message InstanceGroupList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManager. */
                interface IInstanceGroupManager {

                    /** InstanceGroupManager autoHealingPolicies */
                    autoHealingPolicies?: (google.cloud.compute.v1.IInstanceGroupManagerAutoHealingPolicy[]|null);

                    /** InstanceGroupManager baseInstanceName */
                    baseInstanceName?: (string|null);

                    /** InstanceGroupManager creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** InstanceGroupManager currentActions */
                    currentActions?: (google.cloud.compute.v1.IInstanceGroupManagerActionsSummary|null);

                    /** InstanceGroupManager description */
                    description?: (string|null);

                    /** InstanceGroupManager distributionPolicy */
                    distributionPolicy?: (google.cloud.compute.v1.IDistributionPolicy|null);

                    /** InstanceGroupManager fingerprint */
                    fingerprint?: (string|null);

                    /** InstanceGroupManager id */
                    id?: (number|Long|string|null);

                    /** InstanceGroupManager instanceGroup */
                    instanceGroup?: (string|null);

                    /** InstanceGroupManager instanceTemplate */
                    instanceTemplate?: (string|null);

                    /** InstanceGroupManager kind */
                    kind?: (string|null);

                    /** InstanceGroupManager listManagedInstancesResults */
                    listManagedInstancesResults?: (string|null);

                    /** InstanceGroupManager name */
                    name?: (string|null);

                    /** InstanceGroupManager namedPorts */
                    namedPorts?: (google.cloud.compute.v1.INamedPort[]|null);

                    /** InstanceGroupManager region */
                    region?: (string|null);

                    /** InstanceGroupManager selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroupManager statefulPolicy */
                    statefulPolicy?: (google.cloud.compute.v1.IStatefulPolicy|null);

                    /** InstanceGroupManager status */
                    status?: (google.cloud.compute.v1.IInstanceGroupManagerStatus|null);

                    /** InstanceGroupManager targetPools */
                    targetPools?: (string[]|null);

                    /** InstanceGroupManager targetSize */
                    targetSize?: (number|null);

                    /** InstanceGroupManager updatePolicy */
                    updatePolicy?: (google.cloud.compute.v1.IInstanceGroupManagerUpdatePolicy|null);

                    /** InstanceGroupManager versions */
                    versions?: (google.cloud.compute.v1.IInstanceGroupManagerVersion[]|null);

                    /** InstanceGroupManager zone */
                    zone?: (string|null);
                }

                /** Represents an InstanceGroupManager. */
                class InstanceGroupManager implements IInstanceGroupManager {

                    /**
                     * Constructs a new InstanceGroupManager.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManager);

                    /** InstanceGroupManager autoHealingPolicies. */
                    public autoHealingPolicies: google.cloud.compute.v1.IInstanceGroupManagerAutoHealingPolicy[];

                    /** InstanceGroupManager baseInstanceName. */
                    public baseInstanceName?: (string|null);

                    /** InstanceGroupManager creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** InstanceGroupManager currentActions. */
                    public currentActions?: (google.cloud.compute.v1.IInstanceGroupManagerActionsSummary|null);

                    /** InstanceGroupManager description. */
                    public description?: (string|null);

                    /** InstanceGroupManager distributionPolicy. */
                    public distributionPolicy?: (google.cloud.compute.v1.IDistributionPolicy|null);

                    /** InstanceGroupManager fingerprint. */
                    public fingerprint?: (string|null);

                    /** InstanceGroupManager id. */
                    public id?: (number|Long|string|null);

                    /** InstanceGroupManager instanceGroup. */
                    public instanceGroup?: (string|null);

                    /** InstanceGroupManager instanceTemplate. */
                    public instanceTemplate?: (string|null);

                    /** InstanceGroupManager kind. */
                    public kind?: (string|null);

                    /** InstanceGroupManager listManagedInstancesResults. */
                    public listManagedInstancesResults?: (string|null);

                    /** InstanceGroupManager name. */
                    public name?: (string|null);

                    /** InstanceGroupManager namedPorts. */
                    public namedPorts: google.cloud.compute.v1.INamedPort[];

                    /** InstanceGroupManager region. */
                    public region?: (string|null);

                    /** InstanceGroupManager selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroupManager statefulPolicy. */
                    public statefulPolicy?: (google.cloud.compute.v1.IStatefulPolicy|null);

                    /** InstanceGroupManager status. */
                    public status?: (google.cloud.compute.v1.IInstanceGroupManagerStatus|null);

                    /** InstanceGroupManager targetPools. */
                    public targetPools: string[];

                    /** InstanceGroupManager targetSize. */
                    public targetSize?: (number|null);

                    /** InstanceGroupManager updatePolicy. */
                    public updatePolicy?: (google.cloud.compute.v1.IInstanceGroupManagerUpdatePolicy|null);

                    /** InstanceGroupManager versions. */
                    public versions: google.cloud.compute.v1.IInstanceGroupManagerVersion[];

                    /** InstanceGroupManager zone. */
                    public zone?: (string|null);

                    /** InstanceGroupManager _baseInstanceName. */
                    public _baseInstanceName?: "baseInstanceName";

                    /** InstanceGroupManager _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** InstanceGroupManager _currentActions. */
                    public _currentActions?: "currentActions";

                    /** InstanceGroupManager _description. */
                    public _description?: "description";

                    /** InstanceGroupManager _distributionPolicy. */
                    public _distributionPolicy?: "distributionPolicy";

                    /** InstanceGroupManager _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** InstanceGroupManager _id. */
                    public _id?: "id";

                    /** InstanceGroupManager _instanceGroup. */
                    public _instanceGroup?: "instanceGroup";

                    /** InstanceGroupManager _instanceTemplate. */
                    public _instanceTemplate?: "instanceTemplate";

                    /** InstanceGroupManager _kind. */
                    public _kind?: "kind";

                    /** InstanceGroupManager _listManagedInstancesResults. */
                    public _listManagedInstancesResults?: "listManagedInstancesResults";

                    /** InstanceGroupManager _name. */
                    public _name?: "name";

                    /** InstanceGroupManager _region. */
                    public _region?: "region";

                    /** InstanceGroupManager _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroupManager _statefulPolicy. */
                    public _statefulPolicy?: "statefulPolicy";

                    /** InstanceGroupManager _status. */
                    public _status?: "status";

                    /** InstanceGroupManager _targetSize. */
                    public _targetSize?: "targetSize";

                    /** InstanceGroupManager _updatePolicy. */
                    public _updatePolicy?: "updatePolicy";

                    /** InstanceGroupManager _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new InstanceGroupManager instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManager instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManager): google.cloud.compute.v1.InstanceGroupManager;

                    /**
                     * Encodes the specified InstanceGroupManager message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManager.verify|verify} messages.
                     * @param message InstanceGroupManager message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManager, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManager message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManager.verify|verify} messages.
                     * @param message InstanceGroupManager message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManager, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManager message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManager
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManager;

                    /**
                     * Decodes an InstanceGroupManager message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManager
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManager;

                    /**
                     * Verifies an InstanceGroupManager message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManager message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManager
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManager;

                    /**
                     * Creates a plain object from an InstanceGroupManager message. Also converts values to other types if specified.
                     * @param message InstanceGroupManager
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManager, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManager to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManager
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceGroupManager {

                    /** ListManagedInstancesResults enum. */
                    enum ListManagedInstancesResults {
                        UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0,
                        PAGELESS = 32183464,
                        PAGINATED = 40190637
                    }
                }

                /** Properties of an InstanceGroupManagerActionsSummary. */
                interface IInstanceGroupManagerActionsSummary {

                    /** InstanceGroupManagerActionsSummary abandoning */
                    abandoning?: (number|null);

                    /** InstanceGroupManagerActionsSummary creating */
                    creating?: (number|null);

                    /** InstanceGroupManagerActionsSummary creatingWithoutRetries */
                    creatingWithoutRetries?: (number|null);

                    /** InstanceGroupManagerActionsSummary deleting */
                    deleting?: (number|null);

                    /** InstanceGroupManagerActionsSummary none */
                    none?: (number|null);

                    /** InstanceGroupManagerActionsSummary recreating */
                    recreating?: (number|null);

                    /** InstanceGroupManagerActionsSummary refreshing */
                    refreshing?: (number|null);

                    /** InstanceGroupManagerActionsSummary restarting */
                    restarting?: (number|null);

                    /** InstanceGroupManagerActionsSummary resuming */
                    resuming?: (number|null);

                    /** InstanceGroupManagerActionsSummary starting */
                    starting?: (number|null);

                    /** InstanceGroupManagerActionsSummary stopping */
                    stopping?: (number|null);

                    /** InstanceGroupManagerActionsSummary suspending */
                    suspending?: (number|null);

                    /** InstanceGroupManagerActionsSummary verifying */
                    verifying?: (number|null);
                }

                /** Represents an InstanceGroupManagerActionsSummary. */
                class InstanceGroupManagerActionsSummary implements IInstanceGroupManagerActionsSummary {

                    /**
                     * Constructs a new InstanceGroupManagerActionsSummary.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerActionsSummary);

                    /** InstanceGroupManagerActionsSummary abandoning. */
                    public abandoning?: (number|null);

                    /** InstanceGroupManagerActionsSummary creating. */
                    public creating?: (number|null);

                    /** InstanceGroupManagerActionsSummary creatingWithoutRetries. */
                    public creatingWithoutRetries?: (number|null);

                    /** InstanceGroupManagerActionsSummary deleting. */
                    public deleting?: (number|null);

                    /** InstanceGroupManagerActionsSummary none. */
                    public none?: (number|null);

                    /** InstanceGroupManagerActionsSummary recreating. */
                    public recreating?: (number|null);

                    /** InstanceGroupManagerActionsSummary refreshing. */
                    public refreshing?: (number|null);

                    /** InstanceGroupManagerActionsSummary restarting. */
                    public restarting?: (number|null);

                    /** InstanceGroupManagerActionsSummary resuming. */
                    public resuming?: (number|null);

                    /** InstanceGroupManagerActionsSummary starting. */
                    public starting?: (number|null);

                    /** InstanceGroupManagerActionsSummary stopping. */
                    public stopping?: (number|null);

                    /** InstanceGroupManagerActionsSummary suspending. */
                    public suspending?: (number|null);

                    /** InstanceGroupManagerActionsSummary verifying. */
                    public verifying?: (number|null);

                    /** InstanceGroupManagerActionsSummary _abandoning. */
                    public _abandoning?: "abandoning";

                    /** InstanceGroupManagerActionsSummary _creating. */
                    public _creating?: "creating";

                    /** InstanceGroupManagerActionsSummary _creatingWithoutRetries. */
                    public _creatingWithoutRetries?: "creatingWithoutRetries";

                    /** InstanceGroupManagerActionsSummary _deleting. */
                    public _deleting?: "deleting";

                    /** InstanceGroupManagerActionsSummary _none. */
                    public _none?: "none";

                    /** InstanceGroupManagerActionsSummary _recreating. */
                    public _recreating?: "recreating";

                    /** InstanceGroupManagerActionsSummary _refreshing. */
                    public _refreshing?: "refreshing";

                    /** InstanceGroupManagerActionsSummary _restarting. */
                    public _restarting?: "restarting";

                    /** InstanceGroupManagerActionsSummary _resuming. */
                    public _resuming?: "resuming";

                    /** InstanceGroupManagerActionsSummary _starting. */
                    public _starting?: "starting";

                    /** InstanceGroupManagerActionsSummary _stopping. */
                    public _stopping?: "stopping";

                    /** InstanceGroupManagerActionsSummary _suspending. */
                    public _suspending?: "suspending";

                    /** InstanceGroupManagerActionsSummary _verifying. */
                    public _verifying?: "verifying";

                    /**
                     * Creates a new InstanceGroupManagerActionsSummary instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerActionsSummary instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerActionsSummary): google.cloud.compute.v1.InstanceGroupManagerActionsSummary;

                    /**
                     * Encodes the specified InstanceGroupManagerActionsSummary message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerActionsSummary.verify|verify} messages.
                     * @param message InstanceGroupManagerActionsSummary message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerActionsSummary, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerActionsSummary message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerActionsSummary.verify|verify} messages.
                     * @param message InstanceGroupManagerActionsSummary message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerActionsSummary, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerActionsSummary message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerActionsSummary
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerActionsSummary;

                    /**
                     * Decodes an InstanceGroupManagerActionsSummary message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerActionsSummary
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerActionsSummary;

                    /**
                     * Verifies an InstanceGroupManagerActionsSummary message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerActionsSummary message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerActionsSummary
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerActionsSummary;

                    /**
                     * Creates a plain object from an InstanceGroupManagerActionsSummary message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerActionsSummary
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerActionsSummary, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerActionsSummary to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerActionsSummary
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerAggregatedList. */
                interface IInstanceGroupManagerAggregatedList {

                    /** InstanceGroupManagerAggregatedList id */
                    id?: (string|null);

                    /** InstanceGroupManagerAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IInstanceGroupManagersScopedList }|null);

                    /** InstanceGroupManagerAggregatedList kind */
                    kind?: (string|null);

                    /** InstanceGroupManagerAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceGroupManagerAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroupManagerAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** InstanceGroupManagerAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupManagerAggregatedList. */
                class InstanceGroupManagerAggregatedList implements IInstanceGroupManagerAggregatedList {

                    /**
                     * Constructs a new InstanceGroupManagerAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerAggregatedList);

                    /** InstanceGroupManagerAggregatedList id. */
                    public id?: (string|null);

                    /** InstanceGroupManagerAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IInstanceGroupManagersScopedList };

                    /** InstanceGroupManagerAggregatedList kind. */
                    public kind?: (string|null);

                    /** InstanceGroupManagerAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupManagerAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroupManagerAggregatedList unreachables. */
                    public unreachables: string[];

                    /** InstanceGroupManagerAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupManagerAggregatedList _id. */
                    public _id?: "id";

                    /** InstanceGroupManagerAggregatedList _kind. */
                    public _kind?: "kind";

                    /** InstanceGroupManagerAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceGroupManagerAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroupManagerAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupManagerAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerAggregatedList): google.cloud.compute.v1.InstanceGroupManagerAggregatedList;

                    /**
                     * Encodes the specified InstanceGroupManagerAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerAggregatedList.verify|verify} messages.
                     * @param message InstanceGroupManagerAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerAggregatedList.verify|verify} messages.
                     * @param message InstanceGroupManagerAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerAggregatedList;

                    /**
                     * Decodes an InstanceGroupManagerAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerAggregatedList;

                    /**
                     * Verifies an InstanceGroupManagerAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerAggregatedList;

                    /**
                     * Creates a plain object from an InstanceGroupManagerAggregatedList message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerAutoHealingPolicy. */
                interface IInstanceGroupManagerAutoHealingPolicy {

                    /** InstanceGroupManagerAutoHealingPolicy healthCheck */
                    healthCheck?: (string|null);

                    /** InstanceGroupManagerAutoHealingPolicy initialDelaySec */
                    initialDelaySec?: (number|null);
                }

                /** Represents an InstanceGroupManagerAutoHealingPolicy. */
                class InstanceGroupManagerAutoHealingPolicy implements IInstanceGroupManagerAutoHealingPolicy {

                    /**
                     * Constructs a new InstanceGroupManagerAutoHealingPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerAutoHealingPolicy);

                    /** InstanceGroupManagerAutoHealingPolicy healthCheck. */
                    public healthCheck?: (string|null);

                    /** InstanceGroupManagerAutoHealingPolicy initialDelaySec. */
                    public initialDelaySec?: (number|null);

                    /** InstanceGroupManagerAutoHealingPolicy _healthCheck. */
                    public _healthCheck?: "healthCheck";

                    /** InstanceGroupManagerAutoHealingPolicy _initialDelaySec. */
                    public _initialDelaySec?: "initialDelaySec";

                    /**
                     * Creates a new InstanceGroupManagerAutoHealingPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerAutoHealingPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerAutoHealingPolicy): google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy;

                    /**
                     * Encodes the specified InstanceGroupManagerAutoHealingPolicy message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy.verify|verify} messages.
                     * @param message InstanceGroupManagerAutoHealingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerAutoHealingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerAutoHealingPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy.verify|verify} messages.
                     * @param message InstanceGroupManagerAutoHealingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerAutoHealingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerAutoHealingPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerAutoHealingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy;

                    /**
                     * Decodes an InstanceGroupManagerAutoHealingPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerAutoHealingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy;

                    /**
                     * Verifies an InstanceGroupManagerAutoHealingPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerAutoHealingPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerAutoHealingPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy;

                    /**
                     * Creates a plain object from an InstanceGroupManagerAutoHealingPolicy message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerAutoHealingPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerAutoHealingPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerAutoHealingPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerAutoHealingPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerList. */
                interface IInstanceGroupManagerList {

                    /** InstanceGroupManagerList id */
                    id?: (string|null);

                    /** InstanceGroupManagerList items */
                    items?: (google.cloud.compute.v1.IInstanceGroupManager[]|null);

                    /** InstanceGroupManagerList kind */
                    kind?: (string|null);

                    /** InstanceGroupManagerList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceGroupManagerList selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroupManagerList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupManagerList. */
                class InstanceGroupManagerList implements IInstanceGroupManagerList {

                    /**
                     * Constructs a new InstanceGroupManagerList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerList);

                    /** InstanceGroupManagerList id. */
                    public id?: (string|null);

                    /** InstanceGroupManagerList items. */
                    public items: google.cloud.compute.v1.IInstanceGroupManager[];

                    /** InstanceGroupManagerList kind. */
                    public kind?: (string|null);

                    /** InstanceGroupManagerList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupManagerList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroupManagerList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupManagerList _id. */
                    public _id?: "id";

                    /** InstanceGroupManagerList _kind. */
                    public _kind?: "kind";

                    /** InstanceGroupManagerList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceGroupManagerList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroupManagerList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupManagerList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerList): google.cloud.compute.v1.InstanceGroupManagerList;

                    /**
                     * Encodes the specified InstanceGroupManagerList message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerList.verify|verify} messages.
                     * @param message InstanceGroupManagerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerList.verify|verify} messages.
                     * @param message InstanceGroupManagerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerList;

                    /**
                     * Decodes an InstanceGroupManagerList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerList;

                    /**
                     * Verifies an InstanceGroupManagerList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerList;

                    /**
                     * Creates a plain object from an InstanceGroupManagerList message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerStatus. */
                interface IInstanceGroupManagerStatus {

                    /** InstanceGroupManagerStatus autoscaler */
                    autoscaler?: (string|null);

                    /** InstanceGroupManagerStatus isStable */
                    isStable?: (boolean|null);

                    /** InstanceGroupManagerStatus stateful */
                    stateful?: (google.cloud.compute.v1.IInstanceGroupManagerStatusStateful|null);

                    /** InstanceGroupManagerStatus versionTarget */
                    versionTarget?: (google.cloud.compute.v1.IInstanceGroupManagerStatusVersionTarget|null);
                }

                /** Represents an InstanceGroupManagerStatus. */
                class InstanceGroupManagerStatus implements IInstanceGroupManagerStatus {

                    /**
                     * Constructs a new InstanceGroupManagerStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatus);

                    /** InstanceGroupManagerStatus autoscaler. */
                    public autoscaler?: (string|null);

                    /** InstanceGroupManagerStatus isStable. */
                    public isStable?: (boolean|null);

                    /** InstanceGroupManagerStatus stateful. */
                    public stateful?: (google.cloud.compute.v1.IInstanceGroupManagerStatusStateful|null);

                    /** InstanceGroupManagerStatus versionTarget. */
                    public versionTarget?: (google.cloud.compute.v1.IInstanceGroupManagerStatusVersionTarget|null);

                    /** InstanceGroupManagerStatus _autoscaler. */
                    public _autoscaler?: "autoscaler";

                    /** InstanceGroupManagerStatus _isStable. */
                    public _isStable?: "isStable";

                    /** InstanceGroupManagerStatus _stateful. */
                    public _stateful?: "stateful";

                    /** InstanceGroupManagerStatus _versionTarget. */
                    public _versionTarget?: "versionTarget";

                    /**
                     * Creates a new InstanceGroupManagerStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatus): google.cloud.compute.v1.InstanceGroupManagerStatus;

                    /**
                     * Encodes the specified InstanceGroupManagerStatus message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatus.verify|verify} messages.
                     * @param message InstanceGroupManagerStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatus.verify|verify} messages.
                     * @param message InstanceGroupManagerStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerStatus;

                    /**
                     * Decodes an InstanceGroupManagerStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerStatus;

                    /**
                     * Verifies an InstanceGroupManagerStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerStatus;

                    /**
                     * Creates a plain object from an InstanceGroupManagerStatus message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerStatusStateful. */
                interface IInstanceGroupManagerStatusStateful {

                    /** InstanceGroupManagerStatusStateful hasStatefulConfig */
                    hasStatefulConfig?: (boolean|null);

                    /** InstanceGroupManagerStatusStateful perInstanceConfigs */
                    perInstanceConfigs?: (google.cloud.compute.v1.IInstanceGroupManagerStatusStatefulPerInstanceConfigs|null);
                }

                /** Represents an InstanceGroupManagerStatusStateful. */
                class InstanceGroupManagerStatusStateful implements IInstanceGroupManagerStatusStateful {

                    /**
                     * Constructs a new InstanceGroupManagerStatusStateful.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatusStateful);

                    /** InstanceGroupManagerStatusStateful hasStatefulConfig. */
                    public hasStatefulConfig?: (boolean|null);

                    /** InstanceGroupManagerStatusStateful perInstanceConfigs. */
                    public perInstanceConfigs?: (google.cloud.compute.v1.IInstanceGroupManagerStatusStatefulPerInstanceConfigs|null);

                    /** InstanceGroupManagerStatusStateful _hasStatefulConfig. */
                    public _hasStatefulConfig?: "hasStatefulConfig";

                    /** InstanceGroupManagerStatusStateful _perInstanceConfigs. */
                    public _perInstanceConfigs?: "perInstanceConfigs";

                    /**
                     * Creates a new InstanceGroupManagerStatusStateful instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerStatusStateful instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatusStateful): google.cloud.compute.v1.InstanceGroupManagerStatusStateful;

                    /**
                     * Encodes the specified InstanceGroupManagerStatusStateful message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatusStateful.verify|verify} messages.
                     * @param message InstanceGroupManagerStatusStateful message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerStatusStateful, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerStatusStateful message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatusStateful.verify|verify} messages.
                     * @param message InstanceGroupManagerStatusStateful message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerStatusStateful, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerStatusStateful message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerStatusStateful
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerStatusStateful;

                    /**
                     * Decodes an InstanceGroupManagerStatusStateful message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerStatusStateful
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerStatusStateful;

                    /**
                     * Verifies an InstanceGroupManagerStatusStateful message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerStatusStateful message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerStatusStateful
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerStatusStateful;

                    /**
                     * Creates a plain object from an InstanceGroupManagerStatusStateful message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerStatusStateful
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerStatusStateful, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerStatusStateful to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerStatusStateful
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerStatusStatefulPerInstanceConfigs. */
                interface IInstanceGroupManagerStatusStatefulPerInstanceConfigs {

                    /** InstanceGroupManagerStatusStatefulPerInstanceConfigs allEffective */
                    allEffective?: (boolean|null);
                }

                /** Represents an InstanceGroupManagerStatusStatefulPerInstanceConfigs. */
                class InstanceGroupManagerStatusStatefulPerInstanceConfigs implements IInstanceGroupManagerStatusStatefulPerInstanceConfigs {

                    /**
                     * Constructs a new InstanceGroupManagerStatusStatefulPerInstanceConfigs.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatusStatefulPerInstanceConfigs);

                    /** InstanceGroupManagerStatusStatefulPerInstanceConfigs allEffective. */
                    public allEffective?: (boolean|null);

                    /** InstanceGroupManagerStatusStatefulPerInstanceConfigs _allEffective. */
                    public _allEffective?: "allEffective";

                    /**
                     * Creates a new InstanceGroupManagerStatusStatefulPerInstanceConfigs instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerStatusStatefulPerInstanceConfigs instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatusStatefulPerInstanceConfigs): google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs;

                    /**
                     * Encodes the specified InstanceGroupManagerStatusStatefulPerInstanceConfigs message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs.verify|verify} messages.
                     * @param message InstanceGroupManagerStatusStatefulPerInstanceConfigs message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerStatusStatefulPerInstanceConfigs, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerStatusStatefulPerInstanceConfigs message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs.verify|verify} messages.
                     * @param message InstanceGroupManagerStatusStatefulPerInstanceConfigs message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerStatusStatefulPerInstanceConfigs, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerStatusStatefulPerInstanceConfigs message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerStatusStatefulPerInstanceConfigs
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs;

                    /**
                     * Decodes an InstanceGroupManagerStatusStatefulPerInstanceConfigs message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerStatusStatefulPerInstanceConfigs
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs;

                    /**
                     * Verifies an InstanceGroupManagerStatusStatefulPerInstanceConfigs message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerStatusStatefulPerInstanceConfigs message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerStatusStatefulPerInstanceConfigs
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs;

                    /**
                     * Creates a plain object from an InstanceGroupManagerStatusStatefulPerInstanceConfigs message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerStatusStatefulPerInstanceConfigs
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerStatusStatefulPerInstanceConfigs, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerStatusStatefulPerInstanceConfigs to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerStatusStatefulPerInstanceConfigs
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerStatusVersionTarget. */
                interface IInstanceGroupManagerStatusVersionTarget {

                    /** InstanceGroupManagerStatusVersionTarget isReached */
                    isReached?: (boolean|null);
                }

                /** Represents an InstanceGroupManagerStatusVersionTarget. */
                class InstanceGroupManagerStatusVersionTarget implements IInstanceGroupManagerStatusVersionTarget {

                    /**
                     * Constructs a new InstanceGroupManagerStatusVersionTarget.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatusVersionTarget);

                    /** InstanceGroupManagerStatusVersionTarget isReached. */
                    public isReached?: (boolean|null);

                    /** InstanceGroupManagerStatusVersionTarget _isReached. */
                    public _isReached?: "isReached";

                    /**
                     * Creates a new InstanceGroupManagerStatusVersionTarget instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerStatusVersionTarget instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerStatusVersionTarget): google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget;

                    /**
                     * Encodes the specified InstanceGroupManagerStatusVersionTarget message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget.verify|verify} messages.
                     * @param message InstanceGroupManagerStatusVersionTarget message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerStatusVersionTarget, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerStatusVersionTarget message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget.verify|verify} messages.
                     * @param message InstanceGroupManagerStatusVersionTarget message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerStatusVersionTarget, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerStatusVersionTarget message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerStatusVersionTarget
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget;

                    /**
                     * Decodes an InstanceGroupManagerStatusVersionTarget message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerStatusVersionTarget
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget;

                    /**
                     * Verifies an InstanceGroupManagerStatusVersionTarget message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerStatusVersionTarget message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerStatusVersionTarget
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget;

                    /**
                     * Creates a plain object from an InstanceGroupManagerStatusVersionTarget message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerStatusVersionTarget
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerStatusVersionTarget, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerStatusVersionTarget to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerStatusVersionTarget
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagerUpdatePolicy. */
                interface IInstanceGroupManagerUpdatePolicy {

                    /** InstanceGroupManagerUpdatePolicy instanceRedistributionType */
                    instanceRedistributionType?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy maxSurge */
                    maxSurge?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** InstanceGroupManagerUpdatePolicy maxUnavailable */
                    maxUnavailable?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** InstanceGroupManagerUpdatePolicy minimalAction */
                    minimalAction?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy mostDisruptiveAllowedAction */
                    mostDisruptiveAllowedAction?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy replacementMethod */
                    replacementMethod?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy type */
                    type?: (string|null);
                }

                /** Represents an InstanceGroupManagerUpdatePolicy. */
                class InstanceGroupManagerUpdatePolicy implements IInstanceGroupManagerUpdatePolicy {

                    /**
                     * Constructs a new InstanceGroupManagerUpdatePolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerUpdatePolicy);

                    /** InstanceGroupManagerUpdatePolicy instanceRedistributionType. */
                    public instanceRedistributionType?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy maxSurge. */
                    public maxSurge?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** InstanceGroupManagerUpdatePolicy maxUnavailable. */
                    public maxUnavailable?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** InstanceGroupManagerUpdatePolicy minimalAction. */
                    public minimalAction?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy mostDisruptiveAllowedAction. */
                    public mostDisruptiveAllowedAction?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy replacementMethod. */
                    public replacementMethod?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy type. */
                    public type?: (string|null);

                    /** InstanceGroupManagerUpdatePolicy _instanceRedistributionType. */
                    public _instanceRedistributionType?: "instanceRedistributionType";

                    /** InstanceGroupManagerUpdatePolicy _maxSurge. */
                    public _maxSurge?: "maxSurge";

                    /** InstanceGroupManagerUpdatePolicy _maxUnavailable. */
                    public _maxUnavailable?: "maxUnavailable";

                    /** InstanceGroupManagerUpdatePolicy _minimalAction. */
                    public _minimalAction?: "minimalAction";

                    /** InstanceGroupManagerUpdatePolicy _mostDisruptiveAllowedAction. */
                    public _mostDisruptiveAllowedAction?: "mostDisruptiveAllowedAction";

                    /** InstanceGroupManagerUpdatePolicy _replacementMethod. */
                    public _replacementMethod?: "replacementMethod";

                    /** InstanceGroupManagerUpdatePolicy _type. */
                    public _type?: "type";

                    /**
                     * Creates a new InstanceGroupManagerUpdatePolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerUpdatePolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerUpdatePolicy): google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy;

                    /**
                     * Encodes the specified InstanceGroupManagerUpdatePolicy message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy.verify|verify} messages.
                     * @param message InstanceGroupManagerUpdatePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerUpdatePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerUpdatePolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy.verify|verify} messages.
                     * @param message InstanceGroupManagerUpdatePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerUpdatePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerUpdatePolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerUpdatePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy;

                    /**
                     * Decodes an InstanceGroupManagerUpdatePolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerUpdatePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy;

                    /**
                     * Verifies an InstanceGroupManagerUpdatePolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerUpdatePolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerUpdatePolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy;

                    /**
                     * Creates a plain object from an InstanceGroupManagerUpdatePolicy message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerUpdatePolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerUpdatePolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerUpdatePolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerUpdatePolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceGroupManagerUpdatePolicy {

                    /** InstanceRedistributionType enum. */
                    enum InstanceRedistributionType {
                        UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
                    }

                    /** MinimalAction enum. */
                    enum MinimalAction {
                        UNDEFINED_MINIMAL_ACTION = 0
                    }

                    /** MostDisruptiveAllowedAction enum. */
                    enum MostDisruptiveAllowedAction {
                        UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
                    }

                    /** ReplacementMethod enum. */
                    enum ReplacementMethod {
                        UNDEFINED_REPLACEMENT_METHOD = 0,
                        RECREATE = 522644719,
                        SUBSTITUTE = 280924314
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        OPPORTUNISTIC = 429530089
                    }
                }

                /** Properties of an InstanceGroupManagerVersion. */
                interface IInstanceGroupManagerVersion {

                    /** InstanceGroupManagerVersion instanceTemplate */
                    instanceTemplate?: (string|null);

                    /** InstanceGroupManagerVersion name */
                    name?: (string|null);

                    /** InstanceGroupManagerVersion targetSize */
                    targetSize?: (google.cloud.compute.v1.IFixedOrPercent|null);
                }

                /** Represents an InstanceGroupManagerVersion. */
                class InstanceGroupManagerVersion implements IInstanceGroupManagerVersion {

                    /**
                     * Constructs a new InstanceGroupManagerVersion.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagerVersion);

                    /** InstanceGroupManagerVersion instanceTemplate. */
                    public instanceTemplate?: (string|null);

                    /** InstanceGroupManagerVersion name. */
                    public name?: (string|null);

                    /** InstanceGroupManagerVersion targetSize. */
                    public targetSize?: (google.cloud.compute.v1.IFixedOrPercent|null);

                    /** InstanceGroupManagerVersion _instanceTemplate. */
                    public _instanceTemplate?: "instanceTemplate";

                    /** InstanceGroupManagerVersion _name. */
                    public _name?: "name";

                    /** InstanceGroupManagerVersion _targetSize. */
                    public _targetSize?: "targetSize";

                    /**
                     * Creates a new InstanceGroupManagerVersion instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagerVersion instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagerVersion): google.cloud.compute.v1.InstanceGroupManagerVersion;

                    /**
                     * Encodes the specified InstanceGroupManagerVersion message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerVersion.verify|verify} messages.
                     * @param message InstanceGroupManagerVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagerVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagerVersion message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagerVersion.verify|verify} messages.
                     * @param message InstanceGroupManagerVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagerVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagerVersion message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagerVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagerVersion;

                    /**
                     * Decodes an InstanceGroupManagerVersion message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagerVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagerVersion;

                    /**
                     * Verifies an InstanceGroupManagerVersion message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagerVersion message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagerVersion
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagerVersion;

                    /**
                     * Creates a plain object from an InstanceGroupManagerVersion message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagerVersion
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagerVersion, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagerVersion to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagerVersion
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersAbandonInstancesRequest. */
                interface IInstanceGroupManagersAbandonInstancesRequest {

                    /** InstanceGroupManagersAbandonInstancesRequest instances */
                    instances?: (string[]|null);
                }

                /** Represents an InstanceGroupManagersAbandonInstancesRequest. */
                class InstanceGroupManagersAbandonInstancesRequest implements IInstanceGroupManagersAbandonInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupManagersAbandonInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersAbandonInstancesRequest);

                    /** InstanceGroupManagersAbandonInstancesRequest instances. */
                    public instances: string[];

                    /**
                     * Creates a new InstanceGroupManagersAbandonInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersAbandonInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersAbandonInstancesRequest): google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersAbandonInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersAbandonInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersAbandonInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersAbandonInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersAbandonInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersAbandonInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersAbandonInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersAbandonInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Decodes an InstanceGroupManagersAbandonInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersAbandonInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Verifies an InstanceGroupManagersAbandonInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersAbandonInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersAbandonInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersAbandonInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersAbandonInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersAbandonInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersAbandonInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersAbandonInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersApplyUpdatesRequest. */
                interface IInstanceGroupManagersApplyUpdatesRequest {

                    /** InstanceGroupManagersApplyUpdatesRequest allInstances */
                    allInstances?: (boolean|null);

                    /** InstanceGroupManagersApplyUpdatesRequest instances */
                    instances?: (string[]|null);

                    /** InstanceGroupManagersApplyUpdatesRequest minimalAction */
                    minimalAction?: (string|null);

                    /** InstanceGroupManagersApplyUpdatesRequest mostDisruptiveAllowedAction */
                    mostDisruptiveAllowedAction?: (string|null);
                }

                /** Represents an InstanceGroupManagersApplyUpdatesRequest. */
                class InstanceGroupManagersApplyUpdatesRequest implements IInstanceGroupManagersApplyUpdatesRequest {

                    /**
                     * Constructs a new InstanceGroupManagersApplyUpdatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersApplyUpdatesRequest);

                    /** InstanceGroupManagersApplyUpdatesRequest allInstances. */
                    public allInstances?: (boolean|null);

                    /** InstanceGroupManagersApplyUpdatesRequest instances. */
                    public instances: string[];

                    /** InstanceGroupManagersApplyUpdatesRequest minimalAction. */
                    public minimalAction?: (string|null);

                    /** InstanceGroupManagersApplyUpdatesRequest mostDisruptiveAllowedAction. */
                    public mostDisruptiveAllowedAction?: (string|null);

                    /** InstanceGroupManagersApplyUpdatesRequest _allInstances. */
                    public _allInstances?: "allInstances";

                    /** InstanceGroupManagersApplyUpdatesRequest _minimalAction. */
                    public _minimalAction?: "minimalAction";

                    /** InstanceGroupManagersApplyUpdatesRequest _mostDisruptiveAllowedAction. */
                    public _mostDisruptiveAllowedAction?: "mostDisruptiveAllowedAction";

                    /**
                     * Creates a new InstanceGroupManagersApplyUpdatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersApplyUpdatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersApplyUpdatesRequest): google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersApplyUpdatesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersApplyUpdatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersApplyUpdatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersApplyUpdatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersApplyUpdatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersApplyUpdatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersApplyUpdatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersApplyUpdatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Decodes an InstanceGroupManagersApplyUpdatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersApplyUpdatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Verifies an InstanceGroupManagersApplyUpdatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersApplyUpdatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersApplyUpdatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersApplyUpdatesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersApplyUpdatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersApplyUpdatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersApplyUpdatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersApplyUpdatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceGroupManagersApplyUpdatesRequest {

                    /** MinimalAction enum. */
                    enum MinimalAction {
                        UNDEFINED_MINIMAL_ACTION = 0
                    }

                    /** MostDisruptiveAllowedAction enum. */
                    enum MostDisruptiveAllowedAction {
                        UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
                    }
                }

                /** Properties of an InstanceGroupManagersCreateInstancesRequest. */
                interface IInstanceGroupManagersCreateInstancesRequest {

                    /** InstanceGroupManagersCreateInstancesRequest instances */
                    instances?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);
                }

                /** Represents an InstanceGroupManagersCreateInstancesRequest. */
                class InstanceGroupManagersCreateInstancesRequest implements IInstanceGroupManagersCreateInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupManagersCreateInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersCreateInstancesRequest);

                    /** InstanceGroupManagersCreateInstancesRequest instances. */
                    public instances: google.cloud.compute.v1.IPerInstanceConfig[];

                    /**
                     * Creates a new InstanceGroupManagersCreateInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersCreateInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersCreateInstancesRequest): google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersCreateInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersCreateInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersCreateInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersCreateInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersCreateInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersCreateInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersCreateInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersCreateInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Decodes an InstanceGroupManagersCreateInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersCreateInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Verifies an InstanceGroupManagersCreateInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersCreateInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersCreateInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersCreateInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersCreateInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersCreateInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersCreateInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersCreateInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersDeleteInstancesRequest. */
                interface IInstanceGroupManagersDeleteInstancesRequest {

                    /** InstanceGroupManagersDeleteInstancesRequest instances */
                    instances?: (string[]|null);

                    /** InstanceGroupManagersDeleteInstancesRequest skipInstancesOnValidationError */
                    skipInstancesOnValidationError?: (boolean|null);
                }

                /** Represents an InstanceGroupManagersDeleteInstancesRequest. */
                class InstanceGroupManagersDeleteInstancesRequest implements IInstanceGroupManagersDeleteInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupManagersDeleteInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersDeleteInstancesRequest);

                    /** InstanceGroupManagersDeleteInstancesRequest instances. */
                    public instances: string[];

                    /** InstanceGroupManagersDeleteInstancesRequest skipInstancesOnValidationError. */
                    public skipInstancesOnValidationError?: (boolean|null);

                    /** InstanceGroupManagersDeleteInstancesRequest _skipInstancesOnValidationError. */
                    public _skipInstancesOnValidationError?: "skipInstancesOnValidationError";

                    /**
                     * Creates a new InstanceGroupManagersDeleteInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersDeleteInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersDeleteInstancesRequest): google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersDeleteInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersDeleteInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersDeleteInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersDeleteInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersDeleteInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersDeleteInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersDeleteInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersDeleteInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Decodes an InstanceGroupManagersDeleteInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersDeleteInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Verifies an InstanceGroupManagersDeleteInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersDeleteInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersDeleteInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersDeleteInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersDeleteInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersDeleteInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersDeleteInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersDeleteInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersDeletePerInstanceConfigsReq. */
                interface IInstanceGroupManagersDeletePerInstanceConfigsReq {

                    /** InstanceGroupManagersDeletePerInstanceConfigsReq names */
                    names?: (string[]|null);
                }

                /** Represents an InstanceGroupManagersDeletePerInstanceConfigsReq. */
                class InstanceGroupManagersDeletePerInstanceConfigsReq implements IInstanceGroupManagersDeletePerInstanceConfigsReq {

                    /**
                     * Constructs a new InstanceGroupManagersDeletePerInstanceConfigsReq.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersDeletePerInstanceConfigsReq);

                    /** InstanceGroupManagersDeletePerInstanceConfigsReq names. */
                    public names: string[];

                    /**
                     * Creates a new InstanceGroupManagersDeletePerInstanceConfigsReq instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersDeletePerInstanceConfigsReq instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersDeletePerInstanceConfigsReq): google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq;

                    /**
                     * Encodes the specified InstanceGroupManagersDeletePerInstanceConfigsReq message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq.verify|verify} messages.
                     * @param message InstanceGroupManagersDeletePerInstanceConfigsReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersDeletePerInstanceConfigsReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersDeletePerInstanceConfigsReq message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq.verify|verify} messages.
                     * @param message InstanceGroupManagersDeletePerInstanceConfigsReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersDeletePerInstanceConfigsReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersDeletePerInstanceConfigsReq message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersDeletePerInstanceConfigsReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq;

                    /**
                     * Decodes an InstanceGroupManagersDeletePerInstanceConfigsReq message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersDeletePerInstanceConfigsReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq;

                    /**
                     * Verifies an InstanceGroupManagersDeletePerInstanceConfigsReq message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersDeletePerInstanceConfigsReq message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersDeletePerInstanceConfigsReq
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq;

                    /**
                     * Creates a plain object from an InstanceGroupManagersDeletePerInstanceConfigsReq message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersDeletePerInstanceConfigsReq
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersDeletePerInstanceConfigsReq, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersDeletePerInstanceConfigsReq to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersDeletePerInstanceConfigsReq
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersListErrorsResponse. */
                interface IInstanceGroupManagersListErrorsResponse {

                    /** InstanceGroupManagersListErrorsResponse items */
                    items?: (google.cloud.compute.v1.IInstanceManagedByIgmError[]|null);

                    /** InstanceGroupManagersListErrorsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents an InstanceGroupManagersListErrorsResponse. */
                class InstanceGroupManagersListErrorsResponse implements IInstanceGroupManagersListErrorsResponse {

                    /**
                     * Constructs a new InstanceGroupManagersListErrorsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse);

                    /** InstanceGroupManagersListErrorsResponse items. */
                    public items: google.cloud.compute.v1.IInstanceManagedByIgmError[];

                    /** InstanceGroupManagersListErrorsResponse nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupManagersListErrorsResponse _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /**
                     * Creates a new InstanceGroupManagersListErrorsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersListErrorsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse): google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse;

                    /**
                     * Encodes the specified InstanceGroupManagersListErrorsResponse message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse.verify|verify} messages.
                     * @param message InstanceGroupManagersListErrorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersListErrorsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse.verify|verify} messages.
                     * @param message InstanceGroupManagersListErrorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersListErrorsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersListErrorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse;

                    /**
                     * Decodes an InstanceGroupManagersListErrorsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersListErrorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse;

                    /**
                     * Verifies an InstanceGroupManagersListErrorsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersListErrorsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersListErrorsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse;

                    /**
                     * Creates a plain object from an InstanceGroupManagersListErrorsResponse message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersListErrorsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersListErrorsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersListErrorsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersListManagedInstancesResponse. */
                interface IInstanceGroupManagersListManagedInstancesResponse {

                    /** InstanceGroupManagersListManagedInstancesResponse managedInstances */
                    managedInstances?: (google.cloud.compute.v1.IManagedInstance[]|null);

                    /** InstanceGroupManagersListManagedInstancesResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents an InstanceGroupManagersListManagedInstancesResponse. */
                class InstanceGroupManagersListManagedInstancesResponse implements IInstanceGroupManagersListManagedInstancesResponse {

                    /**
                     * Constructs a new InstanceGroupManagersListManagedInstancesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse);

                    /** InstanceGroupManagersListManagedInstancesResponse managedInstances. */
                    public managedInstances: google.cloud.compute.v1.IManagedInstance[];

                    /** InstanceGroupManagersListManagedInstancesResponse nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupManagersListManagedInstancesResponse _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /**
                     * Creates a new InstanceGroupManagersListManagedInstancesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersListManagedInstancesResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse): google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse;

                    /**
                     * Encodes the specified InstanceGroupManagersListManagedInstancesResponse message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse.verify|verify} messages.
                     * @param message InstanceGroupManagersListManagedInstancesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersListManagedInstancesResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse.verify|verify} messages.
                     * @param message InstanceGroupManagersListManagedInstancesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersListManagedInstancesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersListManagedInstancesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse;

                    /**
                     * Decodes an InstanceGroupManagersListManagedInstancesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersListManagedInstancesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse;

                    /**
                     * Verifies an InstanceGroupManagersListManagedInstancesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersListManagedInstancesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersListManagedInstancesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse;

                    /**
                     * Creates a plain object from an InstanceGroupManagersListManagedInstancesResponse message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersListManagedInstancesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersListManagedInstancesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersListManagedInstancesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersListPerInstanceConfigsResp. */
                interface IInstanceGroupManagersListPerInstanceConfigsResp {

                    /** InstanceGroupManagersListPerInstanceConfigsResp items */
                    items?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);

                    /** InstanceGroupManagersListPerInstanceConfigsResp nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceGroupManagersListPerInstanceConfigsResp warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupManagersListPerInstanceConfigsResp. */
                class InstanceGroupManagersListPerInstanceConfigsResp implements IInstanceGroupManagersListPerInstanceConfigsResp {

                    /**
                     * Constructs a new InstanceGroupManagersListPerInstanceConfigsResp.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp);

                    /** InstanceGroupManagersListPerInstanceConfigsResp items. */
                    public items: google.cloud.compute.v1.IPerInstanceConfig[];

                    /** InstanceGroupManagersListPerInstanceConfigsResp nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupManagersListPerInstanceConfigsResp warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupManagersListPerInstanceConfigsResp _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceGroupManagersListPerInstanceConfigsResp _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupManagersListPerInstanceConfigsResp instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersListPerInstanceConfigsResp instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp): google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp;

                    /**
                     * Encodes the specified InstanceGroupManagersListPerInstanceConfigsResp message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp.verify|verify} messages.
                     * @param message InstanceGroupManagersListPerInstanceConfigsResp message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersListPerInstanceConfigsResp message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp.verify|verify} messages.
                     * @param message InstanceGroupManagersListPerInstanceConfigsResp message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersListPerInstanceConfigsResp message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersListPerInstanceConfigsResp
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp;

                    /**
                     * Decodes an InstanceGroupManagersListPerInstanceConfigsResp message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersListPerInstanceConfigsResp
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp;

                    /**
                     * Verifies an InstanceGroupManagersListPerInstanceConfigsResp message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersListPerInstanceConfigsResp message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersListPerInstanceConfigsResp
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp;

                    /**
                     * Creates a plain object from an InstanceGroupManagersListPerInstanceConfigsResp message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersListPerInstanceConfigsResp
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersListPerInstanceConfigsResp to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersListPerInstanceConfigsResp
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersPatchPerInstanceConfigsReq. */
                interface IInstanceGroupManagersPatchPerInstanceConfigsReq {

                    /** InstanceGroupManagersPatchPerInstanceConfigsReq perInstanceConfigs */
                    perInstanceConfigs?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);
                }

                /** Represents an InstanceGroupManagersPatchPerInstanceConfigsReq. */
                class InstanceGroupManagersPatchPerInstanceConfigsReq implements IInstanceGroupManagersPatchPerInstanceConfigsReq {

                    /**
                     * Constructs a new InstanceGroupManagersPatchPerInstanceConfigsReq.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersPatchPerInstanceConfigsReq);

                    /** InstanceGroupManagersPatchPerInstanceConfigsReq perInstanceConfigs. */
                    public perInstanceConfigs: google.cloud.compute.v1.IPerInstanceConfig[];

                    /**
                     * Creates a new InstanceGroupManagersPatchPerInstanceConfigsReq instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersPatchPerInstanceConfigsReq instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersPatchPerInstanceConfigsReq): google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq;

                    /**
                     * Encodes the specified InstanceGroupManagersPatchPerInstanceConfigsReq message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq.verify|verify} messages.
                     * @param message InstanceGroupManagersPatchPerInstanceConfigsReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersPatchPerInstanceConfigsReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersPatchPerInstanceConfigsReq message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq.verify|verify} messages.
                     * @param message InstanceGroupManagersPatchPerInstanceConfigsReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersPatchPerInstanceConfigsReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersPatchPerInstanceConfigsReq message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersPatchPerInstanceConfigsReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq;

                    /**
                     * Decodes an InstanceGroupManagersPatchPerInstanceConfigsReq message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersPatchPerInstanceConfigsReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq;

                    /**
                     * Verifies an InstanceGroupManagersPatchPerInstanceConfigsReq message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersPatchPerInstanceConfigsReq message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersPatchPerInstanceConfigsReq
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq;

                    /**
                     * Creates a plain object from an InstanceGroupManagersPatchPerInstanceConfigsReq message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersPatchPerInstanceConfigsReq
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersPatchPerInstanceConfigsReq, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersPatchPerInstanceConfigsReq to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersPatchPerInstanceConfigsReq
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersRecreateInstancesRequest. */
                interface IInstanceGroupManagersRecreateInstancesRequest {

                    /** InstanceGroupManagersRecreateInstancesRequest instances */
                    instances?: (string[]|null);
                }

                /** Represents an InstanceGroupManagersRecreateInstancesRequest. */
                class InstanceGroupManagersRecreateInstancesRequest implements IInstanceGroupManagersRecreateInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupManagersRecreateInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersRecreateInstancesRequest);

                    /** InstanceGroupManagersRecreateInstancesRequest instances. */
                    public instances: string[];

                    /**
                     * Creates a new InstanceGroupManagersRecreateInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersRecreateInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersRecreateInstancesRequest): google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersRecreateInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersRecreateInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersRecreateInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersRecreateInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersRecreateInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersRecreateInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersRecreateInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersRecreateInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest;

                    /**
                     * Decodes an InstanceGroupManagersRecreateInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersRecreateInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest;

                    /**
                     * Verifies an InstanceGroupManagersRecreateInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersRecreateInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersRecreateInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersRecreateInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersRecreateInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersRecreateInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersRecreateInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersRecreateInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersScopedList. */
                interface IInstanceGroupManagersScopedList {

                    /** InstanceGroupManagersScopedList instanceGroupManagers */
                    instanceGroupManagers?: (google.cloud.compute.v1.IInstanceGroupManager[]|null);

                    /** InstanceGroupManagersScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupManagersScopedList. */
                class InstanceGroupManagersScopedList implements IInstanceGroupManagersScopedList {

                    /**
                     * Constructs a new InstanceGroupManagersScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersScopedList);

                    /** InstanceGroupManagersScopedList instanceGroupManagers. */
                    public instanceGroupManagers: google.cloud.compute.v1.IInstanceGroupManager[];

                    /** InstanceGroupManagersScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupManagersScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupManagersScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersScopedList): google.cloud.compute.v1.InstanceGroupManagersScopedList;

                    /**
                     * Encodes the specified InstanceGroupManagersScopedList message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersScopedList.verify|verify} messages.
                     * @param message InstanceGroupManagersScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersScopedList.verify|verify} messages.
                     * @param message InstanceGroupManagersScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersScopedList;

                    /**
                     * Decodes an InstanceGroupManagersScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersScopedList;

                    /**
                     * Verifies an InstanceGroupManagersScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersScopedList;

                    /**
                     * Creates a plain object from an InstanceGroupManagersScopedList message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersSetInstanceTemplateRequest. */
                interface IInstanceGroupManagersSetInstanceTemplateRequest {

                    /** InstanceGroupManagersSetInstanceTemplateRequest instanceTemplate */
                    instanceTemplate?: (string|null);
                }

                /** Represents an InstanceGroupManagersSetInstanceTemplateRequest. */
                class InstanceGroupManagersSetInstanceTemplateRequest implements IInstanceGroupManagersSetInstanceTemplateRequest {

                    /**
                     * Constructs a new InstanceGroupManagersSetInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersSetInstanceTemplateRequest);

                    /** InstanceGroupManagersSetInstanceTemplateRequest instanceTemplate. */
                    public instanceTemplate?: (string|null);

                    /** InstanceGroupManagersSetInstanceTemplateRequest _instanceTemplate. */
                    public _instanceTemplate?: "instanceTemplate";

                    /**
                     * Creates a new InstanceGroupManagersSetInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersSetInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersSetInstanceTemplateRequest): google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersSetInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersSetInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersSetInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersSetInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersSetInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersSetInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersSetInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersSetInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest;

                    /**
                     * Decodes an InstanceGroupManagersSetInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersSetInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest;

                    /**
                     * Verifies an InstanceGroupManagersSetInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersSetInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersSetInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersSetInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersSetInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersSetInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersSetInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersSetInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersSetTargetPoolsRequest. */
                interface IInstanceGroupManagersSetTargetPoolsRequest {

                    /** InstanceGroupManagersSetTargetPoolsRequest fingerprint */
                    fingerprint?: (string|null);

                    /** InstanceGroupManagersSetTargetPoolsRequest targetPools */
                    targetPools?: (string[]|null);
                }

                /** Represents an InstanceGroupManagersSetTargetPoolsRequest. */
                class InstanceGroupManagersSetTargetPoolsRequest implements IInstanceGroupManagersSetTargetPoolsRequest {

                    /**
                     * Constructs a new InstanceGroupManagersSetTargetPoolsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersSetTargetPoolsRequest);

                    /** InstanceGroupManagersSetTargetPoolsRequest fingerprint. */
                    public fingerprint?: (string|null);

                    /** InstanceGroupManagersSetTargetPoolsRequest targetPools. */
                    public targetPools: string[];

                    /** InstanceGroupManagersSetTargetPoolsRequest _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /**
                     * Creates a new InstanceGroupManagersSetTargetPoolsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersSetTargetPoolsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersSetTargetPoolsRequest): google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Encodes the specified InstanceGroupManagersSetTargetPoolsRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersSetTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersSetTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersSetTargetPoolsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest.verify|verify} messages.
                     * @param message InstanceGroupManagersSetTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersSetTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersSetTargetPoolsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersSetTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Decodes an InstanceGroupManagersSetTargetPoolsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersSetTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Verifies an InstanceGroupManagersSetTargetPoolsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersSetTargetPoolsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersSetTargetPoolsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Creates a plain object from an InstanceGroupManagersSetTargetPoolsRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersSetTargetPoolsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersSetTargetPoolsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersSetTargetPoolsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersSetTargetPoolsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupManagersUpdatePerInstanceConfigsReq. */
                interface IInstanceGroupManagersUpdatePerInstanceConfigsReq {

                    /** InstanceGroupManagersUpdatePerInstanceConfigsReq perInstanceConfigs */
                    perInstanceConfigs?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);
                }

                /** Represents an InstanceGroupManagersUpdatePerInstanceConfigsReq. */
                class InstanceGroupManagersUpdatePerInstanceConfigsReq implements IInstanceGroupManagersUpdatePerInstanceConfigsReq {

                    /**
                     * Constructs a new InstanceGroupManagersUpdatePerInstanceConfigsReq.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupManagersUpdatePerInstanceConfigsReq);

                    /** InstanceGroupManagersUpdatePerInstanceConfigsReq perInstanceConfigs. */
                    public perInstanceConfigs: google.cloud.compute.v1.IPerInstanceConfig[];

                    /**
                     * Creates a new InstanceGroupManagersUpdatePerInstanceConfigsReq instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupManagersUpdatePerInstanceConfigsReq instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupManagersUpdatePerInstanceConfigsReq): google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq;

                    /**
                     * Encodes the specified InstanceGroupManagersUpdatePerInstanceConfigsReq message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq.verify|verify} messages.
                     * @param message InstanceGroupManagersUpdatePerInstanceConfigsReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupManagersUpdatePerInstanceConfigsReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupManagersUpdatePerInstanceConfigsReq message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq.verify|verify} messages.
                     * @param message InstanceGroupManagersUpdatePerInstanceConfigsReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupManagersUpdatePerInstanceConfigsReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupManagersUpdatePerInstanceConfigsReq message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupManagersUpdatePerInstanceConfigsReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq;

                    /**
                     * Decodes an InstanceGroupManagersUpdatePerInstanceConfigsReq message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupManagersUpdatePerInstanceConfigsReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq;

                    /**
                     * Verifies an InstanceGroupManagersUpdatePerInstanceConfigsReq message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupManagersUpdatePerInstanceConfigsReq message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupManagersUpdatePerInstanceConfigsReq
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq;

                    /**
                     * Creates a plain object from an InstanceGroupManagersUpdatePerInstanceConfigsReq message. Also converts values to other types if specified.
                     * @param message InstanceGroupManagersUpdatePerInstanceConfigsReq
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupManagersUpdatePerInstanceConfigsReq, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupManagersUpdatePerInstanceConfigsReq to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupManagersUpdatePerInstanceConfigsReq
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupsAddInstancesRequest. */
                interface IInstanceGroupsAddInstancesRequest {

                    /** InstanceGroupsAddInstancesRequest instances */
                    instances?: (google.cloud.compute.v1.IInstanceReference[]|null);
                }

                /** Represents an InstanceGroupsAddInstancesRequest. */
                class InstanceGroupsAddInstancesRequest implements IInstanceGroupsAddInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupsAddInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupsAddInstancesRequest);

                    /** InstanceGroupsAddInstancesRequest instances. */
                    public instances: google.cloud.compute.v1.IInstanceReference[];

                    /**
                     * Creates a new InstanceGroupsAddInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupsAddInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupsAddInstancesRequest): google.cloud.compute.v1.InstanceGroupsAddInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupsAddInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsAddInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupsAddInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupsAddInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupsAddInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsAddInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupsAddInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupsAddInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupsAddInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupsAddInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupsAddInstancesRequest;

                    /**
                     * Decodes an InstanceGroupsAddInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupsAddInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupsAddInstancesRequest;

                    /**
                     * Verifies an InstanceGroupsAddInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupsAddInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupsAddInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupsAddInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupsAddInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupsAddInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupsAddInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupsAddInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupsAddInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupsListInstances. */
                interface IInstanceGroupsListInstances {

                    /** InstanceGroupsListInstances id */
                    id?: (string|null);

                    /** InstanceGroupsListInstances items */
                    items?: (google.cloud.compute.v1.IInstanceWithNamedPorts[]|null);

                    /** InstanceGroupsListInstances kind */
                    kind?: (string|null);

                    /** InstanceGroupsListInstances nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceGroupsListInstances selfLink */
                    selfLink?: (string|null);

                    /** InstanceGroupsListInstances warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupsListInstances. */
                class InstanceGroupsListInstances implements IInstanceGroupsListInstances {

                    /**
                     * Constructs a new InstanceGroupsListInstances.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupsListInstances);

                    /** InstanceGroupsListInstances id. */
                    public id?: (string|null);

                    /** InstanceGroupsListInstances items. */
                    public items: google.cloud.compute.v1.IInstanceWithNamedPorts[];

                    /** InstanceGroupsListInstances kind. */
                    public kind?: (string|null);

                    /** InstanceGroupsListInstances nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceGroupsListInstances selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceGroupsListInstances warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupsListInstances _id. */
                    public _id?: "id";

                    /** InstanceGroupsListInstances _kind. */
                    public _kind?: "kind";

                    /** InstanceGroupsListInstances _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceGroupsListInstances _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceGroupsListInstances _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupsListInstances instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupsListInstances instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupsListInstances): google.cloud.compute.v1.InstanceGroupsListInstances;

                    /**
                     * Encodes the specified InstanceGroupsListInstances message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsListInstances.verify|verify} messages.
                     * @param message InstanceGroupsListInstances message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupsListInstances, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupsListInstances message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsListInstances.verify|verify} messages.
                     * @param message InstanceGroupsListInstances message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupsListInstances, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupsListInstances message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupsListInstances
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupsListInstances;

                    /**
                     * Decodes an InstanceGroupsListInstances message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupsListInstances
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupsListInstances;

                    /**
                     * Verifies an InstanceGroupsListInstances message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupsListInstances message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupsListInstances
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupsListInstances;

                    /**
                     * Creates a plain object from an InstanceGroupsListInstances message. Also converts values to other types if specified.
                     * @param message InstanceGroupsListInstances
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupsListInstances, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupsListInstances to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupsListInstances
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupsListInstancesRequest. */
                interface IInstanceGroupsListInstancesRequest {

                    /** InstanceGroupsListInstancesRequest instanceState */
                    instanceState?: (string|null);
                }

                /** Represents an InstanceGroupsListInstancesRequest. */
                class InstanceGroupsListInstancesRequest implements IInstanceGroupsListInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupsListInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupsListInstancesRequest);

                    /** InstanceGroupsListInstancesRequest instanceState. */
                    public instanceState?: (string|null);

                    /** InstanceGroupsListInstancesRequest _instanceState. */
                    public _instanceState?: "instanceState";

                    /**
                     * Creates a new InstanceGroupsListInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupsListInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupsListInstancesRequest): google.cloud.compute.v1.InstanceGroupsListInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupsListInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsListInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupsListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupsListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupsListInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsListInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupsListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupsListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupsListInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupsListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupsListInstancesRequest;

                    /**
                     * Decodes an InstanceGroupsListInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupsListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupsListInstancesRequest;

                    /**
                     * Verifies an InstanceGroupsListInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupsListInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupsListInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupsListInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupsListInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupsListInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupsListInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupsListInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupsListInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceGroupsListInstancesRequest {

                    /** InstanceState enum. */
                    enum InstanceState {
                        UNDEFINED_INSTANCE_STATE = 0,
                        ALL = 64897,
                        RUNNING = 121282975
                    }
                }

                /** Properties of an InstanceGroupsRemoveInstancesRequest. */
                interface IInstanceGroupsRemoveInstancesRequest {

                    /** InstanceGroupsRemoveInstancesRequest instances */
                    instances?: (google.cloud.compute.v1.IInstanceReference[]|null);
                }

                /** Represents an InstanceGroupsRemoveInstancesRequest. */
                class InstanceGroupsRemoveInstancesRequest implements IInstanceGroupsRemoveInstancesRequest {

                    /**
                     * Constructs a new InstanceGroupsRemoveInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupsRemoveInstancesRequest);

                    /** InstanceGroupsRemoveInstancesRequest instances. */
                    public instances: google.cloud.compute.v1.IInstanceReference[];

                    /**
                     * Creates a new InstanceGroupsRemoveInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupsRemoveInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupsRemoveInstancesRequest): google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest;

                    /**
                     * Encodes the specified InstanceGroupsRemoveInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupsRemoveInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupsRemoveInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupsRemoveInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest.verify|verify} messages.
                     * @param message InstanceGroupsRemoveInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupsRemoveInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupsRemoveInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupsRemoveInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest;

                    /**
                     * Decodes an InstanceGroupsRemoveInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupsRemoveInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest;

                    /**
                     * Verifies an InstanceGroupsRemoveInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupsRemoveInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupsRemoveInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest;

                    /**
                     * Creates a plain object from an InstanceGroupsRemoveInstancesRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupsRemoveInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupsRemoveInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupsRemoveInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupsRemoveInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupsScopedList. */
                interface IInstanceGroupsScopedList {

                    /** InstanceGroupsScopedList instanceGroups */
                    instanceGroups?: (google.cloud.compute.v1.IInstanceGroup[]|null);

                    /** InstanceGroupsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceGroupsScopedList. */
                class InstanceGroupsScopedList implements IInstanceGroupsScopedList {

                    /**
                     * Constructs a new InstanceGroupsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupsScopedList);

                    /** InstanceGroupsScopedList instanceGroups. */
                    public instanceGroups: google.cloud.compute.v1.IInstanceGroup[];

                    /** InstanceGroupsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceGroupsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceGroupsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupsScopedList): google.cloud.compute.v1.InstanceGroupsScopedList;

                    /**
                     * Encodes the specified InstanceGroupsScopedList message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsScopedList.verify|verify} messages.
                     * @param message InstanceGroupsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsScopedList.verify|verify} messages.
                     * @param message InstanceGroupsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupsScopedList;

                    /**
                     * Decodes an InstanceGroupsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupsScopedList;

                    /**
                     * Verifies an InstanceGroupsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupsScopedList;

                    /**
                     * Creates a plain object from an InstanceGroupsScopedList message. Also converts values to other types if specified.
                     * @param message InstanceGroupsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceGroupsSetNamedPortsRequest. */
                interface IInstanceGroupsSetNamedPortsRequest {

                    /** InstanceGroupsSetNamedPortsRequest fingerprint */
                    fingerprint?: (string|null);

                    /** InstanceGroupsSetNamedPortsRequest namedPorts */
                    namedPorts?: (google.cloud.compute.v1.INamedPort[]|null);
                }

                /** Represents an InstanceGroupsSetNamedPortsRequest. */
                class InstanceGroupsSetNamedPortsRequest implements IInstanceGroupsSetNamedPortsRequest {

                    /**
                     * Constructs a new InstanceGroupsSetNamedPortsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceGroupsSetNamedPortsRequest);

                    /** InstanceGroupsSetNamedPortsRequest fingerprint. */
                    public fingerprint?: (string|null);

                    /** InstanceGroupsSetNamedPortsRequest namedPorts. */
                    public namedPorts: google.cloud.compute.v1.INamedPort[];

                    /** InstanceGroupsSetNamedPortsRequest _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /**
                     * Creates a new InstanceGroupsSetNamedPortsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceGroupsSetNamedPortsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceGroupsSetNamedPortsRequest): google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest;

                    /**
                     * Encodes the specified InstanceGroupsSetNamedPortsRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest.verify|verify} messages.
                     * @param message InstanceGroupsSetNamedPortsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceGroupsSetNamedPortsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceGroupsSetNamedPortsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest.verify|verify} messages.
                     * @param message InstanceGroupsSetNamedPortsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceGroupsSetNamedPortsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceGroupsSetNamedPortsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceGroupsSetNamedPortsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest;

                    /**
                     * Decodes an InstanceGroupsSetNamedPortsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceGroupsSetNamedPortsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest;

                    /**
                     * Verifies an InstanceGroupsSetNamedPortsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceGroupsSetNamedPortsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceGroupsSetNamedPortsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest;

                    /**
                     * Creates a plain object from an InstanceGroupsSetNamedPortsRequest message. Also converts values to other types if specified.
                     * @param message InstanceGroupsSetNamedPortsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceGroupsSetNamedPortsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceGroupsSetNamedPortsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceGroupsSetNamedPortsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceList. */
                interface IInstanceList {

                    /** InstanceList id */
                    id?: (string|null);

                    /** InstanceList items */
                    items?: (google.cloud.compute.v1.IInstance[]|null);

                    /** InstanceList kind */
                    kind?: (string|null);

                    /** InstanceList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceList selfLink */
                    selfLink?: (string|null);

                    /** InstanceList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceList. */
                class InstanceList implements IInstanceList {

                    /**
                     * Constructs a new InstanceList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceList);

                    /** InstanceList id. */
                    public id?: (string|null);

                    /** InstanceList items. */
                    public items: google.cloud.compute.v1.IInstance[];

                    /** InstanceList kind. */
                    public kind?: (string|null);

                    /** InstanceList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceList _id. */
                    public _id?: "id";

                    /** InstanceList _kind. */
                    public _kind?: "kind";

                    /** InstanceList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceList): google.cloud.compute.v1.InstanceList;

                    /**
                     * Encodes the specified InstanceList message. Does not implicitly {@link google.cloud.compute.v1.InstanceList.verify|verify} messages.
                     * @param message InstanceList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceList.verify|verify} messages.
                     * @param message InstanceList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceList;

                    /**
                     * Decodes an InstanceList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceList;

                    /**
                     * Verifies an InstanceList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceList;

                    /**
                     * Creates a plain object from an InstanceList message. Also converts values to other types if specified.
                     * @param message InstanceList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceListReferrers. */
                interface IInstanceListReferrers {

                    /** InstanceListReferrers id */
                    id?: (string|null);

                    /** InstanceListReferrers items */
                    items?: (google.cloud.compute.v1.IReference[]|null);

                    /** InstanceListReferrers kind */
                    kind?: (string|null);

                    /** InstanceListReferrers nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceListReferrers selfLink */
                    selfLink?: (string|null);

                    /** InstanceListReferrers warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceListReferrers. */
                class InstanceListReferrers implements IInstanceListReferrers {

                    /**
                     * Constructs a new InstanceListReferrers.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceListReferrers);

                    /** InstanceListReferrers id. */
                    public id?: (string|null);

                    /** InstanceListReferrers items. */
                    public items: google.cloud.compute.v1.IReference[];

                    /** InstanceListReferrers kind. */
                    public kind?: (string|null);

                    /** InstanceListReferrers nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceListReferrers selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceListReferrers warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceListReferrers _id. */
                    public _id?: "id";

                    /** InstanceListReferrers _kind. */
                    public _kind?: "kind";

                    /** InstanceListReferrers _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceListReferrers _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceListReferrers _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceListReferrers instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceListReferrers instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceListReferrers): google.cloud.compute.v1.InstanceListReferrers;

                    /**
                     * Encodes the specified InstanceListReferrers message. Does not implicitly {@link google.cloud.compute.v1.InstanceListReferrers.verify|verify} messages.
                     * @param message InstanceListReferrers message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceListReferrers, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceListReferrers message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceListReferrers.verify|verify} messages.
                     * @param message InstanceListReferrers message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceListReferrers, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceListReferrers message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceListReferrers
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceListReferrers;

                    /**
                     * Decodes an InstanceListReferrers message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceListReferrers
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceListReferrers;

                    /**
                     * Verifies an InstanceListReferrers message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceListReferrers message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceListReferrers
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceListReferrers;

                    /**
                     * Creates a plain object from an InstanceListReferrers message. Also converts values to other types if specified.
                     * @param message InstanceListReferrers
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceListReferrers, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceListReferrers to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceListReferrers
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceManagedByIgmError. */
                interface IInstanceManagedByIgmError {

                    /** InstanceManagedByIgmError error */
                    error?: (google.cloud.compute.v1.IInstanceManagedByIgmErrorManagedInstanceError|null);

                    /** InstanceManagedByIgmError instanceActionDetails */
                    instanceActionDetails?: (google.cloud.compute.v1.IInstanceManagedByIgmErrorInstanceActionDetails|null);

                    /** InstanceManagedByIgmError timestamp */
                    timestamp?: (string|null);
                }

                /** Represents an InstanceManagedByIgmError. */
                class InstanceManagedByIgmError implements IInstanceManagedByIgmError {

                    /**
                     * Constructs a new InstanceManagedByIgmError.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceManagedByIgmError);

                    /** InstanceManagedByIgmError error. */
                    public error?: (google.cloud.compute.v1.IInstanceManagedByIgmErrorManagedInstanceError|null);

                    /** InstanceManagedByIgmError instanceActionDetails. */
                    public instanceActionDetails?: (google.cloud.compute.v1.IInstanceManagedByIgmErrorInstanceActionDetails|null);

                    /** InstanceManagedByIgmError timestamp. */
                    public timestamp?: (string|null);

                    /** InstanceManagedByIgmError _error. */
                    public _error?: "error";

                    /** InstanceManagedByIgmError _instanceActionDetails. */
                    public _instanceActionDetails?: "instanceActionDetails";

                    /** InstanceManagedByIgmError _timestamp. */
                    public _timestamp?: "timestamp";

                    /**
                     * Creates a new InstanceManagedByIgmError instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceManagedByIgmError instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceManagedByIgmError): google.cloud.compute.v1.InstanceManagedByIgmError;

                    /**
                     * Encodes the specified InstanceManagedByIgmError message. Does not implicitly {@link google.cloud.compute.v1.InstanceManagedByIgmError.verify|verify} messages.
                     * @param message InstanceManagedByIgmError message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceManagedByIgmError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceManagedByIgmError message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceManagedByIgmError.verify|verify} messages.
                     * @param message InstanceManagedByIgmError message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceManagedByIgmError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceManagedByIgmError message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceManagedByIgmError
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceManagedByIgmError;

                    /**
                     * Decodes an InstanceManagedByIgmError message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceManagedByIgmError
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceManagedByIgmError;

                    /**
                     * Verifies an InstanceManagedByIgmError message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceManagedByIgmError message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceManagedByIgmError
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceManagedByIgmError;

                    /**
                     * Creates a plain object from an InstanceManagedByIgmError message. Also converts values to other types if specified.
                     * @param message InstanceManagedByIgmError
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceManagedByIgmError, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceManagedByIgmError to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceManagedByIgmError
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceManagedByIgmErrorInstanceActionDetails. */
                interface IInstanceManagedByIgmErrorInstanceActionDetails {

                    /** InstanceManagedByIgmErrorInstanceActionDetails action */
                    action?: (string|null);

                    /** InstanceManagedByIgmErrorInstanceActionDetails instance */
                    instance?: (string|null);

                    /** InstanceManagedByIgmErrorInstanceActionDetails version */
                    version?: (google.cloud.compute.v1.IManagedInstanceVersion|null);
                }

                /** Represents an InstanceManagedByIgmErrorInstanceActionDetails. */
                class InstanceManagedByIgmErrorInstanceActionDetails implements IInstanceManagedByIgmErrorInstanceActionDetails {

                    /**
                     * Constructs a new InstanceManagedByIgmErrorInstanceActionDetails.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceManagedByIgmErrorInstanceActionDetails);

                    /** InstanceManagedByIgmErrorInstanceActionDetails action. */
                    public action?: (string|null);

                    /** InstanceManagedByIgmErrorInstanceActionDetails instance. */
                    public instance?: (string|null);

                    /** InstanceManagedByIgmErrorInstanceActionDetails version. */
                    public version?: (google.cloud.compute.v1.IManagedInstanceVersion|null);

                    /** InstanceManagedByIgmErrorInstanceActionDetails _action. */
                    public _action?: "action";

                    /** InstanceManagedByIgmErrorInstanceActionDetails _instance. */
                    public _instance?: "instance";

                    /** InstanceManagedByIgmErrorInstanceActionDetails _version. */
                    public _version?: "version";

                    /**
                     * Creates a new InstanceManagedByIgmErrorInstanceActionDetails instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceManagedByIgmErrorInstanceActionDetails instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceManagedByIgmErrorInstanceActionDetails): google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails;

                    /**
                     * Encodes the specified InstanceManagedByIgmErrorInstanceActionDetails message. Does not implicitly {@link google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails.verify|verify} messages.
                     * @param message InstanceManagedByIgmErrorInstanceActionDetails message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceManagedByIgmErrorInstanceActionDetails, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceManagedByIgmErrorInstanceActionDetails message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails.verify|verify} messages.
                     * @param message InstanceManagedByIgmErrorInstanceActionDetails message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceManagedByIgmErrorInstanceActionDetails, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceManagedByIgmErrorInstanceActionDetails message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceManagedByIgmErrorInstanceActionDetails
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails;

                    /**
                     * Decodes an InstanceManagedByIgmErrorInstanceActionDetails message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceManagedByIgmErrorInstanceActionDetails
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails;

                    /**
                     * Verifies an InstanceManagedByIgmErrorInstanceActionDetails message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceManagedByIgmErrorInstanceActionDetails message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceManagedByIgmErrorInstanceActionDetails
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails;

                    /**
                     * Creates a plain object from an InstanceManagedByIgmErrorInstanceActionDetails message. Also converts values to other types if specified.
                     * @param message InstanceManagedByIgmErrorInstanceActionDetails
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceManagedByIgmErrorInstanceActionDetails, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceManagedByIgmErrorInstanceActionDetails to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceManagedByIgmErrorInstanceActionDetails
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceManagedByIgmErrorInstanceActionDetails {

                    /** Action enum. */
                    enum Action {
                        UNDEFINED_ACTION = 0,
                        ABANDONING = 388244813,
                        CREATING = 455564985,
                        CREATING_WITHOUT_RETRIES = 428843785,
                        DELETING = 528602024,
                        NONE = 2402104,
                        RECREATING = 287278572,
                        REFRESHING = 163266343,
                        RESTARTING = 320534387,
                        RESUMING = 446856618,
                        STARTING = 488820800,
                        STOPPING = 350791796,
                        SUSPENDING = 514206246,
                        VERIFYING = 16982185
                    }
                }

                /** Properties of an InstanceManagedByIgmErrorManagedInstanceError. */
                interface IInstanceManagedByIgmErrorManagedInstanceError {

                    /** InstanceManagedByIgmErrorManagedInstanceError code */
                    code?: (string|null);

                    /** InstanceManagedByIgmErrorManagedInstanceError message */
                    message?: (string|null);
                }

                /** Represents an InstanceManagedByIgmErrorManagedInstanceError. */
                class InstanceManagedByIgmErrorManagedInstanceError implements IInstanceManagedByIgmErrorManagedInstanceError {

                    /**
                     * Constructs a new InstanceManagedByIgmErrorManagedInstanceError.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceManagedByIgmErrorManagedInstanceError);

                    /** InstanceManagedByIgmErrorManagedInstanceError code. */
                    public code?: (string|null);

                    /** InstanceManagedByIgmErrorManagedInstanceError message. */
                    public message?: (string|null);

                    /** InstanceManagedByIgmErrorManagedInstanceError _code. */
                    public _code?: "code";

                    /** InstanceManagedByIgmErrorManagedInstanceError _message. */
                    public _message?: "message";

                    /**
                     * Creates a new InstanceManagedByIgmErrorManagedInstanceError instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceManagedByIgmErrorManagedInstanceError instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceManagedByIgmErrorManagedInstanceError): google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError;

                    /**
                     * Encodes the specified InstanceManagedByIgmErrorManagedInstanceError message. Does not implicitly {@link google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError.verify|verify} messages.
                     * @param message InstanceManagedByIgmErrorManagedInstanceError message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceManagedByIgmErrorManagedInstanceError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceManagedByIgmErrorManagedInstanceError message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError.verify|verify} messages.
                     * @param message InstanceManagedByIgmErrorManagedInstanceError message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceManagedByIgmErrorManagedInstanceError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceManagedByIgmErrorManagedInstanceError message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceManagedByIgmErrorManagedInstanceError
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError;

                    /**
                     * Decodes an InstanceManagedByIgmErrorManagedInstanceError message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceManagedByIgmErrorManagedInstanceError
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError;

                    /**
                     * Verifies an InstanceManagedByIgmErrorManagedInstanceError message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceManagedByIgmErrorManagedInstanceError message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceManagedByIgmErrorManagedInstanceError
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError;

                    /**
                     * Creates a plain object from an InstanceManagedByIgmErrorManagedInstanceError message. Also converts values to other types if specified.
                     * @param message InstanceManagedByIgmErrorManagedInstanceError
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceManagedByIgmErrorManagedInstanceError, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceManagedByIgmErrorManagedInstanceError to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceManagedByIgmErrorManagedInstanceError
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceMoveRequest. */
                interface IInstanceMoveRequest {

                    /** InstanceMoveRequest destinationZone */
                    destinationZone?: (string|null);

                    /** InstanceMoveRequest targetInstance */
                    targetInstance?: (string|null);
                }

                /** Represents an InstanceMoveRequest. */
                class InstanceMoveRequest implements IInstanceMoveRequest {

                    /**
                     * Constructs a new InstanceMoveRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceMoveRequest);

                    /** InstanceMoveRequest destinationZone. */
                    public destinationZone?: (string|null);

                    /** InstanceMoveRequest targetInstance. */
                    public targetInstance?: (string|null);

                    /** InstanceMoveRequest _destinationZone. */
                    public _destinationZone?: "destinationZone";

                    /** InstanceMoveRequest _targetInstance. */
                    public _targetInstance?: "targetInstance";

                    /**
                     * Creates a new InstanceMoveRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceMoveRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceMoveRequest): google.cloud.compute.v1.InstanceMoveRequest;

                    /**
                     * Encodes the specified InstanceMoveRequest message. Does not implicitly {@link google.cloud.compute.v1.InstanceMoveRequest.verify|verify} messages.
                     * @param message InstanceMoveRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceMoveRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceMoveRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceMoveRequest.verify|verify} messages.
                     * @param message InstanceMoveRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceMoveRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceMoveRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceMoveRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceMoveRequest;

                    /**
                     * Decodes an InstanceMoveRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceMoveRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceMoveRequest;

                    /**
                     * Verifies an InstanceMoveRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceMoveRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceMoveRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceMoveRequest;

                    /**
                     * Creates a plain object from an InstanceMoveRequest message. Also converts values to other types if specified.
                     * @param message InstanceMoveRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceMoveRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceMoveRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceMoveRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceParams. */
                interface IInstanceParams {

                    /** InstanceParams resourceManagerTags */
                    resourceManagerTags?: ({ [k: string]: string }|null);
                }

                /** Represents an InstanceParams. */
                class InstanceParams implements IInstanceParams {

                    /**
                     * Constructs a new InstanceParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceParams);

                    /** InstanceParams resourceManagerTags. */
                    public resourceManagerTags: { [k: string]: string };

                    /**
                     * Creates a new InstanceParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceParams instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceParams): google.cloud.compute.v1.InstanceParams;

                    /**
                     * Encodes the specified InstanceParams message. Does not implicitly {@link google.cloud.compute.v1.InstanceParams.verify|verify} messages.
                     * @param message InstanceParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceParams message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceParams.verify|verify} messages.
                     * @param message InstanceParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceParams;

                    /**
                     * Decodes an InstanceParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceParams;

                    /**
                     * Verifies an InstanceParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceParams;

                    /**
                     * Creates a plain object from an InstanceParams message. Also converts values to other types if specified.
                     * @param message InstanceParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceProperties. */
                interface IInstanceProperties {

                    /** InstanceProperties advancedMachineFeatures */
                    advancedMachineFeatures?: (google.cloud.compute.v1.IAdvancedMachineFeatures|null);

                    /** InstanceProperties canIpForward */
                    canIpForward?: (boolean|null);

                    /** InstanceProperties confidentialInstanceConfig */
                    confidentialInstanceConfig?: (google.cloud.compute.v1.IConfidentialInstanceConfig|null);

                    /** InstanceProperties description */
                    description?: (string|null);

                    /** InstanceProperties disks */
                    disks?: (google.cloud.compute.v1.IAttachedDisk[]|null);

                    /** InstanceProperties guestAccelerators */
                    guestAccelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);

                    /** InstanceProperties keyRevocationActionType */
                    keyRevocationActionType?: (string|null);

                    /** InstanceProperties labels */
                    labels?: ({ [k: string]: string }|null);

                    /** InstanceProperties machineType */
                    machineType?: (string|null);

                    /** InstanceProperties metadata */
                    metadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** InstanceProperties minCpuPlatform */
                    minCpuPlatform?: (string|null);

                    /** InstanceProperties networkInterfaces */
                    networkInterfaces?: (google.cloud.compute.v1.INetworkInterface[]|null);

                    /** InstanceProperties networkPerformanceConfig */
                    networkPerformanceConfig?: (google.cloud.compute.v1.INetworkPerformanceConfig|null);

                    /** InstanceProperties privateIpv6GoogleAccess */
                    privateIpv6GoogleAccess?: (string|null);

                    /** InstanceProperties reservationAffinity */
                    reservationAffinity?: (google.cloud.compute.v1.IReservationAffinity|null);

                    /** InstanceProperties resourceManagerTags */
                    resourceManagerTags?: ({ [k: string]: string }|null);

                    /** InstanceProperties resourcePolicies */
                    resourcePolicies?: (string[]|null);

                    /** InstanceProperties scheduling */
                    scheduling?: (google.cloud.compute.v1.IScheduling|null);

                    /** InstanceProperties serviceAccounts */
                    serviceAccounts?: (google.cloud.compute.v1.IServiceAccount[]|null);

                    /** InstanceProperties shieldedInstanceConfig */
                    shieldedInstanceConfig?: (google.cloud.compute.v1.IShieldedInstanceConfig|null);

                    /** InstanceProperties tags */
                    tags?: (google.cloud.compute.v1.ITags|null);
                }

                /** Represents an InstanceProperties. */
                class InstanceProperties implements IInstanceProperties {

                    /**
                     * Constructs a new InstanceProperties.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceProperties);

                    /** InstanceProperties advancedMachineFeatures. */
                    public advancedMachineFeatures?: (google.cloud.compute.v1.IAdvancedMachineFeatures|null);

                    /** InstanceProperties canIpForward. */
                    public canIpForward?: (boolean|null);

                    /** InstanceProperties confidentialInstanceConfig. */
                    public confidentialInstanceConfig?: (google.cloud.compute.v1.IConfidentialInstanceConfig|null);

                    /** InstanceProperties description. */
                    public description?: (string|null);

                    /** InstanceProperties disks. */
                    public disks: google.cloud.compute.v1.IAttachedDisk[];

                    /** InstanceProperties guestAccelerators. */
                    public guestAccelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /** InstanceProperties keyRevocationActionType. */
                    public keyRevocationActionType?: (string|null);

                    /** InstanceProperties labels. */
                    public labels: { [k: string]: string };

                    /** InstanceProperties machineType. */
                    public machineType?: (string|null);

                    /** InstanceProperties metadata. */
                    public metadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** InstanceProperties minCpuPlatform. */
                    public minCpuPlatform?: (string|null);

                    /** InstanceProperties networkInterfaces. */
                    public networkInterfaces: google.cloud.compute.v1.INetworkInterface[];

                    /** InstanceProperties networkPerformanceConfig. */
                    public networkPerformanceConfig?: (google.cloud.compute.v1.INetworkPerformanceConfig|null);

                    /** InstanceProperties privateIpv6GoogleAccess. */
                    public privateIpv6GoogleAccess?: (string|null);

                    /** InstanceProperties reservationAffinity. */
                    public reservationAffinity?: (google.cloud.compute.v1.IReservationAffinity|null);

                    /** InstanceProperties resourceManagerTags. */
                    public resourceManagerTags: { [k: string]: string };

                    /** InstanceProperties resourcePolicies. */
                    public resourcePolicies: string[];

                    /** InstanceProperties scheduling. */
                    public scheduling?: (google.cloud.compute.v1.IScheduling|null);

                    /** InstanceProperties serviceAccounts. */
                    public serviceAccounts: google.cloud.compute.v1.IServiceAccount[];

                    /** InstanceProperties shieldedInstanceConfig. */
                    public shieldedInstanceConfig?: (google.cloud.compute.v1.IShieldedInstanceConfig|null);

                    /** InstanceProperties tags. */
                    public tags?: (google.cloud.compute.v1.ITags|null);

                    /** InstanceProperties _advancedMachineFeatures. */
                    public _advancedMachineFeatures?: "advancedMachineFeatures";

                    /** InstanceProperties _canIpForward. */
                    public _canIpForward?: "canIpForward";

                    /** InstanceProperties _confidentialInstanceConfig. */
                    public _confidentialInstanceConfig?: "confidentialInstanceConfig";

                    /** InstanceProperties _description. */
                    public _description?: "description";

                    /** InstanceProperties _keyRevocationActionType. */
                    public _keyRevocationActionType?: "keyRevocationActionType";

                    /** InstanceProperties _machineType. */
                    public _machineType?: "machineType";

                    /** InstanceProperties _metadata. */
                    public _metadata?: "metadata";

                    /** InstanceProperties _minCpuPlatform. */
                    public _minCpuPlatform?: "minCpuPlatform";

                    /** InstanceProperties _networkPerformanceConfig. */
                    public _networkPerformanceConfig?: "networkPerformanceConfig";

                    /** InstanceProperties _privateIpv6GoogleAccess. */
                    public _privateIpv6GoogleAccess?: "privateIpv6GoogleAccess";

                    /** InstanceProperties _reservationAffinity. */
                    public _reservationAffinity?: "reservationAffinity";

                    /** InstanceProperties _scheduling. */
                    public _scheduling?: "scheduling";

                    /** InstanceProperties _shieldedInstanceConfig. */
                    public _shieldedInstanceConfig?: "shieldedInstanceConfig";

                    /** InstanceProperties _tags. */
                    public _tags?: "tags";

                    /**
                     * Creates a new InstanceProperties instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceProperties instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceProperties): google.cloud.compute.v1.InstanceProperties;

                    /**
                     * Encodes the specified InstanceProperties message. Does not implicitly {@link google.cloud.compute.v1.InstanceProperties.verify|verify} messages.
                     * @param message InstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceProperties message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceProperties.verify|verify} messages.
                     * @param message InstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceProperties message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceProperties;

                    /**
                     * Decodes an InstanceProperties message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceProperties;

                    /**
                     * Verifies an InstanceProperties message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceProperties message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceProperties
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceProperties;

                    /**
                     * Creates a plain object from an InstanceProperties message. Also converts values to other types if specified.
                     * @param message InstanceProperties
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceProperties, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceProperties to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceProperties
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceProperties {

                    /** KeyRevocationActionType enum. */
                    enum KeyRevocationActionType {
                        UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0,
                        KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467110106,
                        NONE = 2402104,
                        STOP = 2555906
                    }

                    /** PrivateIpv6GoogleAccess enum. */
                    enum PrivateIpv6GoogleAccess {
                        UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS = 0,
                        ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 427975994,
                        ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 288210263,
                        INHERIT_FROM_SUBNETWORK = 530256959
                    }
                }

                /** Properties of an InstanceReference. */
                interface IInstanceReference {

                    /** InstanceReference instance */
                    instance?: (string|null);
                }

                /** Represents an InstanceReference. */
                class InstanceReference implements IInstanceReference {

                    /**
                     * Constructs a new InstanceReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceReference);

                    /** InstanceReference instance. */
                    public instance?: (string|null);

                    /** InstanceReference _instance. */
                    public _instance?: "instance";

                    /**
                     * Creates a new InstanceReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceReference): google.cloud.compute.v1.InstanceReference;

                    /**
                     * Encodes the specified InstanceReference message. Does not implicitly {@link google.cloud.compute.v1.InstanceReference.verify|verify} messages.
                     * @param message InstanceReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceReference.verify|verify} messages.
                     * @param message InstanceReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceReference;

                    /**
                     * Decodes an InstanceReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceReference;

                    /**
                     * Verifies an InstanceReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceReference;

                    /**
                     * Creates a plain object from an InstanceReference message. Also converts values to other types if specified.
                     * @param message InstanceReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceTemplate. */
                interface IInstanceTemplate {

                    /** InstanceTemplate creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** InstanceTemplate description */
                    description?: (string|null);

                    /** InstanceTemplate id */
                    id?: (number|Long|string|null);

                    /** InstanceTemplate kind */
                    kind?: (string|null);

                    /** InstanceTemplate name */
                    name?: (string|null);

                    /** InstanceTemplate properties */
                    properties?: (google.cloud.compute.v1.IInstanceProperties|null);

                    /** InstanceTemplate selfLink */
                    selfLink?: (string|null);

                    /** InstanceTemplate sourceInstance */
                    sourceInstance?: (string|null);

                    /** InstanceTemplate sourceInstanceParams */
                    sourceInstanceParams?: (google.cloud.compute.v1.ISourceInstanceParams|null);
                }

                /** Represents an InstanceTemplate. */
                class InstanceTemplate implements IInstanceTemplate {

                    /**
                     * Constructs a new InstanceTemplate.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceTemplate);

                    /** InstanceTemplate creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** InstanceTemplate description. */
                    public description?: (string|null);

                    /** InstanceTemplate id. */
                    public id?: (number|Long|string|null);

                    /** InstanceTemplate kind. */
                    public kind?: (string|null);

                    /** InstanceTemplate name. */
                    public name?: (string|null);

                    /** InstanceTemplate properties. */
                    public properties?: (google.cloud.compute.v1.IInstanceProperties|null);

                    /** InstanceTemplate selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceTemplate sourceInstance. */
                    public sourceInstance?: (string|null);

                    /** InstanceTemplate sourceInstanceParams. */
                    public sourceInstanceParams?: (google.cloud.compute.v1.ISourceInstanceParams|null);

                    /** InstanceTemplate _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** InstanceTemplate _description. */
                    public _description?: "description";

                    /** InstanceTemplate _id. */
                    public _id?: "id";

                    /** InstanceTemplate _kind. */
                    public _kind?: "kind";

                    /** InstanceTemplate _name. */
                    public _name?: "name";

                    /** InstanceTemplate _properties. */
                    public _properties?: "properties";

                    /** InstanceTemplate _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceTemplate _sourceInstance. */
                    public _sourceInstance?: "sourceInstance";

                    /** InstanceTemplate _sourceInstanceParams. */
                    public _sourceInstanceParams?: "sourceInstanceParams";

                    /**
                     * Creates a new InstanceTemplate instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceTemplate instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceTemplate): google.cloud.compute.v1.InstanceTemplate;

                    /**
                     * Encodes the specified InstanceTemplate message. Does not implicitly {@link google.cloud.compute.v1.InstanceTemplate.verify|verify} messages.
                     * @param message InstanceTemplate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceTemplate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceTemplate message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceTemplate.verify|verify} messages.
                     * @param message InstanceTemplate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceTemplate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceTemplate message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceTemplate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceTemplate;

                    /**
                     * Decodes an InstanceTemplate message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceTemplate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceTemplate;

                    /**
                     * Verifies an InstanceTemplate message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceTemplate message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceTemplate
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceTemplate;

                    /**
                     * Creates a plain object from an InstanceTemplate message. Also converts values to other types if specified.
                     * @param message InstanceTemplate
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceTemplate, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceTemplate to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceTemplate
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceTemplateList. */
                interface IInstanceTemplateList {

                    /** InstanceTemplateList id */
                    id?: (string|null);

                    /** InstanceTemplateList items */
                    items?: (google.cloud.compute.v1.IInstanceTemplate[]|null);

                    /** InstanceTemplateList kind */
                    kind?: (string|null);

                    /** InstanceTemplateList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InstanceTemplateList selfLink */
                    selfLink?: (string|null);

                    /** InstanceTemplateList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstanceTemplateList. */
                class InstanceTemplateList implements IInstanceTemplateList {

                    /**
                     * Constructs a new InstanceTemplateList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceTemplateList);

                    /** InstanceTemplateList id. */
                    public id?: (string|null);

                    /** InstanceTemplateList items. */
                    public items: google.cloud.compute.v1.IInstanceTemplate[];

                    /** InstanceTemplateList kind. */
                    public kind?: (string|null);

                    /** InstanceTemplateList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InstanceTemplateList selfLink. */
                    public selfLink?: (string|null);

                    /** InstanceTemplateList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstanceTemplateList _id. */
                    public _id?: "id";

                    /** InstanceTemplateList _kind. */
                    public _kind?: "kind";

                    /** InstanceTemplateList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InstanceTemplateList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InstanceTemplateList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstanceTemplateList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceTemplateList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceTemplateList): google.cloud.compute.v1.InstanceTemplateList;

                    /**
                     * Encodes the specified InstanceTemplateList message. Does not implicitly {@link google.cloud.compute.v1.InstanceTemplateList.verify|verify} messages.
                     * @param message InstanceTemplateList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceTemplateList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceTemplateList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceTemplateList.verify|verify} messages.
                     * @param message InstanceTemplateList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceTemplateList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceTemplateList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceTemplateList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceTemplateList;

                    /**
                     * Decodes an InstanceTemplateList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceTemplateList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceTemplateList;

                    /**
                     * Verifies an InstanceTemplateList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceTemplateList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceTemplateList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceTemplateList;

                    /**
                     * Creates a plain object from an InstanceTemplateList message. Also converts values to other types if specified.
                     * @param message InstanceTemplateList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceTemplateList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceTemplateList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceTemplateList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstanceWithNamedPorts. */
                interface IInstanceWithNamedPorts {

                    /** InstanceWithNamedPorts instance */
                    instance?: (string|null);

                    /** InstanceWithNamedPorts namedPorts */
                    namedPorts?: (google.cloud.compute.v1.INamedPort[]|null);

                    /** InstanceWithNamedPorts status */
                    status?: (string|null);
                }

                /** Represents an InstanceWithNamedPorts. */
                class InstanceWithNamedPorts implements IInstanceWithNamedPorts {

                    /**
                     * Constructs a new InstanceWithNamedPorts.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstanceWithNamedPorts);

                    /** InstanceWithNamedPorts instance. */
                    public instance?: (string|null);

                    /** InstanceWithNamedPorts namedPorts. */
                    public namedPorts: google.cloud.compute.v1.INamedPort[];

                    /** InstanceWithNamedPorts status. */
                    public status?: (string|null);

                    /** InstanceWithNamedPorts _instance. */
                    public _instance?: "instance";

                    /** InstanceWithNamedPorts _status. */
                    public _status?: "status";

                    /**
                     * Creates a new InstanceWithNamedPorts instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstanceWithNamedPorts instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstanceWithNamedPorts): google.cloud.compute.v1.InstanceWithNamedPorts;

                    /**
                     * Encodes the specified InstanceWithNamedPorts message. Does not implicitly {@link google.cloud.compute.v1.InstanceWithNamedPorts.verify|verify} messages.
                     * @param message InstanceWithNamedPorts message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstanceWithNamedPorts, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstanceWithNamedPorts message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstanceWithNamedPorts.verify|verify} messages.
                     * @param message InstanceWithNamedPorts message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstanceWithNamedPorts, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstanceWithNamedPorts message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstanceWithNamedPorts
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstanceWithNamedPorts;

                    /**
                     * Decodes an InstanceWithNamedPorts message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstanceWithNamedPorts
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstanceWithNamedPorts;

                    /**
                     * Verifies an InstanceWithNamedPorts message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstanceWithNamedPorts message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstanceWithNamedPorts
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstanceWithNamedPorts;

                    /**
                     * Creates a plain object from an InstanceWithNamedPorts message. Also converts values to other types if specified.
                     * @param message InstanceWithNamedPorts
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstanceWithNamedPorts, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstanceWithNamedPorts to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstanceWithNamedPorts
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstanceWithNamedPorts {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DEPROVISIONING = 428935662,
                        PROVISIONING = 290896621,
                        REPAIRING = 413483285,
                        RUNNING = 121282975,
                        STAGING = 431072283,
                        STOPPED = 444276141,
                        STOPPING = 350791796,
                        SUSPENDED = 51223995,
                        SUSPENDING = 514206246,
                        TERMINATED = 250018339
                    }
                }

                /** Properties of an InstancesAddResourcePoliciesRequest. */
                interface IInstancesAddResourcePoliciesRequest {

                    /** InstancesAddResourcePoliciesRequest resourcePolicies */
                    resourcePolicies?: (string[]|null);
                }

                /** Represents an InstancesAddResourcePoliciesRequest. */
                class InstancesAddResourcePoliciesRequest implements IInstancesAddResourcePoliciesRequest {

                    /**
                     * Constructs a new InstancesAddResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesAddResourcePoliciesRequest);

                    /** InstancesAddResourcePoliciesRequest resourcePolicies. */
                    public resourcePolicies: string[];

                    /**
                     * Creates a new InstancesAddResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesAddResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesAddResourcePoliciesRequest): google.cloud.compute.v1.InstancesAddResourcePoliciesRequest;

                    /**
                     * Encodes the specified InstancesAddResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesAddResourcePoliciesRequest.verify|verify} messages.
                     * @param message InstancesAddResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesAddResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesAddResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesAddResourcePoliciesRequest.verify|verify} messages.
                     * @param message InstancesAddResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesAddResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesAddResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesAddResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesAddResourcePoliciesRequest;

                    /**
                     * Decodes an InstancesAddResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesAddResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesAddResourcePoliciesRequest;

                    /**
                     * Verifies an InstancesAddResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesAddResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesAddResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesAddResourcePoliciesRequest;

                    /**
                     * Creates a plain object from an InstancesAddResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message InstancesAddResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesAddResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesAddResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesAddResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesGetEffectiveFirewallsResponse. */
                interface IInstancesGetEffectiveFirewallsResponse {

                    /** InstancesGetEffectiveFirewallsResponse firewallPolicys */
                    firewallPolicys?: (google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy[]|null);

                    /** InstancesGetEffectiveFirewallsResponse firewalls */
                    firewalls?: (google.cloud.compute.v1.IFirewall[]|null);
                }

                /** Represents an InstancesGetEffectiveFirewallsResponse. */
                class InstancesGetEffectiveFirewallsResponse implements IInstancesGetEffectiveFirewallsResponse {

                    /**
                     * Constructs a new InstancesGetEffectiveFirewallsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponse);

                    /** InstancesGetEffectiveFirewallsResponse firewallPolicys. */
                    public firewallPolicys: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy[];

                    /** InstancesGetEffectiveFirewallsResponse firewalls. */
                    public firewalls: google.cloud.compute.v1.IFirewall[];

                    /**
                     * Creates a new InstancesGetEffectiveFirewallsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesGetEffectiveFirewallsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponse): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse;

                    /**
                     * Encodes the specified InstancesGetEffectiveFirewallsResponse message. Does not implicitly {@link google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse.verify|verify} messages.
                     * @param message InstancesGetEffectiveFirewallsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesGetEffectiveFirewallsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse.verify|verify} messages.
                     * @param message InstancesGetEffectiveFirewallsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesGetEffectiveFirewallsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesGetEffectiveFirewallsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse;

                    /**
                     * Decodes an InstancesGetEffectiveFirewallsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesGetEffectiveFirewallsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse;

                    /**
                     * Verifies an InstancesGetEffectiveFirewallsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesGetEffectiveFirewallsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesGetEffectiveFirewallsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse;

                    /**
                     * Creates a plain object from an InstancesGetEffectiveFirewallsResponse message. Also converts values to other types if specified.
                     * @param message InstancesGetEffectiveFirewallsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesGetEffectiveFirewallsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesGetEffectiveFirewallsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy. */
                interface IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy displayName */
                    displayName?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy name */
                    name?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy rules */
                    rules?: (google.cloud.compute.v1.IFirewallPolicyRule[]|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy shortName */
                    shortName?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy type */
                    type?: (string|null);
                }

                /** Represents an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy. */
                class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy implements IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /**
                     * Constructs a new InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy displayName. */
                    public displayName?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy name. */
                    public name?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy rules. */
                    public rules: google.cloud.compute.v1.IFirewallPolicyRule[];

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy shortName. */
                    public shortName?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy type. */
                    public type?: (string|null);

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _displayName. */
                    public _displayName?: "displayName";

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _name. */
                    public _name?: "name";

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _shortName. */
                    public _shortName?: "shortName";

                    /** InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _type. */
                    public _type?: "type";

                    /**
                     * Creates a new InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Encodes the specified InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message. Does not implicitly {@link google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.verify|verify} messages.
                     * @param message InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.verify|verify} messages.
                     * @param message InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Decodes an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Verifies an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Creates a plain object from an InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message. Also converts values to other types if specified.
                     * @param message InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        HIERARCHY = 69902869,
                        NETWORK = 413984270,
                        NETWORK_REGIONAL = 190804272,
                        UNSPECIFIED = 526786327
                    }
                }

                /** Properties of an InstancesRemoveResourcePoliciesRequest. */
                interface IInstancesRemoveResourcePoliciesRequest {

                    /** InstancesRemoveResourcePoliciesRequest resourcePolicies */
                    resourcePolicies?: (string[]|null);
                }

                /** Represents an InstancesRemoveResourcePoliciesRequest. */
                class InstancesRemoveResourcePoliciesRequest implements IInstancesRemoveResourcePoliciesRequest {

                    /**
                     * Constructs a new InstancesRemoveResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesRemoveResourcePoliciesRequest);

                    /** InstancesRemoveResourcePoliciesRequest resourcePolicies. */
                    public resourcePolicies: string[];

                    /**
                     * Creates a new InstancesRemoveResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesRemoveResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesRemoveResourcePoliciesRequest): google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest;

                    /**
                     * Encodes the specified InstancesRemoveResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest.verify|verify} messages.
                     * @param message InstancesRemoveResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesRemoveResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesRemoveResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest.verify|verify} messages.
                     * @param message InstancesRemoveResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesRemoveResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesRemoveResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesRemoveResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest;

                    /**
                     * Decodes an InstancesRemoveResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesRemoveResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest;

                    /**
                     * Verifies an InstancesRemoveResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesRemoveResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesRemoveResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest;

                    /**
                     * Creates a plain object from an InstancesRemoveResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message InstancesRemoveResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesRemoveResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesRemoveResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesRemoveResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesScopedList. */
                interface IInstancesScopedList {

                    /** InstancesScopedList instances */
                    instances?: (google.cloud.compute.v1.IInstance[]|null);

                    /** InstancesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InstancesScopedList. */
                class InstancesScopedList implements IInstancesScopedList {

                    /**
                     * Constructs a new InstancesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesScopedList);

                    /** InstancesScopedList instances. */
                    public instances: google.cloud.compute.v1.IInstance[];

                    /** InstancesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InstancesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InstancesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesScopedList): google.cloud.compute.v1.InstancesScopedList;

                    /**
                     * Encodes the specified InstancesScopedList message. Does not implicitly {@link google.cloud.compute.v1.InstancesScopedList.verify|verify} messages.
                     * @param message InstancesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesScopedList.verify|verify} messages.
                     * @param message InstancesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesScopedList;

                    /**
                     * Decodes an InstancesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesScopedList;

                    /**
                     * Verifies an InstancesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesScopedList;

                    /**
                     * Creates a plain object from an InstancesScopedList message. Also converts values to other types if specified.
                     * @param message InstancesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesSetLabelsRequest. */
                interface IInstancesSetLabelsRequest {

                    /** InstancesSetLabelsRequest labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** InstancesSetLabelsRequest labels */
                    labels?: ({ [k: string]: string }|null);
                }

                /** Represents an InstancesSetLabelsRequest. */
                class InstancesSetLabelsRequest implements IInstancesSetLabelsRequest {

                    /**
                     * Constructs a new InstancesSetLabelsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesSetLabelsRequest);

                    /** InstancesSetLabelsRequest labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** InstancesSetLabelsRequest labels. */
                    public labels: { [k: string]: string };

                    /** InstancesSetLabelsRequest _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /**
                     * Creates a new InstancesSetLabelsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesSetLabelsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesSetLabelsRequest): google.cloud.compute.v1.InstancesSetLabelsRequest;

                    /**
                     * Encodes the specified InstancesSetLabelsRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesSetLabelsRequest.verify|verify} messages.
                     * @param message InstancesSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesSetLabelsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesSetLabelsRequest.verify|verify} messages.
                     * @param message InstancesSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesSetLabelsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesSetLabelsRequest;

                    /**
                     * Decodes an InstancesSetLabelsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesSetLabelsRequest;

                    /**
                     * Verifies an InstancesSetLabelsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesSetLabelsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesSetLabelsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesSetLabelsRequest;

                    /**
                     * Creates a plain object from an InstancesSetLabelsRequest message. Also converts values to other types if specified.
                     * @param message InstancesSetLabelsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesSetLabelsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesSetLabelsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesSetLabelsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesSetMachineResourcesRequest. */
                interface IInstancesSetMachineResourcesRequest {

                    /** InstancesSetMachineResourcesRequest guestAccelerators */
                    guestAccelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);
                }

                /** Represents an InstancesSetMachineResourcesRequest. */
                class InstancesSetMachineResourcesRequest implements IInstancesSetMachineResourcesRequest {

                    /**
                     * Constructs a new InstancesSetMachineResourcesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesSetMachineResourcesRequest);

                    /** InstancesSetMachineResourcesRequest guestAccelerators. */
                    public guestAccelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /**
                     * Creates a new InstancesSetMachineResourcesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesSetMachineResourcesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesSetMachineResourcesRequest): google.cloud.compute.v1.InstancesSetMachineResourcesRequest;

                    /**
                     * Encodes the specified InstancesSetMachineResourcesRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesSetMachineResourcesRequest.verify|verify} messages.
                     * @param message InstancesSetMachineResourcesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesSetMachineResourcesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesSetMachineResourcesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesSetMachineResourcesRequest.verify|verify} messages.
                     * @param message InstancesSetMachineResourcesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesSetMachineResourcesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesSetMachineResourcesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesSetMachineResourcesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesSetMachineResourcesRequest;

                    /**
                     * Decodes an InstancesSetMachineResourcesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesSetMachineResourcesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesSetMachineResourcesRequest;

                    /**
                     * Verifies an InstancesSetMachineResourcesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesSetMachineResourcesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesSetMachineResourcesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesSetMachineResourcesRequest;

                    /**
                     * Creates a plain object from an InstancesSetMachineResourcesRequest message. Also converts values to other types if specified.
                     * @param message InstancesSetMachineResourcesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesSetMachineResourcesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesSetMachineResourcesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesSetMachineResourcesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesSetMachineTypeRequest. */
                interface IInstancesSetMachineTypeRequest {

                    /** InstancesSetMachineTypeRequest machineType */
                    machineType?: (string|null);
                }

                /** Represents an InstancesSetMachineTypeRequest. */
                class InstancesSetMachineTypeRequest implements IInstancesSetMachineTypeRequest {

                    /**
                     * Constructs a new InstancesSetMachineTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesSetMachineTypeRequest);

                    /** InstancesSetMachineTypeRequest machineType. */
                    public machineType?: (string|null);

                    /** InstancesSetMachineTypeRequest _machineType. */
                    public _machineType?: "machineType";

                    /**
                     * Creates a new InstancesSetMachineTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesSetMachineTypeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesSetMachineTypeRequest): google.cloud.compute.v1.InstancesSetMachineTypeRequest;

                    /**
                     * Encodes the specified InstancesSetMachineTypeRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesSetMachineTypeRequest.verify|verify} messages.
                     * @param message InstancesSetMachineTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesSetMachineTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesSetMachineTypeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesSetMachineTypeRequest.verify|verify} messages.
                     * @param message InstancesSetMachineTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesSetMachineTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesSetMachineTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesSetMachineTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesSetMachineTypeRequest;

                    /**
                     * Decodes an InstancesSetMachineTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesSetMachineTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesSetMachineTypeRequest;

                    /**
                     * Verifies an InstancesSetMachineTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesSetMachineTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesSetMachineTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesSetMachineTypeRequest;

                    /**
                     * Creates a plain object from an InstancesSetMachineTypeRequest message. Also converts values to other types if specified.
                     * @param message InstancesSetMachineTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesSetMachineTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesSetMachineTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesSetMachineTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesSetMinCpuPlatformRequest. */
                interface IInstancesSetMinCpuPlatformRequest {

                    /** InstancesSetMinCpuPlatformRequest minCpuPlatform */
                    minCpuPlatform?: (string|null);
                }

                /** Represents an InstancesSetMinCpuPlatformRequest. */
                class InstancesSetMinCpuPlatformRequest implements IInstancesSetMinCpuPlatformRequest {

                    /**
                     * Constructs a new InstancesSetMinCpuPlatformRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesSetMinCpuPlatformRequest);

                    /** InstancesSetMinCpuPlatformRequest minCpuPlatform. */
                    public minCpuPlatform?: (string|null);

                    /** InstancesSetMinCpuPlatformRequest _minCpuPlatform. */
                    public _minCpuPlatform?: "minCpuPlatform";

                    /**
                     * Creates a new InstancesSetMinCpuPlatformRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesSetMinCpuPlatformRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesSetMinCpuPlatformRequest): google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest;

                    /**
                     * Encodes the specified InstancesSetMinCpuPlatformRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest.verify|verify} messages.
                     * @param message InstancesSetMinCpuPlatformRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesSetMinCpuPlatformRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesSetMinCpuPlatformRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest.verify|verify} messages.
                     * @param message InstancesSetMinCpuPlatformRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesSetMinCpuPlatformRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesSetMinCpuPlatformRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesSetMinCpuPlatformRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest;

                    /**
                     * Decodes an InstancesSetMinCpuPlatformRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesSetMinCpuPlatformRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest;

                    /**
                     * Verifies an InstancesSetMinCpuPlatformRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesSetMinCpuPlatformRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesSetMinCpuPlatformRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest;

                    /**
                     * Creates a plain object from an InstancesSetMinCpuPlatformRequest message. Also converts values to other types if specified.
                     * @param message InstancesSetMinCpuPlatformRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesSetMinCpuPlatformRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesSetMinCpuPlatformRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesSetMinCpuPlatformRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesSetServiceAccountRequest. */
                interface IInstancesSetServiceAccountRequest {

                    /** InstancesSetServiceAccountRequest email */
                    email?: (string|null);

                    /** InstancesSetServiceAccountRequest scopes */
                    scopes?: (string[]|null);
                }

                /** Represents an InstancesSetServiceAccountRequest. */
                class InstancesSetServiceAccountRequest implements IInstancesSetServiceAccountRequest {

                    /**
                     * Constructs a new InstancesSetServiceAccountRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesSetServiceAccountRequest);

                    /** InstancesSetServiceAccountRequest email. */
                    public email?: (string|null);

                    /** InstancesSetServiceAccountRequest scopes. */
                    public scopes: string[];

                    /** InstancesSetServiceAccountRequest _email. */
                    public _email?: "email";

                    /**
                     * Creates a new InstancesSetServiceAccountRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesSetServiceAccountRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesSetServiceAccountRequest): google.cloud.compute.v1.InstancesSetServiceAccountRequest;

                    /**
                     * Encodes the specified InstancesSetServiceAccountRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesSetServiceAccountRequest.verify|verify} messages.
                     * @param message InstancesSetServiceAccountRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesSetServiceAccountRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesSetServiceAccountRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesSetServiceAccountRequest.verify|verify} messages.
                     * @param message InstancesSetServiceAccountRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesSetServiceAccountRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesSetServiceAccountRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesSetServiceAccountRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesSetServiceAccountRequest;

                    /**
                     * Decodes an InstancesSetServiceAccountRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesSetServiceAccountRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesSetServiceAccountRequest;

                    /**
                     * Verifies an InstancesSetServiceAccountRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesSetServiceAccountRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesSetServiceAccountRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesSetServiceAccountRequest;

                    /**
                     * Creates a plain object from an InstancesSetServiceAccountRequest message. Also converts values to other types if specified.
                     * @param message InstancesSetServiceAccountRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesSetServiceAccountRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesSetServiceAccountRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesSetServiceAccountRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InstancesStartWithEncryptionKeyRequest. */
                interface IInstancesStartWithEncryptionKeyRequest {

                    /** InstancesStartWithEncryptionKeyRequest disks */
                    disks?: (google.cloud.compute.v1.ICustomerEncryptionKeyProtectedDisk[]|null);
                }

                /** Represents an InstancesStartWithEncryptionKeyRequest. */
                class InstancesStartWithEncryptionKeyRequest implements IInstancesStartWithEncryptionKeyRequest {

                    /**
                     * Constructs a new InstancesStartWithEncryptionKeyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInstancesStartWithEncryptionKeyRequest);

                    /** InstancesStartWithEncryptionKeyRequest disks. */
                    public disks: google.cloud.compute.v1.ICustomerEncryptionKeyProtectedDisk[];

                    /**
                     * Creates a new InstancesStartWithEncryptionKeyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InstancesStartWithEncryptionKeyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInstancesStartWithEncryptionKeyRequest): google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest;

                    /**
                     * Encodes the specified InstancesStartWithEncryptionKeyRequest message. Does not implicitly {@link google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest.verify|verify} messages.
                     * @param message InstancesStartWithEncryptionKeyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInstancesStartWithEncryptionKeyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InstancesStartWithEncryptionKeyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest.verify|verify} messages.
                     * @param message InstancesStartWithEncryptionKeyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInstancesStartWithEncryptionKeyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InstancesStartWithEncryptionKeyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InstancesStartWithEncryptionKeyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest;

                    /**
                     * Decodes an InstancesStartWithEncryptionKeyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InstancesStartWithEncryptionKeyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest;

                    /**
                     * Verifies an InstancesStartWithEncryptionKeyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InstancesStartWithEncryptionKeyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InstancesStartWithEncryptionKeyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest;

                    /**
                     * Creates a plain object from an InstancesStartWithEncryptionKeyRequest message. Also converts values to other types if specified.
                     * @param message InstancesStartWithEncryptionKeyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InstancesStartWithEncryptionKeyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InstancesStartWithEncryptionKeyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InstancesStartWithEncryptionKeyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Int64RangeMatch. */
                interface IInt64RangeMatch {

                    /** Int64RangeMatch rangeEnd */
                    rangeEnd?: (number|Long|string|null);

                    /** Int64RangeMatch rangeStart */
                    rangeStart?: (number|Long|string|null);
                }

                /** Represents an Int64RangeMatch. */
                class Int64RangeMatch implements IInt64RangeMatch {

                    /**
                     * Constructs a new Int64RangeMatch.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInt64RangeMatch);

                    /** Int64RangeMatch rangeEnd. */
                    public rangeEnd?: (number|Long|string|null);

                    /** Int64RangeMatch rangeStart. */
                    public rangeStart?: (number|Long|string|null);

                    /** Int64RangeMatch _rangeEnd. */
                    public _rangeEnd?: "rangeEnd";

                    /** Int64RangeMatch _rangeStart. */
                    public _rangeStart?: "rangeStart";

                    /**
                     * Creates a new Int64RangeMatch instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Int64RangeMatch instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInt64RangeMatch): google.cloud.compute.v1.Int64RangeMatch;

                    /**
                     * Encodes the specified Int64RangeMatch message. Does not implicitly {@link google.cloud.compute.v1.Int64RangeMatch.verify|verify} messages.
                     * @param message Int64RangeMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInt64RangeMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Int64RangeMatch message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Int64RangeMatch.verify|verify} messages.
                     * @param message Int64RangeMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInt64RangeMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Int64RangeMatch message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Int64RangeMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Int64RangeMatch;

                    /**
                     * Decodes an Int64RangeMatch message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Int64RangeMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Int64RangeMatch;

                    /**
                     * Verifies an Int64RangeMatch message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Int64RangeMatch message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Int64RangeMatch
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Int64RangeMatch;

                    /**
                     * Creates a plain object from an Int64RangeMatch message. Also converts values to other types if specified.
                     * @param message Int64RangeMatch
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Int64RangeMatch, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Int64RangeMatch to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Int64RangeMatch
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Interconnect. */
                interface IInterconnect {

                    /** Interconnect adminEnabled */
                    adminEnabled?: (boolean|null);

                    /** Interconnect circuitInfos */
                    circuitInfos?: (google.cloud.compute.v1.IInterconnectCircuitInfo[]|null);

                    /** Interconnect creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Interconnect customerName */
                    customerName?: (string|null);

                    /** Interconnect description */
                    description?: (string|null);

                    /** Interconnect expectedOutages */
                    expectedOutages?: (google.cloud.compute.v1.IInterconnectOutageNotification[]|null);

                    /** Interconnect googleIpAddress */
                    googleIpAddress?: (string|null);

                    /** Interconnect googleReferenceId */
                    googleReferenceId?: (string|null);

                    /** Interconnect id */
                    id?: (number|Long|string|null);

                    /** Interconnect interconnectAttachments */
                    interconnectAttachments?: (string[]|null);

                    /** Interconnect interconnectType */
                    interconnectType?: (string|null);

                    /** Interconnect kind */
                    kind?: (string|null);

                    /** Interconnect linkType */
                    linkType?: (string|null);

                    /** Interconnect location */
                    location?: (string|null);

                    /** Interconnect name */
                    name?: (string|null);

                    /** Interconnect nocContactEmail */
                    nocContactEmail?: (string|null);

                    /** Interconnect operationalStatus */
                    operationalStatus?: (string|null);

                    /** Interconnect peerIpAddress */
                    peerIpAddress?: (string|null);

                    /** Interconnect provisionedLinkCount */
                    provisionedLinkCount?: (number|null);

                    /** Interconnect requestedLinkCount */
                    requestedLinkCount?: (number|null);

                    /** Interconnect satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Interconnect selfLink */
                    selfLink?: (string|null);

                    /** Interconnect state */
                    state?: (string|null);
                }

                /** Represents an Interconnect. */
                class Interconnect implements IInterconnect {

                    /**
                     * Constructs a new Interconnect.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnect);

                    /** Interconnect adminEnabled. */
                    public adminEnabled?: (boolean|null);

                    /** Interconnect circuitInfos. */
                    public circuitInfos: google.cloud.compute.v1.IInterconnectCircuitInfo[];

                    /** Interconnect creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Interconnect customerName. */
                    public customerName?: (string|null);

                    /** Interconnect description. */
                    public description?: (string|null);

                    /** Interconnect expectedOutages. */
                    public expectedOutages: google.cloud.compute.v1.IInterconnectOutageNotification[];

                    /** Interconnect googleIpAddress. */
                    public googleIpAddress?: (string|null);

                    /** Interconnect googleReferenceId. */
                    public googleReferenceId?: (string|null);

                    /** Interconnect id. */
                    public id?: (number|Long|string|null);

                    /** Interconnect interconnectAttachments. */
                    public interconnectAttachments: string[];

                    /** Interconnect interconnectType. */
                    public interconnectType?: (string|null);

                    /** Interconnect kind. */
                    public kind?: (string|null);

                    /** Interconnect linkType. */
                    public linkType?: (string|null);

                    /** Interconnect location. */
                    public location?: (string|null);

                    /** Interconnect name. */
                    public name?: (string|null);

                    /** Interconnect nocContactEmail. */
                    public nocContactEmail?: (string|null);

                    /** Interconnect operationalStatus. */
                    public operationalStatus?: (string|null);

                    /** Interconnect peerIpAddress. */
                    public peerIpAddress?: (string|null);

                    /** Interconnect provisionedLinkCount. */
                    public provisionedLinkCount?: (number|null);

                    /** Interconnect requestedLinkCount. */
                    public requestedLinkCount?: (number|null);

                    /** Interconnect satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** Interconnect selfLink. */
                    public selfLink?: (string|null);

                    /** Interconnect state. */
                    public state?: (string|null);

                    /** Interconnect _adminEnabled. */
                    public _adminEnabled?: "adminEnabled";

                    /** Interconnect _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Interconnect _customerName. */
                    public _customerName?: "customerName";

                    /** Interconnect _description. */
                    public _description?: "description";

                    /** Interconnect _googleIpAddress. */
                    public _googleIpAddress?: "googleIpAddress";

                    /** Interconnect _googleReferenceId. */
                    public _googleReferenceId?: "googleReferenceId";

                    /** Interconnect _id. */
                    public _id?: "id";

                    /** Interconnect _interconnectType. */
                    public _interconnectType?: "interconnectType";

                    /** Interconnect _kind. */
                    public _kind?: "kind";

                    /** Interconnect _linkType. */
                    public _linkType?: "linkType";

                    /** Interconnect _location. */
                    public _location?: "location";

                    /** Interconnect _name. */
                    public _name?: "name";

                    /** Interconnect _nocContactEmail. */
                    public _nocContactEmail?: "nocContactEmail";

                    /** Interconnect _operationalStatus. */
                    public _operationalStatus?: "operationalStatus";

                    /** Interconnect _peerIpAddress. */
                    public _peerIpAddress?: "peerIpAddress";

                    /** Interconnect _provisionedLinkCount. */
                    public _provisionedLinkCount?: "provisionedLinkCount";

                    /** Interconnect _requestedLinkCount. */
                    public _requestedLinkCount?: "requestedLinkCount";

                    /** Interconnect _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** Interconnect _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Interconnect _state. */
                    public _state?: "state";

                    /**
                     * Creates a new Interconnect instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Interconnect instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnect): google.cloud.compute.v1.Interconnect;

                    /**
                     * Encodes the specified Interconnect message. Does not implicitly {@link google.cloud.compute.v1.Interconnect.verify|verify} messages.
                     * @param message Interconnect message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnect, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Interconnect message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Interconnect.verify|verify} messages.
                     * @param message Interconnect message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnect, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Interconnect message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Interconnect
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Interconnect;

                    /**
                     * Decodes an Interconnect message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Interconnect
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Interconnect;

                    /**
                     * Verifies an Interconnect message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Interconnect message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Interconnect
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Interconnect;

                    /**
                     * Creates a plain object from an Interconnect message. Also converts values to other types if specified.
                     * @param message Interconnect
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Interconnect, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Interconnect to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Interconnect
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Interconnect {

                    /** InterconnectType enum. */
                    enum InterconnectType {
                        UNDEFINED_INTERCONNECT_TYPE = 0,
                        DEDICATED = 258411983,
                        IT_PRIVATE = 335677007,
                        PARTNER = 461924520
                    }

                    /** LinkType enum. */
                    enum LinkType {
                        UNDEFINED_LINK_TYPE = 0,
                        LINK_TYPE_ETHERNET_100G_LR = 337672551,
                        LINK_TYPE_ETHERNET_10G_LR = 236739749
                    }

                    /** OperationalStatus enum. */
                    enum OperationalStatus {
                        UNDEFINED_OPERATIONAL_STATUS = 0,
                        OS_ACTIVE = 55721409,
                        OS_UNPROVISIONED = 239771840
                    }

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        UNPROVISIONED = 517333979
                    }
                }

                /** Properties of an InterconnectAttachment. */
                interface IInterconnectAttachment {

                    /** InterconnectAttachment adminEnabled */
                    adminEnabled?: (boolean|null);

                    /** InterconnectAttachment bandwidth */
                    bandwidth?: (string|null);

                    /** InterconnectAttachment candidateIpv6Subnets */
                    candidateIpv6Subnets?: (string[]|null);

                    /** InterconnectAttachment candidateSubnets */
                    candidateSubnets?: (string[]|null);

                    /** InterconnectAttachment cloudRouterIpAddress */
                    cloudRouterIpAddress?: (string|null);

                    /** InterconnectAttachment cloudRouterIpv6Address */
                    cloudRouterIpv6Address?: (string|null);

                    /** InterconnectAttachment cloudRouterIpv6InterfaceId */
                    cloudRouterIpv6InterfaceId?: (string|null);

                    /** InterconnectAttachment creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** InterconnectAttachment customerRouterIpAddress */
                    customerRouterIpAddress?: (string|null);

                    /** InterconnectAttachment customerRouterIpv6Address */
                    customerRouterIpv6Address?: (string|null);

                    /** InterconnectAttachment customerRouterIpv6InterfaceId */
                    customerRouterIpv6InterfaceId?: (string|null);

                    /** InterconnectAttachment dataplaneVersion */
                    dataplaneVersion?: (number|null);

                    /** InterconnectAttachment description */
                    description?: (string|null);

                    /** InterconnectAttachment edgeAvailabilityDomain */
                    edgeAvailabilityDomain?: (string|null);

                    /** InterconnectAttachment encryption */
                    encryption?: (string|null);

                    /** InterconnectAttachment googleReferenceId */
                    googleReferenceId?: (string|null);

                    /** InterconnectAttachment id */
                    id?: (number|Long|string|null);

                    /** InterconnectAttachment interconnect */
                    interconnect?: (string|null);

                    /** InterconnectAttachment ipsecInternalAddresses */
                    ipsecInternalAddresses?: (string[]|null);

                    /** InterconnectAttachment kind */
                    kind?: (string|null);

                    /** InterconnectAttachment mtu */
                    mtu?: (number|null);

                    /** InterconnectAttachment name */
                    name?: (string|null);

                    /** InterconnectAttachment operationalStatus */
                    operationalStatus?: (string|null);

                    /** InterconnectAttachment pairingKey */
                    pairingKey?: (string|null);

                    /** InterconnectAttachment partnerAsn */
                    partnerAsn?: (number|Long|string|null);

                    /** InterconnectAttachment partnerMetadata */
                    partnerMetadata?: (google.cloud.compute.v1.IInterconnectAttachmentPartnerMetadata|null);

                    /** InterconnectAttachment privateInterconnectInfo */
                    privateInterconnectInfo?: (google.cloud.compute.v1.IInterconnectAttachmentPrivateInfo|null);

                    /** InterconnectAttachment region */
                    region?: (string|null);

                    /** InterconnectAttachment router */
                    router?: (string|null);

                    /** InterconnectAttachment satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** InterconnectAttachment selfLink */
                    selfLink?: (string|null);

                    /** InterconnectAttachment stackType */
                    stackType?: (string|null);

                    /** InterconnectAttachment state */
                    state?: (string|null);

                    /** InterconnectAttachment type */
                    type?: (string|null);

                    /** InterconnectAttachment vlanTag8021q */
                    vlanTag8021q?: (number|null);
                }

                /** Represents an InterconnectAttachment. */
                class InterconnectAttachment implements IInterconnectAttachment {

                    /**
                     * Constructs a new InterconnectAttachment.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectAttachment);

                    /** InterconnectAttachment adminEnabled. */
                    public adminEnabled?: (boolean|null);

                    /** InterconnectAttachment bandwidth. */
                    public bandwidth?: (string|null);

                    /** InterconnectAttachment candidateIpv6Subnets. */
                    public candidateIpv6Subnets: string[];

                    /** InterconnectAttachment candidateSubnets. */
                    public candidateSubnets: string[];

                    /** InterconnectAttachment cloudRouterIpAddress. */
                    public cloudRouterIpAddress?: (string|null);

                    /** InterconnectAttachment cloudRouterIpv6Address. */
                    public cloudRouterIpv6Address?: (string|null);

                    /** InterconnectAttachment cloudRouterIpv6InterfaceId. */
                    public cloudRouterIpv6InterfaceId?: (string|null);

                    /** InterconnectAttachment creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** InterconnectAttachment customerRouterIpAddress. */
                    public customerRouterIpAddress?: (string|null);

                    /** InterconnectAttachment customerRouterIpv6Address. */
                    public customerRouterIpv6Address?: (string|null);

                    /** InterconnectAttachment customerRouterIpv6InterfaceId. */
                    public customerRouterIpv6InterfaceId?: (string|null);

                    /** InterconnectAttachment dataplaneVersion. */
                    public dataplaneVersion?: (number|null);

                    /** InterconnectAttachment description. */
                    public description?: (string|null);

                    /** InterconnectAttachment edgeAvailabilityDomain. */
                    public edgeAvailabilityDomain?: (string|null);

                    /** InterconnectAttachment encryption. */
                    public encryption?: (string|null);

                    /** InterconnectAttachment googleReferenceId. */
                    public googleReferenceId?: (string|null);

                    /** InterconnectAttachment id. */
                    public id?: (number|Long|string|null);

                    /** InterconnectAttachment interconnect. */
                    public interconnect?: (string|null);

                    /** InterconnectAttachment ipsecInternalAddresses. */
                    public ipsecInternalAddresses: string[];

                    /** InterconnectAttachment kind. */
                    public kind?: (string|null);

                    /** InterconnectAttachment mtu. */
                    public mtu?: (number|null);

                    /** InterconnectAttachment name. */
                    public name?: (string|null);

                    /** InterconnectAttachment operationalStatus. */
                    public operationalStatus?: (string|null);

                    /** InterconnectAttachment pairingKey. */
                    public pairingKey?: (string|null);

                    /** InterconnectAttachment partnerAsn. */
                    public partnerAsn?: (number|Long|string|null);

                    /** InterconnectAttachment partnerMetadata. */
                    public partnerMetadata?: (google.cloud.compute.v1.IInterconnectAttachmentPartnerMetadata|null);

                    /** InterconnectAttachment privateInterconnectInfo. */
                    public privateInterconnectInfo?: (google.cloud.compute.v1.IInterconnectAttachmentPrivateInfo|null);

                    /** InterconnectAttachment region. */
                    public region?: (string|null);

                    /** InterconnectAttachment router. */
                    public router?: (string|null);

                    /** InterconnectAttachment satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** InterconnectAttachment selfLink. */
                    public selfLink?: (string|null);

                    /** InterconnectAttachment stackType. */
                    public stackType?: (string|null);

                    /** InterconnectAttachment state. */
                    public state?: (string|null);

                    /** InterconnectAttachment type. */
                    public type?: (string|null);

                    /** InterconnectAttachment vlanTag8021q. */
                    public vlanTag8021q?: (number|null);

                    /** InterconnectAttachment _adminEnabled. */
                    public _adminEnabled?: "adminEnabled";

                    /** InterconnectAttachment _bandwidth. */
                    public _bandwidth?: "bandwidth";

                    /** InterconnectAttachment _cloudRouterIpAddress. */
                    public _cloudRouterIpAddress?: "cloudRouterIpAddress";

                    /** InterconnectAttachment _cloudRouterIpv6Address. */
                    public _cloudRouterIpv6Address?: "cloudRouterIpv6Address";

                    /** InterconnectAttachment _cloudRouterIpv6InterfaceId. */
                    public _cloudRouterIpv6InterfaceId?: "cloudRouterIpv6InterfaceId";

                    /** InterconnectAttachment _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** InterconnectAttachment _customerRouterIpAddress. */
                    public _customerRouterIpAddress?: "customerRouterIpAddress";

                    /** InterconnectAttachment _customerRouterIpv6Address. */
                    public _customerRouterIpv6Address?: "customerRouterIpv6Address";

                    /** InterconnectAttachment _customerRouterIpv6InterfaceId. */
                    public _customerRouterIpv6InterfaceId?: "customerRouterIpv6InterfaceId";

                    /** InterconnectAttachment _dataplaneVersion. */
                    public _dataplaneVersion?: "dataplaneVersion";

                    /** InterconnectAttachment _description. */
                    public _description?: "description";

                    /** InterconnectAttachment _edgeAvailabilityDomain. */
                    public _edgeAvailabilityDomain?: "edgeAvailabilityDomain";

                    /** InterconnectAttachment _encryption. */
                    public _encryption?: "encryption";

                    /** InterconnectAttachment _googleReferenceId. */
                    public _googleReferenceId?: "googleReferenceId";

                    /** InterconnectAttachment _id. */
                    public _id?: "id";

                    /** InterconnectAttachment _interconnect. */
                    public _interconnect?: "interconnect";

                    /** InterconnectAttachment _kind. */
                    public _kind?: "kind";

                    /** InterconnectAttachment _mtu. */
                    public _mtu?: "mtu";

                    /** InterconnectAttachment _name. */
                    public _name?: "name";

                    /** InterconnectAttachment _operationalStatus. */
                    public _operationalStatus?: "operationalStatus";

                    /** InterconnectAttachment _pairingKey. */
                    public _pairingKey?: "pairingKey";

                    /** InterconnectAttachment _partnerAsn. */
                    public _partnerAsn?: "partnerAsn";

                    /** InterconnectAttachment _partnerMetadata. */
                    public _partnerMetadata?: "partnerMetadata";

                    /** InterconnectAttachment _privateInterconnectInfo. */
                    public _privateInterconnectInfo?: "privateInterconnectInfo";

                    /** InterconnectAttachment _region. */
                    public _region?: "region";

                    /** InterconnectAttachment _router. */
                    public _router?: "router";

                    /** InterconnectAttachment _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** InterconnectAttachment _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InterconnectAttachment _stackType. */
                    public _stackType?: "stackType";

                    /** InterconnectAttachment _state. */
                    public _state?: "state";

                    /** InterconnectAttachment _type. */
                    public _type?: "type";

                    /** InterconnectAttachment _vlanTag8021q. */
                    public _vlanTag8021q?: "vlanTag8021q";

                    /**
                     * Creates a new InterconnectAttachment instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectAttachment instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectAttachment): google.cloud.compute.v1.InterconnectAttachment;

                    /**
                     * Encodes the specified InterconnectAttachment message. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachment.verify|verify} messages.
                     * @param message InterconnectAttachment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectAttachment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectAttachment message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachment.verify|verify} messages.
                     * @param message InterconnectAttachment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectAttachment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectAttachment message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectAttachment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectAttachment;

                    /**
                     * Decodes an InterconnectAttachment message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectAttachment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectAttachment;

                    /**
                     * Verifies an InterconnectAttachment message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectAttachment message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectAttachment
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectAttachment;

                    /**
                     * Creates a plain object from an InterconnectAttachment message. Also converts values to other types if specified.
                     * @param message InterconnectAttachment
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectAttachment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectAttachment to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectAttachment
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InterconnectAttachment {

                    /** Bandwidth enum. */
                    enum Bandwidth {
                        UNDEFINED_BANDWIDTH = 0,
                        BPS_100M = 49547958,
                        BPS_10G = 278693006,
                        BPS_1G = 355358448,
                        BPS_200M = 49577749,
                        BPS_20G = 278693967,
                        BPS_2G = 355358479,
                        BPS_300M = 49607540,
                        BPS_400M = 49637331,
                        BPS_500M = 49667122,
                        BPS_50G = 278696850,
                        BPS_50M = 278696856,
                        BPS_5G = 355358572
                    }

                    /** EdgeAvailabilityDomain enum. */
                    enum EdgeAvailabilityDomain {
                        UNDEFINED_EDGE_AVAILABILITY_DOMAIN = 0,
                        AVAILABILITY_DOMAIN_1 = 349552090,
                        AVAILABILITY_DOMAIN_2 = 349552091,
                        AVAILABILITY_DOMAIN_ANY = 375256373
                    }

                    /** Encryption enum. */
                    enum Encryption {
                        UNDEFINED_ENCRYPTION = 0,
                        IPSEC = 69882282,
                        NONE = 2402104
                    }

                    /** OperationalStatus enum. */
                    enum OperationalStatus {
                        UNDEFINED_OPERATIONAL_STATUS = 0,
                        OS_ACTIVE = 55721409,
                        OS_UNPROVISIONED = 239771840
                    }

                    /** StackType enum. */
                    enum StackType {
                        UNDEFINED_STACK_TYPE = 0,
                        IPV4_IPV6 = 22197249,
                        IPV4_ONLY = 22373798
                    }

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        DEFUNCT = 115891759,
                        PARTNER_REQUEST_RECEIVED = 513587304,
                        PENDING_CUSTOMER = 167494054,
                        PENDING_PARTNER = 387890656,
                        STATE_UNSPECIFIED = 470755401,
                        UNPROVISIONED = 517333979
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        DEDICATED = 258411983,
                        PARTNER = 461924520,
                        PARTNER_PROVIDER = 483261352
                    }
                }

                /** Properties of an InterconnectAttachmentAggregatedList. */
                interface IInterconnectAttachmentAggregatedList {

                    /** InterconnectAttachmentAggregatedList id */
                    id?: (string|null);

                    /** InterconnectAttachmentAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IInterconnectAttachmentsScopedList }|null);

                    /** InterconnectAttachmentAggregatedList kind */
                    kind?: (string|null);

                    /** InterconnectAttachmentAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InterconnectAttachmentAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** InterconnectAttachmentAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** InterconnectAttachmentAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InterconnectAttachmentAggregatedList. */
                class InterconnectAttachmentAggregatedList implements IInterconnectAttachmentAggregatedList {

                    /**
                     * Constructs a new InterconnectAttachmentAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectAttachmentAggregatedList);

                    /** InterconnectAttachmentAggregatedList id. */
                    public id?: (string|null);

                    /** InterconnectAttachmentAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IInterconnectAttachmentsScopedList };

                    /** InterconnectAttachmentAggregatedList kind. */
                    public kind?: (string|null);

                    /** InterconnectAttachmentAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InterconnectAttachmentAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** InterconnectAttachmentAggregatedList unreachables. */
                    public unreachables: string[];

                    /** InterconnectAttachmentAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InterconnectAttachmentAggregatedList _id. */
                    public _id?: "id";

                    /** InterconnectAttachmentAggregatedList _kind. */
                    public _kind?: "kind";

                    /** InterconnectAttachmentAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InterconnectAttachmentAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InterconnectAttachmentAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InterconnectAttachmentAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectAttachmentAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectAttachmentAggregatedList): google.cloud.compute.v1.InterconnectAttachmentAggregatedList;

                    /**
                     * Encodes the specified InterconnectAttachmentAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentAggregatedList.verify|verify} messages.
                     * @param message InterconnectAttachmentAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectAttachmentAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectAttachmentAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentAggregatedList.verify|verify} messages.
                     * @param message InterconnectAttachmentAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectAttachmentAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectAttachmentAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectAttachmentAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectAttachmentAggregatedList;

                    /**
                     * Decodes an InterconnectAttachmentAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectAttachmentAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectAttachmentAggregatedList;

                    /**
                     * Verifies an InterconnectAttachmentAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectAttachmentAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectAttachmentAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectAttachmentAggregatedList;

                    /**
                     * Creates a plain object from an InterconnectAttachmentAggregatedList message. Also converts values to other types if specified.
                     * @param message InterconnectAttachmentAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectAttachmentAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectAttachmentAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectAttachmentAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectAttachmentList. */
                interface IInterconnectAttachmentList {

                    /** InterconnectAttachmentList id */
                    id?: (string|null);

                    /** InterconnectAttachmentList items */
                    items?: (google.cloud.compute.v1.IInterconnectAttachment[]|null);

                    /** InterconnectAttachmentList kind */
                    kind?: (string|null);

                    /** InterconnectAttachmentList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InterconnectAttachmentList selfLink */
                    selfLink?: (string|null);

                    /** InterconnectAttachmentList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InterconnectAttachmentList. */
                class InterconnectAttachmentList implements IInterconnectAttachmentList {

                    /**
                     * Constructs a new InterconnectAttachmentList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectAttachmentList);

                    /** InterconnectAttachmentList id. */
                    public id?: (string|null);

                    /** InterconnectAttachmentList items. */
                    public items: google.cloud.compute.v1.IInterconnectAttachment[];

                    /** InterconnectAttachmentList kind. */
                    public kind?: (string|null);

                    /** InterconnectAttachmentList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InterconnectAttachmentList selfLink. */
                    public selfLink?: (string|null);

                    /** InterconnectAttachmentList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InterconnectAttachmentList _id. */
                    public _id?: "id";

                    /** InterconnectAttachmentList _kind. */
                    public _kind?: "kind";

                    /** InterconnectAttachmentList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InterconnectAttachmentList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InterconnectAttachmentList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InterconnectAttachmentList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectAttachmentList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectAttachmentList): google.cloud.compute.v1.InterconnectAttachmentList;

                    /**
                     * Encodes the specified InterconnectAttachmentList message. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentList.verify|verify} messages.
                     * @param message InterconnectAttachmentList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectAttachmentList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectAttachmentList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentList.verify|verify} messages.
                     * @param message InterconnectAttachmentList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectAttachmentList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectAttachmentList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectAttachmentList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectAttachmentList;

                    /**
                     * Decodes an InterconnectAttachmentList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectAttachmentList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectAttachmentList;

                    /**
                     * Verifies an InterconnectAttachmentList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectAttachmentList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectAttachmentList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectAttachmentList;

                    /**
                     * Creates a plain object from an InterconnectAttachmentList message. Also converts values to other types if specified.
                     * @param message InterconnectAttachmentList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectAttachmentList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectAttachmentList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectAttachmentList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectAttachmentPartnerMetadata. */
                interface IInterconnectAttachmentPartnerMetadata {

                    /** InterconnectAttachmentPartnerMetadata interconnectName */
                    interconnectName?: (string|null);

                    /** InterconnectAttachmentPartnerMetadata partnerName */
                    partnerName?: (string|null);

                    /** InterconnectAttachmentPartnerMetadata portalUrl */
                    portalUrl?: (string|null);
                }

                /** Represents an InterconnectAttachmentPartnerMetadata. */
                class InterconnectAttachmentPartnerMetadata implements IInterconnectAttachmentPartnerMetadata {

                    /**
                     * Constructs a new InterconnectAttachmentPartnerMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectAttachmentPartnerMetadata);

                    /** InterconnectAttachmentPartnerMetadata interconnectName. */
                    public interconnectName?: (string|null);

                    /** InterconnectAttachmentPartnerMetadata partnerName. */
                    public partnerName?: (string|null);

                    /** InterconnectAttachmentPartnerMetadata portalUrl. */
                    public portalUrl?: (string|null);

                    /** InterconnectAttachmentPartnerMetadata _interconnectName. */
                    public _interconnectName?: "interconnectName";

                    /** InterconnectAttachmentPartnerMetadata _partnerName. */
                    public _partnerName?: "partnerName";

                    /** InterconnectAttachmentPartnerMetadata _portalUrl. */
                    public _portalUrl?: "portalUrl";

                    /**
                     * Creates a new InterconnectAttachmentPartnerMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectAttachmentPartnerMetadata instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectAttachmentPartnerMetadata): google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata;

                    /**
                     * Encodes the specified InterconnectAttachmentPartnerMetadata message. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata.verify|verify} messages.
                     * @param message InterconnectAttachmentPartnerMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectAttachmentPartnerMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectAttachmentPartnerMetadata message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata.verify|verify} messages.
                     * @param message InterconnectAttachmentPartnerMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectAttachmentPartnerMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectAttachmentPartnerMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectAttachmentPartnerMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata;

                    /**
                     * Decodes an InterconnectAttachmentPartnerMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectAttachmentPartnerMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata;

                    /**
                     * Verifies an InterconnectAttachmentPartnerMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectAttachmentPartnerMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectAttachmentPartnerMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata;

                    /**
                     * Creates a plain object from an InterconnectAttachmentPartnerMetadata message. Also converts values to other types if specified.
                     * @param message InterconnectAttachmentPartnerMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectAttachmentPartnerMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectAttachmentPartnerMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectAttachmentPartnerMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectAttachmentPrivateInfo. */
                interface IInterconnectAttachmentPrivateInfo {

                    /** InterconnectAttachmentPrivateInfo tag8021q */
                    tag8021q?: (number|null);
                }

                /** Represents an InterconnectAttachmentPrivateInfo. */
                class InterconnectAttachmentPrivateInfo implements IInterconnectAttachmentPrivateInfo {

                    /**
                     * Constructs a new InterconnectAttachmentPrivateInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectAttachmentPrivateInfo);

                    /** InterconnectAttachmentPrivateInfo tag8021q. */
                    public tag8021q?: (number|null);

                    /** InterconnectAttachmentPrivateInfo _tag8021q. */
                    public _tag8021q?: "tag8021q";

                    /**
                     * Creates a new InterconnectAttachmentPrivateInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectAttachmentPrivateInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectAttachmentPrivateInfo): google.cloud.compute.v1.InterconnectAttachmentPrivateInfo;

                    /**
                     * Encodes the specified InterconnectAttachmentPrivateInfo message. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentPrivateInfo.verify|verify} messages.
                     * @param message InterconnectAttachmentPrivateInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectAttachmentPrivateInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectAttachmentPrivateInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentPrivateInfo.verify|verify} messages.
                     * @param message InterconnectAttachmentPrivateInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectAttachmentPrivateInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectAttachmentPrivateInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectAttachmentPrivateInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectAttachmentPrivateInfo;

                    /**
                     * Decodes an InterconnectAttachmentPrivateInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectAttachmentPrivateInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectAttachmentPrivateInfo;

                    /**
                     * Verifies an InterconnectAttachmentPrivateInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectAttachmentPrivateInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectAttachmentPrivateInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectAttachmentPrivateInfo;

                    /**
                     * Creates a plain object from an InterconnectAttachmentPrivateInfo message. Also converts values to other types if specified.
                     * @param message InterconnectAttachmentPrivateInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectAttachmentPrivateInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectAttachmentPrivateInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectAttachmentPrivateInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectAttachmentsScopedList. */
                interface IInterconnectAttachmentsScopedList {

                    /** InterconnectAttachmentsScopedList interconnectAttachments */
                    interconnectAttachments?: (google.cloud.compute.v1.IInterconnectAttachment[]|null);

                    /** InterconnectAttachmentsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InterconnectAttachmentsScopedList. */
                class InterconnectAttachmentsScopedList implements IInterconnectAttachmentsScopedList {

                    /**
                     * Constructs a new InterconnectAttachmentsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectAttachmentsScopedList);

                    /** InterconnectAttachmentsScopedList interconnectAttachments. */
                    public interconnectAttachments: google.cloud.compute.v1.IInterconnectAttachment[];

                    /** InterconnectAttachmentsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InterconnectAttachmentsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InterconnectAttachmentsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectAttachmentsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectAttachmentsScopedList): google.cloud.compute.v1.InterconnectAttachmentsScopedList;

                    /**
                     * Encodes the specified InterconnectAttachmentsScopedList message. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentsScopedList.verify|verify} messages.
                     * @param message InterconnectAttachmentsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectAttachmentsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectAttachmentsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectAttachmentsScopedList.verify|verify} messages.
                     * @param message InterconnectAttachmentsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectAttachmentsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectAttachmentsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectAttachmentsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectAttachmentsScopedList;

                    /**
                     * Decodes an InterconnectAttachmentsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectAttachmentsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectAttachmentsScopedList;

                    /**
                     * Verifies an InterconnectAttachmentsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectAttachmentsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectAttachmentsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectAttachmentsScopedList;

                    /**
                     * Creates a plain object from an InterconnectAttachmentsScopedList message. Also converts values to other types if specified.
                     * @param message InterconnectAttachmentsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectAttachmentsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectAttachmentsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectAttachmentsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectCircuitInfo. */
                interface IInterconnectCircuitInfo {

                    /** InterconnectCircuitInfo customerDemarcId */
                    customerDemarcId?: (string|null);

                    /** InterconnectCircuitInfo googleCircuitId */
                    googleCircuitId?: (string|null);

                    /** InterconnectCircuitInfo googleDemarcId */
                    googleDemarcId?: (string|null);
                }

                /** Represents an InterconnectCircuitInfo. */
                class InterconnectCircuitInfo implements IInterconnectCircuitInfo {

                    /**
                     * Constructs a new InterconnectCircuitInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectCircuitInfo);

                    /** InterconnectCircuitInfo customerDemarcId. */
                    public customerDemarcId?: (string|null);

                    /** InterconnectCircuitInfo googleCircuitId. */
                    public googleCircuitId?: (string|null);

                    /** InterconnectCircuitInfo googleDemarcId. */
                    public googleDemarcId?: (string|null);

                    /** InterconnectCircuitInfo _customerDemarcId. */
                    public _customerDemarcId?: "customerDemarcId";

                    /** InterconnectCircuitInfo _googleCircuitId. */
                    public _googleCircuitId?: "googleCircuitId";

                    /** InterconnectCircuitInfo _googleDemarcId. */
                    public _googleDemarcId?: "googleDemarcId";

                    /**
                     * Creates a new InterconnectCircuitInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectCircuitInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectCircuitInfo): google.cloud.compute.v1.InterconnectCircuitInfo;

                    /**
                     * Encodes the specified InterconnectCircuitInfo message. Does not implicitly {@link google.cloud.compute.v1.InterconnectCircuitInfo.verify|verify} messages.
                     * @param message InterconnectCircuitInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectCircuitInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectCircuitInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectCircuitInfo.verify|verify} messages.
                     * @param message InterconnectCircuitInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectCircuitInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectCircuitInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectCircuitInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectCircuitInfo;

                    /**
                     * Decodes an InterconnectCircuitInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectCircuitInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectCircuitInfo;

                    /**
                     * Verifies an InterconnectCircuitInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectCircuitInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectCircuitInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectCircuitInfo;

                    /**
                     * Creates a plain object from an InterconnectCircuitInfo message. Also converts values to other types if specified.
                     * @param message InterconnectCircuitInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectCircuitInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectCircuitInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectCircuitInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectDiagnostics. */
                interface IInterconnectDiagnostics {

                    /** InterconnectDiagnostics arpCaches */
                    arpCaches?: (google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry[]|null);

                    /** InterconnectDiagnostics links */
                    links?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkStatus[]|null);

                    /** InterconnectDiagnostics macAddress */
                    macAddress?: (string|null);
                }

                /** Represents an InterconnectDiagnostics. */
                class InterconnectDiagnostics implements IInterconnectDiagnostics {

                    /**
                     * Constructs a new InterconnectDiagnostics.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectDiagnostics);

                    /** InterconnectDiagnostics arpCaches. */
                    public arpCaches: google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry[];

                    /** InterconnectDiagnostics links. */
                    public links: google.cloud.compute.v1.IInterconnectDiagnosticsLinkStatus[];

                    /** InterconnectDiagnostics macAddress. */
                    public macAddress?: (string|null);

                    /** InterconnectDiagnostics _macAddress. */
                    public _macAddress?: "macAddress";

                    /**
                     * Creates a new InterconnectDiagnostics instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectDiagnostics instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectDiagnostics): google.cloud.compute.v1.InterconnectDiagnostics;

                    /**
                     * Encodes the specified InterconnectDiagnostics message. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnostics.verify|verify} messages.
                     * @param message InterconnectDiagnostics message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectDiagnostics, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectDiagnostics message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnostics.verify|verify} messages.
                     * @param message InterconnectDiagnostics message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectDiagnostics, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectDiagnostics message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectDiagnostics
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectDiagnostics;

                    /**
                     * Decodes an InterconnectDiagnostics message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectDiagnostics
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectDiagnostics;

                    /**
                     * Verifies an InterconnectDiagnostics message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectDiagnostics message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectDiagnostics
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectDiagnostics;

                    /**
                     * Creates a plain object from an InterconnectDiagnostics message. Also converts values to other types if specified.
                     * @param message InterconnectDiagnostics
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectDiagnostics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectDiagnostics to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectDiagnostics
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectDiagnosticsARPEntry. */
                interface IInterconnectDiagnosticsARPEntry {

                    /** InterconnectDiagnosticsARPEntry ipAddress */
                    ipAddress?: (string|null);

                    /** InterconnectDiagnosticsARPEntry macAddress */
                    macAddress?: (string|null);
                }

                /** Represents an InterconnectDiagnosticsARPEntry. */
                class InterconnectDiagnosticsARPEntry implements IInterconnectDiagnosticsARPEntry {

                    /**
                     * Constructs a new InterconnectDiagnosticsARPEntry.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry);

                    /** InterconnectDiagnosticsARPEntry ipAddress. */
                    public ipAddress?: (string|null);

                    /** InterconnectDiagnosticsARPEntry macAddress. */
                    public macAddress?: (string|null);

                    /** InterconnectDiagnosticsARPEntry _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /** InterconnectDiagnosticsARPEntry _macAddress. */
                    public _macAddress?: "macAddress";

                    /**
                     * Creates a new InterconnectDiagnosticsARPEntry instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectDiagnosticsARPEntry instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry): google.cloud.compute.v1.InterconnectDiagnosticsARPEntry;

                    /**
                     * Encodes the specified InterconnectDiagnosticsARPEntry message. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsARPEntry.verify|verify} messages.
                     * @param message InterconnectDiagnosticsARPEntry message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectDiagnosticsARPEntry message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsARPEntry.verify|verify} messages.
                     * @param message InterconnectDiagnosticsARPEntry message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectDiagnosticsARPEntry message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectDiagnosticsARPEntry
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectDiagnosticsARPEntry;

                    /**
                     * Decodes an InterconnectDiagnosticsARPEntry message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectDiagnosticsARPEntry
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectDiagnosticsARPEntry;

                    /**
                     * Verifies an InterconnectDiagnosticsARPEntry message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectDiagnosticsARPEntry message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectDiagnosticsARPEntry
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectDiagnosticsARPEntry;

                    /**
                     * Creates a plain object from an InterconnectDiagnosticsARPEntry message. Also converts values to other types if specified.
                     * @param message InterconnectDiagnosticsARPEntry
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectDiagnosticsARPEntry, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectDiagnosticsARPEntry to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectDiagnosticsARPEntry
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectDiagnosticsLinkLACPStatus. */
                interface IInterconnectDiagnosticsLinkLACPStatus {

                    /** InterconnectDiagnosticsLinkLACPStatus googleSystemId */
                    googleSystemId?: (string|null);

                    /** InterconnectDiagnosticsLinkLACPStatus neighborSystemId */
                    neighborSystemId?: (string|null);

                    /** InterconnectDiagnosticsLinkLACPStatus state */
                    state?: (string|null);
                }

                /** Represents an InterconnectDiagnosticsLinkLACPStatus. */
                class InterconnectDiagnosticsLinkLACPStatus implements IInterconnectDiagnosticsLinkLACPStatus {

                    /**
                     * Constructs a new InterconnectDiagnosticsLinkLACPStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsLinkLACPStatus);

                    /** InterconnectDiagnosticsLinkLACPStatus googleSystemId. */
                    public googleSystemId?: (string|null);

                    /** InterconnectDiagnosticsLinkLACPStatus neighborSystemId. */
                    public neighborSystemId?: (string|null);

                    /** InterconnectDiagnosticsLinkLACPStatus state. */
                    public state?: (string|null);

                    /** InterconnectDiagnosticsLinkLACPStatus _googleSystemId. */
                    public _googleSystemId?: "googleSystemId";

                    /** InterconnectDiagnosticsLinkLACPStatus _neighborSystemId. */
                    public _neighborSystemId?: "neighborSystemId";

                    /** InterconnectDiagnosticsLinkLACPStatus _state. */
                    public _state?: "state";

                    /**
                     * Creates a new InterconnectDiagnosticsLinkLACPStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectDiagnosticsLinkLACPStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsLinkLACPStatus): google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus;

                    /**
                     * Encodes the specified InterconnectDiagnosticsLinkLACPStatus message. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus.verify|verify} messages.
                     * @param message InterconnectDiagnosticsLinkLACPStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectDiagnosticsLinkLACPStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectDiagnosticsLinkLACPStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus.verify|verify} messages.
                     * @param message InterconnectDiagnosticsLinkLACPStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectDiagnosticsLinkLACPStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectDiagnosticsLinkLACPStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectDiagnosticsLinkLACPStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus;

                    /**
                     * Decodes an InterconnectDiagnosticsLinkLACPStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectDiagnosticsLinkLACPStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus;

                    /**
                     * Verifies an InterconnectDiagnosticsLinkLACPStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectDiagnosticsLinkLACPStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectDiagnosticsLinkLACPStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus;

                    /**
                     * Creates a plain object from an InterconnectDiagnosticsLinkLACPStatus message. Also converts values to other types if specified.
                     * @param message InterconnectDiagnosticsLinkLACPStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectDiagnosticsLinkLACPStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectDiagnosticsLinkLACPStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectDiagnosticsLinkLACPStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InterconnectDiagnosticsLinkLACPStatus {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        DETACHED = 216562546
                    }
                }

                /** Properties of an InterconnectDiagnosticsLinkOpticalPower. */
                interface IInterconnectDiagnosticsLinkOpticalPower {

                    /** InterconnectDiagnosticsLinkOpticalPower state */
                    state?: (string|null);

                    /** InterconnectDiagnosticsLinkOpticalPower value */
                    value?: (number|null);
                }

                /** Represents an InterconnectDiagnosticsLinkOpticalPower. */
                class InterconnectDiagnosticsLinkOpticalPower implements IInterconnectDiagnosticsLinkOpticalPower {

                    /**
                     * Constructs a new InterconnectDiagnosticsLinkOpticalPower.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower);

                    /** InterconnectDiagnosticsLinkOpticalPower state. */
                    public state?: (string|null);

                    /** InterconnectDiagnosticsLinkOpticalPower value. */
                    public value?: (number|null);

                    /** InterconnectDiagnosticsLinkOpticalPower _state. */
                    public _state?: "state";

                    /** InterconnectDiagnosticsLinkOpticalPower _value. */
                    public _value?: "value";

                    /**
                     * Creates a new InterconnectDiagnosticsLinkOpticalPower instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectDiagnosticsLinkOpticalPower instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower): google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower;

                    /**
                     * Encodes the specified InterconnectDiagnosticsLinkOpticalPower message. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower.verify|verify} messages.
                     * @param message InterconnectDiagnosticsLinkOpticalPower message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectDiagnosticsLinkOpticalPower message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower.verify|verify} messages.
                     * @param message InterconnectDiagnosticsLinkOpticalPower message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectDiagnosticsLinkOpticalPower message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectDiagnosticsLinkOpticalPower
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower;

                    /**
                     * Decodes an InterconnectDiagnosticsLinkOpticalPower message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectDiagnosticsLinkOpticalPower
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower;

                    /**
                     * Verifies an InterconnectDiagnosticsLinkOpticalPower message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectDiagnosticsLinkOpticalPower message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectDiagnosticsLinkOpticalPower
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower;

                    /**
                     * Creates a plain object from an InterconnectDiagnosticsLinkOpticalPower message. Also converts values to other types if specified.
                     * @param message InterconnectDiagnosticsLinkOpticalPower
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectDiagnosticsLinkOpticalPower, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectDiagnosticsLinkOpticalPower to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectDiagnosticsLinkOpticalPower
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InterconnectDiagnosticsLinkOpticalPower {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        HIGH_ALARM = 305363284,
                        HIGH_WARNING = 220984799,
                        LOW_ALARM = 316659046,
                        LOW_WARNING = 338793841,
                        OK = 2524
                    }
                }

                /** Properties of an InterconnectDiagnosticsLinkStatus. */
                interface IInterconnectDiagnosticsLinkStatus {

                    /** InterconnectDiagnosticsLinkStatus arpCaches */
                    arpCaches?: (google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry[]|null);

                    /** InterconnectDiagnosticsLinkStatus circuitId */
                    circuitId?: (string|null);

                    /** InterconnectDiagnosticsLinkStatus googleDemarc */
                    googleDemarc?: (string|null);

                    /** InterconnectDiagnosticsLinkStatus lacpStatus */
                    lacpStatus?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkLACPStatus|null);

                    /** InterconnectDiagnosticsLinkStatus receivingOpticalPower */
                    receivingOpticalPower?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower|null);

                    /** InterconnectDiagnosticsLinkStatus transmittingOpticalPower */
                    transmittingOpticalPower?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower|null);
                }

                /** Represents an InterconnectDiagnosticsLinkStatus. */
                class InterconnectDiagnosticsLinkStatus implements IInterconnectDiagnosticsLinkStatus {

                    /**
                     * Constructs a new InterconnectDiagnosticsLinkStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsLinkStatus);

                    /** InterconnectDiagnosticsLinkStatus arpCaches. */
                    public arpCaches: google.cloud.compute.v1.IInterconnectDiagnosticsARPEntry[];

                    /** InterconnectDiagnosticsLinkStatus circuitId. */
                    public circuitId?: (string|null);

                    /** InterconnectDiagnosticsLinkStatus googleDemarc. */
                    public googleDemarc?: (string|null);

                    /** InterconnectDiagnosticsLinkStatus lacpStatus. */
                    public lacpStatus?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkLACPStatus|null);

                    /** InterconnectDiagnosticsLinkStatus receivingOpticalPower. */
                    public receivingOpticalPower?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower|null);

                    /** InterconnectDiagnosticsLinkStatus transmittingOpticalPower. */
                    public transmittingOpticalPower?: (google.cloud.compute.v1.IInterconnectDiagnosticsLinkOpticalPower|null);

                    /** InterconnectDiagnosticsLinkStatus _circuitId. */
                    public _circuitId?: "circuitId";

                    /** InterconnectDiagnosticsLinkStatus _googleDemarc. */
                    public _googleDemarc?: "googleDemarc";

                    /** InterconnectDiagnosticsLinkStatus _lacpStatus. */
                    public _lacpStatus?: "lacpStatus";

                    /** InterconnectDiagnosticsLinkStatus _receivingOpticalPower. */
                    public _receivingOpticalPower?: "receivingOpticalPower";

                    /** InterconnectDiagnosticsLinkStatus _transmittingOpticalPower. */
                    public _transmittingOpticalPower?: "transmittingOpticalPower";

                    /**
                     * Creates a new InterconnectDiagnosticsLinkStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectDiagnosticsLinkStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectDiagnosticsLinkStatus): google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus;

                    /**
                     * Encodes the specified InterconnectDiagnosticsLinkStatus message. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus.verify|verify} messages.
                     * @param message InterconnectDiagnosticsLinkStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectDiagnosticsLinkStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectDiagnosticsLinkStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus.verify|verify} messages.
                     * @param message InterconnectDiagnosticsLinkStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectDiagnosticsLinkStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectDiagnosticsLinkStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectDiagnosticsLinkStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus;

                    /**
                     * Decodes an InterconnectDiagnosticsLinkStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectDiagnosticsLinkStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus;

                    /**
                     * Verifies an InterconnectDiagnosticsLinkStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectDiagnosticsLinkStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectDiagnosticsLinkStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus;

                    /**
                     * Creates a plain object from an InterconnectDiagnosticsLinkStatus message. Also converts values to other types if specified.
                     * @param message InterconnectDiagnosticsLinkStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectDiagnosticsLinkStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectDiagnosticsLinkStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectDiagnosticsLinkStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectList. */
                interface IInterconnectList {

                    /** InterconnectList id */
                    id?: (string|null);

                    /** InterconnectList items */
                    items?: (google.cloud.compute.v1.IInterconnect[]|null);

                    /** InterconnectList kind */
                    kind?: (string|null);

                    /** InterconnectList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InterconnectList selfLink */
                    selfLink?: (string|null);

                    /** InterconnectList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InterconnectList. */
                class InterconnectList implements IInterconnectList {

                    /**
                     * Constructs a new InterconnectList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectList);

                    /** InterconnectList id. */
                    public id?: (string|null);

                    /** InterconnectList items. */
                    public items: google.cloud.compute.v1.IInterconnect[];

                    /** InterconnectList kind. */
                    public kind?: (string|null);

                    /** InterconnectList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InterconnectList selfLink. */
                    public selfLink?: (string|null);

                    /** InterconnectList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InterconnectList _id. */
                    public _id?: "id";

                    /** InterconnectList _kind. */
                    public _kind?: "kind";

                    /** InterconnectList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InterconnectList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InterconnectList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InterconnectList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectList): google.cloud.compute.v1.InterconnectList;

                    /**
                     * Encodes the specified InterconnectList message. Does not implicitly {@link google.cloud.compute.v1.InterconnectList.verify|verify} messages.
                     * @param message InterconnectList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectList.verify|verify} messages.
                     * @param message InterconnectList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectList;

                    /**
                     * Decodes an InterconnectList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectList;

                    /**
                     * Verifies an InterconnectList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectList;

                    /**
                     * Creates a plain object from an InterconnectList message. Also converts values to other types if specified.
                     * @param message InterconnectList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectLocation. */
                interface IInterconnectLocation {

                    /** InterconnectLocation address */
                    address?: (string|null);

                    /** InterconnectLocation availabilityZone */
                    availabilityZone?: (string|null);

                    /** InterconnectLocation city */
                    city?: (string|null);

                    /** InterconnectLocation continent */
                    continent?: (string|null);

                    /** InterconnectLocation creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** InterconnectLocation description */
                    description?: (string|null);

                    /** InterconnectLocation facilityProvider */
                    facilityProvider?: (string|null);

                    /** InterconnectLocation facilityProviderFacilityId */
                    facilityProviderFacilityId?: (string|null);

                    /** InterconnectLocation id */
                    id?: (number|Long|string|null);

                    /** InterconnectLocation kind */
                    kind?: (string|null);

                    /** InterconnectLocation name */
                    name?: (string|null);

                    /** InterconnectLocation peeringdbFacilityId */
                    peeringdbFacilityId?: (string|null);

                    /** InterconnectLocation regionInfos */
                    regionInfos?: (google.cloud.compute.v1.IInterconnectLocationRegionInfo[]|null);

                    /** InterconnectLocation selfLink */
                    selfLink?: (string|null);

                    /** InterconnectLocation status */
                    status?: (string|null);

                    /** InterconnectLocation supportsPzs */
                    supportsPzs?: (boolean|null);
                }

                /** Represents an InterconnectLocation. */
                class InterconnectLocation implements IInterconnectLocation {

                    /**
                     * Constructs a new InterconnectLocation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectLocation);

                    /** InterconnectLocation address. */
                    public address?: (string|null);

                    /** InterconnectLocation availabilityZone. */
                    public availabilityZone?: (string|null);

                    /** InterconnectLocation city. */
                    public city?: (string|null);

                    /** InterconnectLocation continent. */
                    public continent?: (string|null);

                    /** InterconnectLocation creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** InterconnectLocation description. */
                    public description?: (string|null);

                    /** InterconnectLocation facilityProvider. */
                    public facilityProvider?: (string|null);

                    /** InterconnectLocation facilityProviderFacilityId. */
                    public facilityProviderFacilityId?: (string|null);

                    /** InterconnectLocation id. */
                    public id?: (number|Long|string|null);

                    /** InterconnectLocation kind. */
                    public kind?: (string|null);

                    /** InterconnectLocation name. */
                    public name?: (string|null);

                    /** InterconnectLocation peeringdbFacilityId. */
                    public peeringdbFacilityId?: (string|null);

                    /** InterconnectLocation regionInfos. */
                    public regionInfos: google.cloud.compute.v1.IInterconnectLocationRegionInfo[];

                    /** InterconnectLocation selfLink. */
                    public selfLink?: (string|null);

                    /** InterconnectLocation status. */
                    public status?: (string|null);

                    /** InterconnectLocation supportsPzs. */
                    public supportsPzs?: (boolean|null);

                    /** InterconnectLocation _address. */
                    public _address?: "address";

                    /** InterconnectLocation _availabilityZone. */
                    public _availabilityZone?: "availabilityZone";

                    /** InterconnectLocation _city. */
                    public _city?: "city";

                    /** InterconnectLocation _continent. */
                    public _continent?: "continent";

                    /** InterconnectLocation _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** InterconnectLocation _description. */
                    public _description?: "description";

                    /** InterconnectLocation _facilityProvider. */
                    public _facilityProvider?: "facilityProvider";

                    /** InterconnectLocation _facilityProviderFacilityId. */
                    public _facilityProviderFacilityId?: "facilityProviderFacilityId";

                    /** InterconnectLocation _id. */
                    public _id?: "id";

                    /** InterconnectLocation _kind. */
                    public _kind?: "kind";

                    /** InterconnectLocation _name. */
                    public _name?: "name";

                    /** InterconnectLocation _peeringdbFacilityId. */
                    public _peeringdbFacilityId?: "peeringdbFacilityId";

                    /** InterconnectLocation _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InterconnectLocation _status. */
                    public _status?: "status";

                    /** InterconnectLocation _supportsPzs. */
                    public _supportsPzs?: "supportsPzs";

                    /**
                     * Creates a new InterconnectLocation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectLocation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectLocation): google.cloud.compute.v1.InterconnectLocation;

                    /**
                     * Encodes the specified InterconnectLocation message. Does not implicitly {@link google.cloud.compute.v1.InterconnectLocation.verify|verify} messages.
                     * @param message InterconnectLocation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectLocation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectLocation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectLocation.verify|verify} messages.
                     * @param message InterconnectLocation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectLocation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectLocation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectLocation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectLocation;

                    /**
                     * Decodes an InterconnectLocation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectLocation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectLocation;

                    /**
                     * Verifies an InterconnectLocation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectLocation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectLocation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectLocation;

                    /**
                     * Creates a plain object from an InterconnectLocation message. Also converts values to other types if specified.
                     * @param message InterconnectLocation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectLocation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectLocation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectLocation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InterconnectLocation {

                    /** Continent enum. */
                    enum Continent {
                        UNDEFINED_CONTINENT = 0,
                        AFRICA = 317443706,
                        ASIA_PAC = 119782269,
                        C_AFRICA = 71993846,
                        C_ASIA_PAC = 465668089,
                        C_EUROPE = 200369438,
                        C_NORTH_AMERICA = 275697048,
                        C_SOUTH_AMERICA = 397149792,
                        EUROPE = 445819298,
                        NORTH_AMERICA = 448015508,
                        SOUTH_AMERICA = 32597340
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        AVAILABLE = 442079913,
                        CLOSED = 380163436
                    }
                }

                /** Properties of an InterconnectLocationList. */
                interface IInterconnectLocationList {

                    /** InterconnectLocationList id */
                    id?: (string|null);

                    /** InterconnectLocationList items */
                    items?: (google.cloud.compute.v1.IInterconnectLocation[]|null);

                    /** InterconnectLocationList kind */
                    kind?: (string|null);

                    /** InterconnectLocationList nextPageToken */
                    nextPageToken?: (string|null);

                    /** InterconnectLocationList selfLink */
                    selfLink?: (string|null);

                    /** InterconnectLocationList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an InterconnectLocationList. */
                class InterconnectLocationList implements IInterconnectLocationList {

                    /**
                     * Constructs a new InterconnectLocationList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectLocationList);

                    /** InterconnectLocationList id. */
                    public id?: (string|null);

                    /** InterconnectLocationList items. */
                    public items: google.cloud.compute.v1.IInterconnectLocation[];

                    /** InterconnectLocationList kind. */
                    public kind?: (string|null);

                    /** InterconnectLocationList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** InterconnectLocationList selfLink. */
                    public selfLink?: (string|null);

                    /** InterconnectLocationList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** InterconnectLocationList _id. */
                    public _id?: "id";

                    /** InterconnectLocationList _kind. */
                    public _kind?: "kind";

                    /** InterconnectLocationList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** InterconnectLocationList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** InterconnectLocationList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new InterconnectLocationList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectLocationList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectLocationList): google.cloud.compute.v1.InterconnectLocationList;

                    /**
                     * Encodes the specified InterconnectLocationList message. Does not implicitly {@link google.cloud.compute.v1.InterconnectLocationList.verify|verify} messages.
                     * @param message InterconnectLocationList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectLocationList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectLocationList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectLocationList.verify|verify} messages.
                     * @param message InterconnectLocationList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectLocationList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectLocationList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectLocationList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectLocationList;

                    /**
                     * Decodes an InterconnectLocationList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectLocationList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectLocationList;

                    /**
                     * Verifies an InterconnectLocationList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectLocationList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectLocationList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectLocationList;

                    /**
                     * Creates a plain object from an InterconnectLocationList message. Also converts values to other types if specified.
                     * @param message InterconnectLocationList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectLocationList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectLocationList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectLocationList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InterconnectLocationRegionInfo. */
                interface IInterconnectLocationRegionInfo {

                    /** InterconnectLocationRegionInfo expectedRttMs */
                    expectedRttMs?: (number|Long|string|null);

                    /** InterconnectLocationRegionInfo locationPresence */
                    locationPresence?: (string|null);

                    /** InterconnectLocationRegionInfo region */
                    region?: (string|null);
                }

                /** Represents an InterconnectLocationRegionInfo. */
                class InterconnectLocationRegionInfo implements IInterconnectLocationRegionInfo {

                    /**
                     * Constructs a new InterconnectLocationRegionInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectLocationRegionInfo);

                    /** InterconnectLocationRegionInfo expectedRttMs. */
                    public expectedRttMs?: (number|Long|string|null);

                    /** InterconnectLocationRegionInfo locationPresence. */
                    public locationPresence?: (string|null);

                    /** InterconnectLocationRegionInfo region. */
                    public region?: (string|null);

                    /** InterconnectLocationRegionInfo _expectedRttMs. */
                    public _expectedRttMs?: "expectedRttMs";

                    /** InterconnectLocationRegionInfo _locationPresence. */
                    public _locationPresence?: "locationPresence";

                    /** InterconnectLocationRegionInfo _region. */
                    public _region?: "region";

                    /**
                     * Creates a new InterconnectLocationRegionInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectLocationRegionInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectLocationRegionInfo): google.cloud.compute.v1.InterconnectLocationRegionInfo;

                    /**
                     * Encodes the specified InterconnectLocationRegionInfo message. Does not implicitly {@link google.cloud.compute.v1.InterconnectLocationRegionInfo.verify|verify} messages.
                     * @param message InterconnectLocationRegionInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectLocationRegionInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectLocationRegionInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectLocationRegionInfo.verify|verify} messages.
                     * @param message InterconnectLocationRegionInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectLocationRegionInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectLocationRegionInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectLocationRegionInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectLocationRegionInfo;

                    /**
                     * Decodes an InterconnectLocationRegionInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectLocationRegionInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectLocationRegionInfo;

                    /**
                     * Verifies an InterconnectLocationRegionInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectLocationRegionInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectLocationRegionInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectLocationRegionInfo;

                    /**
                     * Creates a plain object from an InterconnectLocationRegionInfo message. Also converts values to other types if specified.
                     * @param message InterconnectLocationRegionInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectLocationRegionInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectLocationRegionInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectLocationRegionInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InterconnectLocationRegionInfo {

                    /** LocationPresence enum. */
                    enum LocationPresence {
                        UNDEFINED_LOCATION_PRESENCE = 0,
                        GLOBAL = 494663587,
                        LOCAL_REGION = 403535464,
                        LP_GLOBAL = 429584062,
                        LP_LOCAL_REGION = 488598851
                    }
                }

                /** Properties of an InterconnectOutageNotification. */
                interface IInterconnectOutageNotification {

                    /** InterconnectOutageNotification affectedCircuits */
                    affectedCircuits?: (string[]|null);

                    /** InterconnectOutageNotification description */
                    description?: (string|null);

                    /** InterconnectOutageNotification endTime */
                    endTime?: (number|Long|string|null);

                    /** InterconnectOutageNotification issueType */
                    issueType?: (string|null);

                    /** InterconnectOutageNotification name */
                    name?: (string|null);

                    /** InterconnectOutageNotification source */
                    source?: (string|null);

                    /** InterconnectOutageNotification startTime */
                    startTime?: (number|Long|string|null);

                    /** InterconnectOutageNotification state */
                    state?: (string|null);
                }

                /** Represents an InterconnectOutageNotification. */
                class InterconnectOutageNotification implements IInterconnectOutageNotification {

                    /**
                     * Constructs a new InterconnectOutageNotification.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectOutageNotification);

                    /** InterconnectOutageNotification affectedCircuits. */
                    public affectedCircuits: string[];

                    /** InterconnectOutageNotification description. */
                    public description?: (string|null);

                    /** InterconnectOutageNotification endTime. */
                    public endTime?: (number|Long|string|null);

                    /** InterconnectOutageNotification issueType. */
                    public issueType?: (string|null);

                    /** InterconnectOutageNotification name. */
                    public name?: (string|null);

                    /** InterconnectOutageNotification source. */
                    public source?: (string|null);

                    /** InterconnectOutageNotification startTime. */
                    public startTime?: (number|Long|string|null);

                    /** InterconnectOutageNotification state. */
                    public state?: (string|null);

                    /** InterconnectOutageNotification _description. */
                    public _description?: "description";

                    /** InterconnectOutageNotification _endTime. */
                    public _endTime?: "endTime";

                    /** InterconnectOutageNotification _issueType. */
                    public _issueType?: "issueType";

                    /** InterconnectOutageNotification _name. */
                    public _name?: "name";

                    /** InterconnectOutageNotification _source. */
                    public _source?: "source";

                    /** InterconnectOutageNotification _startTime. */
                    public _startTime?: "startTime";

                    /** InterconnectOutageNotification _state. */
                    public _state?: "state";

                    /**
                     * Creates a new InterconnectOutageNotification instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectOutageNotification instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectOutageNotification): google.cloud.compute.v1.InterconnectOutageNotification;

                    /**
                     * Encodes the specified InterconnectOutageNotification message. Does not implicitly {@link google.cloud.compute.v1.InterconnectOutageNotification.verify|verify} messages.
                     * @param message InterconnectOutageNotification message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectOutageNotification, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectOutageNotification message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectOutageNotification.verify|verify} messages.
                     * @param message InterconnectOutageNotification message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectOutageNotification, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectOutageNotification message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectOutageNotification
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectOutageNotification;

                    /**
                     * Decodes an InterconnectOutageNotification message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectOutageNotification
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectOutageNotification;

                    /**
                     * Verifies an InterconnectOutageNotification message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectOutageNotification message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectOutageNotification
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectOutageNotification;

                    /**
                     * Creates a plain object from an InterconnectOutageNotification message. Also converts values to other types if specified.
                     * @param message InterconnectOutageNotification
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectOutageNotification, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectOutageNotification to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectOutageNotification
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace InterconnectOutageNotification {

                    /** IssueType enum. */
                    enum IssueType {
                        UNDEFINED_ISSUE_TYPE = 0,
                        IT_OUTAGE = 175779973,
                        IT_PARTIAL_OUTAGE = 92103971,
                        OUTAGE = 195285745,
                        PARTIAL_OUTAGE = 147053455
                    }

                    /** Source enum. */
                    enum Source {
                        UNDEFINED_SOURCE = 0,
                        GOOGLE = 497439289,
                        NSRC_GOOGLE = 510574562
                    }

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        CANCELLED = 41957681,
                        COMPLETED = 309921323,
                        NS_ACTIVE = 252563136,
                        NS_CANCELED = 506579411
                    }
                }

                /** Properties of an InterconnectsGetDiagnosticsResponse. */
                interface IInterconnectsGetDiagnosticsResponse {

                    /** InterconnectsGetDiagnosticsResponse result */
                    result?: (google.cloud.compute.v1.IInterconnectDiagnostics|null);
                }

                /** Represents an InterconnectsGetDiagnosticsResponse. */
                class InterconnectsGetDiagnosticsResponse implements IInterconnectsGetDiagnosticsResponse {

                    /**
                     * Constructs a new InterconnectsGetDiagnosticsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInterconnectsGetDiagnosticsResponse);

                    /** InterconnectsGetDiagnosticsResponse result. */
                    public result?: (google.cloud.compute.v1.IInterconnectDiagnostics|null);

                    /** InterconnectsGetDiagnosticsResponse _result. */
                    public _result?: "result";

                    /**
                     * Creates a new InterconnectsGetDiagnosticsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InterconnectsGetDiagnosticsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInterconnectsGetDiagnosticsResponse): google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse;

                    /**
                     * Encodes the specified InterconnectsGetDiagnosticsResponse message. Does not implicitly {@link google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse.verify|verify} messages.
                     * @param message InterconnectsGetDiagnosticsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInterconnectsGetDiagnosticsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InterconnectsGetDiagnosticsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse.verify|verify} messages.
                     * @param message InterconnectsGetDiagnosticsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInterconnectsGetDiagnosticsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InterconnectsGetDiagnosticsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InterconnectsGetDiagnosticsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse;

                    /**
                     * Decodes an InterconnectsGetDiagnosticsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InterconnectsGetDiagnosticsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse;

                    /**
                     * Verifies an InterconnectsGetDiagnosticsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InterconnectsGetDiagnosticsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InterconnectsGetDiagnosticsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse;

                    /**
                     * Creates a plain object from an InterconnectsGetDiagnosticsResponse message. Also converts values to other types if specified.
                     * @param message InterconnectsGetDiagnosticsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InterconnectsGetDiagnosticsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InterconnectsGetDiagnosticsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InvalidateCacheUrlMapRequest. */
                interface IInvalidateCacheUrlMapRequest {

                    /** InvalidateCacheUrlMapRequest cacheInvalidationRuleResource */
                    cacheInvalidationRuleResource?: (google.cloud.compute.v1.ICacheInvalidationRule|null);

                    /** InvalidateCacheUrlMapRequest project */
                    project?: (string|null);

                    /** InvalidateCacheUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** InvalidateCacheUrlMapRequest urlMap */
                    urlMap?: (string|null);
                }

                /** Represents an InvalidateCacheUrlMapRequest. */
                class InvalidateCacheUrlMapRequest implements IInvalidateCacheUrlMapRequest {

                    /**
                     * Constructs a new InvalidateCacheUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IInvalidateCacheUrlMapRequest);

                    /** InvalidateCacheUrlMapRequest cacheInvalidationRuleResource. */
                    public cacheInvalidationRuleResource?: (google.cloud.compute.v1.ICacheInvalidationRule|null);

                    /** InvalidateCacheUrlMapRequest project. */
                    public project: string;

                    /** InvalidateCacheUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** InvalidateCacheUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** InvalidateCacheUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InvalidateCacheUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InvalidateCacheUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IInvalidateCacheUrlMapRequest): google.cloud.compute.v1.InvalidateCacheUrlMapRequest;

                    /**
                     * Encodes the specified InvalidateCacheUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.InvalidateCacheUrlMapRequest.verify|verify} messages.
                     * @param message InvalidateCacheUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IInvalidateCacheUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InvalidateCacheUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.InvalidateCacheUrlMapRequest.verify|verify} messages.
                     * @param message InvalidateCacheUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IInvalidateCacheUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InvalidateCacheUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InvalidateCacheUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.InvalidateCacheUrlMapRequest;

                    /**
                     * Decodes an InvalidateCacheUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InvalidateCacheUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.InvalidateCacheUrlMapRequest;

                    /**
                     * Verifies an InvalidateCacheUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InvalidateCacheUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InvalidateCacheUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.InvalidateCacheUrlMapRequest;

                    /**
                     * Creates a plain object from an InvalidateCacheUrlMapRequest message. Also converts values to other types if specified.
                     * @param message InvalidateCacheUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.InvalidateCacheUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InvalidateCacheUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InvalidateCacheUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Items. */
                interface IItems {

                    /** Items key */
                    key?: (string|null);

                    /** Items value */
                    value?: (string|null);
                }

                /** Represents an Items. */
                class Items implements IItems {

                    /**
                     * Constructs a new Items.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IItems);

                    /** Items key. */
                    public key?: (string|null);

                    /** Items value. */
                    public value?: (string|null);

                    /** Items _key. */
                    public _key?: "key";

                    /** Items _value. */
                    public _value?: "value";

                    /**
                     * Creates a new Items instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Items instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IItems): google.cloud.compute.v1.Items;

                    /**
                     * Encodes the specified Items message. Does not implicitly {@link google.cloud.compute.v1.Items.verify|verify} messages.
                     * @param message Items message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IItems, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Items message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Items.verify|verify} messages.
                     * @param message Items message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IItems, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Items message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Items
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Items;

                    /**
                     * Decodes an Items message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Items
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Items;

                    /**
                     * Verifies an Items message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Items message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Items
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Items;

                    /**
                     * Creates a plain object from an Items message. Also converts values to other types if specified.
                     * @param message Items
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Items, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Items to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Items
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a License. */
                interface ILicense {

                    /** License chargesUseFee */
                    chargesUseFee?: (boolean|null);

                    /** License creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** License description */
                    description?: (string|null);

                    /** License id */
                    id?: (number|Long|string|null);

                    /** License kind */
                    kind?: (string|null);

                    /** License licenseCode */
                    licenseCode?: (number|Long|string|null);

                    /** License name */
                    name?: (string|null);

                    /** License resourceRequirements */
                    resourceRequirements?: (google.cloud.compute.v1.ILicenseResourceRequirements|null);

                    /** License selfLink */
                    selfLink?: (string|null);

                    /** License transferable */
                    transferable?: (boolean|null);
                }

                /** Represents a License. */
                class License implements ILicense {

                    /**
                     * Constructs a new License.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILicense);

                    /** License chargesUseFee. */
                    public chargesUseFee?: (boolean|null);

                    /** License creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** License description. */
                    public description?: (string|null);

                    /** License id. */
                    public id?: (number|Long|string|null);

                    /** License kind. */
                    public kind?: (string|null);

                    /** License licenseCode. */
                    public licenseCode?: (number|Long|string|null);

                    /** License name. */
                    public name?: (string|null);

                    /** License resourceRequirements. */
                    public resourceRequirements?: (google.cloud.compute.v1.ILicenseResourceRequirements|null);

                    /** License selfLink. */
                    public selfLink?: (string|null);

                    /** License transferable. */
                    public transferable?: (boolean|null);

                    /** License _chargesUseFee. */
                    public _chargesUseFee?: "chargesUseFee";

                    /** License _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** License _description. */
                    public _description?: "description";

                    /** License _id. */
                    public _id?: "id";

                    /** License _kind. */
                    public _kind?: "kind";

                    /** License _licenseCode. */
                    public _licenseCode?: "licenseCode";

                    /** License _name. */
                    public _name?: "name";

                    /** License _resourceRequirements. */
                    public _resourceRequirements?: "resourceRequirements";

                    /** License _selfLink. */
                    public _selfLink?: "selfLink";

                    /** License _transferable. */
                    public _transferable?: "transferable";

                    /**
                     * Creates a new License instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns License instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILicense): google.cloud.compute.v1.License;

                    /**
                     * Encodes the specified License message. Does not implicitly {@link google.cloud.compute.v1.License.verify|verify} messages.
                     * @param message License message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILicense, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified License message, length delimited. Does not implicitly {@link google.cloud.compute.v1.License.verify|verify} messages.
                     * @param message License message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILicense, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a License message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns License
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.License;

                    /**
                     * Decodes a License message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns License
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.License;

                    /**
                     * Verifies a License message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a License message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns License
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.License;

                    /**
                     * Creates a plain object from a License message. Also converts values to other types if specified.
                     * @param message License
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.License, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this License to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for License
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LicenseCode. */
                interface ILicenseCode {

                    /** LicenseCode creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** LicenseCode description */
                    description?: (string|null);

                    /** LicenseCode id */
                    id?: (number|Long|string|null);

                    /** LicenseCode kind */
                    kind?: (string|null);

                    /** LicenseCode licenseAlias */
                    licenseAlias?: (google.cloud.compute.v1.ILicenseCodeLicenseAlias[]|null);

                    /** LicenseCode name */
                    name?: (string|null);

                    /** LicenseCode selfLink */
                    selfLink?: (string|null);

                    /** LicenseCode state */
                    state?: (string|null);

                    /** LicenseCode transferable */
                    transferable?: (boolean|null);
                }

                /** Represents a LicenseCode. */
                class LicenseCode implements ILicenseCode {

                    /**
                     * Constructs a new LicenseCode.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILicenseCode);

                    /** LicenseCode creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** LicenseCode description. */
                    public description?: (string|null);

                    /** LicenseCode id. */
                    public id?: (number|Long|string|null);

                    /** LicenseCode kind. */
                    public kind?: (string|null);

                    /** LicenseCode licenseAlias. */
                    public licenseAlias: google.cloud.compute.v1.ILicenseCodeLicenseAlias[];

                    /** LicenseCode name. */
                    public name?: (string|null);

                    /** LicenseCode selfLink. */
                    public selfLink?: (string|null);

                    /** LicenseCode state. */
                    public state?: (string|null);

                    /** LicenseCode transferable. */
                    public transferable?: (boolean|null);

                    /** LicenseCode _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** LicenseCode _description. */
                    public _description?: "description";

                    /** LicenseCode _id. */
                    public _id?: "id";

                    /** LicenseCode _kind. */
                    public _kind?: "kind";

                    /** LicenseCode _name. */
                    public _name?: "name";

                    /** LicenseCode _selfLink. */
                    public _selfLink?: "selfLink";

                    /** LicenseCode _state. */
                    public _state?: "state";

                    /** LicenseCode _transferable. */
                    public _transferable?: "transferable";

                    /**
                     * Creates a new LicenseCode instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LicenseCode instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILicenseCode): google.cloud.compute.v1.LicenseCode;

                    /**
                     * Encodes the specified LicenseCode message. Does not implicitly {@link google.cloud.compute.v1.LicenseCode.verify|verify} messages.
                     * @param message LicenseCode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILicenseCode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LicenseCode message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LicenseCode.verify|verify} messages.
                     * @param message LicenseCode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILicenseCode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LicenseCode message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LicenseCode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LicenseCode;

                    /**
                     * Decodes a LicenseCode message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LicenseCode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LicenseCode;

                    /**
                     * Verifies a LicenseCode message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LicenseCode message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LicenseCode
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LicenseCode;

                    /**
                     * Creates a plain object from a LicenseCode message. Also converts values to other types if specified.
                     * @param message LicenseCode
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LicenseCode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LicenseCode to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LicenseCode
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace LicenseCode {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        DISABLED = 516696700,
                        ENABLED = 182130465,
                        RESTRICTED = 261551195,
                        STATE_UNSPECIFIED = 470755401,
                        TERMINATED = 250018339
                    }
                }

                /** Properties of a LicenseCodeLicenseAlias. */
                interface ILicenseCodeLicenseAlias {

                    /** LicenseCodeLicenseAlias description */
                    description?: (string|null);

                    /** LicenseCodeLicenseAlias selfLink */
                    selfLink?: (string|null);
                }

                /** Represents a LicenseCodeLicenseAlias. */
                class LicenseCodeLicenseAlias implements ILicenseCodeLicenseAlias {

                    /**
                     * Constructs a new LicenseCodeLicenseAlias.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILicenseCodeLicenseAlias);

                    /** LicenseCodeLicenseAlias description. */
                    public description?: (string|null);

                    /** LicenseCodeLicenseAlias selfLink. */
                    public selfLink?: (string|null);

                    /** LicenseCodeLicenseAlias _description. */
                    public _description?: "description";

                    /** LicenseCodeLicenseAlias _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new LicenseCodeLicenseAlias instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LicenseCodeLicenseAlias instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILicenseCodeLicenseAlias): google.cloud.compute.v1.LicenseCodeLicenseAlias;

                    /**
                     * Encodes the specified LicenseCodeLicenseAlias message. Does not implicitly {@link google.cloud.compute.v1.LicenseCodeLicenseAlias.verify|verify} messages.
                     * @param message LicenseCodeLicenseAlias message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILicenseCodeLicenseAlias, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LicenseCodeLicenseAlias message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LicenseCodeLicenseAlias.verify|verify} messages.
                     * @param message LicenseCodeLicenseAlias message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILicenseCodeLicenseAlias, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LicenseCodeLicenseAlias message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LicenseCodeLicenseAlias
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LicenseCodeLicenseAlias;

                    /**
                     * Decodes a LicenseCodeLicenseAlias message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LicenseCodeLicenseAlias
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LicenseCodeLicenseAlias;

                    /**
                     * Verifies a LicenseCodeLicenseAlias message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LicenseCodeLicenseAlias message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LicenseCodeLicenseAlias
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LicenseCodeLicenseAlias;

                    /**
                     * Creates a plain object from a LicenseCodeLicenseAlias message. Also converts values to other types if specified.
                     * @param message LicenseCodeLicenseAlias
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LicenseCodeLicenseAlias, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LicenseCodeLicenseAlias to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LicenseCodeLicenseAlias
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LicenseResourceCommitment. */
                interface ILicenseResourceCommitment {

                    /** LicenseResourceCommitment amount */
                    amount?: (number|Long|string|null);

                    /** LicenseResourceCommitment coresPerLicense */
                    coresPerLicense?: (string|null);

                    /** LicenseResourceCommitment license */
                    license?: (string|null);
                }

                /** Represents a LicenseResourceCommitment. */
                class LicenseResourceCommitment implements ILicenseResourceCommitment {

                    /**
                     * Constructs a new LicenseResourceCommitment.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILicenseResourceCommitment);

                    /** LicenseResourceCommitment amount. */
                    public amount?: (number|Long|string|null);

                    /** LicenseResourceCommitment coresPerLicense. */
                    public coresPerLicense?: (string|null);

                    /** LicenseResourceCommitment license. */
                    public license?: (string|null);

                    /** LicenseResourceCommitment _amount. */
                    public _amount?: "amount";

                    /** LicenseResourceCommitment _coresPerLicense. */
                    public _coresPerLicense?: "coresPerLicense";

                    /** LicenseResourceCommitment _license. */
                    public _license?: "license";

                    /**
                     * Creates a new LicenseResourceCommitment instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LicenseResourceCommitment instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILicenseResourceCommitment): google.cloud.compute.v1.LicenseResourceCommitment;

                    /**
                     * Encodes the specified LicenseResourceCommitment message. Does not implicitly {@link google.cloud.compute.v1.LicenseResourceCommitment.verify|verify} messages.
                     * @param message LicenseResourceCommitment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILicenseResourceCommitment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LicenseResourceCommitment message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LicenseResourceCommitment.verify|verify} messages.
                     * @param message LicenseResourceCommitment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILicenseResourceCommitment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LicenseResourceCommitment message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LicenseResourceCommitment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LicenseResourceCommitment;

                    /**
                     * Decodes a LicenseResourceCommitment message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LicenseResourceCommitment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LicenseResourceCommitment;

                    /**
                     * Verifies a LicenseResourceCommitment message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LicenseResourceCommitment message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LicenseResourceCommitment
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LicenseResourceCommitment;

                    /**
                     * Creates a plain object from a LicenseResourceCommitment message. Also converts values to other types if specified.
                     * @param message LicenseResourceCommitment
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LicenseResourceCommitment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LicenseResourceCommitment to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LicenseResourceCommitment
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LicenseResourceRequirements. */
                interface ILicenseResourceRequirements {

                    /** LicenseResourceRequirements minGuestCpuCount */
                    minGuestCpuCount?: (number|null);

                    /** LicenseResourceRequirements minMemoryMb */
                    minMemoryMb?: (number|null);
                }

                /** Represents a LicenseResourceRequirements. */
                class LicenseResourceRequirements implements ILicenseResourceRequirements {

                    /**
                     * Constructs a new LicenseResourceRequirements.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILicenseResourceRequirements);

                    /** LicenseResourceRequirements minGuestCpuCount. */
                    public minGuestCpuCount?: (number|null);

                    /** LicenseResourceRequirements minMemoryMb. */
                    public minMemoryMb?: (number|null);

                    /** LicenseResourceRequirements _minGuestCpuCount. */
                    public _minGuestCpuCount?: "minGuestCpuCount";

                    /** LicenseResourceRequirements _minMemoryMb. */
                    public _minMemoryMb?: "minMemoryMb";

                    /**
                     * Creates a new LicenseResourceRequirements instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LicenseResourceRequirements instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILicenseResourceRequirements): google.cloud.compute.v1.LicenseResourceRequirements;

                    /**
                     * Encodes the specified LicenseResourceRequirements message. Does not implicitly {@link google.cloud.compute.v1.LicenseResourceRequirements.verify|verify} messages.
                     * @param message LicenseResourceRequirements message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILicenseResourceRequirements, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LicenseResourceRequirements message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LicenseResourceRequirements.verify|verify} messages.
                     * @param message LicenseResourceRequirements message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILicenseResourceRequirements, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LicenseResourceRequirements message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LicenseResourceRequirements
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LicenseResourceRequirements;

                    /**
                     * Decodes a LicenseResourceRequirements message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LicenseResourceRequirements
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LicenseResourceRequirements;

                    /**
                     * Verifies a LicenseResourceRequirements message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LicenseResourceRequirements message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LicenseResourceRequirements
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LicenseResourceRequirements;

                    /**
                     * Creates a plain object from a LicenseResourceRequirements message. Also converts values to other types if specified.
                     * @param message LicenseResourceRequirements
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LicenseResourceRequirements, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LicenseResourceRequirements to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LicenseResourceRequirements
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LicensesListResponse. */
                interface ILicensesListResponse {

                    /** LicensesListResponse id */
                    id?: (string|null);

                    /** LicensesListResponse items */
                    items?: (google.cloud.compute.v1.ILicense[]|null);

                    /** LicensesListResponse nextPageToken */
                    nextPageToken?: (string|null);

                    /** LicensesListResponse selfLink */
                    selfLink?: (string|null);

                    /** LicensesListResponse warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a LicensesListResponse. */
                class LicensesListResponse implements ILicensesListResponse {

                    /**
                     * Constructs a new LicensesListResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILicensesListResponse);

                    /** LicensesListResponse id. */
                    public id?: (string|null);

                    /** LicensesListResponse items. */
                    public items: google.cloud.compute.v1.ILicense[];

                    /** LicensesListResponse nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** LicensesListResponse selfLink. */
                    public selfLink?: (string|null);

                    /** LicensesListResponse warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** LicensesListResponse _id. */
                    public _id?: "id";

                    /** LicensesListResponse _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** LicensesListResponse _selfLink. */
                    public _selfLink?: "selfLink";

                    /** LicensesListResponse _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new LicensesListResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LicensesListResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILicensesListResponse): google.cloud.compute.v1.LicensesListResponse;

                    /**
                     * Encodes the specified LicensesListResponse message. Does not implicitly {@link google.cloud.compute.v1.LicensesListResponse.verify|verify} messages.
                     * @param message LicensesListResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILicensesListResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LicensesListResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LicensesListResponse.verify|verify} messages.
                     * @param message LicensesListResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILicensesListResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LicensesListResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LicensesListResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LicensesListResponse;

                    /**
                     * Decodes a LicensesListResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LicensesListResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LicensesListResponse;

                    /**
                     * Verifies a LicensesListResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LicensesListResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LicensesListResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LicensesListResponse;

                    /**
                     * Creates a plain object from a LicensesListResponse message. Also converts values to other types if specified.
                     * @param message LicensesListResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LicensesListResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LicensesListResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LicensesListResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAcceleratorTypesRequest. */
                interface IListAcceleratorTypesRequest {

                    /** ListAcceleratorTypesRequest filter */
                    filter?: (string|null);

                    /** ListAcceleratorTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListAcceleratorTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListAcceleratorTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListAcceleratorTypesRequest project */
                    project?: (string|null);

                    /** ListAcceleratorTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListAcceleratorTypesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListAcceleratorTypesRequest. */
                class ListAcceleratorTypesRequest implements IListAcceleratorTypesRequest {

                    /**
                     * Constructs a new ListAcceleratorTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListAcceleratorTypesRequest);

                    /** ListAcceleratorTypesRequest filter. */
                    public filter?: (string|null);

                    /** ListAcceleratorTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListAcceleratorTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListAcceleratorTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListAcceleratorTypesRequest project. */
                    public project: string;

                    /** ListAcceleratorTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListAcceleratorTypesRequest zone. */
                    public zone: string;

                    /** ListAcceleratorTypesRequest _filter. */
                    public _filter?: "filter";

                    /** ListAcceleratorTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListAcceleratorTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListAcceleratorTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListAcceleratorTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListAcceleratorTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAcceleratorTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListAcceleratorTypesRequest): google.cloud.compute.v1.ListAcceleratorTypesRequest;

                    /**
                     * Encodes the specified ListAcceleratorTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListAcceleratorTypesRequest.verify|verify} messages.
                     * @param message ListAcceleratorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListAcceleratorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAcceleratorTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListAcceleratorTypesRequest.verify|verify} messages.
                     * @param message ListAcceleratorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListAcceleratorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAcceleratorTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAcceleratorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListAcceleratorTypesRequest;

                    /**
                     * Decodes a ListAcceleratorTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAcceleratorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListAcceleratorTypesRequest;

                    /**
                     * Verifies a ListAcceleratorTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAcceleratorTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAcceleratorTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListAcceleratorTypesRequest;

                    /**
                     * Creates a plain object from a ListAcceleratorTypesRequest message. Also converts values to other types if specified.
                     * @param message ListAcceleratorTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListAcceleratorTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAcceleratorTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAcceleratorTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAddressesRequest. */
                interface IListAddressesRequest {

                    /** ListAddressesRequest filter */
                    filter?: (string|null);

                    /** ListAddressesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListAddressesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListAddressesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListAddressesRequest project */
                    project?: (string|null);

                    /** ListAddressesRequest region */
                    region?: (string|null);

                    /** ListAddressesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListAddressesRequest. */
                class ListAddressesRequest implements IListAddressesRequest {

                    /**
                     * Constructs a new ListAddressesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListAddressesRequest);

                    /** ListAddressesRequest filter. */
                    public filter?: (string|null);

                    /** ListAddressesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListAddressesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListAddressesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListAddressesRequest project. */
                    public project: string;

                    /** ListAddressesRequest region. */
                    public region: string;

                    /** ListAddressesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListAddressesRequest _filter. */
                    public _filter?: "filter";

                    /** ListAddressesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListAddressesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListAddressesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListAddressesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListAddressesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAddressesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListAddressesRequest): google.cloud.compute.v1.ListAddressesRequest;

                    /**
                     * Encodes the specified ListAddressesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListAddressesRequest.verify|verify} messages.
                     * @param message ListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAddressesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListAddressesRequest.verify|verify} messages.
                     * @param message ListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAddressesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListAddressesRequest;

                    /**
                     * Decodes a ListAddressesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListAddressesRequest;

                    /**
                     * Verifies a ListAddressesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAddressesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAddressesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListAddressesRequest;

                    /**
                     * Creates a plain object from a ListAddressesRequest message. Also converts values to other types if specified.
                     * @param message ListAddressesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListAddressesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAddressesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAddressesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAssociationsFirewallPolicyRequest. */
                interface IListAssociationsFirewallPolicyRequest {

                    /** ListAssociationsFirewallPolicyRequest targetResource */
                    targetResource?: (string|null);
                }

                /** Represents a ListAssociationsFirewallPolicyRequest. */
                class ListAssociationsFirewallPolicyRequest implements IListAssociationsFirewallPolicyRequest {

                    /**
                     * Constructs a new ListAssociationsFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListAssociationsFirewallPolicyRequest);

                    /** ListAssociationsFirewallPolicyRequest targetResource. */
                    public targetResource?: (string|null);

                    /** ListAssociationsFirewallPolicyRequest _targetResource. */
                    public _targetResource?: "targetResource";

                    /**
                     * Creates a new ListAssociationsFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAssociationsFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListAssociationsFirewallPolicyRequest): google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest;

                    /**
                     * Encodes the specified ListAssociationsFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest.verify|verify} messages.
                     * @param message ListAssociationsFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListAssociationsFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAssociationsFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest.verify|verify} messages.
                     * @param message ListAssociationsFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListAssociationsFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAssociationsFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAssociationsFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest;

                    /**
                     * Decodes a ListAssociationsFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAssociationsFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest;

                    /**
                     * Verifies a ListAssociationsFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAssociationsFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAssociationsFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a ListAssociationsFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message ListAssociationsFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListAssociationsFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAssociationsFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAssociationsFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAutoscalersRequest. */
                interface IListAutoscalersRequest {

                    /** ListAutoscalersRequest filter */
                    filter?: (string|null);

                    /** ListAutoscalersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListAutoscalersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListAutoscalersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListAutoscalersRequest project */
                    project?: (string|null);

                    /** ListAutoscalersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListAutoscalersRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListAutoscalersRequest. */
                class ListAutoscalersRequest implements IListAutoscalersRequest {

                    /**
                     * Constructs a new ListAutoscalersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListAutoscalersRequest);

                    /** ListAutoscalersRequest filter. */
                    public filter?: (string|null);

                    /** ListAutoscalersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListAutoscalersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListAutoscalersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListAutoscalersRequest project. */
                    public project: string;

                    /** ListAutoscalersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListAutoscalersRequest zone. */
                    public zone: string;

                    /** ListAutoscalersRequest _filter. */
                    public _filter?: "filter";

                    /** ListAutoscalersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListAutoscalersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListAutoscalersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListAutoscalersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListAutoscalersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAutoscalersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListAutoscalersRequest): google.cloud.compute.v1.ListAutoscalersRequest;

                    /**
                     * Encodes the specified ListAutoscalersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListAutoscalersRequest.verify|verify} messages.
                     * @param message ListAutoscalersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListAutoscalersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAutoscalersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListAutoscalersRequest.verify|verify} messages.
                     * @param message ListAutoscalersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListAutoscalersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAutoscalersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAutoscalersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListAutoscalersRequest;

                    /**
                     * Decodes a ListAutoscalersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAutoscalersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListAutoscalersRequest;

                    /**
                     * Verifies a ListAutoscalersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAutoscalersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAutoscalersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListAutoscalersRequest;

                    /**
                     * Creates a plain object from a ListAutoscalersRequest message. Also converts values to other types if specified.
                     * @param message ListAutoscalersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListAutoscalersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAutoscalersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAutoscalersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAvailableFeaturesRegionSslPoliciesRequest. */
                interface IListAvailableFeaturesRegionSslPoliciesRequest {

                    /** ListAvailableFeaturesRegionSslPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest project */
                    project?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest region */
                    region?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListAvailableFeaturesRegionSslPoliciesRequest. */
                class ListAvailableFeaturesRegionSslPoliciesRequest implements IListAvailableFeaturesRegionSslPoliciesRequest {

                    /**
                     * Constructs a new ListAvailableFeaturesRegionSslPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListAvailableFeaturesRegionSslPoliciesRequest);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest project. */
                    public project: string;

                    /** ListAvailableFeaturesRegionSslPoliciesRequest region. */
                    public region: string;

                    /** ListAvailableFeaturesRegionSslPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListAvailableFeaturesRegionSslPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListAvailableFeaturesRegionSslPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListAvailableFeaturesRegionSslPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListAvailableFeaturesRegionSslPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListAvailableFeaturesRegionSslPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListAvailableFeaturesRegionSslPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAvailableFeaturesRegionSslPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListAvailableFeaturesRegionSslPoliciesRequest): google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest;

                    /**
                     * Encodes the specified ListAvailableFeaturesRegionSslPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest.verify|verify} messages.
                     * @param message ListAvailableFeaturesRegionSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListAvailableFeaturesRegionSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAvailableFeaturesRegionSslPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest.verify|verify} messages.
                     * @param message ListAvailableFeaturesRegionSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListAvailableFeaturesRegionSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAvailableFeaturesRegionSslPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAvailableFeaturesRegionSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest;

                    /**
                     * Decodes a ListAvailableFeaturesRegionSslPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAvailableFeaturesRegionSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest;

                    /**
                     * Verifies a ListAvailableFeaturesRegionSslPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAvailableFeaturesRegionSslPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAvailableFeaturesRegionSslPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest;

                    /**
                     * Creates a plain object from a ListAvailableFeaturesRegionSslPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListAvailableFeaturesRegionSslPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListAvailableFeaturesRegionSslPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAvailableFeaturesRegionSslPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAvailableFeaturesRegionSslPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAvailableFeaturesSslPoliciesRequest. */
                interface IListAvailableFeaturesSslPoliciesRequest {

                    /** ListAvailableFeaturesSslPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListAvailableFeaturesSslPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest project */
                    project?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListAvailableFeaturesSslPoliciesRequest. */
                class ListAvailableFeaturesSslPoliciesRequest implements IListAvailableFeaturesSslPoliciesRequest {

                    /**
                     * Constructs a new ListAvailableFeaturesSslPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListAvailableFeaturesSslPoliciesRequest);

                    /** ListAvailableFeaturesSslPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListAvailableFeaturesSslPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListAvailableFeaturesSslPoliciesRequest project. */
                    public project: string;

                    /** ListAvailableFeaturesSslPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListAvailableFeaturesSslPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListAvailableFeaturesSslPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListAvailableFeaturesSslPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListAvailableFeaturesSslPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListAvailableFeaturesSslPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListAvailableFeaturesSslPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAvailableFeaturesSslPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListAvailableFeaturesSslPoliciesRequest): google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest;

                    /**
                     * Encodes the specified ListAvailableFeaturesSslPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest.verify|verify} messages.
                     * @param message ListAvailableFeaturesSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListAvailableFeaturesSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAvailableFeaturesSslPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest.verify|verify} messages.
                     * @param message ListAvailableFeaturesSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListAvailableFeaturesSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAvailableFeaturesSslPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAvailableFeaturesSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest;

                    /**
                     * Decodes a ListAvailableFeaturesSslPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAvailableFeaturesSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest;

                    /**
                     * Verifies a ListAvailableFeaturesSslPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAvailableFeaturesSslPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAvailableFeaturesSslPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest;

                    /**
                     * Creates a plain object from a ListAvailableFeaturesSslPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListAvailableFeaturesSslPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListAvailableFeaturesSslPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAvailableFeaturesSslPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAvailableFeaturesSslPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListBackendBucketsRequest. */
                interface IListBackendBucketsRequest {

                    /** ListBackendBucketsRequest filter */
                    filter?: (string|null);

                    /** ListBackendBucketsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListBackendBucketsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListBackendBucketsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListBackendBucketsRequest project */
                    project?: (string|null);

                    /** ListBackendBucketsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListBackendBucketsRequest. */
                class ListBackendBucketsRequest implements IListBackendBucketsRequest {

                    /**
                     * Constructs a new ListBackendBucketsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListBackendBucketsRequest);

                    /** ListBackendBucketsRequest filter. */
                    public filter?: (string|null);

                    /** ListBackendBucketsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListBackendBucketsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListBackendBucketsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListBackendBucketsRequest project. */
                    public project: string;

                    /** ListBackendBucketsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListBackendBucketsRequest _filter. */
                    public _filter?: "filter";

                    /** ListBackendBucketsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListBackendBucketsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListBackendBucketsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListBackendBucketsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListBackendBucketsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListBackendBucketsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListBackendBucketsRequest): google.cloud.compute.v1.ListBackendBucketsRequest;

                    /**
                     * Encodes the specified ListBackendBucketsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListBackendBucketsRequest.verify|verify} messages.
                     * @param message ListBackendBucketsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListBackendBucketsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListBackendBucketsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListBackendBucketsRequest.verify|verify} messages.
                     * @param message ListBackendBucketsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListBackendBucketsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListBackendBucketsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListBackendBucketsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListBackendBucketsRequest;

                    /**
                     * Decodes a ListBackendBucketsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListBackendBucketsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListBackendBucketsRequest;

                    /**
                     * Verifies a ListBackendBucketsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListBackendBucketsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListBackendBucketsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListBackendBucketsRequest;

                    /**
                     * Creates a plain object from a ListBackendBucketsRequest message. Also converts values to other types if specified.
                     * @param message ListBackendBucketsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListBackendBucketsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListBackendBucketsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListBackendBucketsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListBackendServicesRequest. */
                interface IListBackendServicesRequest {

                    /** ListBackendServicesRequest filter */
                    filter?: (string|null);

                    /** ListBackendServicesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListBackendServicesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListBackendServicesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListBackendServicesRequest project */
                    project?: (string|null);

                    /** ListBackendServicesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListBackendServicesRequest. */
                class ListBackendServicesRequest implements IListBackendServicesRequest {

                    /**
                     * Constructs a new ListBackendServicesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListBackendServicesRequest);

                    /** ListBackendServicesRequest filter. */
                    public filter?: (string|null);

                    /** ListBackendServicesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListBackendServicesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListBackendServicesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListBackendServicesRequest project. */
                    public project: string;

                    /** ListBackendServicesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListBackendServicesRequest _filter. */
                    public _filter?: "filter";

                    /** ListBackendServicesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListBackendServicesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListBackendServicesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListBackendServicesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListBackendServicesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListBackendServicesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListBackendServicesRequest): google.cloud.compute.v1.ListBackendServicesRequest;

                    /**
                     * Encodes the specified ListBackendServicesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListBackendServicesRequest.verify|verify} messages.
                     * @param message ListBackendServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListBackendServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListBackendServicesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListBackendServicesRequest.verify|verify} messages.
                     * @param message ListBackendServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListBackendServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListBackendServicesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListBackendServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListBackendServicesRequest;

                    /**
                     * Decodes a ListBackendServicesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListBackendServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListBackendServicesRequest;

                    /**
                     * Verifies a ListBackendServicesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListBackendServicesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListBackendServicesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListBackendServicesRequest;

                    /**
                     * Creates a plain object from a ListBackendServicesRequest message. Also converts values to other types if specified.
                     * @param message ListBackendServicesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListBackendServicesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListBackendServicesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListBackendServicesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListDiskTypesRequest. */
                interface IListDiskTypesRequest {

                    /** ListDiskTypesRequest filter */
                    filter?: (string|null);

                    /** ListDiskTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListDiskTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListDiskTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListDiskTypesRequest project */
                    project?: (string|null);

                    /** ListDiskTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListDiskTypesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListDiskTypesRequest. */
                class ListDiskTypesRequest implements IListDiskTypesRequest {

                    /**
                     * Constructs a new ListDiskTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListDiskTypesRequest);

                    /** ListDiskTypesRequest filter. */
                    public filter?: (string|null);

                    /** ListDiskTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListDiskTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListDiskTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListDiskTypesRequest project. */
                    public project: string;

                    /** ListDiskTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListDiskTypesRequest zone. */
                    public zone: string;

                    /** ListDiskTypesRequest _filter. */
                    public _filter?: "filter";

                    /** ListDiskTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListDiskTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListDiskTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListDiskTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListDiskTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListDiskTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListDiskTypesRequest): google.cloud.compute.v1.ListDiskTypesRequest;

                    /**
                     * Encodes the specified ListDiskTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListDiskTypesRequest.verify|verify} messages.
                     * @param message ListDiskTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListDiskTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListDiskTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListDiskTypesRequest.verify|verify} messages.
                     * @param message ListDiskTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListDiskTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListDiskTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListDiskTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListDiskTypesRequest;

                    /**
                     * Decodes a ListDiskTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListDiskTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListDiskTypesRequest;

                    /**
                     * Verifies a ListDiskTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListDiskTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListDiskTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListDiskTypesRequest;

                    /**
                     * Creates a plain object from a ListDiskTypesRequest message. Also converts values to other types if specified.
                     * @param message ListDiskTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListDiskTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListDiskTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListDiskTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListDisksRequest. */
                interface IListDisksRequest {

                    /** ListDisksRequest filter */
                    filter?: (string|null);

                    /** ListDisksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListDisksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListDisksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListDisksRequest project */
                    project?: (string|null);

                    /** ListDisksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListDisksRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListDisksRequest. */
                class ListDisksRequest implements IListDisksRequest {

                    /**
                     * Constructs a new ListDisksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListDisksRequest);

                    /** ListDisksRequest filter. */
                    public filter?: (string|null);

                    /** ListDisksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListDisksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListDisksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListDisksRequest project. */
                    public project: string;

                    /** ListDisksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListDisksRequest zone. */
                    public zone: string;

                    /** ListDisksRequest _filter. */
                    public _filter?: "filter";

                    /** ListDisksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListDisksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListDisksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListDisksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListDisksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListDisksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListDisksRequest): google.cloud.compute.v1.ListDisksRequest;

                    /**
                     * Encodes the specified ListDisksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListDisksRequest.verify|verify} messages.
                     * @param message ListDisksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListDisksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListDisksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListDisksRequest.verify|verify} messages.
                     * @param message ListDisksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListDisksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListDisksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListDisksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListDisksRequest;

                    /**
                     * Decodes a ListDisksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListDisksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListDisksRequest;

                    /**
                     * Verifies a ListDisksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListDisksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListDisksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListDisksRequest;

                    /**
                     * Creates a plain object from a ListDisksRequest message. Also converts values to other types if specified.
                     * @param message ListDisksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListDisksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListDisksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListDisksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListErrorsInstanceGroupManagersRequest. */
                interface IListErrorsInstanceGroupManagersRequest {

                    /** ListErrorsInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListErrorsInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListErrorsInstanceGroupManagersRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListErrorsInstanceGroupManagersRequest. */
                class ListErrorsInstanceGroupManagersRequest implements IListErrorsInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListErrorsInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest);

                    /** ListErrorsInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ListErrorsInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListErrorsInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListErrorsInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListErrorsInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListErrorsInstanceGroupManagersRequest zone. */
                    public zone: string;

                    /** ListErrorsInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListErrorsInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListErrorsInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListErrorsInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListErrorsInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListErrorsInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListErrorsInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest): google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListErrorsInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListErrorsInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListErrorsInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListErrorsInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListErrorsInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListErrorsInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListErrorsInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListErrorsInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListErrorsInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListErrorsInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListErrorsInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListErrorsInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListErrorsInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListErrorsInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListErrorsInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListErrorsInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListErrorsRegionInstanceGroupManagersRequest. */
                interface IListErrorsRegionInstanceGroupManagersRequest {

                    /** ListErrorsRegionInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest region */
                    region?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListErrorsRegionInstanceGroupManagersRequest. */
                class ListErrorsRegionInstanceGroupManagersRequest implements IListErrorsRegionInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListErrorsRegionInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest);

                    /** ListErrorsRegionInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ListErrorsRegionInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListErrorsRegionInstanceGroupManagersRequest region. */
                    public region: string;

                    /** ListErrorsRegionInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListErrorsRegionInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListErrorsRegionInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListErrorsRegionInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListErrorsRegionInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListErrorsRegionInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListErrorsRegionInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListErrorsRegionInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest): google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListErrorsRegionInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListErrorsRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListErrorsRegionInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListErrorsRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListErrorsRegionInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListErrorsRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListErrorsRegionInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListErrorsRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListErrorsRegionInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListErrorsRegionInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListErrorsRegionInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListErrorsRegionInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListErrorsRegionInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListErrorsRegionInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListErrorsRegionInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListErrorsRegionInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListExternalVpnGatewaysRequest. */
                interface IListExternalVpnGatewaysRequest {

                    /** ListExternalVpnGatewaysRequest filter */
                    filter?: (string|null);

                    /** ListExternalVpnGatewaysRequest maxResults */
                    maxResults?: (number|null);

                    /** ListExternalVpnGatewaysRequest orderBy */
                    orderBy?: (string|null);

                    /** ListExternalVpnGatewaysRequest pageToken */
                    pageToken?: (string|null);

                    /** ListExternalVpnGatewaysRequest project */
                    project?: (string|null);

                    /** ListExternalVpnGatewaysRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListExternalVpnGatewaysRequest. */
                class ListExternalVpnGatewaysRequest implements IListExternalVpnGatewaysRequest {

                    /**
                     * Constructs a new ListExternalVpnGatewaysRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListExternalVpnGatewaysRequest);

                    /** ListExternalVpnGatewaysRequest filter. */
                    public filter?: (string|null);

                    /** ListExternalVpnGatewaysRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListExternalVpnGatewaysRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListExternalVpnGatewaysRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListExternalVpnGatewaysRequest project. */
                    public project: string;

                    /** ListExternalVpnGatewaysRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListExternalVpnGatewaysRequest _filter. */
                    public _filter?: "filter";

                    /** ListExternalVpnGatewaysRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListExternalVpnGatewaysRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListExternalVpnGatewaysRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListExternalVpnGatewaysRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListExternalVpnGatewaysRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListExternalVpnGatewaysRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListExternalVpnGatewaysRequest): google.cloud.compute.v1.ListExternalVpnGatewaysRequest;

                    /**
                     * Encodes the specified ListExternalVpnGatewaysRequest message. Does not implicitly {@link google.cloud.compute.v1.ListExternalVpnGatewaysRequest.verify|verify} messages.
                     * @param message ListExternalVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListExternalVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListExternalVpnGatewaysRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListExternalVpnGatewaysRequest.verify|verify} messages.
                     * @param message ListExternalVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListExternalVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListExternalVpnGatewaysRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListExternalVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListExternalVpnGatewaysRequest;

                    /**
                     * Decodes a ListExternalVpnGatewaysRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListExternalVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListExternalVpnGatewaysRequest;

                    /**
                     * Verifies a ListExternalVpnGatewaysRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListExternalVpnGatewaysRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListExternalVpnGatewaysRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListExternalVpnGatewaysRequest;

                    /**
                     * Creates a plain object from a ListExternalVpnGatewaysRequest message. Also converts values to other types if specified.
                     * @param message ListExternalVpnGatewaysRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListExternalVpnGatewaysRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListExternalVpnGatewaysRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListExternalVpnGatewaysRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListFirewallPoliciesRequest. */
                interface IListFirewallPoliciesRequest {

                    /** ListFirewallPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListFirewallPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListFirewallPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListFirewallPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListFirewallPoliciesRequest parentId */
                    parentId?: (string|null);

                    /** ListFirewallPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListFirewallPoliciesRequest. */
                class ListFirewallPoliciesRequest implements IListFirewallPoliciesRequest {

                    /**
                     * Constructs a new ListFirewallPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListFirewallPoliciesRequest);

                    /** ListFirewallPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListFirewallPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListFirewallPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListFirewallPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListFirewallPoliciesRequest parentId. */
                    public parentId?: (string|null);

                    /** ListFirewallPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListFirewallPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListFirewallPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListFirewallPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListFirewallPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListFirewallPoliciesRequest _parentId. */
                    public _parentId?: "parentId";

                    /** ListFirewallPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListFirewallPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListFirewallPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListFirewallPoliciesRequest): google.cloud.compute.v1.ListFirewallPoliciesRequest;

                    /**
                     * Encodes the specified ListFirewallPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListFirewallPoliciesRequest.verify|verify} messages.
                     * @param message ListFirewallPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListFirewallPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListFirewallPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListFirewallPoliciesRequest.verify|verify} messages.
                     * @param message ListFirewallPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListFirewallPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListFirewallPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListFirewallPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListFirewallPoliciesRequest;

                    /**
                     * Decodes a ListFirewallPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListFirewallPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListFirewallPoliciesRequest;

                    /**
                     * Verifies a ListFirewallPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListFirewallPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListFirewallPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListFirewallPoliciesRequest;

                    /**
                     * Creates a plain object from a ListFirewallPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListFirewallPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListFirewallPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListFirewallPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListFirewallPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListFirewallsRequest. */
                interface IListFirewallsRequest {

                    /** ListFirewallsRequest filter */
                    filter?: (string|null);

                    /** ListFirewallsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListFirewallsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListFirewallsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListFirewallsRequest project */
                    project?: (string|null);

                    /** ListFirewallsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListFirewallsRequest. */
                class ListFirewallsRequest implements IListFirewallsRequest {

                    /**
                     * Constructs a new ListFirewallsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListFirewallsRequest);

                    /** ListFirewallsRequest filter. */
                    public filter?: (string|null);

                    /** ListFirewallsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListFirewallsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListFirewallsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListFirewallsRequest project. */
                    public project: string;

                    /** ListFirewallsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListFirewallsRequest _filter. */
                    public _filter?: "filter";

                    /** ListFirewallsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListFirewallsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListFirewallsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListFirewallsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListFirewallsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListFirewallsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListFirewallsRequest): google.cloud.compute.v1.ListFirewallsRequest;

                    /**
                     * Encodes the specified ListFirewallsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListFirewallsRequest.verify|verify} messages.
                     * @param message ListFirewallsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListFirewallsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListFirewallsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListFirewallsRequest.verify|verify} messages.
                     * @param message ListFirewallsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListFirewallsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListFirewallsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListFirewallsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListFirewallsRequest;

                    /**
                     * Decodes a ListFirewallsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListFirewallsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListFirewallsRequest;

                    /**
                     * Verifies a ListFirewallsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListFirewallsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListFirewallsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListFirewallsRequest;

                    /**
                     * Creates a plain object from a ListFirewallsRequest message. Also converts values to other types if specified.
                     * @param message ListFirewallsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListFirewallsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListFirewallsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListFirewallsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListForwardingRulesRequest. */
                interface IListForwardingRulesRequest {

                    /** ListForwardingRulesRequest filter */
                    filter?: (string|null);

                    /** ListForwardingRulesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListForwardingRulesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListForwardingRulesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListForwardingRulesRequest project */
                    project?: (string|null);

                    /** ListForwardingRulesRequest region */
                    region?: (string|null);

                    /** ListForwardingRulesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListForwardingRulesRequest. */
                class ListForwardingRulesRequest implements IListForwardingRulesRequest {

                    /**
                     * Constructs a new ListForwardingRulesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListForwardingRulesRequest);

                    /** ListForwardingRulesRequest filter. */
                    public filter?: (string|null);

                    /** ListForwardingRulesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListForwardingRulesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListForwardingRulesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListForwardingRulesRequest project. */
                    public project: string;

                    /** ListForwardingRulesRequest region. */
                    public region: string;

                    /** ListForwardingRulesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListForwardingRulesRequest _filter. */
                    public _filter?: "filter";

                    /** ListForwardingRulesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListForwardingRulesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListForwardingRulesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListForwardingRulesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListForwardingRulesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListForwardingRulesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListForwardingRulesRequest): google.cloud.compute.v1.ListForwardingRulesRequest;

                    /**
                     * Encodes the specified ListForwardingRulesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListForwardingRulesRequest.verify|verify} messages.
                     * @param message ListForwardingRulesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListForwardingRulesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListForwardingRulesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListForwardingRulesRequest.verify|verify} messages.
                     * @param message ListForwardingRulesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListForwardingRulesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListForwardingRulesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListForwardingRulesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListForwardingRulesRequest;

                    /**
                     * Decodes a ListForwardingRulesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListForwardingRulesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListForwardingRulesRequest;

                    /**
                     * Verifies a ListForwardingRulesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListForwardingRulesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListForwardingRulesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListForwardingRulesRequest;

                    /**
                     * Creates a plain object from a ListForwardingRulesRequest message. Also converts values to other types if specified.
                     * @param message ListForwardingRulesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListForwardingRulesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListForwardingRulesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListForwardingRulesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListGlobalAddressesRequest. */
                interface IListGlobalAddressesRequest {

                    /** ListGlobalAddressesRequest filter */
                    filter?: (string|null);

                    /** ListGlobalAddressesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListGlobalAddressesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListGlobalAddressesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListGlobalAddressesRequest project */
                    project?: (string|null);

                    /** ListGlobalAddressesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListGlobalAddressesRequest. */
                class ListGlobalAddressesRequest implements IListGlobalAddressesRequest {

                    /**
                     * Constructs a new ListGlobalAddressesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListGlobalAddressesRequest);

                    /** ListGlobalAddressesRequest filter. */
                    public filter?: (string|null);

                    /** ListGlobalAddressesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListGlobalAddressesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListGlobalAddressesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListGlobalAddressesRequest project. */
                    public project: string;

                    /** ListGlobalAddressesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListGlobalAddressesRequest _filter. */
                    public _filter?: "filter";

                    /** ListGlobalAddressesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListGlobalAddressesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListGlobalAddressesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListGlobalAddressesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListGlobalAddressesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListGlobalAddressesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListGlobalAddressesRequest): google.cloud.compute.v1.ListGlobalAddressesRequest;

                    /**
                     * Encodes the specified ListGlobalAddressesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListGlobalAddressesRequest.verify|verify} messages.
                     * @param message ListGlobalAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListGlobalAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListGlobalAddressesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListGlobalAddressesRequest.verify|verify} messages.
                     * @param message ListGlobalAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListGlobalAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListGlobalAddressesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListGlobalAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListGlobalAddressesRequest;

                    /**
                     * Decodes a ListGlobalAddressesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListGlobalAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListGlobalAddressesRequest;

                    /**
                     * Verifies a ListGlobalAddressesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListGlobalAddressesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListGlobalAddressesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListGlobalAddressesRequest;

                    /**
                     * Creates a plain object from a ListGlobalAddressesRequest message. Also converts values to other types if specified.
                     * @param message ListGlobalAddressesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListGlobalAddressesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListGlobalAddressesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListGlobalAddressesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListGlobalForwardingRulesRequest. */
                interface IListGlobalForwardingRulesRequest {

                    /** ListGlobalForwardingRulesRequest filter */
                    filter?: (string|null);

                    /** ListGlobalForwardingRulesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListGlobalForwardingRulesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListGlobalForwardingRulesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListGlobalForwardingRulesRequest project */
                    project?: (string|null);

                    /** ListGlobalForwardingRulesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListGlobalForwardingRulesRequest. */
                class ListGlobalForwardingRulesRequest implements IListGlobalForwardingRulesRequest {

                    /**
                     * Constructs a new ListGlobalForwardingRulesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListGlobalForwardingRulesRequest);

                    /** ListGlobalForwardingRulesRequest filter. */
                    public filter?: (string|null);

                    /** ListGlobalForwardingRulesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListGlobalForwardingRulesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListGlobalForwardingRulesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListGlobalForwardingRulesRequest project. */
                    public project: string;

                    /** ListGlobalForwardingRulesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListGlobalForwardingRulesRequest _filter. */
                    public _filter?: "filter";

                    /** ListGlobalForwardingRulesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListGlobalForwardingRulesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListGlobalForwardingRulesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListGlobalForwardingRulesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListGlobalForwardingRulesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListGlobalForwardingRulesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListGlobalForwardingRulesRequest): google.cloud.compute.v1.ListGlobalForwardingRulesRequest;

                    /**
                     * Encodes the specified ListGlobalForwardingRulesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListGlobalForwardingRulesRequest.verify|verify} messages.
                     * @param message ListGlobalForwardingRulesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListGlobalForwardingRulesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListGlobalForwardingRulesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListGlobalForwardingRulesRequest.verify|verify} messages.
                     * @param message ListGlobalForwardingRulesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListGlobalForwardingRulesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListGlobalForwardingRulesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListGlobalForwardingRulesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListGlobalForwardingRulesRequest;

                    /**
                     * Decodes a ListGlobalForwardingRulesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListGlobalForwardingRulesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListGlobalForwardingRulesRequest;

                    /**
                     * Verifies a ListGlobalForwardingRulesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListGlobalForwardingRulesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListGlobalForwardingRulesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListGlobalForwardingRulesRequest;

                    /**
                     * Creates a plain object from a ListGlobalForwardingRulesRequest message. Also converts values to other types if specified.
                     * @param message ListGlobalForwardingRulesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListGlobalForwardingRulesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListGlobalForwardingRulesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListGlobalForwardingRulesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListGlobalNetworkEndpointGroupsRequest. */
                interface IListGlobalNetworkEndpointGroupsRequest {

                    /** ListGlobalNetworkEndpointGroupsRequest filter */
                    filter?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListGlobalNetworkEndpointGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest project */
                    project?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListGlobalNetworkEndpointGroupsRequest. */
                class ListGlobalNetworkEndpointGroupsRequest implements IListGlobalNetworkEndpointGroupsRequest {

                    /**
                     * Constructs a new ListGlobalNetworkEndpointGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest);

                    /** ListGlobalNetworkEndpointGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListGlobalNetworkEndpointGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListGlobalNetworkEndpointGroupsRequest project. */
                    public project: string;

                    /** ListGlobalNetworkEndpointGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListGlobalNetworkEndpointGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListGlobalNetworkEndpointGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListGlobalNetworkEndpointGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListGlobalNetworkEndpointGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListGlobalNetworkEndpointGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListGlobalNetworkEndpointGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListGlobalNetworkEndpointGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest): google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Encodes the specified ListGlobalNetworkEndpointGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListGlobalNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListGlobalNetworkEndpointGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListGlobalNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListGlobalNetworkEndpointGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListGlobalNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Decodes a ListGlobalNetworkEndpointGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListGlobalNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Verifies a ListGlobalNetworkEndpointGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListGlobalNetworkEndpointGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListGlobalNetworkEndpointGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Creates a plain object from a ListGlobalNetworkEndpointGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListGlobalNetworkEndpointGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListGlobalNetworkEndpointGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListGlobalNetworkEndpointGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListGlobalNetworkEndpointGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListGlobalOperationsRequest. */
                interface IListGlobalOperationsRequest {

                    /** ListGlobalOperationsRequest filter */
                    filter?: (string|null);

                    /** ListGlobalOperationsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListGlobalOperationsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListGlobalOperationsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListGlobalOperationsRequest project */
                    project?: (string|null);

                    /** ListGlobalOperationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListGlobalOperationsRequest. */
                class ListGlobalOperationsRequest implements IListGlobalOperationsRequest {

                    /**
                     * Constructs a new ListGlobalOperationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListGlobalOperationsRequest);

                    /** ListGlobalOperationsRequest filter. */
                    public filter?: (string|null);

                    /** ListGlobalOperationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListGlobalOperationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListGlobalOperationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListGlobalOperationsRequest project. */
                    public project: string;

                    /** ListGlobalOperationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListGlobalOperationsRequest _filter. */
                    public _filter?: "filter";

                    /** ListGlobalOperationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListGlobalOperationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListGlobalOperationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListGlobalOperationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListGlobalOperationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListGlobalOperationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListGlobalOperationsRequest): google.cloud.compute.v1.ListGlobalOperationsRequest;

                    /**
                     * Encodes the specified ListGlobalOperationsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListGlobalOperationsRequest.verify|verify} messages.
                     * @param message ListGlobalOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListGlobalOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListGlobalOperationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListGlobalOperationsRequest.verify|verify} messages.
                     * @param message ListGlobalOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListGlobalOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListGlobalOperationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListGlobalOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListGlobalOperationsRequest;

                    /**
                     * Decodes a ListGlobalOperationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListGlobalOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListGlobalOperationsRequest;

                    /**
                     * Verifies a ListGlobalOperationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListGlobalOperationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListGlobalOperationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListGlobalOperationsRequest;

                    /**
                     * Creates a plain object from a ListGlobalOperationsRequest message. Also converts values to other types if specified.
                     * @param message ListGlobalOperationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListGlobalOperationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListGlobalOperationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListGlobalOperationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListGlobalOrganizationOperationsRequest. */
                interface IListGlobalOrganizationOperationsRequest {

                    /** ListGlobalOrganizationOperationsRequest filter */
                    filter?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListGlobalOrganizationOperationsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest parentId */
                    parentId?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListGlobalOrganizationOperationsRequest. */
                class ListGlobalOrganizationOperationsRequest implements IListGlobalOrganizationOperationsRequest {

                    /**
                     * Constructs a new ListGlobalOrganizationOperationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListGlobalOrganizationOperationsRequest);

                    /** ListGlobalOrganizationOperationsRequest filter. */
                    public filter?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListGlobalOrganizationOperationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest parentId. */
                    public parentId?: (string|null);

                    /** ListGlobalOrganizationOperationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListGlobalOrganizationOperationsRequest _filter. */
                    public _filter?: "filter";

                    /** ListGlobalOrganizationOperationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListGlobalOrganizationOperationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListGlobalOrganizationOperationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListGlobalOrganizationOperationsRequest _parentId. */
                    public _parentId?: "parentId";

                    /** ListGlobalOrganizationOperationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListGlobalOrganizationOperationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListGlobalOrganizationOperationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListGlobalOrganizationOperationsRequest): google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest;

                    /**
                     * Encodes the specified ListGlobalOrganizationOperationsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest.verify|verify} messages.
                     * @param message ListGlobalOrganizationOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListGlobalOrganizationOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListGlobalOrganizationOperationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest.verify|verify} messages.
                     * @param message ListGlobalOrganizationOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListGlobalOrganizationOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListGlobalOrganizationOperationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListGlobalOrganizationOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest;

                    /**
                     * Decodes a ListGlobalOrganizationOperationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListGlobalOrganizationOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest;

                    /**
                     * Verifies a ListGlobalOrganizationOperationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListGlobalOrganizationOperationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListGlobalOrganizationOperationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest;

                    /**
                     * Creates a plain object from a ListGlobalOrganizationOperationsRequest message. Also converts values to other types if specified.
                     * @param message ListGlobalOrganizationOperationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListGlobalOrganizationOperationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListGlobalOrganizationOperationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListGlobalOrganizationOperationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListGlobalPublicDelegatedPrefixesRequest. */
                interface IListGlobalPublicDelegatedPrefixesRequest {

                    /** ListGlobalPublicDelegatedPrefixesRequest filter */
                    filter?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest project */
                    project?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListGlobalPublicDelegatedPrefixesRequest. */
                class ListGlobalPublicDelegatedPrefixesRequest implements IListGlobalPublicDelegatedPrefixesRequest {

                    /**
                     * Constructs a new ListGlobalPublicDelegatedPrefixesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListGlobalPublicDelegatedPrefixesRequest);

                    /** ListGlobalPublicDelegatedPrefixesRequest filter. */
                    public filter?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest project. */
                    public project: string;

                    /** ListGlobalPublicDelegatedPrefixesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListGlobalPublicDelegatedPrefixesRequest _filter. */
                    public _filter?: "filter";

                    /** ListGlobalPublicDelegatedPrefixesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListGlobalPublicDelegatedPrefixesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListGlobalPublicDelegatedPrefixesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListGlobalPublicDelegatedPrefixesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListGlobalPublicDelegatedPrefixesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListGlobalPublicDelegatedPrefixesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListGlobalPublicDelegatedPrefixesRequest): google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest;

                    /**
                     * Encodes the specified ListGlobalPublicDelegatedPrefixesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest.verify|verify} messages.
                     * @param message ListGlobalPublicDelegatedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListGlobalPublicDelegatedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListGlobalPublicDelegatedPrefixesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest.verify|verify} messages.
                     * @param message ListGlobalPublicDelegatedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListGlobalPublicDelegatedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListGlobalPublicDelegatedPrefixesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListGlobalPublicDelegatedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest;

                    /**
                     * Decodes a ListGlobalPublicDelegatedPrefixesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListGlobalPublicDelegatedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest;

                    /**
                     * Verifies a ListGlobalPublicDelegatedPrefixesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListGlobalPublicDelegatedPrefixesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListGlobalPublicDelegatedPrefixesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest;

                    /**
                     * Creates a plain object from a ListGlobalPublicDelegatedPrefixesRequest message. Also converts values to other types if specified.
                     * @param message ListGlobalPublicDelegatedPrefixesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListGlobalPublicDelegatedPrefixesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListGlobalPublicDelegatedPrefixesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListGlobalPublicDelegatedPrefixesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListHealthChecksRequest. */
                interface IListHealthChecksRequest {

                    /** ListHealthChecksRequest filter */
                    filter?: (string|null);

                    /** ListHealthChecksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListHealthChecksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListHealthChecksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListHealthChecksRequest project */
                    project?: (string|null);

                    /** ListHealthChecksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListHealthChecksRequest. */
                class ListHealthChecksRequest implements IListHealthChecksRequest {

                    /**
                     * Constructs a new ListHealthChecksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListHealthChecksRequest);

                    /** ListHealthChecksRequest filter. */
                    public filter?: (string|null);

                    /** ListHealthChecksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListHealthChecksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListHealthChecksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListHealthChecksRequest project. */
                    public project: string;

                    /** ListHealthChecksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListHealthChecksRequest _filter. */
                    public _filter?: "filter";

                    /** ListHealthChecksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListHealthChecksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListHealthChecksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListHealthChecksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListHealthChecksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListHealthChecksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListHealthChecksRequest): google.cloud.compute.v1.ListHealthChecksRequest;

                    /**
                     * Encodes the specified ListHealthChecksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListHealthChecksRequest.verify|verify} messages.
                     * @param message ListHealthChecksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListHealthChecksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListHealthChecksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListHealthChecksRequest.verify|verify} messages.
                     * @param message ListHealthChecksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListHealthChecksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListHealthChecksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListHealthChecksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListHealthChecksRequest;

                    /**
                     * Decodes a ListHealthChecksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListHealthChecksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListHealthChecksRequest;

                    /**
                     * Verifies a ListHealthChecksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListHealthChecksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListHealthChecksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListHealthChecksRequest;

                    /**
                     * Creates a plain object from a ListHealthChecksRequest message. Also converts values to other types if specified.
                     * @param message ListHealthChecksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListHealthChecksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListHealthChecksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListHealthChecksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListImagesRequest. */
                interface IListImagesRequest {

                    /** ListImagesRequest filter */
                    filter?: (string|null);

                    /** ListImagesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListImagesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListImagesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListImagesRequest project */
                    project?: (string|null);

                    /** ListImagesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListImagesRequest. */
                class ListImagesRequest implements IListImagesRequest {

                    /**
                     * Constructs a new ListImagesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListImagesRequest);

                    /** ListImagesRequest filter. */
                    public filter?: (string|null);

                    /** ListImagesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListImagesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListImagesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListImagesRequest project. */
                    public project: string;

                    /** ListImagesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListImagesRequest _filter. */
                    public _filter?: "filter";

                    /** ListImagesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListImagesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListImagesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListImagesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListImagesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListImagesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListImagesRequest): google.cloud.compute.v1.ListImagesRequest;

                    /**
                     * Encodes the specified ListImagesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListImagesRequest.verify|verify} messages.
                     * @param message ListImagesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListImagesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListImagesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListImagesRequest.verify|verify} messages.
                     * @param message ListImagesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListImagesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListImagesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListImagesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListImagesRequest;

                    /**
                     * Decodes a ListImagesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListImagesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListImagesRequest;

                    /**
                     * Verifies a ListImagesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListImagesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListImagesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListImagesRequest;

                    /**
                     * Creates a plain object from a ListImagesRequest message. Also converts values to other types if specified.
                     * @param message ListImagesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListImagesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListImagesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListImagesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInstanceGroupManagersRequest. */
                interface IListInstanceGroupManagersRequest {

                    /** ListInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListInstanceGroupManagersRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListInstanceGroupManagersRequest. */
                class ListInstanceGroupManagersRequest implements IListInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInstanceGroupManagersRequest);

                    /** ListInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInstanceGroupManagersRequest zone. */
                    public zone: string;

                    /** ListInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInstanceGroupManagersRequest): google.cloud.compute.v1.ListInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInstanceGroupsRequest. */
                interface IListInstanceGroupsRequest {

                    /** ListInstanceGroupsRequest filter */
                    filter?: (string|null);

                    /** ListInstanceGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInstanceGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInstanceGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInstanceGroupsRequest project */
                    project?: (string|null);

                    /** ListInstanceGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListInstanceGroupsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListInstanceGroupsRequest. */
                class ListInstanceGroupsRequest implements IListInstanceGroupsRequest {

                    /**
                     * Constructs a new ListInstanceGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInstanceGroupsRequest);

                    /** ListInstanceGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListInstanceGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInstanceGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInstanceGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInstanceGroupsRequest project. */
                    public project: string;

                    /** ListInstanceGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInstanceGroupsRequest zone. */
                    public zone: string;

                    /** ListInstanceGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListInstanceGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInstanceGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInstanceGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInstanceGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInstanceGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInstanceGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInstanceGroupsRequest): google.cloud.compute.v1.ListInstanceGroupsRequest;

                    /**
                     * Encodes the specified ListInstanceGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInstanceGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInstanceGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInstanceGroupsRequest;

                    /**
                     * Decodes a ListInstanceGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInstanceGroupsRequest;

                    /**
                     * Verifies a ListInstanceGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInstanceGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInstanceGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInstanceGroupsRequest;

                    /**
                     * Creates a plain object from a ListInstanceGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListInstanceGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInstanceGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInstanceGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInstanceGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInstanceTemplatesRequest. */
                interface IListInstanceTemplatesRequest {

                    /** ListInstanceTemplatesRequest filter */
                    filter?: (string|null);

                    /** ListInstanceTemplatesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInstanceTemplatesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInstanceTemplatesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInstanceTemplatesRequest project */
                    project?: (string|null);

                    /** ListInstanceTemplatesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListInstanceTemplatesRequest. */
                class ListInstanceTemplatesRequest implements IListInstanceTemplatesRequest {

                    /**
                     * Constructs a new ListInstanceTemplatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInstanceTemplatesRequest);

                    /** ListInstanceTemplatesRequest filter. */
                    public filter?: (string|null);

                    /** ListInstanceTemplatesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInstanceTemplatesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInstanceTemplatesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInstanceTemplatesRequest project. */
                    public project: string;

                    /** ListInstanceTemplatesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInstanceTemplatesRequest _filter. */
                    public _filter?: "filter";

                    /** ListInstanceTemplatesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInstanceTemplatesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInstanceTemplatesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInstanceTemplatesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInstanceTemplatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInstanceTemplatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInstanceTemplatesRequest): google.cloud.compute.v1.ListInstanceTemplatesRequest;

                    /**
                     * Encodes the specified ListInstanceTemplatesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInstanceTemplatesRequest.verify|verify} messages.
                     * @param message ListInstanceTemplatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInstanceTemplatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInstanceTemplatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInstanceTemplatesRequest.verify|verify} messages.
                     * @param message ListInstanceTemplatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInstanceTemplatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInstanceTemplatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInstanceTemplatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInstanceTemplatesRequest;

                    /**
                     * Decodes a ListInstanceTemplatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInstanceTemplatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInstanceTemplatesRequest;

                    /**
                     * Verifies a ListInstanceTemplatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInstanceTemplatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInstanceTemplatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInstanceTemplatesRequest;

                    /**
                     * Creates a plain object from a ListInstanceTemplatesRequest message. Also converts values to other types if specified.
                     * @param message ListInstanceTemplatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInstanceTemplatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInstanceTemplatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInstanceTemplatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInstancesInstanceGroupsRequest. */
                interface IListInstancesInstanceGroupsRequest {

                    /** ListInstancesInstanceGroupsRequest filter */
                    filter?: (string|null);

                    /** ListInstancesInstanceGroupsRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** ListInstancesInstanceGroupsRequest instanceGroupsListInstancesRequestResource */
                    instanceGroupsListInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupsListInstancesRequest|null);

                    /** ListInstancesInstanceGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInstancesInstanceGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInstancesInstanceGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInstancesInstanceGroupsRequest project */
                    project?: (string|null);

                    /** ListInstancesInstanceGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListInstancesInstanceGroupsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListInstancesInstanceGroupsRequest. */
                class ListInstancesInstanceGroupsRequest implements IListInstancesInstanceGroupsRequest {

                    /**
                     * Constructs a new ListInstancesInstanceGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInstancesInstanceGroupsRequest);

                    /** ListInstancesInstanceGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListInstancesInstanceGroupsRequest instanceGroup. */
                    public instanceGroup: string;

                    /** ListInstancesInstanceGroupsRequest instanceGroupsListInstancesRequestResource. */
                    public instanceGroupsListInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupsListInstancesRequest|null);

                    /** ListInstancesInstanceGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInstancesInstanceGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInstancesInstanceGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInstancesInstanceGroupsRequest project. */
                    public project: string;

                    /** ListInstancesInstanceGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInstancesInstanceGroupsRequest zone. */
                    public zone: string;

                    /** ListInstancesInstanceGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListInstancesInstanceGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInstancesInstanceGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInstancesInstanceGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInstancesInstanceGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInstancesInstanceGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInstancesInstanceGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInstancesInstanceGroupsRequest): google.cloud.compute.v1.ListInstancesInstanceGroupsRequest;

                    /**
                     * Encodes the specified ListInstancesInstanceGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInstancesInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListInstancesInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInstancesInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInstancesInstanceGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInstancesInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListInstancesInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInstancesInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInstancesInstanceGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInstancesInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInstancesInstanceGroupsRequest;

                    /**
                     * Decodes a ListInstancesInstanceGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInstancesInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInstancesInstanceGroupsRequest;

                    /**
                     * Verifies a ListInstancesInstanceGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInstancesInstanceGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInstancesInstanceGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInstancesInstanceGroupsRequest;

                    /**
                     * Creates a plain object from a ListInstancesInstanceGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListInstancesInstanceGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInstancesInstanceGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInstancesInstanceGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInstancesInstanceGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInstancesRegionInstanceGroupsRequest. */
                interface IListInstancesRegionInstanceGroupsRequest {

                    /** ListInstancesRegionInstanceGroupsRequest filter */
                    filter?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInstancesRegionInstanceGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest project */
                    project?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest region */
                    region?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest regionInstanceGroupsListInstancesRequestResource */
                    regionInstanceGroupsListInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupsListInstancesRequest|null);

                    /** ListInstancesRegionInstanceGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListInstancesRegionInstanceGroupsRequest. */
                class ListInstancesRegionInstanceGroupsRequest implements IListInstancesRegionInstanceGroupsRequest {

                    /**
                     * Constructs a new ListInstancesRegionInstanceGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInstancesRegionInstanceGroupsRequest);

                    /** ListInstancesRegionInstanceGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest instanceGroup. */
                    public instanceGroup: string;

                    /** ListInstancesRegionInstanceGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInstancesRegionInstanceGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInstancesRegionInstanceGroupsRequest project. */
                    public project: string;

                    /** ListInstancesRegionInstanceGroupsRequest region. */
                    public region: string;

                    /** ListInstancesRegionInstanceGroupsRequest regionInstanceGroupsListInstancesRequestResource. */
                    public regionInstanceGroupsListInstancesRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupsListInstancesRequest|null);

                    /** ListInstancesRegionInstanceGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInstancesRegionInstanceGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListInstancesRegionInstanceGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInstancesRegionInstanceGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInstancesRegionInstanceGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInstancesRegionInstanceGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInstancesRegionInstanceGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInstancesRegionInstanceGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInstancesRegionInstanceGroupsRequest): google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest;

                    /**
                     * Encodes the specified ListInstancesRegionInstanceGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListInstancesRegionInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInstancesRegionInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInstancesRegionInstanceGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListInstancesRegionInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInstancesRegionInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInstancesRegionInstanceGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInstancesRegionInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest;

                    /**
                     * Decodes a ListInstancesRegionInstanceGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInstancesRegionInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest;

                    /**
                     * Verifies a ListInstancesRegionInstanceGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInstancesRegionInstanceGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInstancesRegionInstanceGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest;

                    /**
                     * Creates a plain object from a ListInstancesRegionInstanceGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListInstancesRegionInstanceGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInstancesRegionInstanceGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInstancesRegionInstanceGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInstancesRegionInstanceGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInstancesRequest. */
                interface IListInstancesRequest {

                    /** ListInstancesRequest filter */
                    filter?: (string|null);

                    /** ListInstancesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInstancesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInstancesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInstancesRequest project */
                    project?: (string|null);

                    /** ListInstancesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListInstancesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListInstancesRequest. */
                class ListInstancesRequest implements IListInstancesRequest {

                    /**
                     * Constructs a new ListInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInstancesRequest);

                    /** ListInstancesRequest filter. */
                    public filter?: (string|null);

                    /** ListInstancesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInstancesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInstancesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInstancesRequest project. */
                    public project: string;

                    /** ListInstancesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInstancesRequest zone. */
                    public zone: string;

                    /** ListInstancesRequest _filter. */
                    public _filter?: "filter";

                    /** ListInstancesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInstancesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInstancesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInstancesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInstancesRequest): google.cloud.compute.v1.ListInstancesRequest;

                    /**
                     * Encodes the specified ListInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInstancesRequest.verify|verify} messages.
                     * @param message ListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInstancesRequest.verify|verify} messages.
                     * @param message ListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInstancesRequest;

                    /**
                     * Decodes a ListInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInstancesRequest;

                    /**
                     * Verifies a ListInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInstancesRequest;

                    /**
                     * Creates a plain object from a ListInstancesRequest message. Also converts values to other types if specified.
                     * @param message ListInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInterconnectAttachmentsRequest. */
                interface IListInterconnectAttachmentsRequest {

                    /** ListInterconnectAttachmentsRequest filter */
                    filter?: (string|null);

                    /** ListInterconnectAttachmentsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInterconnectAttachmentsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInterconnectAttachmentsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInterconnectAttachmentsRequest project */
                    project?: (string|null);

                    /** ListInterconnectAttachmentsRequest region */
                    region?: (string|null);

                    /** ListInterconnectAttachmentsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListInterconnectAttachmentsRequest. */
                class ListInterconnectAttachmentsRequest implements IListInterconnectAttachmentsRequest {

                    /**
                     * Constructs a new ListInterconnectAttachmentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInterconnectAttachmentsRequest);

                    /** ListInterconnectAttachmentsRequest filter. */
                    public filter?: (string|null);

                    /** ListInterconnectAttachmentsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInterconnectAttachmentsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInterconnectAttachmentsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInterconnectAttachmentsRequest project. */
                    public project: string;

                    /** ListInterconnectAttachmentsRequest region. */
                    public region: string;

                    /** ListInterconnectAttachmentsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInterconnectAttachmentsRequest _filter. */
                    public _filter?: "filter";

                    /** ListInterconnectAttachmentsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInterconnectAttachmentsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInterconnectAttachmentsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInterconnectAttachmentsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInterconnectAttachmentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInterconnectAttachmentsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInterconnectAttachmentsRequest): google.cloud.compute.v1.ListInterconnectAttachmentsRequest;

                    /**
                     * Encodes the specified ListInterconnectAttachmentsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInterconnectAttachmentsRequest.verify|verify} messages.
                     * @param message ListInterconnectAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInterconnectAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInterconnectAttachmentsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInterconnectAttachmentsRequest.verify|verify} messages.
                     * @param message ListInterconnectAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInterconnectAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInterconnectAttachmentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInterconnectAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInterconnectAttachmentsRequest;

                    /**
                     * Decodes a ListInterconnectAttachmentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInterconnectAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInterconnectAttachmentsRequest;

                    /**
                     * Verifies a ListInterconnectAttachmentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInterconnectAttachmentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInterconnectAttachmentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInterconnectAttachmentsRequest;

                    /**
                     * Creates a plain object from a ListInterconnectAttachmentsRequest message. Also converts values to other types if specified.
                     * @param message ListInterconnectAttachmentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInterconnectAttachmentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInterconnectAttachmentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInterconnectAttachmentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInterconnectLocationsRequest. */
                interface IListInterconnectLocationsRequest {

                    /** ListInterconnectLocationsRequest filter */
                    filter?: (string|null);

                    /** ListInterconnectLocationsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInterconnectLocationsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInterconnectLocationsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInterconnectLocationsRequest project */
                    project?: (string|null);

                    /** ListInterconnectLocationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListInterconnectLocationsRequest. */
                class ListInterconnectLocationsRequest implements IListInterconnectLocationsRequest {

                    /**
                     * Constructs a new ListInterconnectLocationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInterconnectLocationsRequest);

                    /** ListInterconnectLocationsRequest filter. */
                    public filter?: (string|null);

                    /** ListInterconnectLocationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInterconnectLocationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInterconnectLocationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInterconnectLocationsRequest project. */
                    public project: string;

                    /** ListInterconnectLocationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInterconnectLocationsRequest _filter. */
                    public _filter?: "filter";

                    /** ListInterconnectLocationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInterconnectLocationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInterconnectLocationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInterconnectLocationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInterconnectLocationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInterconnectLocationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInterconnectLocationsRequest): google.cloud.compute.v1.ListInterconnectLocationsRequest;

                    /**
                     * Encodes the specified ListInterconnectLocationsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInterconnectLocationsRequest.verify|verify} messages.
                     * @param message ListInterconnectLocationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInterconnectLocationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInterconnectLocationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInterconnectLocationsRequest.verify|verify} messages.
                     * @param message ListInterconnectLocationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInterconnectLocationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInterconnectLocationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInterconnectLocationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInterconnectLocationsRequest;

                    /**
                     * Decodes a ListInterconnectLocationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInterconnectLocationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInterconnectLocationsRequest;

                    /**
                     * Verifies a ListInterconnectLocationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInterconnectLocationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInterconnectLocationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInterconnectLocationsRequest;

                    /**
                     * Creates a plain object from a ListInterconnectLocationsRequest message. Also converts values to other types if specified.
                     * @param message ListInterconnectLocationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInterconnectLocationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInterconnectLocationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInterconnectLocationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListInterconnectsRequest. */
                interface IListInterconnectsRequest {

                    /** ListInterconnectsRequest filter */
                    filter?: (string|null);

                    /** ListInterconnectsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListInterconnectsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListInterconnectsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListInterconnectsRequest project */
                    project?: (string|null);

                    /** ListInterconnectsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListInterconnectsRequest. */
                class ListInterconnectsRequest implements IListInterconnectsRequest {

                    /**
                     * Constructs a new ListInterconnectsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListInterconnectsRequest);

                    /** ListInterconnectsRequest filter. */
                    public filter?: (string|null);

                    /** ListInterconnectsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListInterconnectsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListInterconnectsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListInterconnectsRequest project. */
                    public project: string;

                    /** ListInterconnectsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListInterconnectsRequest _filter. */
                    public _filter?: "filter";

                    /** ListInterconnectsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListInterconnectsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListInterconnectsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListInterconnectsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListInterconnectsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListInterconnectsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListInterconnectsRequest): google.cloud.compute.v1.ListInterconnectsRequest;

                    /**
                     * Encodes the specified ListInterconnectsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListInterconnectsRequest.verify|verify} messages.
                     * @param message ListInterconnectsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListInterconnectsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListInterconnectsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListInterconnectsRequest.verify|verify} messages.
                     * @param message ListInterconnectsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListInterconnectsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListInterconnectsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListInterconnectsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListInterconnectsRequest;

                    /**
                     * Decodes a ListInterconnectsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListInterconnectsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListInterconnectsRequest;

                    /**
                     * Verifies a ListInterconnectsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListInterconnectsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListInterconnectsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListInterconnectsRequest;

                    /**
                     * Creates a plain object from a ListInterconnectsRequest message. Also converts values to other types if specified.
                     * @param message ListInterconnectsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListInterconnectsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListInterconnectsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListInterconnectsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListLicensesRequest. */
                interface IListLicensesRequest {

                    /** ListLicensesRequest filter */
                    filter?: (string|null);

                    /** ListLicensesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListLicensesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListLicensesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListLicensesRequest project */
                    project?: (string|null);

                    /** ListLicensesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListLicensesRequest. */
                class ListLicensesRequest implements IListLicensesRequest {

                    /**
                     * Constructs a new ListLicensesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListLicensesRequest);

                    /** ListLicensesRequest filter. */
                    public filter?: (string|null);

                    /** ListLicensesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListLicensesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListLicensesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListLicensesRequest project. */
                    public project: string;

                    /** ListLicensesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListLicensesRequest _filter. */
                    public _filter?: "filter";

                    /** ListLicensesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListLicensesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListLicensesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListLicensesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListLicensesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListLicensesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListLicensesRequest): google.cloud.compute.v1.ListLicensesRequest;

                    /**
                     * Encodes the specified ListLicensesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListLicensesRequest.verify|verify} messages.
                     * @param message ListLicensesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListLicensesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListLicensesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListLicensesRequest.verify|verify} messages.
                     * @param message ListLicensesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListLicensesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListLicensesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListLicensesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListLicensesRequest;

                    /**
                     * Decodes a ListLicensesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListLicensesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListLicensesRequest;

                    /**
                     * Verifies a ListLicensesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListLicensesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListLicensesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListLicensesRequest;

                    /**
                     * Creates a plain object from a ListLicensesRequest message. Also converts values to other types if specified.
                     * @param message ListLicensesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListLicensesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListLicensesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListLicensesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListMachineImagesRequest. */
                interface IListMachineImagesRequest {

                    /** ListMachineImagesRequest filter */
                    filter?: (string|null);

                    /** ListMachineImagesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListMachineImagesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListMachineImagesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListMachineImagesRequest project */
                    project?: (string|null);

                    /** ListMachineImagesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListMachineImagesRequest. */
                class ListMachineImagesRequest implements IListMachineImagesRequest {

                    /**
                     * Constructs a new ListMachineImagesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListMachineImagesRequest);

                    /** ListMachineImagesRequest filter. */
                    public filter?: (string|null);

                    /** ListMachineImagesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListMachineImagesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListMachineImagesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListMachineImagesRequest project. */
                    public project: string;

                    /** ListMachineImagesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListMachineImagesRequest _filter. */
                    public _filter?: "filter";

                    /** ListMachineImagesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListMachineImagesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListMachineImagesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListMachineImagesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListMachineImagesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListMachineImagesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListMachineImagesRequest): google.cloud.compute.v1.ListMachineImagesRequest;

                    /**
                     * Encodes the specified ListMachineImagesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListMachineImagesRequest.verify|verify} messages.
                     * @param message ListMachineImagesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListMachineImagesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListMachineImagesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListMachineImagesRequest.verify|verify} messages.
                     * @param message ListMachineImagesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListMachineImagesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListMachineImagesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListMachineImagesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListMachineImagesRequest;

                    /**
                     * Decodes a ListMachineImagesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListMachineImagesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListMachineImagesRequest;

                    /**
                     * Verifies a ListMachineImagesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListMachineImagesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListMachineImagesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListMachineImagesRequest;

                    /**
                     * Creates a plain object from a ListMachineImagesRequest message. Also converts values to other types if specified.
                     * @param message ListMachineImagesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListMachineImagesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListMachineImagesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListMachineImagesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListMachineTypesRequest. */
                interface IListMachineTypesRequest {

                    /** ListMachineTypesRequest filter */
                    filter?: (string|null);

                    /** ListMachineTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListMachineTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListMachineTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListMachineTypesRequest project */
                    project?: (string|null);

                    /** ListMachineTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListMachineTypesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListMachineTypesRequest. */
                class ListMachineTypesRequest implements IListMachineTypesRequest {

                    /**
                     * Constructs a new ListMachineTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListMachineTypesRequest);

                    /** ListMachineTypesRequest filter. */
                    public filter?: (string|null);

                    /** ListMachineTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListMachineTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListMachineTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListMachineTypesRequest project. */
                    public project: string;

                    /** ListMachineTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListMachineTypesRequest zone. */
                    public zone: string;

                    /** ListMachineTypesRequest _filter. */
                    public _filter?: "filter";

                    /** ListMachineTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListMachineTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListMachineTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListMachineTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListMachineTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListMachineTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListMachineTypesRequest): google.cloud.compute.v1.ListMachineTypesRequest;

                    /**
                     * Encodes the specified ListMachineTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListMachineTypesRequest.verify|verify} messages.
                     * @param message ListMachineTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListMachineTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListMachineTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListMachineTypesRequest.verify|verify} messages.
                     * @param message ListMachineTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListMachineTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListMachineTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListMachineTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListMachineTypesRequest;

                    /**
                     * Decodes a ListMachineTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListMachineTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListMachineTypesRequest;

                    /**
                     * Verifies a ListMachineTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListMachineTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListMachineTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListMachineTypesRequest;

                    /**
                     * Creates a plain object from a ListMachineTypesRequest message. Also converts values to other types if specified.
                     * @param message ListMachineTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListMachineTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListMachineTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListMachineTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListManagedInstancesInstanceGroupManagersRequest. */
                interface IListManagedInstancesInstanceGroupManagersRequest {

                    /** ListManagedInstancesInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListManagedInstancesInstanceGroupManagersRequest. */
                class ListManagedInstancesInstanceGroupManagersRequest implements IListManagedInstancesInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListManagedInstancesInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest);

                    /** ListManagedInstancesInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ListManagedInstancesInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListManagedInstancesInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListManagedInstancesInstanceGroupManagersRequest zone. */
                    public zone: string;

                    /** ListManagedInstancesInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListManagedInstancesInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListManagedInstancesInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListManagedInstancesInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListManagedInstancesInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListManagedInstancesInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListManagedInstancesInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest): google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListManagedInstancesInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListManagedInstancesInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListManagedInstancesInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListManagedInstancesInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListManagedInstancesInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListManagedInstancesInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListManagedInstancesInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListManagedInstancesInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListManagedInstancesInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListManagedInstancesInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListManagedInstancesInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListManagedInstancesInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListManagedInstancesInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListManagedInstancesInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListManagedInstancesInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListManagedInstancesInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListManagedInstancesRegionInstanceGroupManagersRequest. */
                interface IListManagedInstancesRegionInstanceGroupManagersRequest {

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest region */
                    region?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListManagedInstancesRegionInstanceGroupManagersRequest. */
                class ListManagedInstancesRegionInstanceGroupManagersRequest implements IListManagedInstancesRegionInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListManagedInstancesRegionInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest region. */
                    public region: string;

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListManagedInstancesRegionInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListManagedInstancesRegionInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListManagedInstancesRegionInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest): google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListManagedInstancesRegionInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListManagedInstancesRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListManagedInstancesRegionInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListManagedInstancesRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListManagedInstancesRegionInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListManagedInstancesRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListManagedInstancesRegionInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListManagedInstancesRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListManagedInstancesRegionInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListManagedInstancesRegionInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListManagedInstancesRegionInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListManagedInstancesRegionInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListManagedInstancesRegionInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListManagedInstancesRegionInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListManagedInstancesRegionInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListManagedInstancesRegionInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNetworkEndpointGroupsRequest. */
                interface IListNetworkEndpointGroupsRequest {

                    /** ListNetworkEndpointGroupsRequest filter */
                    filter?: (string|null);

                    /** ListNetworkEndpointGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNetworkEndpointGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNetworkEndpointGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNetworkEndpointGroupsRequest project */
                    project?: (string|null);

                    /** ListNetworkEndpointGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListNetworkEndpointGroupsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListNetworkEndpointGroupsRequest. */
                class ListNetworkEndpointGroupsRequest implements IListNetworkEndpointGroupsRequest {

                    /**
                     * Constructs a new ListNetworkEndpointGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNetworkEndpointGroupsRequest);

                    /** ListNetworkEndpointGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListNetworkEndpointGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNetworkEndpointGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNetworkEndpointGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNetworkEndpointGroupsRequest project. */
                    public project: string;

                    /** ListNetworkEndpointGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNetworkEndpointGroupsRequest zone. */
                    public zone: string;

                    /** ListNetworkEndpointGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListNetworkEndpointGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNetworkEndpointGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNetworkEndpointGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNetworkEndpointGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNetworkEndpointGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNetworkEndpointGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNetworkEndpointGroupsRequest): google.cloud.compute.v1.ListNetworkEndpointGroupsRequest;

                    /**
                     * Encodes the specified ListNetworkEndpointGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNetworkEndpointGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNetworkEndpointGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNetworkEndpointGroupsRequest;

                    /**
                     * Decodes a ListNetworkEndpointGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNetworkEndpointGroupsRequest;

                    /**
                     * Verifies a ListNetworkEndpointGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNetworkEndpointGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNetworkEndpointGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNetworkEndpointGroupsRequest;

                    /**
                     * Creates a plain object from a ListNetworkEndpointGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListNetworkEndpointGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNetworkEndpointGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNetworkEndpointGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNetworkEndpointGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest. */
                interface IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest {

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest filter */
                    filter?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest project */
                    project?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest. */
                class ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest implements IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest {

                    /**
                     * Constructs a new ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest project. */
                    public project: string;

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest): google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Encodes the specified ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Decodes a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Verifies a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest;

                    /**
                     * Creates a plain object from a ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNetworkEndpointsNetworkEndpointGroupsRequest. */
                interface IListNetworkEndpointsNetworkEndpointGroupsRequest {

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest filter */
                    filter?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest networkEndpointGroup */
                    networkEndpointGroup?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest networkEndpointGroupsListEndpointsRequestResource */
                    networkEndpointGroupsListEndpointsRequestResource?: (google.cloud.compute.v1.INetworkEndpointGroupsListEndpointsRequest|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest project */
                    project?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListNetworkEndpointsNetworkEndpointGroupsRequest. */
                class ListNetworkEndpointsNetworkEndpointGroupsRequest implements IListNetworkEndpointsNetworkEndpointGroupsRequest {

                    /**
                     * Constructs a new ListNetworkEndpointsNetworkEndpointGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNetworkEndpointsNetworkEndpointGroupsRequest);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest networkEndpointGroup. */
                    public networkEndpointGroup: string;

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest networkEndpointGroupsListEndpointsRequestResource. */
                    public networkEndpointGroupsListEndpointsRequestResource?: (google.cloud.compute.v1.INetworkEndpointGroupsListEndpointsRequest|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest project. */
                    public project: string;

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest zone. */
                    public zone: string;

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNetworkEndpointsNetworkEndpointGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNetworkEndpointsNetworkEndpointGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNetworkEndpointsNetworkEndpointGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNetworkEndpointsNetworkEndpointGroupsRequest): google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest;

                    /**
                     * Encodes the specified ListNetworkEndpointsNetworkEndpointGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListNetworkEndpointsNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNetworkEndpointsNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNetworkEndpointsNetworkEndpointGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListNetworkEndpointsNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNetworkEndpointsNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNetworkEndpointsNetworkEndpointGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNetworkEndpointsNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest;

                    /**
                     * Decodes a ListNetworkEndpointsNetworkEndpointGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNetworkEndpointsNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest;

                    /**
                     * Verifies a ListNetworkEndpointsNetworkEndpointGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNetworkEndpointsNetworkEndpointGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNetworkEndpointsNetworkEndpointGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest;

                    /**
                     * Creates a plain object from a ListNetworkEndpointsNetworkEndpointGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListNetworkEndpointsNetworkEndpointGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNetworkEndpointsNetworkEndpointGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNetworkEndpointsNetworkEndpointGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNetworkEndpointsNetworkEndpointGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNetworkFirewallPoliciesRequest. */
                interface IListNetworkFirewallPoliciesRequest {

                    /** ListNetworkFirewallPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNetworkFirewallPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest project */
                    project?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListNetworkFirewallPoliciesRequest. */
                class ListNetworkFirewallPoliciesRequest implements IListNetworkFirewallPoliciesRequest {

                    /**
                     * Constructs a new ListNetworkFirewallPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNetworkFirewallPoliciesRequest);

                    /** ListNetworkFirewallPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNetworkFirewallPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNetworkFirewallPoliciesRequest project. */
                    public project: string;

                    /** ListNetworkFirewallPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNetworkFirewallPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListNetworkFirewallPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNetworkFirewallPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNetworkFirewallPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNetworkFirewallPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNetworkFirewallPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNetworkFirewallPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNetworkFirewallPoliciesRequest): google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest;

                    /**
                     * Encodes the specified ListNetworkFirewallPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest.verify|verify} messages.
                     * @param message ListNetworkFirewallPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNetworkFirewallPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNetworkFirewallPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest.verify|verify} messages.
                     * @param message ListNetworkFirewallPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNetworkFirewallPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNetworkFirewallPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNetworkFirewallPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest;

                    /**
                     * Decodes a ListNetworkFirewallPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNetworkFirewallPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest;

                    /**
                     * Verifies a ListNetworkFirewallPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNetworkFirewallPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNetworkFirewallPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest;

                    /**
                     * Creates a plain object from a ListNetworkFirewallPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListNetworkFirewallPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNetworkFirewallPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNetworkFirewallPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNetworkFirewallPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNetworksRequest. */
                interface IListNetworksRequest {

                    /** ListNetworksRequest filter */
                    filter?: (string|null);

                    /** ListNetworksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNetworksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNetworksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNetworksRequest project */
                    project?: (string|null);

                    /** ListNetworksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListNetworksRequest. */
                class ListNetworksRequest implements IListNetworksRequest {

                    /**
                     * Constructs a new ListNetworksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNetworksRequest);

                    /** ListNetworksRequest filter. */
                    public filter?: (string|null);

                    /** ListNetworksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNetworksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNetworksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNetworksRequest project. */
                    public project: string;

                    /** ListNetworksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNetworksRequest _filter. */
                    public _filter?: "filter";

                    /** ListNetworksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNetworksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNetworksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNetworksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNetworksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNetworksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNetworksRequest): google.cloud.compute.v1.ListNetworksRequest;

                    /**
                     * Encodes the specified ListNetworksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNetworksRequest.verify|verify} messages.
                     * @param message ListNetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNetworksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNetworksRequest.verify|verify} messages.
                     * @param message ListNetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNetworksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNetworksRequest;

                    /**
                     * Decodes a ListNetworksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNetworksRequest;

                    /**
                     * Verifies a ListNetworksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNetworksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNetworksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNetworksRequest;

                    /**
                     * Creates a plain object from a ListNetworksRequest message. Also converts values to other types if specified.
                     * @param message ListNetworksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNetworksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNetworksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNetworksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNodeGroupsRequest. */
                interface IListNodeGroupsRequest {

                    /** ListNodeGroupsRequest filter */
                    filter?: (string|null);

                    /** ListNodeGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNodeGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNodeGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNodeGroupsRequest project */
                    project?: (string|null);

                    /** ListNodeGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListNodeGroupsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListNodeGroupsRequest. */
                class ListNodeGroupsRequest implements IListNodeGroupsRequest {

                    /**
                     * Constructs a new ListNodeGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNodeGroupsRequest);

                    /** ListNodeGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListNodeGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNodeGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNodeGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNodeGroupsRequest project. */
                    public project: string;

                    /** ListNodeGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNodeGroupsRequest zone. */
                    public zone: string;

                    /** ListNodeGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListNodeGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNodeGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNodeGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNodeGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNodeGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNodeGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNodeGroupsRequest): google.cloud.compute.v1.ListNodeGroupsRequest;

                    /**
                     * Encodes the specified ListNodeGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNodeGroupsRequest.verify|verify} messages.
                     * @param message ListNodeGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNodeGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNodeGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNodeGroupsRequest.verify|verify} messages.
                     * @param message ListNodeGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNodeGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNodeGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNodeGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNodeGroupsRequest;

                    /**
                     * Decodes a ListNodeGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNodeGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNodeGroupsRequest;

                    /**
                     * Verifies a ListNodeGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNodeGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNodeGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNodeGroupsRequest;

                    /**
                     * Creates a plain object from a ListNodeGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListNodeGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNodeGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNodeGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNodeGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNodeTemplatesRequest. */
                interface IListNodeTemplatesRequest {

                    /** ListNodeTemplatesRequest filter */
                    filter?: (string|null);

                    /** ListNodeTemplatesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNodeTemplatesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNodeTemplatesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNodeTemplatesRequest project */
                    project?: (string|null);

                    /** ListNodeTemplatesRequest region */
                    region?: (string|null);

                    /** ListNodeTemplatesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListNodeTemplatesRequest. */
                class ListNodeTemplatesRequest implements IListNodeTemplatesRequest {

                    /**
                     * Constructs a new ListNodeTemplatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNodeTemplatesRequest);

                    /** ListNodeTemplatesRequest filter. */
                    public filter?: (string|null);

                    /** ListNodeTemplatesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNodeTemplatesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNodeTemplatesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNodeTemplatesRequest project. */
                    public project: string;

                    /** ListNodeTemplatesRequest region. */
                    public region: string;

                    /** ListNodeTemplatesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNodeTemplatesRequest _filter. */
                    public _filter?: "filter";

                    /** ListNodeTemplatesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNodeTemplatesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNodeTemplatesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNodeTemplatesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNodeTemplatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNodeTemplatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNodeTemplatesRequest): google.cloud.compute.v1.ListNodeTemplatesRequest;

                    /**
                     * Encodes the specified ListNodeTemplatesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNodeTemplatesRequest.verify|verify} messages.
                     * @param message ListNodeTemplatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNodeTemplatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNodeTemplatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNodeTemplatesRequest.verify|verify} messages.
                     * @param message ListNodeTemplatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNodeTemplatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNodeTemplatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNodeTemplatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNodeTemplatesRequest;

                    /**
                     * Decodes a ListNodeTemplatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNodeTemplatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNodeTemplatesRequest;

                    /**
                     * Verifies a ListNodeTemplatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNodeTemplatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNodeTemplatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNodeTemplatesRequest;

                    /**
                     * Creates a plain object from a ListNodeTemplatesRequest message. Also converts values to other types if specified.
                     * @param message ListNodeTemplatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNodeTemplatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNodeTemplatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNodeTemplatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNodeTypesRequest. */
                interface IListNodeTypesRequest {

                    /** ListNodeTypesRequest filter */
                    filter?: (string|null);

                    /** ListNodeTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNodeTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNodeTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNodeTypesRequest project */
                    project?: (string|null);

                    /** ListNodeTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListNodeTypesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListNodeTypesRequest. */
                class ListNodeTypesRequest implements IListNodeTypesRequest {

                    /**
                     * Constructs a new ListNodeTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNodeTypesRequest);

                    /** ListNodeTypesRequest filter. */
                    public filter?: (string|null);

                    /** ListNodeTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNodeTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNodeTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNodeTypesRequest project. */
                    public project: string;

                    /** ListNodeTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNodeTypesRequest zone. */
                    public zone: string;

                    /** ListNodeTypesRequest _filter. */
                    public _filter?: "filter";

                    /** ListNodeTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNodeTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNodeTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNodeTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNodeTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNodeTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNodeTypesRequest): google.cloud.compute.v1.ListNodeTypesRequest;

                    /**
                     * Encodes the specified ListNodeTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNodeTypesRequest.verify|verify} messages.
                     * @param message ListNodeTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNodeTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNodeTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNodeTypesRequest.verify|verify} messages.
                     * @param message ListNodeTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNodeTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNodeTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNodeTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNodeTypesRequest;

                    /**
                     * Decodes a ListNodeTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNodeTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNodeTypesRequest;

                    /**
                     * Verifies a ListNodeTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNodeTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNodeTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNodeTypesRequest;

                    /**
                     * Creates a plain object from a ListNodeTypesRequest message. Also converts values to other types if specified.
                     * @param message ListNodeTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNodeTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNodeTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNodeTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListNodesNodeGroupsRequest. */
                interface IListNodesNodeGroupsRequest {

                    /** ListNodesNodeGroupsRequest filter */
                    filter?: (string|null);

                    /** ListNodesNodeGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListNodesNodeGroupsRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** ListNodesNodeGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListNodesNodeGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListNodesNodeGroupsRequest project */
                    project?: (string|null);

                    /** ListNodesNodeGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListNodesNodeGroupsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListNodesNodeGroupsRequest. */
                class ListNodesNodeGroupsRequest implements IListNodesNodeGroupsRequest {

                    /**
                     * Constructs a new ListNodesNodeGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListNodesNodeGroupsRequest);

                    /** ListNodesNodeGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListNodesNodeGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListNodesNodeGroupsRequest nodeGroup. */
                    public nodeGroup: string;

                    /** ListNodesNodeGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListNodesNodeGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListNodesNodeGroupsRequest project. */
                    public project: string;

                    /** ListNodesNodeGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListNodesNodeGroupsRequest zone. */
                    public zone: string;

                    /** ListNodesNodeGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListNodesNodeGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListNodesNodeGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListNodesNodeGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListNodesNodeGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListNodesNodeGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListNodesNodeGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListNodesNodeGroupsRequest): google.cloud.compute.v1.ListNodesNodeGroupsRequest;

                    /**
                     * Encodes the specified ListNodesNodeGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListNodesNodeGroupsRequest.verify|verify} messages.
                     * @param message ListNodesNodeGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListNodesNodeGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListNodesNodeGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListNodesNodeGroupsRequest.verify|verify} messages.
                     * @param message ListNodesNodeGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListNodesNodeGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListNodesNodeGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListNodesNodeGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListNodesNodeGroupsRequest;

                    /**
                     * Decodes a ListNodesNodeGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListNodesNodeGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListNodesNodeGroupsRequest;

                    /**
                     * Verifies a ListNodesNodeGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListNodesNodeGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListNodesNodeGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListNodesNodeGroupsRequest;

                    /**
                     * Creates a plain object from a ListNodesNodeGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListNodesNodeGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListNodesNodeGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListNodesNodeGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListNodesNodeGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListPacketMirroringsRequest. */
                interface IListPacketMirroringsRequest {

                    /** ListPacketMirroringsRequest filter */
                    filter?: (string|null);

                    /** ListPacketMirroringsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPacketMirroringsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPacketMirroringsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPacketMirroringsRequest project */
                    project?: (string|null);

                    /** ListPacketMirroringsRequest region */
                    region?: (string|null);

                    /** ListPacketMirroringsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListPacketMirroringsRequest. */
                class ListPacketMirroringsRequest implements IListPacketMirroringsRequest {

                    /**
                     * Constructs a new ListPacketMirroringsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPacketMirroringsRequest);

                    /** ListPacketMirroringsRequest filter. */
                    public filter?: (string|null);

                    /** ListPacketMirroringsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPacketMirroringsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPacketMirroringsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPacketMirroringsRequest project. */
                    public project: string;

                    /** ListPacketMirroringsRequest region. */
                    public region: string;

                    /** ListPacketMirroringsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPacketMirroringsRequest _filter. */
                    public _filter?: "filter";

                    /** ListPacketMirroringsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPacketMirroringsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPacketMirroringsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPacketMirroringsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPacketMirroringsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPacketMirroringsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPacketMirroringsRequest): google.cloud.compute.v1.ListPacketMirroringsRequest;

                    /**
                     * Encodes the specified ListPacketMirroringsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPacketMirroringsRequest.verify|verify} messages.
                     * @param message ListPacketMirroringsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPacketMirroringsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPacketMirroringsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPacketMirroringsRequest.verify|verify} messages.
                     * @param message ListPacketMirroringsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPacketMirroringsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPacketMirroringsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPacketMirroringsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPacketMirroringsRequest;

                    /**
                     * Decodes a ListPacketMirroringsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPacketMirroringsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPacketMirroringsRequest;

                    /**
                     * Verifies a ListPacketMirroringsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPacketMirroringsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPacketMirroringsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPacketMirroringsRequest;

                    /**
                     * Creates a plain object from a ListPacketMirroringsRequest message. Also converts values to other types if specified.
                     * @param message ListPacketMirroringsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPacketMirroringsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPacketMirroringsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPacketMirroringsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListPeeringRoutesNetworksRequest. */
                interface IListPeeringRoutesNetworksRequest {

                    /** ListPeeringRoutesNetworksRequest direction */
                    direction?: (string|null);

                    /** ListPeeringRoutesNetworksRequest filter */
                    filter?: (string|null);

                    /** ListPeeringRoutesNetworksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPeeringRoutesNetworksRequest network */
                    network?: (string|null);

                    /** ListPeeringRoutesNetworksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPeeringRoutesNetworksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPeeringRoutesNetworksRequest peeringName */
                    peeringName?: (string|null);

                    /** ListPeeringRoutesNetworksRequest project */
                    project?: (string|null);

                    /** ListPeeringRoutesNetworksRequest region */
                    region?: (string|null);

                    /** ListPeeringRoutesNetworksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListPeeringRoutesNetworksRequest. */
                class ListPeeringRoutesNetworksRequest implements IListPeeringRoutesNetworksRequest {

                    /**
                     * Constructs a new ListPeeringRoutesNetworksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPeeringRoutesNetworksRequest);

                    /** ListPeeringRoutesNetworksRequest direction. */
                    public direction?: (string|null);

                    /** ListPeeringRoutesNetworksRequest filter. */
                    public filter?: (string|null);

                    /** ListPeeringRoutesNetworksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPeeringRoutesNetworksRequest network. */
                    public network: string;

                    /** ListPeeringRoutesNetworksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPeeringRoutesNetworksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPeeringRoutesNetworksRequest peeringName. */
                    public peeringName?: (string|null);

                    /** ListPeeringRoutesNetworksRequest project. */
                    public project: string;

                    /** ListPeeringRoutesNetworksRequest region. */
                    public region?: (string|null);

                    /** ListPeeringRoutesNetworksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPeeringRoutesNetworksRequest _direction. */
                    public _direction?: "direction";

                    /** ListPeeringRoutesNetworksRequest _filter. */
                    public _filter?: "filter";

                    /** ListPeeringRoutesNetworksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPeeringRoutesNetworksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPeeringRoutesNetworksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPeeringRoutesNetworksRequest _peeringName. */
                    public _peeringName?: "peeringName";

                    /** ListPeeringRoutesNetworksRequest _region. */
                    public _region?: "region";

                    /** ListPeeringRoutesNetworksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPeeringRoutesNetworksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPeeringRoutesNetworksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPeeringRoutesNetworksRequest): google.cloud.compute.v1.ListPeeringRoutesNetworksRequest;

                    /**
                     * Encodes the specified ListPeeringRoutesNetworksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPeeringRoutesNetworksRequest.verify|verify} messages.
                     * @param message ListPeeringRoutesNetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPeeringRoutesNetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPeeringRoutesNetworksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPeeringRoutesNetworksRequest.verify|verify} messages.
                     * @param message ListPeeringRoutesNetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPeeringRoutesNetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPeeringRoutesNetworksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPeeringRoutesNetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPeeringRoutesNetworksRequest;

                    /**
                     * Decodes a ListPeeringRoutesNetworksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPeeringRoutesNetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPeeringRoutesNetworksRequest;

                    /**
                     * Verifies a ListPeeringRoutesNetworksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPeeringRoutesNetworksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPeeringRoutesNetworksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPeeringRoutesNetworksRequest;

                    /**
                     * Creates a plain object from a ListPeeringRoutesNetworksRequest message. Also converts values to other types if specified.
                     * @param message ListPeeringRoutesNetworksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPeeringRoutesNetworksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPeeringRoutesNetworksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPeeringRoutesNetworksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ListPeeringRoutesNetworksRequest {

                    /** Direction enum. */
                    enum Direction {
                        UNDEFINED_DIRECTION = 0,
                        INCOMING = 338552870,
                        OUTGOING = 307438444
                    }
                }

                /** Properties of a ListPerInstanceConfigsInstanceGroupManagersRequest. */
                interface IListPerInstanceConfigsInstanceGroupManagersRequest {

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListPerInstanceConfigsInstanceGroupManagersRequest. */
                class ListPerInstanceConfigsInstanceGroupManagersRequest implements IListPerInstanceConfigsInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListPerInstanceConfigsInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest zone. */
                    public zone: string;

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPerInstanceConfigsInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPerInstanceConfigsInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPerInstanceConfigsInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest): google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListPerInstanceConfigsInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListPerInstanceConfigsInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPerInstanceConfigsInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListPerInstanceConfigsInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPerInstanceConfigsInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPerInstanceConfigsInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListPerInstanceConfigsInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPerInstanceConfigsInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListPerInstanceConfigsInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPerInstanceConfigsInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPerInstanceConfigsInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListPerInstanceConfigsInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListPerInstanceConfigsInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPerInstanceConfigsInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPerInstanceConfigsInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPerInstanceConfigsInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListPerInstanceConfigsRegionInstanceGroupManagersRequest. */
                interface IListPerInstanceConfigsRegionInstanceGroupManagersRequest {

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest region */
                    region?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListPerInstanceConfigsRegionInstanceGroupManagersRequest. */
                class ListPerInstanceConfigsRegionInstanceGroupManagersRequest implements IListPerInstanceConfigsRegionInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListPerInstanceConfigsRegionInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest region. */
                    public region: string;

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPerInstanceConfigsRegionInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPerInstanceConfigsRegionInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPerInstanceConfigsRegionInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest): google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListPerInstanceConfigsRegionInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListPerInstanceConfigsRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPerInstanceConfigsRegionInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListPerInstanceConfigsRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPerInstanceConfigsRegionInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPerInstanceConfigsRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListPerInstanceConfigsRegionInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPerInstanceConfigsRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListPerInstanceConfigsRegionInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPerInstanceConfigsRegionInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPerInstanceConfigsRegionInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListPerInstanceConfigsRegionInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListPerInstanceConfigsRegionInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPerInstanceConfigsRegionInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPerInstanceConfigsRegionInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPerInstanceConfigsRegionInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListPreconfiguredExpressionSetsSecurityPoliciesRequest. */
                interface IListPreconfiguredExpressionSetsSecurityPoliciesRequest {

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest project */
                    project?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListPreconfiguredExpressionSetsSecurityPoliciesRequest. */
                class ListPreconfiguredExpressionSetsSecurityPoliciesRequest implements IListPreconfiguredExpressionSetsSecurityPoliciesRequest {

                    /**
                     * Constructs a new ListPreconfiguredExpressionSetsSecurityPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPreconfiguredExpressionSetsSecurityPoliciesRequest);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest project. */
                    public project: string;

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPreconfiguredExpressionSetsSecurityPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPreconfiguredExpressionSetsSecurityPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPreconfiguredExpressionSetsSecurityPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPreconfiguredExpressionSetsSecurityPoliciesRequest): google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest;

                    /**
                     * Encodes the specified ListPreconfiguredExpressionSetsSecurityPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.verify|verify} messages.
                     * @param message ListPreconfiguredExpressionSetsSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPreconfiguredExpressionSetsSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPreconfiguredExpressionSetsSecurityPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest.verify|verify} messages.
                     * @param message ListPreconfiguredExpressionSetsSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPreconfiguredExpressionSetsSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPreconfiguredExpressionSetsSecurityPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPreconfiguredExpressionSetsSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest;

                    /**
                     * Decodes a ListPreconfiguredExpressionSetsSecurityPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPreconfiguredExpressionSetsSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest;

                    /**
                     * Verifies a ListPreconfiguredExpressionSetsSecurityPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPreconfiguredExpressionSetsSecurityPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPreconfiguredExpressionSetsSecurityPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest;

                    /**
                     * Creates a plain object from a ListPreconfiguredExpressionSetsSecurityPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListPreconfiguredExpressionSetsSecurityPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPreconfiguredExpressionSetsSecurityPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPreconfiguredExpressionSetsSecurityPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPreconfiguredExpressionSetsSecurityPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListPublicAdvertisedPrefixesRequest. */
                interface IListPublicAdvertisedPrefixesRequest {

                    /** ListPublicAdvertisedPrefixesRequest filter */
                    filter?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPublicAdvertisedPrefixesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest project */
                    project?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListPublicAdvertisedPrefixesRequest. */
                class ListPublicAdvertisedPrefixesRequest implements IListPublicAdvertisedPrefixesRequest {

                    /**
                     * Constructs a new ListPublicAdvertisedPrefixesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPublicAdvertisedPrefixesRequest);

                    /** ListPublicAdvertisedPrefixesRequest filter. */
                    public filter?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPublicAdvertisedPrefixesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPublicAdvertisedPrefixesRequest project. */
                    public project: string;

                    /** ListPublicAdvertisedPrefixesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPublicAdvertisedPrefixesRequest _filter. */
                    public _filter?: "filter";

                    /** ListPublicAdvertisedPrefixesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPublicAdvertisedPrefixesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPublicAdvertisedPrefixesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPublicAdvertisedPrefixesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPublicAdvertisedPrefixesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPublicAdvertisedPrefixesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPublicAdvertisedPrefixesRequest): google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest;

                    /**
                     * Encodes the specified ListPublicAdvertisedPrefixesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest.verify|verify} messages.
                     * @param message ListPublicAdvertisedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPublicAdvertisedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPublicAdvertisedPrefixesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest.verify|verify} messages.
                     * @param message ListPublicAdvertisedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPublicAdvertisedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPublicAdvertisedPrefixesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPublicAdvertisedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest;

                    /**
                     * Decodes a ListPublicAdvertisedPrefixesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPublicAdvertisedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest;

                    /**
                     * Verifies a ListPublicAdvertisedPrefixesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPublicAdvertisedPrefixesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPublicAdvertisedPrefixesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest;

                    /**
                     * Creates a plain object from a ListPublicAdvertisedPrefixesRequest message. Also converts values to other types if specified.
                     * @param message ListPublicAdvertisedPrefixesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPublicAdvertisedPrefixesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPublicAdvertisedPrefixesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPublicAdvertisedPrefixesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListPublicDelegatedPrefixesRequest. */
                interface IListPublicDelegatedPrefixesRequest {

                    /** ListPublicDelegatedPrefixesRequest filter */
                    filter?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListPublicDelegatedPrefixesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest project */
                    project?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest region */
                    region?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListPublicDelegatedPrefixesRequest. */
                class ListPublicDelegatedPrefixesRequest implements IListPublicDelegatedPrefixesRequest {

                    /**
                     * Constructs a new ListPublicDelegatedPrefixesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListPublicDelegatedPrefixesRequest);

                    /** ListPublicDelegatedPrefixesRequest filter. */
                    public filter?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListPublicDelegatedPrefixesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListPublicDelegatedPrefixesRequest project. */
                    public project: string;

                    /** ListPublicDelegatedPrefixesRequest region. */
                    public region: string;

                    /** ListPublicDelegatedPrefixesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListPublicDelegatedPrefixesRequest _filter. */
                    public _filter?: "filter";

                    /** ListPublicDelegatedPrefixesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListPublicDelegatedPrefixesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListPublicDelegatedPrefixesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListPublicDelegatedPrefixesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListPublicDelegatedPrefixesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListPublicDelegatedPrefixesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListPublicDelegatedPrefixesRequest): google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest;

                    /**
                     * Encodes the specified ListPublicDelegatedPrefixesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest.verify|verify} messages.
                     * @param message ListPublicDelegatedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListPublicDelegatedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListPublicDelegatedPrefixesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest.verify|verify} messages.
                     * @param message ListPublicDelegatedPrefixesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListPublicDelegatedPrefixesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListPublicDelegatedPrefixesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListPublicDelegatedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest;

                    /**
                     * Decodes a ListPublicDelegatedPrefixesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListPublicDelegatedPrefixesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest;

                    /**
                     * Verifies a ListPublicDelegatedPrefixesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListPublicDelegatedPrefixesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListPublicDelegatedPrefixesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest;

                    /**
                     * Creates a plain object from a ListPublicDelegatedPrefixesRequest message. Also converts values to other types if specified.
                     * @param message ListPublicDelegatedPrefixesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListPublicDelegatedPrefixesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListPublicDelegatedPrefixesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListPublicDelegatedPrefixesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListReferrersInstancesRequest. */
                interface IListReferrersInstancesRequest {

                    /** ListReferrersInstancesRequest filter */
                    filter?: (string|null);

                    /** ListReferrersInstancesRequest instance */
                    instance?: (string|null);

                    /** ListReferrersInstancesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListReferrersInstancesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListReferrersInstancesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListReferrersInstancesRequest project */
                    project?: (string|null);

                    /** ListReferrersInstancesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListReferrersInstancesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListReferrersInstancesRequest. */
                class ListReferrersInstancesRequest implements IListReferrersInstancesRequest {

                    /**
                     * Constructs a new ListReferrersInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListReferrersInstancesRequest);

                    /** ListReferrersInstancesRequest filter. */
                    public filter?: (string|null);

                    /** ListReferrersInstancesRequest instance. */
                    public instance: string;

                    /** ListReferrersInstancesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListReferrersInstancesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListReferrersInstancesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListReferrersInstancesRequest project. */
                    public project: string;

                    /** ListReferrersInstancesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListReferrersInstancesRequest zone. */
                    public zone: string;

                    /** ListReferrersInstancesRequest _filter. */
                    public _filter?: "filter";

                    /** ListReferrersInstancesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListReferrersInstancesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListReferrersInstancesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListReferrersInstancesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListReferrersInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListReferrersInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListReferrersInstancesRequest): google.cloud.compute.v1.ListReferrersInstancesRequest;

                    /**
                     * Encodes the specified ListReferrersInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListReferrersInstancesRequest.verify|verify} messages.
                     * @param message ListReferrersInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListReferrersInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListReferrersInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListReferrersInstancesRequest.verify|verify} messages.
                     * @param message ListReferrersInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListReferrersInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListReferrersInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListReferrersInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListReferrersInstancesRequest;

                    /**
                     * Decodes a ListReferrersInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListReferrersInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListReferrersInstancesRequest;

                    /**
                     * Verifies a ListReferrersInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListReferrersInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListReferrersInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListReferrersInstancesRequest;

                    /**
                     * Creates a plain object from a ListReferrersInstancesRequest message. Also converts values to other types if specified.
                     * @param message ListReferrersInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListReferrersInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListReferrersInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListReferrersInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionAutoscalersRequest. */
                interface IListRegionAutoscalersRequest {

                    /** ListRegionAutoscalersRequest filter */
                    filter?: (string|null);

                    /** ListRegionAutoscalersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionAutoscalersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionAutoscalersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionAutoscalersRequest project */
                    project?: (string|null);

                    /** ListRegionAutoscalersRequest region */
                    region?: (string|null);

                    /** ListRegionAutoscalersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionAutoscalersRequest. */
                class ListRegionAutoscalersRequest implements IListRegionAutoscalersRequest {

                    /**
                     * Constructs a new ListRegionAutoscalersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionAutoscalersRequest);

                    /** ListRegionAutoscalersRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionAutoscalersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionAutoscalersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionAutoscalersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionAutoscalersRequest project. */
                    public project: string;

                    /** ListRegionAutoscalersRequest region. */
                    public region: string;

                    /** ListRegionAutoscalersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionAutoscalersRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionAutoscalersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionAutoscalersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionAutoscalersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionAutoscalersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionAutoscalersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionAutoscalersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionAutoscalersRequest): google.cloud.compute.v1.ListRegionAutoscalersRequest;

                    /**
                     * Encodes the specified ListRegionAutoscalersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionAutoscalersRequest.verify|verify} messages.
                     * @param message ListRegionAutoscalersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionAutoscalersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionAutoscalersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionAutoscalersRequest.verify|verify} messages.
                     * @param message ListRegionAutoscalersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionAutoscalersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionAutoscalersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionAutoscalersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionAutoscalersRequest;

                    /**
                     * Decodes a ListRegionAutoscalersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionAutoscalersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionAutoscalersRequest;

                    /**
                     * Verifies a ListRegionAutoscalersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionAutoscalersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionAutoscalersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionAutoscalersRequest;

                    /**
                     * Creates a plain object from a ListRegionAutoscalersRequest message. Also converts values to other types if specified.
                     * @param message ListRegionAutoscalersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionAutoscalersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionAutoscalersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionAutoscalersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionBackendServicesRequest. */
                interface IListRegionBackendServicesRequest {

                    /** ListRegionBackendServicesRequest filter */
                    filter?: (string|null);

                    /** ListRegionBackendServicesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionBackendServicesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionBackendServicesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionBackendServicesRequest project */
                    project?: (string|null);

                    /** ListRegionBackendServicesRequest region */
                    region?: (string|null);

                    /** ListRegionBackendServicesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionBackendServicesRequest. */
                class ListRegionBackendServicesRequest implements IListRegionBackendServicesRequest {

                    /**
                     * Constructs a new ListRegionBackendServicesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionBackendServicesRequest);

                    /** ListRegionBackendServicesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionBackendServicesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionBackendServicesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionBackendServicesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionBackendServicesRequest project. */
                    public project: string;

                    /** ListRegionBackendServicesRequest region. */
                    public region: string;

                    /** ListRegionBackendServicesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionBackendServicesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionBackendServicesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionBackendServicesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionBackendServicesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionBackendServicesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionBackendServicesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionBackendServicesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionBackendServicesRequest): google.cloud.compute.v1.ListRegionBackendServicesRequest;

                    /**
                     * Encodes the specified ListRegionBackendServicesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionBackendServicesRequest.verify|verify} messages.
                     * @param message ListRegionBackendServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionBackendServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionBackendServicesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionBackendServicesRequest.verify|verify} messages.
                     * @param message ListRegionBackendServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionBackendServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionBackendServicesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionBackendServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionBackendServicesRequest;

                    /**
                     * Decodes a ListRegionBackendServicesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionBackendServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionBackendServicesRequest;

                    /**
                     * Verifies a ListRegionBackendServicesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionBackendServicesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionBackendServicesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionBackendServicesRequest;

                    /**
                     * Creates a plain object from a ListRegionBackendServicesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionBackendServicesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionBackendServicesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionBackendServicesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionBackendServicesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionCommitmentsRequest. */
                interface IListRegionCommitmentsRequest {

                    /** ListRegionCommitmentsRequest filter */
                    filter?: (string|null);

                    /** ListRegionCommitmentsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionCommitmentsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionCommitmentsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionCommitmentsRequest project */
                    project?: (string|null);

                    /** ListRegionCommitmentsRequest region */
                    region?: (string|null);

                    /** ListRegionCommitmentsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionCommitmentsRequest. */
                class ListRegionCommitmentsRequest implements IListRegionCommitmentsRequest {

                    /**
                     * Constructs a new ListRegionCommitmentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionCommitmentsRequest);

                    /** ListRegionCommitmentsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionCommitmentsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionCommitmentsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionCommitmentsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionCommitmentsRequest project. */
                    public project: string;

                    /** ListRegionCommitmentsRequest region. */
                    public region: string;

                    /** ListRegionCommitmentsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionCommitmentsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionCommitmentsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionCommitmentsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionCommitmentsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionCommitmentsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionCommitmentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionCommitmentsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionCommitmentsRequest): google.cloud.compute.v1.ListRegionCommitmentsRequest;

                    /**
                     * Encodes the specified ListRegionCommitmentsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionCommitmentsRequest.verify|verify} messages.
                     * @param message ListRegionCommitmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionCommitmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionCommitmentsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionCommitmentsRequest.verify|verify} messages.
                     * @param message ListRegionCommitmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionCommitmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionCommitmentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionCommitmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionCommitmentsRequest;

                    /**
                     * Decodes a ListRegionCommitmentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionCommitmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionCommitmentsRequest;

                    /**
                     * Verifies a ListRegionCommitmentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionCommitmentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionCommitmentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionCommitmentsRequest;

                    /**
                     * Creates a plain object from a ListRegionCommitmentsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionCommitmentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionCommitmentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionCommitmentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionCommitmentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionDiskTypesRequest. */
                interface IListRegionDiskTypesRequest {

                    /** ListRegionDiskTypesRequest filter */
                    filter?: (string|null);

                    /** ListRegionDiskTypesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionDiskTypesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionDiskTypesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionDiskTypesRequest project */
                    project?: (string|null);

                    /** ListRegionDiskTypesRequest region */
                    region?: (string|null);

                    /** ListRegionDiskTypesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionDiskTypesRequest. */
                class ListRegionDiskTypesRequest implements IListRegionDiskTypesRequest {

                    /**
                     * Constructs a new ListRegionDiskTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionDiskTypesRequest);

                    /** ListRegionDiskTypesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionDiskTypesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionDiskTypesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionDiskTypesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionDiskTypesRequest project. */
                    public project: string;

                    /** ListRegionDiskTypesRequest region. */
                    public region: string;

                    /** ListRegionDiskTypesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionDiskTypesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionDiskTypesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionDiskTypesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionDiskTypesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionDiskTypesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionDiskTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionDiskTypesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionDiskTypesRequest): google.cloud.compute.v1.ListRegionDiskTypesRequest;

                    /**
                     * Encodes the specified ListRegionDiskTypesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionDiskTypesRequest.verify|verify} messages.
                     * @param message ListRegionDiskTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionDiskTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionDiskTypesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionDiskTypesRequest.verify|verify} messages.
                     * @param message ListRegionDiskTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionDiskTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionDiskTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionDiskTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionDiskTypesRequest;

                    /**
                     * Decodes a ListRegionDiskTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionDiskTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionDiskTypesRequest;

                    /**
                     * Verifies a ListRegionDiskTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionDiskTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionDiskTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionDiskTypesRequest;

                    /**
                     * Creates a plain object from a ListRegionDiskTypesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionDiskTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionDiskTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionDiskTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionDiskTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionDisksRequest. */
                interface IListRegionDisksRequest {

                    /** ListRegionDisksRequest filter */
                    filter?: (string|null);

                    /** ListRegionDisksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionDisksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionDisksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionDisksRequest project */
                    project?: (string|null);

                    /** ListRegionDisksRequest region */
                    region?: (string|null);

                    /** ListRegionDisksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionDisksRequest. */
                class ListRegionDisksRequest implements IListRegionDisksRequest {

                    /**
                     * Constructs a new ListRegionDisksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionDisksRequest);

                    /** ListRegionDisksRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionDisksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionDisksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionDisksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionDisksRequest project. */
                    public project: string;

                    /** ListRegionDisksRequest region. */
                    public region: string;

                    /** ListRegionDisksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionDisksRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionDisksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionDisksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionDisksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionDisksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionDisksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionDisksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionDisksRequest): google.cloud.compute.v1.ListRegionDisksRequest;

                    /**
                     * Encodes the specified ListRegionDisksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionDisksRequest.verify|verify} messages.
                     * @param message ListRegionDisksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionDisksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionDisksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionDisksRequest.verify|verify} messages.
                     * @param message ListRegionDisksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionDisksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionDisksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionDisksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionDisksRequest;

                    /**
                     * Decodes a ListRegionDisksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionDisksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionDisksRequest;

                    /**
                     * Verifies a ListRegionDisksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionDisksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionDisksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionDisksRequest;

                    /**
                     * Creates a plain object from a ListRegionDisksRequest message. Also converts values to other types if specified.
                     * @param message ListRegionDisksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionDisksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionDisksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionDisksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionHealthCheckServicesRequest. */
                interface IListRegionHealthCheckServicesRequest {

                    /** ListRegionHealthCheckServicesRequest filter */
                    filter?: (string|null);

                    /** ListRegionHealthCheckServicesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionHealthCheckServicesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionHealthCheckServicesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionHealthCheckServicesRequest project */
                    project?: (string|null);

                    /** ListRegionHealthCheckServicesRequest region */
                    region?: (string|null);

                    /** ListRegionHealthCheckServicesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionHealthCheckServicesRequest. */
                class ListRegionHealthCheckServicesRequest implements IListRegionHealthCheckServicesRequest {

                    /**
                     * Constructs a new ListRegionHealthCheckServicesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionHealthCheckServicesRequest);

                    /** ListRegionHealthCheckServicesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionHealthCheckServicesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionHealthCheckServicesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionHealthCheckServicesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionHealthCheckServicesRequest project. */
                    public project: string;

                    /** ListRegionHealthCheckServicesRequest region. */
                    public region: string;

                    /** ListRegionHealthCheckServicesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionHealthCheckServicesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionHealthCheckServicesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionHealthCheckServicesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionHealthCheckServicesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionHealthCheckServicesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionHealthCheckServicesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionHealthCheckServicesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionHealthCheckServicesRequest): google.cloud.compute.v1.ListRegionHealthCheckServicesRequest;

                    /**
                     * Encodes the specified ListRegionHealthCheckServicesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionHealthCheckServicesRequest.verify|verify} messages.
                     * @param message ListRegionHealthCheckServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionHealthCheckServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionHealthCheckServicesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionHealthCheckServicesRequest.verify|verify} messages.
                     * @param message ListRegionHealthCheckServicesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionHealthCheckServicesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionHealthCheckServicesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionHealthCheckServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionHealthCheckServicesRequest;

                    /**
                     * Decodes a ListRegionHealthCheckServicesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionHealthCheckServicesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionHealthCheckServicesRequest;

                    /**
                     * Verifies a ListRegionHealthCheckServicesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionHealthCheckServicesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionHealthCheckServicesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionHealthCheckServicesRequest;

                    /**
                     * Creates a plain object from a ListRegionHealthCheckServicesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionHealthCheckServicesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionHealthCheckServicesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionHealthCheckServicesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionHealthCheckServicesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionHealthChecksRequest. */
                interface IListRegionHealthChecksRequest {

                    /** ListRegionHealthChecksRequest filter */
                    filter?: (string|null);

                    /** ListRegionHealthChecksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionHealthChecksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionHealthChecksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionHealthChecksRequest project */
                    project?: (string|null);

                    /** ListRegionHealthChecksRequest region */
                    region?: (string|null);

                    /** ListRegionHealthChecksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionHealthChecksRequest. */
                class ListRegionHealthChecksRequest implements IListRegionHealthChecksRequest {

                    /**
                     * Constructs a new ListRegionHealthChecksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionHealthChecksRequest);

                    /** ListRegionHealthChecksRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionHealthChecksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionHealthChecksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionHealthChecksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionHealthChecksRequest project. */
                    public project: string;

                    /** ListRegionHealthChecksRequest region. */
                    public region: string;

                    /** ListRegionHealthChecksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionHealthChecksRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionHealthChecksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionHealthChecksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionHealthChecksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionHealthChecksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionHealthChecksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionHealthChecksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionHealthChecksRequest): google.cloud.compute.v1.ListRegionHealthChecksRequest;

                    /**
                     * Encodes the specified ListRegionHealthChecksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionHealthChecksRequest.verify|verify} messages.
                     * @param message ListRegionHealthChecksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionHealthChecksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionHealthChecksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionHealthChecksRequest.verify|verify} messages.
                     * @param message ListRegionHealthChecksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionHealthChecksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionHealthChecksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionHealthChecksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionHealthChecksRequest;

                    /**
                     * Decodes a ListRegionHealthChecksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionHealthChecksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionHealthChecksRequest;

                    /**
                     * Verifies a ListRegionHealthChecksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionHealthChecksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionHealthChecksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionHealthChecksRequest;

                    /**
                     * Creates a plain object from a ListRegionHealthChecksRequest message. Also converts values to other types if specified.
                     * @param message ListRegionHealthChecksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionHealthChecksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionHealthChecksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionHealthChecksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionInstanceGroupManagersRequest. */
                interface IListRegionInstanceGroupManagersRequest {

                    /** ListRegionInstanceGroupManagersRequest filter */
                    filter?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionInstanceGroupManagersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest project */
                    project?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest region */
                    region?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionInstanceGroupManagersRequest. */
                class ListRegionInstanceGroupManagersRequest implements IListRegionInstanceGroupManagersRequest {

                    /**
                     * Constructs a new ListRegionInstanceGroupManagersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest);

                    /** ListRegionInstanceGroupManagersRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionInstanceGroupManagersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionInstanceGroupManagersRequest project. */
                    public project: string;

                    /** ListRegionInstanceGroupManagersRequest region. */
                    public region: string;

                    /** ListRegionInstanceGroupManagersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionInstanceGroupManagersRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionInstanceGroupManagersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionInstanceGroupManagersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionInstanceGroupManagersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionInstanceGroupManagersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionInstanceGroupManagersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionInstanceGroupManagersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest): google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest;

                    /**
                     * Encodes the specified ListRegionInstanceGroupManagersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionInstanceGroupManagersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest.verify|verify} messages.
                     * @param message ListRegionInstanceGroupManagersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionInstanceGroupManagersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest;

                    /**
                     * Decodes a ListRegionInstanceGroupManagersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionInstanceGroupManagersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest;

                    /**
                     * Verifies a ListRegionInstanceGroupManagersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionInstanceGroupManagersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionInstanceGroupManagersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest;

                    /**
                     * Creates a plain object from a ListRegionInstanceGroupManagersRequest message. Also converts values to other types if specified.
                     * @param message ListRegionInstanceGroupManagersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionInstanceGroupManagersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionInstanceGroupManagersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionInstanceGroupManagersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionInstanceGroupsRequest. */
                interface IListRegionInstanceGroupsRequest {

                    /** ListRegionInstanceGroupsRequest filter */
                    filter?: (string|null);

                    /** ListRegionInstanceGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionInstanceGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionInstanceGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionInstanceGroupsRequest project */
                    project?: (string|null);

                    /** ListRegionInstanceGroupsRequest region */
                    region?: (string|null);

                    /** ListRegionInstanceGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionInstanceGroupsRequest. */
                class ListRegionInstanceGroupsRequest implements IListRegionInstanceGroupsRequest {

                    /**
                     * Constructs a new ListRegionInstanceGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionInstanceGroupsRequest);

                    /** ListRegionInstanceGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionInstanceGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionInstanceGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionInstanceGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionInstanceGroupsRequest project. */
                    public project: string;

                    /** ListRegionInstanceGroupsRequest region. */
                    public region: string;

                    /** ListRegionInstanceGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionInstanceGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionInstanceGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionInstanceGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionInstanceGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionInstanceGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionInstanceGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionInstanceGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionInstanceGroupsRequest): google.cloud.compute.v1.ListRegionInstanceGroupsRequest;

                    /**
                     * Encodes the specified ListRegionInstanceGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListRegionInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionInstanceGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionInstanceGroupsRequest.verify|verify} messages.
                     * @param message ListRegionInstanceGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionInstanceGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionInstanceGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionInstanceGroupsRequest;

                    /**
                     * Decodes a ListRegionInstanceGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionInstanceGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionInstanceGroupsRequest;

                    /**
                     * Verifies a ListRegionInstanceGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionInstanceGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionInstanceGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionInstanceGroupsRequest;

                    /**
                     * Creates a plain object from a ListRegionInstanceGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionInstanceGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionInstanceGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionInstanceGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionInstanceGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionNetworkEndpointGroupsRequest. */
                interface IListRegionNetworkEndpointGroupsRequest {

                    /** ListRegionNetworkEndpointGroupsRequest filter */
                    filter?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionNetworkEndpointGroupsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest project */
                    project?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest region */
                    region?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionNetworkEndpointGroupsRequest. */
                class ListRegionNetworkEndpointGroupsRequest implements IListRegionNetworkEndpointGroupsRequest {

                    /**
                     * Constructs a new ListRegionNetworkEndpointGroupsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionNetworkEndpointGroupsRequest);

                    /** ListRegionNetworkEndpointGroupsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionNetworkEndpointGroupsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionNetworkEndpointGroupsRequest project. */
                    public project: string;

                    /** ListRegionNetworkEndpointGroupsRequest region. */
                    public region: string;

                    /** ListRegionNetworkEndpointGroupsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionNetworkEndpointGroupsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionNetworkEndpointGroupsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionNetworkEndpointGroupsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionNetworkEndpointGroupsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionNetworkEndpointGroupsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionNetworkEndpointGroupsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionNetworkEndpointGroupsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionNetworkEndpointGroupsRequest): google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest;

                    /**
                     * Encodes the specified ListRegionNetworkEndpointGroupsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListRegionNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionNetworkEndpointGroupsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest.verify|verify} messages.
                     * @param message ListRegionNetworkEndpointGroupsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionNetworkEndpointGroupsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionNetworkEndpointGroupsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest;

                    /**
                     * Decodes a ListRegionNetworkEndpointGroupsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionNetworkEndpointGroupsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest;

                    /**
                     * Verifies a ListRegionNetworkEndpointGroupsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionNetworkEndpointGroupsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionNetworkEndpointGroupsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest;

                    /**
                     * Creates a plain object from a ListRegionNetworkEndpointGroupsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionNetworkEndpointGroupsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionNetworkEndpointGroupsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionNetworkEndpointGroupsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionNetworkEndpointGroupsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionNetworkFirewallPoliciesRequest. */
                interface IListRegionNetworkFirewallPoliciesRequest {

                    /** ListRegionNetworkFirewallPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionNetworkFirewallPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest project */
                    project?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest region */
                    region?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionNetworkFirewallPoliciesRequest. */
                class ListRegionNetworkFirewallPoliciesRequest implements IListRegionNetworkFirewallPoliciesRequest {

                    /**
                     * Constructs a new ListRegionNetworkFirewallPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionNetworkFirewallPoliciesRequest);

                    /** ListRegionNetworkFirewallPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionNetworkFirewallPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionNetworkFirewallPoliciesRequest project. */
                    public project: string;

                    /** ListRegionNetworkFirewallPoliciesRequest region. */
                    public region: string;

                    /** ListRegionNetworkFirewallPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionNetworkFirewallPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionNetworkFirewallPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionNetworkFirewallPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionNetworkFirewallPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionNetworkFirewallPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionNetworkFirewallPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionNetworkFirewallPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionNetworkFirewallPoliciesRequest): google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest;

                    /**
                     * Encodes the specified ListRegionNetworkFirewallPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest.verify|verify} messages.
                     * @param message ListRegionNetworkFirewallPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionNetworkFirewallPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionNetworkFirewallPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest.verify|verify} messages.
                     * @param message ListRegionNetworkFirewallPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionNetworkFirewallPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionNetworkFirewallPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionNetworkFirewallPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest;

                    /**
                     * Decodes a ListRegionNetworkFirewallPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionNetworkFirewallPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest;

                    /**
                     * Verifies a ListRegionNetworkFirewallPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionNetworkFirewallPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionNetworkFirewallPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest;

                    /**
                     * Creates a plain object from a ListRegionNetworkFirewallPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionNetworkFirewallPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionNetworkFirewallPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionNetworkFirewallPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionNetworkFirewallPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionNotificationEndpointsRequest. */
                interface IListRegionNotificationEndpointsRequest {

                    /** ListRegionNotificationEndpointsRequest filter */
                    filter?: (string|null);

                    /** ListRegionNotificationEndpointsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionNotificationEndpointsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionNotificationEndpointsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionNotificationEndpointsRequest project */
                    project?: (string|null);

                    /** ListRegionNotificationEndpointsRequest region */
                    region?: (string|null);

                    /** ListRegionNotificationEndpointsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionNotificationEndpointsRequest. */
                class ListRegionNotificationEndpointsRequest implements IListRegionNotificationEndpointsRequest {

                    /**
                     * Constructs a new ListRegionNotificationEndpointsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionNotificationEndpointsRequest);

                    /** ListRegionNotificationEndpointsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionNotificationEndpointsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionNotificationEndpointsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionNotificationEndpointsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionNotificationEndpointsRequest project. */
                    public project: string;

                    /** ListRegionNotificationEndpointsRequest region. */
                    public region: string;

                    /** ListRegionNotificationEndpointsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionNotificationEndpointsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionNotificationEndpointsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionNotificationEndpointsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionNotificationEndpointsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionNotificationEndpointsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionNotificationEndpointsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionNotificationEndpointsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionNotificationEndpointsRequest): google.cloud.compute.v1.ListRegionNotificationEndpointsRequest;

                    /**
                     * Encodes the specified ListRegionNotificationEndpointsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionNotificationEndpointsRequest.verify|verify} messages.
                     * @param message ListRegionNotificationEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionNotificationEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionNotificationEndpointsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionNotificationEndpointsRequest.verify|verify} messages.
                     * @param message ListRegionNotificationEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionNotificationEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionNotificationEndpointsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionNotificationEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionNotificationEndpointsRequest;

                    /**
                     * Decodes a ListRegionNotificationEndpointsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionNotificationEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionNotificationEndpointsRequest;

                    /**
                     * Verifies a ListRegionNotificationEndpointsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionNotificationEndpointsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionNotificationEndpointsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionNotificationEndpointsRequest;

                    /**
                     * Creates a plain object from a ListRegionNotificationEndpointsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionNotificationEndpointsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionNotificationEndpointsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionNotificationEndpointsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionNotificationEndpointsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionOperationsRequest. */
                interface IListRegionOperationsRequest {

                    /** ListRegionOperationsRequest filter */
                    filter?: (string|null);

                    /** ListRegionOperationsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionOperationsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionOperationsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionOperationsRequest project */
                    project?: (string|null);

                    /** ListRegionOperationsRequest region */
                    region?: (string|null);

                    /** ListRegionOperationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionOperationsRequest. */
                class ListRegionOperationsRequest implements IListRegionOperationsRequest {

                    /**
                     * Constructs a new ListRegionOperationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionOperationsRequest);

                    /** ListRegionOperationsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionOperationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionOperationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionOperationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionOperationsRequest project. */
                    public project: string;

                    /** ListRegionOperationsRequest region. */
                    public region: string;

                    /** ListRegionOperationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionOperationsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionOperationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionOperationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionOperationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionOperationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionOperationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionOperationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionOperationsRequest): google.cloud.compute.v1.ListRegionOperationsRequest;

                    /**
                     * Encodes the specified ListRegionOperationsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionOperationsRequest.verify|verify} messages.
                     * @param message ListRegionOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionOperationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionOperationsRequest.verify|verify} messages.
                     * @param message ListRegionOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionOperationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionOperationsRequest;

                    /**
                     * Decodes a ListRegionOperationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionOperationsRequest;

                    /**
                     * Verifies a ListRegionOperationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionOperationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionOperationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionOperationsRequest;

                    /**
                     * Creates a plain object from a ListRegionOperationsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionOperationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionOperationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionOperationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionOperationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionSecurityPoliciesRequest. */
                interface IListRegionSecurityPoliciesRequest {

                    /** ListRegionSecurityPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListRegionSecurityPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionSecurityPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionSecurityPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionSecurityPoliciesRequest project */
                    project?: (string|null);

                    /** ListRegionSecurityPoliciesRequest region */
                    region?: (string|null);

                    /** ListRegionSecurityPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionSecurityPoliciesRequest. */
                class ListRegionSecurityPoliciesRequest implements IListRegionSecurityPoliciesRequest {

                    /**
                     * Constructs a new ListRegionSecurityPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionSecurityPoliciesRequest);

                    /** ListRegionSecurityPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionSecurityPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionSecurityPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionSecurityPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionSecurityPoliciesRequest project. */
                    public project: string;

                    /** ListRegionSecurityPoliciesRequest region. */
                    public region: string;

                    /** ListRegionSecurityPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionSecurityPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionSecurityPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionSecurityPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionSecurityPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionSecurityPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionSecurityPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionSecurityPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionSecurityPoliciesRequest): google.cloud.compute.v1.ListRegionSecurityPoliciesRequest;

                    /**
                     * Encodes the specified ListRegionSecurityPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionSecurityPoliciesRequest.verify|verify} messages.
                     * @param message ListRegionSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionSecurityPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionSecurityPoliciesRequest.verify|verify} messages.
                     * @param message ListRegionSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionSecurityPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionSecurityPoliciesRequest;

                    /**
                     * Decodes a ListRegionSecurityPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionSecurityPoliciesRequest;

                    /**
                     * Verifies a ListRegionSecurityPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionSecurityPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionSecurityPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionSecurityPoliciesRequest;

                    /**
                     * Creates a plain object from a ListRegionSecurityPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionSecurityPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionSecurityPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionSecurityPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionSecurityPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionSslCertificatesRequest. */
                interface IListRegionSslCertificatesRequest {

                    /** ListRegionSslCertificatesRequest filter */
                    filter?: (string|null);

                    /** ListRegionSslCertificatesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionSslCertificatesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionSslCertificatesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionSslCertificatesRequest project */
                    project?: (string|null);

                    /** ListRegionSslCertificatesRequest region */
                    region?: (string|null);

                    /** ListRegionSslCertificatesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionSslCertificatesRequest. */
                class ListRegionSslCertificatesRequest implements IListRegionSslCertificatesRequest {

                    /**
                     * Constructs a new ListRegionSslCertificatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionSslCertificatesRequest);

                    /** ListRegionSslCertificatesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionSslCertificatesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionSslCertificatesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionSslCertificatesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionSslCertificatesRequest project. */
                    public project: string;

                    /** ListRegionSslCertificatesRequest region. */
                    public region: string;

                    /** ListRegionSslCertificatesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionSslCertificatesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionSslCertificatesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionSslCertificatesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionSslCertificatesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionSslCertificatesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionSslCertificatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionSslCertificatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionSslCertificatesRequest): google.cloud.compute.v1.ListRegionSslCertificatesRequest;

                    /**
                     * Encodes the specified ListRegionSslCertificatesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionSslCertificatesRequest.verify|verify} messages.
                     * @param message ListRegionSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionSslCertificatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionSslCertificatesRequest.verify|verify} messages.
                     * @param message ListRegionSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionSslCertificatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionSslCertificatesRequest;

                    /**
                     * Decodes a ListRegionSslCertificatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionSslCertificatesRequest;

                    /**
                     * Verifies a ListRegionSslCertificatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionSslCertificatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionSslCertificatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionSslCertificatesRequest;

                    /**
                     * Creates a plain object from a ListRegionSslCertificatesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionSslCertificatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionSslCertificatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionSslCertificatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionSslCertificatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionSslPoliciesRequest. */
                interface IListRegionSslPoliciesRequest {

                    /** ListRegionSslPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListRegionSslPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionSslPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionSslPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionSslPoliciesRequest project */
                    project?: (string|null);

                    /** ListRegionSslPoliciesRequest region */
                    region?: (string|null);

                    /** ListRegionSslPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionSslPoliciesRequest. */
                class ListRegionSslPoliciesRequest implements IListRegionSslPoliciesRequest {

                    /**
                     * Constructs a new ListRegionSslPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionSslPoliciesRequest);

                    /** ListRegionSslPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionSslPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionSslPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionSslPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionSslPoliciesRequest project. */
                    public project: string;

                    /** ListRegionSslPoliciesRequest region. */
                    public region: string;

                    /** ListRegionSslPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionSslPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionSslPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionSslPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionSslPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionSslPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionSslPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionSslPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionSslPoliciesRequest): google.cloud.compute.v1.ListRegionSslPoliciesRequest;

                    /**
                     * Encodes the specified ListRegionSslPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionSslPoliciesRequest.verify|verify} messages.
                     * @param message ListRegionSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionSslPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionSslPoliciesRequest.verify|verify} messages.
                     * @param message ListRegionSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionSslPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionSslPoliciesRequest;

                    /**
                     * Decodes a ListRegionSslPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionSslPoliciesRequest;

                    /**
                     * Verifies a ListRegionSslPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionSslPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionSslPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionSslPoliciesRequest;

                    /**
                     * Creates a plain object from a ListRegionSslPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionSslPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionSslPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionSslPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionSslPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionTargetHttpProxiesRequest. */
                interface IListRegionTargetHttpProxiesRequest {

                    /** ListRegionTargetHttpProxiesRequest filter */
                    filter?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionTargetHttpProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest project */
                    project?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest region */
                    region?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionTargetHttpProxiesRequest. */
                class ListRegionTargetHttpProxiesRequest implements IListRegionTargetHttpProxiesRequest {

                    /**
                     * Constructs a new ListRegionTargetHttpProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionTargetHttpProxiesRequest);

                    /** ListRegionTargetHttpProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionTargetHttpProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionTargetHttpProxiesRequest project. */
                    public project: string;

                    /** ListRegionTargetHttpProxiesRequest region. */
                    public region: string;

                    /** ListRegionTargetHttpProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionTargetHttpProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionTargetHttpProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionTargetHttpProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionTargetHttpProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionTargetHttpProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionTargetHttpProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionTargetHttpProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionTargetHttpProxiesRequest): google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest;

                    /**
                     * Encodes the specified ListRegionTargetHttpProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest.verify|verify} messages.
                     * @param message ListRegionTargetHttpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionTargetHttpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionTargetHttpProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest.verify|verify} messages.
                     * @param message ListRegionTargetHttpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionTargetHttpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionTargetHttpProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionTargetHttpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest;

                    /**
                     * Decodes a ListRegionTargetHttpProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionTargetHttpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest;

                    /**
                     * Verifies a ListRegionTargetHttpProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionTargetHttpProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionTargetHttpProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest;

                    /**
                     * Creates a plain object from a ListRegionTargetHttpProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionTargetHttpProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionTargetHttpProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionTargetHttpProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionTargetHttpProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionTargetHttpsProxiesRequest. */
                interface IListRegionTargetHttpsProxiesRequest {

                    /** ListRegionTargetHttpsProxiesRequest filter */
                    filter?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionTargetHttpsProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest project */
                    project?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest region */
                    region?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionTargetHttpsProxiesRequest. */
                class ListRegionTargetHttpsProxiesRequest implements IListRegionTargetHttpsProxiesRequest {

                    /**
                     * Constructs a new ListRegionTargetHttpsProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionTargetHttpsProxiesRequest);

                    /** ListRegionTargetHttpsProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionTargetHttpsProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionTargetHttpsProxiesRequest project. */
                    public project: string;

                    /** ListRegionTargetHttpsProxiesRequest region. */
                    public region: string;

                    /** ListRegionTargetHttpsProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionTargetHttpsProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionTargetHttpsProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionTargetHttpsProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionTargetHttpsProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionTargetHttpsProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionTargetHttpsProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionTargetHttpsProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionTargetHttpsProxiesRequest): google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest;

                    /**
                     * Encodes the specified ListRegionTargetHttpsProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest.verify|verify} messages.
                     * @param message ListRegionTargetHttpsProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionTargetHttpsProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionTargetHttpsProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest.verify|verify} messages.
                     * @param message ListRegionTargetHttpsProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionTargetHttpsProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionTargetHttpsProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionTargetHttpsProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest;

                    /**
                     * Decodes a ListRegionTargetHttpsProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionTargetHttpsProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest;

                    /**
                     * Verifies a ListRegionTargetHttpsProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionTargetHttpsProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionTargetHttpsProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest;

                    /**
                     * Creates a plain object from a ListRegionTargetHttpsProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionTargetHttpsProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionTargetHttpsProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionTargetHttpsProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionTargetHttpsProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionTargetTcpProxiesRequest. */
                interface IListRegionTargetTcpProxiesRequest {

                    /** ListRegionTargetTcpProxiesRequest filter */
                    filter?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionTargetTcpProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest project */
                    project?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest region */
                    region?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionTargetTcpProxiesRequest. */
                class ListRegionTargetTcpProxiesRequest implements IListRegionTargetTcpProxiesRequest {

                    /**
                     * Constructs a new ListRegionTargetTcpProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionTargetTcpProxiesRequest);

                    /** ListRegionTargetTcpProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionTargetTcpProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionTargetTcpProxiesRequest project. */
                    public project: string;

                    /** ListRegionTargetTcpProxiesRequest region. */
                    public region: string;

                    /** ListRegionTargetTcpProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionTargetTcpProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionTargetTcpProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionTargetTcpProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionTargetTcpProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionTargetTcpProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionTargetTcpProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionTargetTcpProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionTargetTcpProxiesRequest): google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest;

                    /**
                     * Encodes the specified ListRegionTargetTcpProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest.verify|verify} messages.
                     * @param message ListRegionTargetTcpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionTargetTcpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionTargetTcpProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest.verify|verify} messages.
                     * @param message ListRegionTargetTcpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionTargetTcpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionTargetTcpProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionTargetTcpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest;

                    /**
                     * Decodes a ListRegionTargetTcpProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionTargetTcpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest;

                    /**
                     * Verifies a ListRegionTargetTcpProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionTargetTcpProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionTargetTcpProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest;

                    /**
                     * Creates a plain object from a ListRegionTargetTcpProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListRegionTargetTcpProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionTargetTcpProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionTargetTcpProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionTargetTcpProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionUrlMapsRequest. */
                interface IListRegionUrlMapsRequest {

                    /** ListRegionUrlMapsRequest filter */
                    filter?: (string|null);

                    /** ListRegionUrlMapsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionUrlMapsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionUrlMapsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionUrlMapsRequest project */
                    project?: (string|null);

                    /** ListRegionUrlMapsRequest region */
                    region?: (string|null);

                    /** ListRegionUrlMapsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionUrlMapsRequest. */
                class ListRegionUrlMapsRequest implements IListRegionUrlMapsRequest {

                    /**
                     * Constructs a new ListRegionUrlMapsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionUrlMapsRequest);

                    /** ListRegionUrlMapsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionUrlMapsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionUrlMapsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionUrlMapsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionUrlMapsRequest project. */
                    public project: string;

                    /** ListRegionUrlMapsRequest region. */
                    public region: string;

                    /** ListRegionUrlMapsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionUrlMapsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionUrlMapsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionUrlMapsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionUrlMapsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionUrlMapsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionUrlMapsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionUrlMapsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionUrlMapsRequest): google.cloud.compute.v1.ListRegionUrlMapsRequest;

                    /**
                     * Encodes the specified ListRegionUrlMapsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionUrlMapsRequest.verify|verify} messages.
                     * @param message ListRegionUrlMapsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionUrlMapsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionUrlMapsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionUrlMapsRequest.verify|verify} messages.
                     * @param message ListRegionUrlMapsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionUrlMapsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionUrlMapsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionUrlMapsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionUrlMapsRequest;

                    /**
                     * Decodes a ListRegionUrlMapsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionUrlMapsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionUrlMapsRequest;

                    /**
                     * Verifies a ListRegionUrlMapsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionUrlMapsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionUrlMapsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionUrlMapsRequest;

                    /**
                     * Creates a plain object from a ListRegionUrlMapsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionUrlMapsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionUrlMapsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionUrlMapsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionUrlMapsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRegionsRequest. */
                interface IListRegionsRequest {

                    /** ListRegionsRequest filter */
                    filter?: (string|null);

                    /** ListRegionsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRegionsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRegionsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRegionsRequest project */
                    project?: (string|null);

                    /** ListRegionsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRegionsRequest. */
                class ListRegionsRequest implements IListRegionsRequest {

                    /**
                     * Constructs a new ListRegionsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRegionsRequest);

                    /** ListRegionsRequest filter. */
                    public filter?: (string|null);

                    /** ListRegionsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRegionsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRegionsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRegionsRequest project. */
                    public project: string;

                    /** ListRegionsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRegionsRequest _filter. */
                    public _filter?: "filter";

                    /** ListRegionsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRegionsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRegionsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRegionsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRegionsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRegionsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRegionsRequest): google.cloud.compute.v1.ListRegionsRequest;

                    /**
                     * Encodes the specified ListRegionsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRegionsRequest.verify|verify} messages.
                     * @param message ListRegionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRegionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRegionsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRegionsRequest.verify|verify} messages.
                     * @param message ListRegionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRegionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRegionsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRegionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRegionsRequest;

                    /**
                     * Decodes a ListRegionsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRegionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRegionsRequest;

                    /**
                     * Verifies a ListRegionsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRegionsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRegionsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRegionsRequest;

                    /**
                     * Creates a plain object from a ListRegionsRequest message. Also converts values to other types if specified.
                     * @param message ListRegionsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRegionsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRegionsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRegionsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListReservationsRequest. */
                interface IListReservationsRequest {

                    /** ListReservationsRequest filter */
                    filter?: (string|null);

                    /** ListReservationsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListReservationsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListReservationsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListReservationsRequest project */
                    project?: (string|null);

                    /** ListReservationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListReservationsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListReservationsRequest. */
                class ListReservationsRequest implements IListReservationsRequest {

                    /**
                     * Constructs a new ListReservationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListReservationsRequest);

                    /** ListReservationsRequest filter. */
                    public filter?: (string|null);

                    /** ListReservationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListReservationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListReservationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListReservationsRequest project. */
                    public project: string;

                    /** ListReservationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListReservationsRequest zone. */
                    public zone: string;

                    /** ListReservationsRequest _filter. */
                    public _filter?: "filter";

                    /** ListReservationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListReservationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListReservationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListReservationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListReservationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListReservationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListReservationsRequest): google.cloud.compute.v1.ListReservationsRequest;

                    /**
                     * Encodes the specified ListReservationsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListReservationsRequest.verify|verify} messages.
                     * @param message ListReservationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListReservationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListReservationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListReservationsRequest.verify|verify} messages.
                     * @param message ListReservationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListReservationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListReservationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListReservationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListReservationsRequest;

                    /**
                     * Decodes a ListReservationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListReservationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListReservationsRequest;

                    /**
                     * Verifies a ListReservationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListReservationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListReservationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListReservationsRequest;

                    /**
                     * Creates a plain object from a ListReservationsRequest message. Also converts values to other types if specified.
                     * @param message ListReservationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListReservationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListReservationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListReservationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListResourcePoliciesRequest. */
                interface IListResourcePoliciesRequest {

                    /** ListResourcePoliciesRequest filter */
                    filter?: (string|null);

                    /** ListResourcePoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListResourcePoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListResourcePoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListResourcePoliciesRequest project */
                    project?: (string|null);

                    /** ListResourcePoliciesRequest region */
                    region?: (string|null);

                    /** ListResourcePoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListResourcePoliciesRequest. */
                class ListResourcePoliciesRequest implements IListResourcePoliciesRequest {

                    /**
                     * Constructs a new ListResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListResourcePoliciesRequest);

                    /** ListResourcePoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListResourcePoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListResourcePoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListResourcePoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListResourcePoliciesRequest project. */
                    public project: string;

                    /** ListResourcePoliciesRequest region. */
                    public region: string;

                    /** ListResourcePoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListResourcePoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListResourcePoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListResourcePoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListResourcePoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListResourcePoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListResourcePoliciesRequest): google.cloud.compute.v1.ListResourcePoliciesRequest;

                    /**
                     * Encodes the specified ListResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListResourcePoliciesRequest.verify|verify} messages.
                     * @param message ListResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListResourcePoliciesRequest.verify|verify} messages.
                     * @param message ListResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListResourcePoliciesRequest;

                    /**
                     * Decodes a ListResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListResourcePoliciesRequest;

                    /**
                     * Verifies a ListResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListResourcePoliciesRequest;

                    /**
                     * Creates a plain object from a ListResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRoutersRequest. */
                interface IListRoutersRequest {

                    /** ListRoutersRequest filter */
                    filter?: (string|null);

                    /** ListRoutersRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRoutersRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRoutersRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRoutersRequest project */
                    project?: (string|null);

                    /** ListRoutersRequest region */
                    region?: (string|null);

                    /** ListRoutersRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRoutersRequest. */
                class ListRoutersRequest implements IListRoutersRequest {

                    /**
                     * Constructs a new ListRoutersRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRoutersRequest);

                    /** ListRoutersRequest filter. */
                    public filter?: (string|null);

                    /** ListRoutersRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRoutersRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRoutersRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRoutersRequest project. */
                    public project: string;

                    /** ListRoutersRequest region. */
                    public region: string;

                    /** ListRoutersRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRoutersRequest _filter. */
                    public _filter?: "filter";

                    /** ListRoutersRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRoutersRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRoutersRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRoutersRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRoutersRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRoutersRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRoutersRequest): google.cloud.compute.v1.ListRoutersRequest;

                    /**
                     * Encodes the specified ListRoutersRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRoutersRequest.verify|verify} messages.
                     * @param message ListRoutersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRoutersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRoutersRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRoutersRequest.verify|verify} messages.
                     * @param message ListRoutersRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRoutersRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRoutersRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRoutersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRoutersRequest;

                    /**
                     * Decodes a ListRoutersRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRoutersRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRoutersRequest;

                    /**
                     * Verifies a ListRoutersRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRoutersRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRoutersRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRoutersRequest;

                    /**
                     * Creates a plain object from a ListRoutersRequest message. Also converts values to other types if specified.
                     * @param message ListRoutersRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRoutersRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRoutersRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRoutersRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListRoutesRequest. */
                interface IListRoutesRequest {

                    /** ListRoutesRequest filter */
                    filter?: (string|null);

                    /** ListRoutesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListRoutesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListRoutesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListRoutesRequest project */
                    project?: (string|null);

                    /** ListRoutesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListRoutesRequest. */
                class ListRoutesRequest implements IListRoutesRequest {

                    /**
                     * Constructs a new ListRoutesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListRoutesRequest);

                    /** ListRoutesRequest filter. */
                    public filter?: (string|null);

                    /** ListRoutesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListRoutesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListRoutesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListRoutesRequest project. */
                    public project: string;

                    /** ListRoutesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListRoutesRequest _filter. */
                    public _filter?: "filter";

                    /** ListRoutesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListRoutesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListRoutesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListRoutesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListRoutesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListRoutesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListRoutesRequest): google.cloud.compute.v1.ListRoutesRequest;

                    /**
                     * Encodes the specified ListRoutesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListRoutesRequest.verify|verify} messages.
                     * @param message ListRoutesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListRoutesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListRoutesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListRoutesRequest.verify|verify} messages.
                     * @param message ListRoutesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListRoutesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListRoutesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListRoutesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListRoutesRequest;

                    /**
                     * Decodes a ListRoutesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListRoutesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListRoutesRequest;

                    /**
                     * Verifies a ListRoutesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListRoutesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListRoutesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListRoutesRequest;

                    /**
                     * Creates a plain object from a ListRoutesRequest message. Also converts values to other types if specified.
                     * @param message ListRoutesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListRoutesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListRoutesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListRoutesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListSecurityPoliciesRequest. */
                interface IListSecurityPoliciesRequest {

                    /** ListSecurityPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListSecurityPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListSecurityPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListSecurityPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListSecurityPoliciesRequest project */
                    project?: (string|null);

                    /** ListSecurityPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListSecurityPoliciesRequest. */
                class ListSecurityPoliciesRequest implements IListSecurityPoliciesRequest {

                    /**
                     * Constructs a new ListSecurityPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListSecurityPoliciesRequest);

                    /** ListSecurityPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListSecurityPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListSecurityPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListSecurityPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListSecurityPoliciesRequest project. */
                    public project: string;

                    /** ListSecurityPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListSecurityPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListSecurityPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListSecurityPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListSecurityPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListSecurityPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListSecurityPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListSecurityPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListSecurityPoliciesRequest): google.cloud.compute.v1.ListSecurityPoliciesRequest;

                    /**
                     * Encodes the specified ListSecurityPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListSecurityPoliciesRequest.verify|verify} messages.
                     * @param message ListSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListSecurityPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListSecurityPoliciesRequest.verify|verify} messages.
                     * @param message ListSecurityPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListSecurityPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListSecurityPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListSecurityPoliciesRequest;

                    /**
                     * Decodes a ListSecurityPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListSecurityPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListSecurityPoliciesRequest;

                    /**
                     * Verifies a ListSecurityPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListSecurityPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListSecurityPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListSecurityPoliciesRequest;

                    /**
                     * Creates a plain object from a ListSecurityPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListSecurityPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListSecurityPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListSecurityPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListSecurityPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListServiceAttachmentsRequest. */
                interface IListServiceAttachmentsRequest {

                    /** ListServiceAttachmentsRequest filter */
                    filter?: (string|null);

                    /** ListServiceAttachmentsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListServiceAttachmentsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListServiceAttachmentsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListServiceAttachmentsRequest project */
                    project?: (string|null);

                    /** ListServiceAttachmentsRequest region */
                    region?: (string|null);

                    /** ListServiceAttachmentsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListServiceAttachmentsRequest. */
                class ListServiceAttachmentsRequest implements IListServiceAttachmentsRequest {

                    /**
                     * Constructs a new ListServiceAttachmentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListServiceAttachmentsRequest);

                    /** ListServiceAttachmentsRequest filter. */
                    public filter?: (string|null);

                    /** ListServiceAttachmentsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListServiceAttachmentsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListServiceAttachmentsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListServiceAttachmentsRequest project. */
                    public project: string;

                    /** ListServiceAttachmentsRequest region. */
                    public region: string;

                    /** ListServiceAttachmentsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListServiceAttachmentsRequest _filter. */
                    public _filter?: "filter";

                    /** ListServiceAttachmentsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListServiceAttachmentsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListServiceAttachmentsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListServiceAttachmentsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListServiceAttachmentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListServiceAttachmentsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListServiceAttachmentsRequest): google.cloud.compute.v1.ListServiceAttachmentsRequest;

                    /**
                     * Encodes the specified ListServiceAttachmentsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListServiceAttachmentsRequest.verify|verify} messages.
                     * @param message ListServiceAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListServiceAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListServiceAttachmentsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListServiceAttachmentsRequest.verify|verify} messages.
                     * @param message ListServiceAttachmentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListServiceAttachmentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListServiceAttachmentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListServiceAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListServiceAttachmentsRequest;

                    /**
                     * Decodes a ListServiceAttachmentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListServiceAttachmentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListServiceAttachmentsRequest;

                    /**
                     * Verifies a ListServiceAttachmentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListServiceAttachmentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListServiceAttachmentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListServiceAttachmentsRequest;

                    /**
                     * Creates a plain object from a ListServiceAttachmentsRequest message. Also converts values to other types if specified.
                     * @param message ListServiceAttachmentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListServiceAttachmentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListServiceAttachmentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListServiceAttachmentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListSnapshotsRequest. */
                interface IListSnapshotsRequest {

                    /** ListSnapshotsRequest filter */
                    filter?: (string|null);

                    /** ListSnapshotsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListSnapshotsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListSnapshotsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListSnapshotsRequest project */
                    project?: (string|null);

                    /** ListSnapshotsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListSnapshotsRequest. */
                class ListSnapshotsRequest implements IListSnapshotsRequest {

                    /**
                     * Constructs a new ListSnapshotsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListSnapshotsRequest);

                    /** ListSnapshotsRequest filter. */
                    public filter?: (string|null);

                    /** ListSnapshotsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListSnapshotsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListSnapshotsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListSnapshotsRequest project. */
                    public project: string;

                    /** ListSnapshotsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListSnapshotsRequest _filter. */
                    public _filter?: "filter";

                    /** ListSnapshotsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListSnapshotsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListSnapshotsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListSnapshotsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListSnapshotsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListSnapshotsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListSnapshotsRequest): google.cloud.compute.v1.ListSnapshotsRequest;

                    /**
                     * Encodes the specified ListSnapshotsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListSnapshotsRequest.verify|verify} messages.
                     * @param message ListSnapshotsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListSnapshotsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListSnapshotsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListSnapshotsRequest.verify|verify} messages.
                     * @param message ListSnapshotsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListSnapshotsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListSnapshotsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListSnapshotsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListSnapshotsRequest;

                    /**
                     * Decodes a ListSnapshotsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListSnapshotsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListSnapshotsRequest;

                    /**
                     * Verifies a ListSnapshotsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListSnapshotsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListSnapshotsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListSnapshotsRequest;

                    /**
                     * Creates a plain object from a ListSnapshotsRequest message. Also converts values to other types if specified.
                     * @param message ListSnapshotsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListSnapshotsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListSnapshotsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListSnapshotsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListSslCertificatesRequest. */
                interface IListSslCertificatesRequest {

                    /** ListSslCertificatesRequest filter */
                    filter?: (string|null);

                    /** ListSslCertificatesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListSslCertificatesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListSslCertificatesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListSslCertificatesRequest project */
                    project?: (string|null);

                    /** ListSslCertificatesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListSslCertificatesRequest. */
                class ListSslCertificatesRequest implements IListSslCertificatesRequest {

                    /**
                     * Constructs a new ListSslCertificatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListSslCertificatesRequest);

                    /** ListSslCertificatesRequest filter. */
                    public filter?: (string|null);

                    /** ListSslCertificatesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListSslCertificatesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListSslCertificatesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListSslCertificatesRequest project. */
                    public project: string;

                    /** ListSslCertificatesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListSslCertificatesRequest _filter. */
                    public _filter?: "filter";

                    /** ListSslCertificatesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListSslCertificatesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListSslCertificatesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListSslCertificatesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListSslCertificatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListSslCertificatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListSslCertificatesRequest): google.cloud.compute.v1.ListSslCertificatesRequest;

                    /**
                     * Encodes the specified ListSslCertificatesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListSslCertificatesRequest.verify|verify} messages.
                     * @param message ListSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListSslCertificatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListSslCertificatesRequest.verify|verify} messages.
                     * @param message ListSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListSslCertificatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListSslCertificatesRequest;

                    /**
                     * Decodes a ListSslCertificatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListSslCertificatesRequest;

                    /**
                     * Verifies a ListSslCertificatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListSslCertificatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListSslCertificatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListSslCertificatesRequest;

                    /**
                     * Creates a plain object from a ListSslCertificatesRequest message. Also converts values to other types if specified.
                     * @param message ListSslCertificatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListSslCertificatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListSslCertificatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListSslCertificatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListSslPoliciesRequest. */
                interface IListSslPoliciesRequest {

                    /** ListSslPoliciesRequest filter */
                    filter?: (string|null);

                    /** ListSslPoliciesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListSslPoliciesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListSslPoliciesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListSslPoliciesRequest project */
                    project?: (string|null);

                    /** ListSslPoliciesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListSslPoliciesRequest. */
                class ListSslPoliciesRequest implements IListSslPoliciesRequest {

                    /**
                     * Constructs a new ListSslPoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListSslPoliciesRequest);

                    /** ListSslPoliciesRequest filter. */
                    public filter?: (string|null);

                    /** ListSslPoliciesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListSslPoliciesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListSslPoliciesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListSslPoliciesRequest project. */
                    public project: string;

                    /** ListSslPoliciesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListSslPoliciesRequest _filter. */
                    public _filter?: "filter";

                    /** ListSslPoliciesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListSslPoliciesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListSslPoliciesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListSslPoliciesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListSslPoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListSslPoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListSslPoliciesRequest): google.cloud.compute.v1.ListSslPoliciesRequest;

                    /**
                     * Encodes the specified ListSslPoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListSslPoliciesRequest.verify|verify} messages.
                     * @param message ListSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListSslPoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListSslPoliciesRequest.verify|verify} messages.
                     * @param message ListSslPoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListSslPoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListSslPoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListSslPoliciesRequest;

                    /**
                     * Decodes a ListSslPoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListSslPoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListSslPoliciesRequest;

                    /**
                     * Verifies a ListSslPoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListSslPoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListSslPoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListSslPoliciesRequest;

                    /**
                     * Creates a plain object from a ListSslPoliciesRequest message. Also converts values to other types if specified.
                     * @param message ListSslPoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListSslPoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListSslPoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListSslPoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListSubnetworksRequest. */
                interface IListSubnetworksRequest {

                    /** ListSubnetworksRequest filter */
                    filter?: (string|null);

                    /** ListSubnetworksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListSubnetworksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListSubnetworksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListSubnetworksRequest project */
                    project?: (string|null);

                    /** ListSubnetworksRequest region */
                    region?: (string|null);

                    /** ListSubnetworksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListSubnetworksRequest. */
                class ListSubnetworksRequest implements IListSubnetworksRequest {

                    /**
                     * Constructs a new ListSubnetworksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListSubnetworksRequest);

                    /** ListSubnetworksRequest filter. */
                    public filter?: (string|null);

                    /** ListSubnetworksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListSubnetworksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListSubnetworksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListSubnetworksRequest project. */
                    public project: string;

                    /** ListSubnetworksRequest region. */
                    public region: string;

                    /** ListSubnetworksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListSubnetworksRequest _filter. */
                    public _filter?: "filter";

                    /** ListSubnetworksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListSubnetworksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListSubnetworksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListSubnetworksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListSubnetworksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListSubnetworksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListSubnetworksRequest): google.cloud.compute.v1.ListSubnetworksRequest;

                    /**
                     * Encodes the specified ListSubnetworksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListSubnetworksRequest.verify|verify} messages.
                     * @param message ListSubnetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListSubnetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListSubnetworksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListSubnetworksRequest.verify|verify} messages.
                     * @param message ListSubnetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListSubnetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListSubnetworksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListSubnetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListSubnetworksRequest;

                    /**
                     * Decodes a ListSubnetworksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListSubnetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListSubnetworksRequest;

                    /**
                     * Verifies a ListSubnetworksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListSubnetworksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListSubnetworksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListSubnetworksRequest;

                    /**
                     * Creates a plain object from a ListSubnetworksRequest message. Also converts values to other types if specified.
                     * @param message ListSubnetworksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListSubnetworksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListSubnetworksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListSubnetworksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetGrpcProxiesRequest. */
                interface IListTargetGrpcProxiesRequest {

                    /** ListTargetGrpcProxiesRequest filter */
                    filter?: (string|null);

                    /** ListTargetGrpcProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetGrpcProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetGrpcProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetGrpcProxiesRequest project */
                    project?: (string|null);

                    /** ListTargetGrpcProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetGrpcProxiesRequest. */
                class ListTargetGrpcProxiesRequest implements IListTargetGrpcProxiesRequest {

                    /**
                     * Constructs a new ListTargetGrpcProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetGrpcProxiesRequest);

                    /** ListTargetGrpcProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetGrpcProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetGrpcProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetGrpcProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetGrpcProxiesRequest project. */
                    public project: string;

                    /** ListTargetGrpcProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetGrpcProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetGrpcProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetGrpcProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetGrpcProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetGrpcProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetGrpcProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetGrpcProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetGrpcProxiesRequest): google.cloud.compute.v1.ListTargetGrpcProxiesRequest;

                    /**
                     * Encodes the specified ListTargetGrpcProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetGrpcProxiesRequest.verify|verify} messages.
                     * @param message ListTargetGrpcProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetGrpcProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetGrpcProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetGrpcProxiesRequest.verify|verify} messages.
                     * @param message ListTargetGrpcProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetGrpcProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetGrpcProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetGrpcProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetGrpcProxiesRequest;

                    /**
                     * Decodes a ListTargetGrpcProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetGrpcProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetGrpcProxiesRequest;

                    /**
                     * Verifies a ListTargetGrpcProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetGrpcProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetGrpcProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetGrpcProxiesRequest;

                    /**
                     * Creates a plain object from a ListTargetGrpcProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListTargetGrpcProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetGrpcProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetGrpcProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetGrpcProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetHttpProxiesRequest. */
                interface IListTargetHttpProxiesRequest {

                    /** ListTargetHttpProxiesRequest filter */
                    filter?: (string|null);

                    /** ListTargetHttpProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetHttpProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetHttpProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetHttpProxiesRequest project */
                    project?: (string|null);

                    /** ListTargetHttpProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetHttpProxiesRequest. */
                class ListTargetHttpProxiesRequest implements IListTargetHttpProxiesRequest {

                    /**
                     * Constructs a new ListTargetHttpProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetHttpProxiesRequest);

                    /** ListTargetHttpProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetHttpProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetHttpProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetHttpProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetHttpProxiesRequest project. */
                    public project: string;

                    /** ListTargetHttpProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetHttpProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetHttpProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetHttpProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetHttpProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetHttpProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetHttpProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetHttpProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetHttpProxiesRequest): google.cloud.compute.v1.ListTargetHttpProxiesRequest;

                    /**
                     * Encodes the specified ListTargetHttpProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetHttpProxiesRequest.verify|verify} messages.
                     * @param message ListTargetHttpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetHttpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetHttpProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetHttpProxiesRequest.verify|verify} messages.
                     * @param message ListTargetHttpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetHttpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetHttpProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetHttpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetHttpProxiesRequest;

                    /**
                     * Decodes a ListTargetHttpProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetHttpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetHttpProxiesRequest;

                    /**
                     * Verifies a ListTargetHttpProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetHttpProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetHttpProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetHttpProxiesRequest;

                    /**
                     * Creates a plain object from a ListTargetHttpProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListTargetHttpProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetHttpProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetHttpProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetHttpProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetHttpsProxiesRequest. */
                interface IListTargetHttpsProxiesRequest {

                    /** ListTargetHttpsProxiesRequest filter */
                    filter?: (string|null);

                    /** ListTargetHttpsProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetHttpsProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetHttpsProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetHttpsProxiesRequest project */
                    project?: (string|null);

                    /** ListTargetHttpsProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetHttpsProxiesRequest. */
                class ListTargetHttpsProxiesRequest implements IListTargetHttpsProxiesRequest {

                    /**
                     * Constructs a new ListTargetHttpsProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetHttpsProxiesRequest);

                    /** ListTargetHttpsProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetHttpsProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetHttpsProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetHttpsProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetHttpsProxiesRequest project. */
                    public project: string;

                    /** ListTargetHttpsProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetHttpsProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetHttpsProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetHttpsProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetHttpsProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetHttpsProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetHttpsProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetHttpsProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetHttpsProxiesRequest): google.cloud.compute.v1.ListTargetHttpsProxiesRequest;

                    /**
                     * Encodes the specified ListTargetHttpsProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetHttpsProxiesRequest.verify|verify} messages.
                     * @param message ListTargetHttpsProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetHttpsProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetHttpsProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetHttpsProxiesRequest.verify|verify} messages.
                     * @param message ListTargetHttpsProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetHttpsProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetHttpsProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetHttpsProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetHttpsProxiesRequest;

                    /**
                     * Decodes a ListTargetHttpsProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetHttpsProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetHttpsProxiesRequest;

                    /**
                     * Verifies a ListTargetHttpsProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetHttpsProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetHttpsProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetHttpsProxiesRequest;

                    /**
                     * Creates a plain object from a ListTargetHttpsProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListTargetHttpsProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetHttpsProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetHttpsProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetHttpsProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetInstancesRequest. */
                interface IListTargetInstancesRequest {

                    /** ListTargetInstancesRequest filter */
                    filter?: (string|null);

                    /** ListTargetInstancesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetInstancesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetInstancesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetInstancesRequest project */
                    project?: (string|null);

                    /** ListTargetInstancesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListTargetInstancesRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListTargetInstancesRequest. */
                class ListTargetInstancesRequest implements IListTargetInstancesRequest {

                    /**
                     * Constructs a new ListTargetInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetInstancesRequest);

                    /** ListTargetInstancesRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetInstancesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetInstancesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetInstancesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetInstancesRequest project. */
                    public project: string;

                    /** ListTargetInstancesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetInstancesRequest zone. */
                    public zone: string;

                    /** ListTargetInstancesRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetInstancesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetInstancesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetInstancesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetInstancesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetInstancesRequest): google.cloud.compute.v1.ListTargetInstancesRequest;

                    /**
                     * Encodes the specified ListTargetInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetInstancesRequest.verify|verify} messages.
                     * @param message ListTargetInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetInstancesRequest.verify|verify} messages.
                     * @param message ListTargetInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetInstancesRequest;

                    /**
                     * Decodes a ListTargetInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetInstancesRequest;

                    /**
                     * Verifies a ListTargetInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetInstancesRequest;

                    /**
                     * Creates a plain object from a ListTargetInstancesRequest message. Also converts values to other types if specified.
                     * @param message ListTargetInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetPoolsRequest. */
                interface IListTargetPoolsRequest {

                    /** ListTargetPoolsRequest filter */
                    filter?: (string|null);

                    /** ListTargetPoolsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetPoolsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetPoolsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetPoolsRequest project */
                    project?: (string|null);

                    /** ListTargetPoolsRequest region */
                    region?: (string|null);

                    /** ListTargetPoolsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetPoolsRequest. */
                class ListTargetPoolsRequest implements IListTargetPoolsRequest {

                    /**
                     * Constructs a new ListTargetPoolsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetPoolsRequest);

                    /** ListTargetPoolsRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetPoolsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetPoolsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetPoolsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetPoolsRequest project. */
                    public project: string;

                    /** ListTargetPoolsRequest region. */
                    public region: string;

                    /** ListTargetPoolsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetPoolsRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetPoolsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetPoolsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetPoolsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetPoolsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetPoolsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetPoolsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetPoolsRequest): google.cloud.compute.v1.ListTargetPoolsRequest;

                    /**
                     * Encodes the specified ListTargetPoolsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetPoolsRequest.verify|verify} messages.
                     * @param message ListTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetPoolsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetPoolsRequest.verify|verify} messages.
                     * @param message ListTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetPoolsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetPoolsRequest;

                    /**
                     * Decodes a ListTargetPoolsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetPoolsRequest;

                    /**
                     * Verifies a ListTargetPoolsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetPoolsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetPoolsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetPoolsRequest;

                    /**
                     * Creates a plain object from a ListTargetPoolsRequest message. Also converts values to other types if specified.
                     * @param message ListTargetPoolsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetPoolsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetPoolsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetPoolsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetSslProxiesRequest. */
                interface IListTargetSslProxiesRequest {

                    /** ListTargetSslProxiesRequest filter */
                    filter?: (string|null);

                    /** ListTargetSslProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetSslProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetSslProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetSslProxiesRequest project */
                    project?: (string|null);

                    /** ListTargetSslProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetSslProxiesRequest. */
                class ListTargetSslProxiesRequest implements IListTargetSslProxiesRequest {

                    /**
                     * Constructs a new ListTargetSslProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetSslProxiesRequest);

                    /** ListTargetSslProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetSslProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetSslProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetSslProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetSslProxiesRequest project. */
                    public project: string;

                    /** ListTargetSslProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetSslProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetSslProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetSslProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetSslProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetSslProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetSslProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetSslProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetSslProxiesRequest): google.cloud.compute.v1.ListTargetSslProxiesRequest;

                    /**
                     * Encodes the specified ListTargetSslProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetSslProxiesRequest.verify|verify} messages.
                     * @param message ListTargetSslProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetSslProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetSslProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetSslProxiesRequest.verify|verify} messages.
                     * @param message ListTargetSslProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetSslProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetSslProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetSslProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetSslProxiesRequest;

                    /**
                     * Decodes a ListTargetSslProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetSslProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetSslProxiesRequest;

                    /**
                     * Verifies a ListTargetSslProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetSslProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetSslProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetSslProxiesRequest;

                    /**
                     * Creates a plain object from a ListTargetSslProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListTargetSslProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetSslProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetSslProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetSslProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetTcpProxiesRequest. */
                interface IListTargetTcpProxiesRequest {

                    /** ListTargetTcpProxiesRequest filter */
                    filter?: (string|null);

                    /** ListTargetTcpProxiesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetTcpProxiesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetTcpProxiesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetTcpProxiesRequest project */
                    project?: (string|null);

                    /** ListTargetTcpProxiesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetTcpProxiesRequest. */
                class ListTargetTcpProxiesRequest implements IListTargetTcpProxiesRequest {

                    /**
                     * Constructs a new ListTargetTcpProxiesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetTcpProxiesRequest);

                    /** ListTargetTcpProxiesRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetTcpProxiesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetTcpProxiesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetTcpProxiesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetTcpProxiesRequest project. */
                    public project: string;

                    /** ListTargetTcpProxiesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetTcpProxiesRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetTcpProxiesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetTcpProxiesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetTcpProxiesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetTcpProxiesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetTcpProxiesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetTcpProxiesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetTcpProxiesRequest): google.cloud.compute.v1.ListTargetTcpProxiesRequest;

                    /**
                     * Encodes the specified ListTargetTcpProxiesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetTcpProxiesRequest.verify|verify} messages.
                     * @param message ListTargetTcpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetTcpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetTcpProxiesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetTcpProxiesRequest.verify|verify} messages.
                     * @param message ListTargetTcpProxiesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetTcpProxiesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetTcpProxiesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetTcpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetTcpProxiesRequest;

                    /**
                     * Decodes a ListTargetTcpProxiesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetTcpProxiesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetTcpProxiesRequest;

                    /**
                     * Verifies a ListTargetTcpProxiesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetTcpProxiesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetTcpProxiesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetTcpProxiesRequest;

                    /**
                     * Creates a plain object from a ListTargetTcpProxiesRequest message. Also converts values to other types if specified.
                     * @param message ListTargetTcpProxiesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetTcpProxiesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetTcpProxiesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetTcpProxiesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListTargetVpnGatewaysRequest. */
                interface IListTargetVpnGatewaysRequest {

                    /** ListTargetVpnGatewaysRequest filter */
                    filter?: (string|null);

                    /** ListTargetVpnGatewaysRequest maxResults */
                    maxResults?: (number|null);

                    /** ListTargetVpnGatewaysRequest orderBy */
                    orderBy?: (string|null);

                    /** ListTargetVpnGatewaysRequest pageToken */
                    pageToken?: (string|null);

                    /** ListTargetVpnGatewaysRequest project */
                    project?: (string|null);

                    /** ListTargetVpnGatewaysRequest region */
                    region?: (string|null);

                    /** ListTargetVpnGatewaysRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListTargetVpnGatewaysRequest. */
                class ListTargetVpnGatewaysRequest implements IListTargetVpnGatewaysRequest {

                    /**
                     * Constructs a new ListTargetVpnGatewaysRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListTargetVpnGatewaysRequest);

                    /** ListTargetVpnGatewaysRequest filter. */
                    public filter?: (string|null);

                    /** ListTargetVpnGatewaysRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListTargetVpnGatewaysRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListTargetVpnGatewaysRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListTargetVpnGatewaysRequest project. */
                    public project: string;

                    /** ListTargetVpnGatewaysRequest region. */
                    public region: string;

                    /** ListTargetVpnGatewaysRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListTargetVpnGatewaysRequest _filter. */
                    public _filter?: "filter";

                    /** ListTargetVpnGatewaysRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListTargetVpnGatewaysRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListTargetVpnGatewaysRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListTargetVpnGatewaysRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListTargetVpnGatewaysRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListTargetVpnGatewaysRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListTargetVpnGatewaysRequest): google.cloud.compute.v1.ListTargetVpnGatewaysRequest;

                    /**
                     * Encodes the specified ListTargetVpnGatewaysRequest message. Does not implicitly {@link google.cloud.compute.v1.ListTargetVpnGatewaysRequest.verify|verify} messages.
                     * @param message ListTargetVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListTargetVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListTargetVpnGatewaysRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListTargetVpnGatewaysRequest.verify|verify} messages.
                     * @param message ListTargetVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListTargetVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListTargetVpnGatewaysRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListTargetVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListTargetVpnGatewaysRequest;

                    /**
                     * Decodes a ListTargetVpnGatewaysRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListTargetVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListTargetVpnGatewaysRequest;

                    /**
                     * Verifies a ListTargetVpnGatewaysRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListTargetVpnGatewaysRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListTargetVpnGatewaysRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListTargetVpnGatewaysRequest;

                    /**
                     * Creates a plain object from a ListTargetVpnGatewaysRequest message. Also converts values to other types if specified.
                     * @param message ListTargetVpnGatewaysRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListTargetVpnGatewaysRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListTargetVpnGatewaysRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListTargetVpnGatewaysRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListUrlMapsRequest. */
                interface IListUrlMapsRequest {

                    /** ListUrlMapsRequest filter */
                    filter?: (string|null);

                    /** ListUrlMapsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListUrlMapsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListUrlMapsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListUrlMapsRequest project */
                    project?: (string|null);

                    /** ListUrlMapsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListUrlMapsRequest. */
                class ListUrlMapsRequest implements IListUrlMapsRequest {

                    /**
                     * Constructs a new ListUrlMapsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListUrlMapsRequest);

                    /** ListUrlMapsRequest filter. */
                    public filter?: (string|null);

                    /** ListUrlMapsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListUrlMapsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListUrlMapsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListUrlMapsRequest project. */
                    public project: string;

                    /** ListUrlMapsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListUrlMapsRequest _filter. */
                    public _filter?: "filter";

                    /** ListUrlMapsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListUrlMapsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListUrlMapsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListUrlMapsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListUrlMapsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListUrlMapsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListUrlMapsRequest): google.cloud.compute.v1.ListUrlMapsRequest;

                    /**
                     * Encodes the specified ListUrlMapsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListUrlMapsRequest.verify|verify} messages.
                     * @param message ListUrlMapsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListUrlMapsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListUrlMapsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListUrlMapsRequest.verify|verify} messages.
                     * @param message ListUrlMapsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListUrlMapsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListUrlMapsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListUrlMapsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListUrlMapsRequest;

                    /**
                     * Decodes a ListUrlMapsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListUrlMapsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListUrlMapsRequest;

                    /**
                     * Verifies a ListUrlMapsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListUrlMapsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListUrlMapsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListUrlMapsRequest;

                    /**
                     * Creates a plain object from a ListUrlMapsRequest message. Also converts values to other types if specified.
                     * @param message ListUrlMapsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListUrlMapsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListUrlMapsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListUrlMapsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListUsableSubnetworksRequest. */
                interface IListUsableSubnetworksRequest {

                    /** ListUsableSubnetworksRequest filter */
                    filter?: (string|null);

                    /** ListUsableSubnetworksRequest maxResults */
                    maxResults?: (number|null);

                    /** ListUsableSubnetworksRequest orderBy */
                    orderBy?: (string|null);

                    /** ListUsableSubnetworksRequest pageToken */
                    pageToken?: (string|null);

                    /** ListUsableSubnetworksRequest project */
                    project?: (string|null);

                    /** ListUsableSubnetworksRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListUsableSubnetworksRequest. */
                class ListUsableSubnetworksRequest implements IListUsableSubnetworksRequest {

                    /**
                     * Constructs a new ListUsableSubnetworksRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListUsableSubnetworksRequest);

                    /** ListUsableSubnetworksRequest filter. */
                    public filter?: (string|null);

                    /** ListUsableSubnetworksRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListUsableSubnetworksRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListUsableSubnetworksRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListUsableSubnetworksRequest project. */
                    public project: string;

                    /** ListUsableSubnetworksRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListUsableSubnetworksRequest _filter. */
                    public _filter?: "filter";

                    /** ListUsableSubnetworksRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListUsableSubnetworksRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListUsableSubnetworksRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListUsableSubnetworksRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListUsableSubnetworksRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListUsableSubnetworksRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListUsableSubnetworksRequest): google.cloud.compute.v1.ListUsableSubnetworksRequest;

                    /**
                     * Encodes the specified ListUsableSubnetworksRequest message. Does not implicitly {@link google.cloud.compute.v1.ListUsableSubnetworksRequest.verify|verify} messages.
                     * @param message ListUsableSubnetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListUsableSubnetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListUsableSubnetworksRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListUsableSubnetworksRequest.verify|verify} messages.
                     * @param message ListUsableSubnetworksRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListUsableSubnetworksRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListUsableSubnetworksRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListUsableSubnetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListUsableSubnetworksRequest;

                    /**
                     * Decodes a ListUsableSubnetworksRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListUsableSubnetworksRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListUsableSubnetworksRequest;

                    /**
                     * Verifies a ListUsableSubnetworksRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListUsableSubnetworksRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListUsableSubnetworksRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListUsableSubnetworksRequest;

                    /**
                     * Creates a plain object from a ListUsableSubnetworksRequest message. Also converts values to other types if specified.
                     * @param message ListUsableSubnetworksRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListUsableSubnetworksRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListUsableSubnetworksRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListUsableSubnetworksRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListVpnGatewaysRequest. */
                interface IListVpnGatewaysRequest {

                    /** ListVpnGatewaysRequest filter */
                    filter?: (string|null);

                    /** ListVpnGatewaysRequest maxResults */
                    maxResults?: (number|null);

                    /** ListVpnGatewaysRequest orderBy */
                    orderBy?: (string|null);

                    /** ListVpnGatewaysRequest pageToken */
                    pageToken?: (string|null);

                    /** ListVpnGatewaysRequest project */
                    project?: (string|null);

                    /** ListVpnGatewaysRequest region */
                    region?: (string|null);

                    /** ListVpnGatewaysRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListVpnGatewaysRequest. */
                class ListVpnGatewaysRequest implements IListVpnGatewaysRequest {

                    /**
                     * Constructs a new ListVpnGatewaysRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListVpnGatewaysRequest);

                    /** ListVpnGatewaysRequest filter. */
                    public filter?: (string|null);

                    /** ListVpnGatewaysRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListVpnGatewaysRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListVpnGatewaysRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListVpnGatewaysRequest project. */
                    public project: string;

                    /** ListVpnGatewaysRequest region. */
                    public region: string;

                    /** ListVpnGatewaysRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListVpnGatewaysRequest _filter. */
                    public _filter?: "filter";

                    /** ListVpnGatewaysRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListVpnGatewaysRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListVpnGatewaysRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListVpnGatewaysRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListVpnGatewaysRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListVpnGatewaysRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListVpnGatewaysRequest): google.cloud.compute.v1.ListVpnGatewaysRequest;

                    /**
                     * Encodes the specified ListVpnGatewaysRequest message. Does not implicitly {@link google.cloud.compute.v1.ListVpnGatewaysRequest.verify|verify} messages.
                     * @param message ListVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListVpnGatewaysRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListVpnGatewaysRequest.verify|verify} messages.
                     * @param message ListVpnGatewaysRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListVpnGatewaysRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListVpnGatewaysRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListVpnGatewaysRequest;

                    /**
                     * Decodes a ListVpnGatewaysRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListVpnGatewaysRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListVpnGatewaysRequest;

                    /**
                     * Verifies a ListVpnGatewaysRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListVpnGatewaysRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListVpnGatewaysRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListVpnGatewaysRequest;

                    /**
                     * Creates a plain object from a ListVpnGatewaysRequest message. Also converts values to other types if specified.
                     * @param message ListVpnGatewaysRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListVpnGatewaysRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListVpnGatewaysRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListVpnGatewaysRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListVpnTunnelsRequest. */
                interface IListVpnTunnelsRequest {

                    /** ListVpnTunnelsRequest filter */
                    filter?: (string|null);

                    /** ListVpnTunnelsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListVpnTunnelsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListVpnTunnelsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListVpnTunnelsRequest project */
                    project?: (string|null);

                    /** ListVpnTunnelsRequest region */
                    region?: (string|null);

                    /** ListVpnTunnelsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListVpnTunnelsRequest. */
                class ListVpnTunnelsRequest implements IListVpnTunnelsRequest {

                    /**
                     * Constructs a new ListVpnTunnelsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListVpnTunnelsRequest);

                    /** ListVpnTunnelsRequest filter. */
                    public filter?: (string|null);

                    /** ListVpnTunnelsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListVpnTunnelsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListVpnTunnelsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListVpnTunnelsRequest project. */
                    public project: string;

                    /** ListVpnTunnelsRequest region. */
                    public region: string;

                    /** ListVpnTunnelsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListVpnTunnelsRequest _filter. */
                    public _filter?: "filter";

                    /** ListVpnTunnelsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListVpnTunnelsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListVpnTunnelsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListVpnTunnelsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListVpnTunnelsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListVpnTunnelsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListVpnTunnelsRequest): google.cloud.compute.v1.ListVpnTunnelsRequest;

                    /**
                     * Encodes the specified ListVpnTunnelsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListVpnTunnelsRequest.verify|verify} messages.
                     * @param message ListVpnTunnelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListVpnTunnelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListVpnTunnelsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListVpnTunnelsRequest.verify|verify} messages.
                     * @param message ListVpnTunnelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListVpnTunnelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListVpnTunnelsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListVpnTunnelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListVpnTunnelsRequest;

                    /**
                     * Decodes a ListVpnTunnelsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListVpnTunnelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListVpnTunnelsRequest;

                    /**
                     * Verifies a ListVpnTunnelsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListVpnTunnelsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListVpnTunnelsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListVpnTunnelsRequest;

                    /**
                     * Creates a plain object from a ListVpnTunnelsRequest message. Also converts values to other types if specified.
                     * @param message ListVpnTunnelsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListVpnTunnelsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListVpnTunnelsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListVpnTunnelsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListXpnHostsProjectsRequest. */
                interface IListXpnHostsProjectsRequest {

                    /** ListXpnHostsProjectsRequest filter */
                    filter?: (string|null);

                    /** ListXpnHostsProjectsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListXpnHostsProjectsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListXpnHostsProjectsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListXpnHostsProjectsRequest project */
                    project?: (string|null);

                    /** ListXpnHostsProjectsRequest projectsListXpnHostsRequestResource */
                    projectsListXpnHostsRequestResource?: (google.cloud.compute.v1.IProjectsListXpnHostsRequest|null);

                    /** ListXpnHostsProjectsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListXpnHostsProjectsRequest. */
                class ListXpnHostsProjectsRequest implements IListXpnHostsProjectsRequest {

                    /**
                     * Constructs a new ListXpnHostsProjectsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListXpnHostsProjectsRequest);

                    /** ListXpnHostsProjectsRequest filter. */
                    public filter?: (string|null);

                    /** ListXpnHostsProjectsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListXpnHostsProjectsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListXpnHostsProjectsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListXpnHostsProjectsRequest project. */
                    public project: string;

                    /** ListXpnHostsProjectsRequest projectsListXpnHostsRequestResource. */
                    public projectsListXpnHostsRequestResource?: (google.cloud.compute.v1.IProjectsListXpnHostsRequest|null);

                    /** ListXpnHostsProjectsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListXpnHostsProjectsRequest _filter. */
                    public _filter?: "filter";

                    /** ListXpnHostsProjectsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListXpnHostsProjectsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListXpnHostsProjectsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListXpnHostsProjectsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListXpnHostsProjectsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListXpnHostsProjectsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListXpnHostsProjectsRequest): google.cloud.compute.v1.ListXpnHostsProjectsRequest;

                    /**
                     * Encodes the specified ListXpnHostsProjectsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListXpnHostsProjectsRequest.verify|verify} messages.
                     * @param message ListXpnHostsProjectsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListXpnHostsProjectsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListXpnHostsProjectsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListXpnHostsProjectsRequest.verify|verify} messages.
                     * @param message ListXpnHostsProjectsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListXpnHostsProjectsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListXpnHostsProjectsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListXpnHostsProjectsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListXpnHostsProjectsRequest;

                    /**
                     * Decodes a ListXpnHostsProjectsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListXpnHostsProjectsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListXpnHostsProjectsRequest;

                    /**
                     * Verifies a ListXpnHostsProjectsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListXpnHostsProjectsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListXpnHostsProjectsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListXpnHostsProjectsRequest;

                    /**
                     * Creates a plain object from a ListXpnHostsProjectsRequest message. Also converts values to other types if specified.
                     * @param message ListXpnHostsProjectsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListXpnHostsProjectsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListXpnHostsProjectsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListXpnHostsProjectsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListZoneOperationsRequest. */
                interface IListZoneOperationsRequest {

                    /** ListZoneOperationsRequest filter */
                    filter?: (string|null);

                    /** ListZoneOperationsRequest maxResults */
                    maxResults?: (number|null);

                    /** ListZoneOperationsRequest orderBy */
                    orderBy?: (string|null);

                    /** ListZoneOperationsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListZoneOperationsRequest project */
                    project?: (string|null);

                    /** ListZoneOperationsRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);

                    /** ListZoneOperationsRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ListZoneOperationsRequest. */
                class ListZoneOperationsRequest implements IListZoneOperationsRequest {

                    /**
                     * Constructs a new ListZoneOperationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListZoneOperationsRequest);

                    /** ListZoneOperationsRequest filter. */
                    public filter?: (string|null);

                    /** ListZoneOperationsRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListZoneOperationsRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListZoneOperationsRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListZoneOperationsRequest project. */
                    public project: string;

                    /** ListZoneOperationsRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListZoneOperationsRequest zone. */
                    public zone: string;

                    /** ListZoneOperationsRequest _filter. */
                    public _filter?: "filter";

                    /** ListZoneOperationsRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListZoneOperationsRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListZoneOperationsRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListZoneOperationsRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListZoneOperationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListZoneOperationsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListZoneOperationsRequest): google.cloud.compute.v1.ListZoneOperationsRequest;

                    /**
                     * Encodes the specified ListZoneOperationsRequest message. Does not implicitly {@link google.cloud.compute.v1.ListZoneOperationsRequest.verify|verify} messages.
                     * @param message ListZoneOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListZoneOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListZoneOperationsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListZoneOperationsRequest.verify|verify} messages.
                     * @param message ListZoneOperationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListZoneOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListZoneOperationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListZoneOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListZoneOperationsRequest;

                    /**
                     * Decodes a ListZoneOperationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListZoneOperationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListZoneOperationsRequest;

                    /**
                     * Verifies a ListZoneOperationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListZoneOperationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListZoneOperationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListZoneOperationsRequest;

                    /**
                     * Creates a plain object from a ListZoneOperationsRequest message. Also converts values to other types if specified.
                     * @param message ListZoneOperationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListZoneOperationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListZoneOperationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListZoneOperationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListZonesRequest. */
                interface IListZonesRequest {

                    /** ListZonesRequest filter */
                    filter?: (string|null);

                    /** ListZonesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListZonesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListZonesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListZonesRequest project */
                    project?: (string|null);

                    /** ListZonesRequest returnPartialSuccess */
                    returnPartialSuccess?: (boolean|null);
                }

                /** Represents a ListZonesRequest. */
                class ListZonesRequest implements IListZonesRequest {

                    /**
                     * Constructs a new ListZonesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IListZonesRequest);

                    /** ListZonesRequest filter. */
                    public filter?: (string|null);

                    /** ListZonesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListZonesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** ListZonesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListZonesRequest project. */
                    public project: string;

                    /** ListZonesRequest returnPartialSuccess. */
                    public returnPartialSuccess?: (boolean|null);

                    /** ListZonesRequest _filter. */
                    public _filter?: "filter";

                    /** ListZonesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListZonesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** ListZonesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /** ListZonesRequest _returnPartialSuccess. */
                    public _returnPartialSuccess?: "returnPartialSuccess";

                    /**
                     * Creates a new ListZonesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListZonesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IListZonesRequest): google.cloud.compute.v1.ListZonesRequest;

                    /**
                     * Encodes the specified ListZonesRequest message. Does not implicitly {@link google.cloud.compute.v1.ListZonesRequest.verify|verify} messages.
                     * @param message ListZonesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IListZonesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListZonesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ListZonesRequest.verify|verify} messages.
                     * @param message ListZonesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IListZonesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListZonesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListZonesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ListZonesRequest;

                    /**
                     * Decodes a ListZonesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListZonesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ListZonesRequest;

                    /**
                     * Verifies a ListZonesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListZonesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListZonesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ListZonesRequest;

                    /**
                     * Creates a plain object from a ListZonesRequest message. Also converts values to other types if specified.
                     * @param message ListZonesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ListZonesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListZonesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListZonesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LocalDisk. */
                interface ILocalDisk {

                    /** LocalDisk diskCount */
                    diskCount?: (number|null);

                    /** LocalDisk diskSizeGb */
                    diskSizeGb?: (number|null);

                    /** LocalDisk diskType */
                    diskType?: (string|null);
                }

                /** Represents a LocalDisk. */
                class LocalDisk implements ILocalDisk {

                    /**
                     * Constructs a new LocalDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILocalDisk);

                    /** LocalDisk diskCount. */
                    public diskCount?: (number|null);

                    /** LocalDisk diskSizeGb. */
                    public diskSizeGb?: (number|null);

                    /** LocalDisk diskType. */
                    public diskType?: (string|null);

                    /** LocalDisk _diskCount. */
                    public _diskCount?: "diskCount";

                    /** LocalDisk _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** LocalDisk _diskType. */
                    public _diskType?: "diskType";

                    /**
                     * Creates a new LocalDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LocalDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILocalDisk): google.cloud.compute.v1.LocalDisk;

                    /**
                     * Encodes the specified LocalDisk message. Does not implicitly {@link google.cloud.compute.v1.LocalDisk.verify|verify} messages.
                     * @param message LocalDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILocalDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LocalDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LocalDisk.verify|verify} messages.
                     * @param message LocalDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILocalDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LocalDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LocalDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LocalDisk;

                    /**
                     * Decodes a LocalDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LocalDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LocalDisk;

                    /**
                     * Verifies a LocalDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LocalDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LocalDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LocalDisk;

                    /**
                     * Creates a plain object from a LocalDisk message. Also converts values to other types if specified.
                     * @param message LocalDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LocalDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LocalDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LocalDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LocalizedMessage. */
                interface ILocalizedMessage {

                    /** LocalizedMessage locale */
                    locale?: (string|null);

                    /** LocalizedMessage message */
                    message?: (string|null);
                }

                /** Represents a LocalizedMessage. */
                class LocalizedMessage implements ILocalizedMessage {

                    /**
                     * Constructs a new LocalizedMessage.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILocalizedMessage);

                    /** LocalizedMessage locale. */
                    public locale?: (string|null);

                    /** LocalizedMessage message. */
                    public message?: (string|null);

                    /** LocalizedMessage _locale. */
                    public _locale?: "locale";

                    /** LocalizedMessage _message. */
                    public _message?: "message";

                    /**
                     * Creates a new LocalizedMessage instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LocalizedMessage instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILocalizedMessage): google.cloud.compute.v1.LocalizedMessage;

                    /**
                     * Encodes the specified LocalizedMessage message. Does not implicitly {@link google.cloud.compute.v1.LocalizedMessage.verify|verify} messages.
                     * @param message LocalizedMessage message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILocalizedMessage, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LocalizedMessage message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LocalizedMessage.verify|verify} messages.
                     * @param message LocalizedMessage message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILocalizedMessage, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LocalizedMessage message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LocalizedMessage
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LocalizedMessage;

                    /**
                     * Decodes a LocalizedMessage message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LocalizedMessage
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LocalizedMessage;

                    /**
                     * Verifies a LocalizedMessage message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LocalizedMessage message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LocalizedMessage
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LocalizedMessage;

                    /**
                     * Creates a plain object from a LocalizedMessage message. Also converts values to other types if specified.
                     * @param message LocalizedMessage
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LocalizedMessage, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LocalizedMessage to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LocalizedMessage
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LocationPolicy. */
                interface ILocationPolicy {

                    /** LocationPolicy locations */
                    locations?: ({ [k: string]: google.cloud.compute.v1.ILocationPolicyLocation }|null);

                    /** LocationPolicy targetShape */
                    targetShape?: (string|null);
                }

                /** Represents a LocationPolicy. */
                class LocationPolicy implements ILocationPolicy {

                    /**
                     * Constructs a new LocationPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILocationPolicy);

                    /** LocationPolicy locations. */
                    public locations: { [k: string]: google.cloud.compute.v1.ILocationPolicyLocation };

                    /** LocationPolicy targetShape. */
                    public targetShape?: (string|null);

                    /** LocationPolicy _targetShape. */
                    public _targetShape?: "targetShape";

                    /**
                     * Creates a new LocationPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LocationPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILocationPolicy): google.cloud.compute.v1.LocationPolicy;

                    /**
                     * Encodes the specified LocationPolicy message. Does not implicitly {@link google.cloud.compute.v1.LocationPolicy.verify|verify} messages.
                     * @param message LocationPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILocationPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LocationPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LocationPolicy.verify|verify} messages.
                     * @param message LocationPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILocationPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LocationPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LocationPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LocationPolicy;

                    /**
                     * Decodes a LocationPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LocationPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LocationPolicy;

                    /**
                     * Verifies a LocationPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LocationPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LocationPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LocationPolicy;

                    /**
                     * Creates a plain object from a LocationPolicy message. Also converts values to other types if specified.
                     * @param message LocationPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LocationPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LocationPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LocationPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace LocationPolicy {

                    /** TargetShape enum. */
                    enum TargetShape {
                        UNDEFINED_TARGET_SHAPE = 0,
                        ANY = 64972,
                        ANY_SINGLE_ZONE = 61100880,
                        BALANCED = 468409608
                    }
                }

                /** Properties of a LocationPolicyLocation. */
                interface ILocationPolicyLocation {

                    /** LocationPolicyLocation constraints */
                    constraints?: (google.cloud.compute.v1.ILocationPolicyLocationConstraints|null);

                    /** LocationPolicyLocation preference */
                    preference?: (string|null);
                }

                /** Represents a LocationPolicyLocation. */
                class LocationPolicyLocation implements ILocationPolicyLocation {

                    /**
                     * Constructs a new LocationPolicyLocation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILocationPolicyLocation);

                    /** LocationPolicyLocation constraints. */
                    public constraints?: (google.cloud.compute.v1.ILocationPolicyLocationConstraints|null);

                    /** LocationPolicyLocation preference. */
                    public preference?: (string|null);

                    /** LocationPolicyLocation _constraints. */
                    public _constraints?: "constraints";

                    /** LocationPolicyLocation _preference. */
                    public _preference?: "preference";

                    /**
                     * Creates a new LocationPolicyLocation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LocationPolicyLocation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILocationPolicyLocation): google.cloud.compute.v1.LocationPolicyLocation;

                    /**
                     * Encodes the specified LocationPolicyLocation message. Does not implicitly {@link google.cloud.compute.v1.LocationPolicyLocation.verify|verify} messages.
                     * @param message LocationPolicyLocation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILocationPolicyLocation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LocationPolicyLocation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LocationPolicyLocation.verify|verify} messages.
                     * @param message LocationPolicyLocation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILocationPolicyLocation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LocationPolicyLocation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LocationPolicyLocation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LocationPolicyLocation;

                    /**
                     * Decodes a LocationPolicyLocation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LocationPolicyLocation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LocationPolicyLocation;

                    /**
                     * Verifies a LocationPolicyLocation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LocationPolicyLocation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LocationPolicyLocation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LocationPolicyLocation;

                    /**
                     * Creates a plain object from a LocationPolicyLocation message. Also converts values to other types if specified.
                     * @param message LocationPolicyLocation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LocationPolicyLocation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LocationPolicyLocation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LocationPolicyLocation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace LocationPolicyLocation {

                    /** Preference enum. */
                    enum Preference {
                        UNDEFINED_PREFERENCE = 0,
                        ALLOW = 62368553,
                        DENY = 2094604,
                        PREFERENCE_UNSPECIFIED = 496219571
                    }
                }

                /** Properties of a LocationPolicyLocationConstraints. */
                interface ILocationPolicyLocationConstraints {

                    /** LocationPolicyLocationConstraints maxCount */
                    maxCount?: (number|null);
                }

                /** Represents a LocationPolicyLocationConstraints. */
                class LocationPolicyLocationConstraints implements ILocationPolicyLocationConstraints {

                    /**
                     * Constructs a new LocationPolicyLocationConstraints.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILocationPolicyLocationConstraints);

                    /** LocationPolicyLocationConstraints maxCount. */
                    public maxCount?: (number|null);

                    /** LocationPolicyLocationConstraints _maxCount. */
                    public _maxCount?: "maxCount";

                    /**
                     * Creates a new LocationPolicyLocationConstraints instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LocationPolicyLocationConstraints instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILocationPolicyLocationConstraints): google.cloud.compute.v1.LocationPolicyLocationConstraints;

                    /**
                     * Encodes the specified LocationPolicyLocationConstraints message. Does not implicitly {@link google.cloud.compute.v1.LocationPolicyLocationConstraints.verify|verify} messages.
                     * @param message LocationPolicyLocationConstraints message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILocationPolicyLocationConstraints, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LocationPolicyLocationConstraints message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LocationPolicyLocationConstraints.verify|verify} messages.
                     * @param message LocationPolicyLocationConstraints message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILocationPolicyLocationConstraints, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LocationPolicyLocationConstraints message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LocationPolicyLocationConstraints
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LocationPolicyLocationConstraints;

                    /**
                     * Decodes a LocationPolicyLocationConstraints message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LocationPolicyLocationConstraints
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LocationPolicyLocationConstraints;

                    /**
                     * Verifies a LocationPolicyLocationConstraints message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LocationPolicyLocationConstraints message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LocationPolicyLocationConstraints
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LocationPolicyLocationConstraints;

                    /**
                     * Creates a plain object from a LocationPolicyLocationConstraints message. Also converts values to other types if specified.
                     * @param message LocationPolicyLocationConstraints
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LocationPolicyLocationConstraints, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LocationPolicyLocationConstraints to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LocationPolicyLocationConstraints
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LogConfig. */
                interface ILogConfig {

                    /** LogConfig cloudAudit */
                    cloudAudit?: (google.cloud.compute.v1.ILogConfigCloudAuditOptions|null);

                    /** LogConfig counter */
                    counter?: (google.cloud.compute.v1.ILogConfigCounterOptions|null);

                    /** LogConfig dataAccess */
                    dataAccess?: (google.cloud.compute.v1.ILogConfigDataAccessOptions|null);
                }

                /** Represents a LogConfig. */
                class LogConfig implements ILogConfig {

                    /**
                     * Constructs a new LogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILogConfig);

                    /** LogConfig cloudAudit. */
                    public cloudAudit?: (google.cloud.compute.v1.ILogConfigCloudAuditOptions|null);

                    /** LogConfig counter. */
                    public counter?: (google.cloud.compute.v1.ILogConfigCounterOptions|null);

                    /** LogConfig dataAccess. */
                    public dataAccess?: (google.cloud.compute.v1.ILogConfigDataAccessOptions|null);

                    /** LogConfig _cloudAudit. */
                    public _cloudAudit?: "cloudAudit";

                    /** LogConfig _counter. */
                    public _counter?: "counter";

                    /** LogConfig _dataAccess. */
                    public _dataAccess?: "dataAccess";

                    /**
                     * Creates a new LogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILogConfig): google.cloud.compute.v1.LogConfig;

                    /**
                     * Encodes the specified LogConfig message. Does not implicitly {@link google.cloud.compute.v1.LogConfig.verify|verify} messages.
                     * @param message LogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LogConfig.verify|verify} messages.
                     * @param message LogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LogConfig;

                    /**
                     * Decodes a LogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LogConfig;

                    /**
                     * Verifies a LogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LogConfig;

                    /**
                     * Creates a plain object from a LogConfig message. Also converts values to other types if specified.
                     * @param message LogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LogConfigCloudAuditOptions. */
                interface ILogConfigCloudAuditOptions {

                    /** LogConfigCloudAuditOptions authorizationLoggingOptions */
                    authorizationLoggingOptions?: (google.cloud.compute.v1.IAuthorizationLoggingOptions|null);

                    /** LogConfigCloudAuditOptions logName */
                    logName?: (string|null);
                }

                /** Represents a LogConfigCloudAuditOptions. */
                class LogConfigCloudAuditOptions implements ILogConfigCloudAuditOptions {

                    /**
                     * Constructs a new LogConfigCloudAuditOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILogConfigCloudAuditOptions);

                    /** LogConfigCloudAuditOptions authorizationLoggingOptions. */
                    public authorizationLoggingOptions?: (google.cloud.compute.v1.IAuthorizationLoggingOptions|null);

                    /** LogConfigCloudAuditOptions logName. */
                    public logName?: (string|null);

                    /** LogConfigCloudAuditOptions _authorizationLoggingOptions. */
                    public _authorizationLoggingOptions?: "authorizationLoggingOptions";

                    /** LogConfigCloudAuditOptions _logName. */
                    public _logName?: "logName";

                    /**
                     * Creates a new LogConfigCloudAuditOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LogConfigCloudAuditOptions instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILogConfigCloudAuditOptions): google.cloud.compute.v1.LogConfigCloudAuditOptions;

                    /**
                     * Encodes the specified LogConfigCloudAuditOptions message. Does not implicitly {@link google.cloud.compute.v1.LogConfigCloudAuditOptions.verify|verify} messages.
                     * @param message LogConfigCloudAuditOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILogConfigCloudAuditOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LogConfigCloudAuditOptions message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LogConfigCloudAuditOptions.verify|verify} messages.
                     * @param message LogConfigCloudAuditOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILogConfigCloudAuditOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LogConfigCloudAuditOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LogConfigCloudAuditOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LogConfigCloudAuditOptions;

                    /**
                     * Decodes a LogConfigCloudAuditOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LogConfigCloudAuditOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LogConfigCloudAuditOptions;

                    /**
                     * Verifies a LogConfigCloudAuditOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LogConfigCloudAuditOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LogConfigCloudAuditOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LogConfigCloudAuditOptions;

                    /**
                     * Creates a plain object from a LogConfigCloudAuditOptions message. Also converts values to other types if specified.
                     * @param message LogConfigCloudAuditOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LogConfigCloudAuditOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LogConfigCloudAuditOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LogConfigCloudAuditOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace LogConfigCloudAuditOptions {

                    /** LogName enum. */
                    enum LogName {
                        UNDEFINED_LOG_NAME = 0,
                        ADMIN_ACTIVITY = 427503135,
                        DATA_ACCESS = 238070681,
                        UNSPECIFIED_LOG_NAME = 410515182
                    }
                }

                /** Properties of a LogConfigCounterOptions. */
                interface ILogConfigCounterOptions {

                    /** LogConfigCounterOptions customFields */
                    customFields?: (google.cloud.compute.v1.ILogConfigCounterOptionsCustomField[]|null);

                    /** LogConfigCounterOptions field */
                    field?: (string|null);

                    /** LogConfigCounterOptions metric */
                    metric?: (string|null);
                }

                /** Represents a LogConfigCounterOptions. */
                class LogConfigCounterOptions implements ILogConfigCounterOptions {

                    /**
                     * Constructs a new LogConfigCounterOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILogConfigCounterOptions);

                    /** LogConfigCounterOptions customFields. */
                    public customFields: google.cloud.compute.v1.ILogConfigCounterOptionsCustomField[];

                    /** LogConfigCounterOptions field. */
                    public field?: (string|null);

                    /** LogConfigCounterOptions metric. */
                    public metric?: (string|null);

                    /** LogConfigCounterOptions _field. */
                    public _field?: "field";

                    /** LogConfigCounterOptions _metric. */
                    public _metric?: "metric";

                    /**
                     * Creates a new LogConfigCounterOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LogConfigCounterOptions instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILogConfigCounterOptions): google.cloud.compute.v1.LogConfigCounterOptions;

                    /**
                     * Encodes the specified LogConfigCounterOptions message. Does not implicitly {@link google.cloud.compute.v1.LogConfigCounterOptions.verify|verify} messages.
                     * @param message LogConfigCounterOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILogConfigCounterOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LogConfigCounterOptions message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LogConfigCounterOptions.verify|verify} messages.
                     * @param message LogConfigCounterOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILogConfigCounterOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LogConfigCounterOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LogConfigCounterOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LogConfigCounterOptions;

                    /**
                     * Decodes a LogConfigCounterOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LogConfigCounterOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LogConfigCounterOptions;

                    /**
                     * Verifies a LogConfigCounterOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LogConfigCounterOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LogConfigCounterOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LogConfigCounterOptions;

                    /**
                     * Creates a plain object from a LogConfigCounterOptions message. Also converts values to other types if specified.
                     * @param message LogConfigCounterOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LogConfigCounterOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LogConfigCounterOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LogConfigCounterOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LogConfigCounterOptionsCustomField. */
                interface ILogConfigCounterOptionsCustomField {

                    /** LogConfigCounterOptionsCustomField name */
                    name?: (string|null);

                    /** LogConfigCounterOptionsCustomField value */
                    value?: (string|null);
                }

                /** Represents a LogConfigCounterOptionsCustomField. */
                class LogConfigCounterOptionsCustomField implements ILogConfigCounterOptionsCustomField {

                    /**
                     * Constructs a new LogConfigCounterOptionsCustomField.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILogConfigCounterOptionsCustomField);

                    /** LogConfigCounterOptionsCustomField name. */
                    public name?: (string|null);

                    /** LogConfigCounterOptionsCustomField value. */
                    public value?: (string|null);

                    /** LogConfigCounterOptionsCustomField _name. */
                    public _name?: "name";

                    /** LogConfigCounterOptionsCustomField _value. */
                    public _value?: "value";

                    /**
                     * Creates a new LogConfigCounterOptionsCustomField instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LogConfigCounterOptionsCustomField instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILogConfigCounterOptionsCustomField): google.cloud.compute.v1.LogConfigCounterOptionsCustomField;

                    /**
                     * Encodes the specified LogConfigCounterOptionsCustomField message. Does not implicitly {@link google.cloud.compute.v1.LogConfigCounterOptionsCustomField.verify|verify} messages.
                     * @param message LogConfigCounterOptionsCustomField message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILogConfigCounterOptionsCustomField, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LogConfigCounterOptionsCustomField message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LogConfigCounterOptionsCustomField.verify|verify} messages.
                     * @param message LogConfigCounterOptionsCustomField message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILogConfigCounterOptionsCustomField, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LogConfigCounterOptionsCustomField message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LogConfigCounterOptionsCustomField
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LogConfigCounterOptionsCustomField;

                    /**
                     * Decodes a LogConfigCounterOptionsCustomField message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LogConfigCounterOptionsCustomField
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LogConfigCounterOptionsCustomField;

                    /**
                     * Verifies a LogConfigCounterOptionsCustomField message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LogConfigCounterOptionsCustomField message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LogConfigCounterOptionsCustomField
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LogConfigCounterOptionsCustomField;

                    /**
                     * Creates a plain object from a LogConfigCounterOptionsCustomField message. Also converts values to other types if specified.
                     * @param message LogConfigCounterOptionsCustomField
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LogConfigCounterOptionsCustomField, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LogConfigCounterOptionsCustomField to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LogConfigCounterOptionsCustomField
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a LogConfigDataAccessOptions. */
                interface ILogConfigDataAccessOptions {

                    /** LogConfigDataAccessOptions logMode */
                    logMode?: (string|null);
                }

                /** Represents a LogConfigDataAccessOptions. */
                class LogConfigDataAccessOptions implements ILogConfigDataAccessOptions {

                    /**
                     * Constructs a new LogConfigDataAccessOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ILogConfigDataAccessOptions);

                    /** LogConfigDataAccessOptions logMode. */
                    public logMode?: (string|null);

                    /** LogConfigDataAccessOptions _logMode. */
                    public _logMode?: "logMode";

                    /**
                     * Creates a new LogConfigDataAccessOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns LogConfigDataAccessOptions instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ILogConfigDataAccessOptions): google.cloud.compute.v1.LogConfigDataAccessOptions;

                    /**
                     * Encodes the specified LogConfigDataAccessOptions message. Does not implicitly {@link google.cloud.compute.v1.LogConfigDataAccessOptions.verify|verify} messages.
                     * @param message LogConfigDataAccessOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ILogConfigDataAccessOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified LogConfigDataAccessOptions message, length delimited. Does not implicitly {@link google.cloud.compute.v1.LogConfigDataAccessOptions.verify|verify} messages.
                     * @param message LogConfigDataAccessOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ILogConfigDataAccessOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a LogConfigDataAccessOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns LogConfigDataAccessOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.LogConfigDataAccessOptions;

                    /**
                     * Decodes a LogConfigDataAccessOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns LogConfigDataAccessOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.LogConfigDataAccessOptions;

                    /**
                     * Verifies a LogConfigDataAccessOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a LogConfigDataAccessOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns LogConfigDataAccessOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.LogConfigDataAccessOptions;

                    /**
                     * Creates a plain object from a LogConfigDataAccessOptions message. Also converts values to other types if specified.
                     * @param message LogConfigDataAccessOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.LogConfigDataAccessOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this LogConfigDataAccessOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for LogConfigDataAccessOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace LogConfigDataAccessOptions {

                    /** LogMode enum. */
                    enum LogMode {
                        UNDEFINED_LOG_MODE = 0,
                        LOG_FAIL_CLOSED = 360469778,
                        LOG_MODE_UNSPECIFIED = 88160822
                    }
                }

                /** Properties of a MachineImage. */
                interface IMachineImage {

                    /** MachineImage creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** MachineImage description */
                    description?: (string|null);

                    /** MachineImage guestFlush */
                    guestFlush?: (boolean|null);

                    /** MachineImage id */
                    id?: (number|Long|string|null);

                    /** MachineImage instanceProperties */
                    instanceProperties?: (google.cloud.compute.v1.IInstanceProperties|null);

                    /** MachineImage kind */
                    kind?: (string|null);

                    /** MachineImage machineImageEncryptionKey */
                    machineImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** MachineImage name */
                    name?: (string|null);

                    /** MachineImage satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** MachineImage savedDisks */
                    savedDisks?: (google.cloud.compute.v1.ISavedDisk[]|null);

                    /** MachineImage selfLink */
                    selfLink?: (string|null);

                    /** MachineImage sourceDiskEncryptionKeys */
                    sourceDiskEncryptionKeys?: (google.cloud.compute.v1.ISourceDiskEncryptionKey[]|null);

                    /** MachineImage sourceInstance */
                    sourceInstance?: (string|null);

                    /** MachineImage sourceInstanceProperties */
                    sourceInstanceProperties?: (google.cloud.compute.v1.ISourceInstanceProperties|null);

                    /** MachineImage status */
                    status?: (string|null);

                    /** MachineImage storageLocations */
                    storageLocations?: (string[]|null);

                    /** MachineImage totalStorageBytes */
                    totalStorageBytes?: (number|Long|string|null);
                }

                /** Represents a MachineImage. */
                class MachineImage implements IMachineImage {

                    /**
                     * Constructs a new MachineImage.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMachineImage);

                    /** MachineImage creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** MachineImage description. */
                    public description?: (string|null);

                    /** MachineImage guestFlush. */
                    public guestFlush?: (boolean|null);

                    /** MachineImage id. */
                    public id?: (number|Long|string|null);

                    /** MachineImage instanceProperties. */
                    public instanceProperties?: (google.cloud.compute.v1.IInstanceProperties|null);

                    /** MachineImage kind. */
                    public kind?: (string|null);

                    /** MachineImage machineImageEncryptionKey. */
                    public machineImageEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** MachineImage name. */
                    public name?: (string|null);

                    /** MachineImage satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** MachineImage savedDisks. */
                    public savedDisks: google.cloud.compute.v1.ISavedDisk[];

                    /** MachineImage selfLink. */
                    public selfLink?: (string|null);

                    /** MachineImage sourceDiskEncryptionKeys. */
                    public sourceDiskEncryptionKeys: google.cloud.compute.v1.ISourceDiskEncryptionKey[];

                    /** MachineImage sourceInstance. */
                    public sourceInstance?: (string|null);

                    /** MachineImage sourceInstanceProperties. */
                    public sourceInstanceProperties?: (google.cloud.compute.v1.ISourceInstanceProperties|null);

                    /** MachineImage status. */
                    public status?: (string|null);

                    /** MachineImage storageLocations. */
                    public storageLocations: string[];

                    /** MachineImage totalStorageBytes. */
                    public totalStorageBytes?: (number|Long|string|null);

                    /** MachineImage _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** MachineImage _description. */
                    public _description?: "description";

                    /** MachineImage _guestFlush. */
                    public _guestFlush?: "guestFlush";

                    /** MachineImage _id. */
                    public _id?: "id";

                    /** MachineImage _instanceProperties. */
                    public _instanceProperties?: "instanceProperties";

                    /** MachineImage _kind. */
                    public _kind?: "kind";

                    /** MachineImage _machineImageEncryptionKey. */
                    public _machineImageEncryptionKey?: "machineImageEncryptionKey";

                    /** MachineImage _name. */
                    public _name?: "name";

                    /** MachineImage _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** MachineImage _selfLink. */
                    public _selfLink?: "selfLink";

                    /** MachineImage _sourceInstance. */
                    public _sourceInstance?: "sourceInstance";

                    /** MachineImage _sourceInstanceProperties. */
                    public _sourceInstanceProperties?: "sourceInstanceProperties";

                    /** MachineImage _status. */
                    public _status?: "status";

                    /** MachineImage _totalStorageBytes. */
                    public _totalStorageBytes?: "totalStorageBytes";

                    /**
                     * Creates a new MachineImage instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MachineImage instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMachineImage): google.cloud.compute.v1.MachineImage;

                    /**
                     * Encodes the specified MachineImage message. Does not implicitly {@link google.cloud.compute.v1.MachineImage.verify|verify} messages.
                     * @param message MachineImage message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMachineImage, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MachineImage message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MachineImage.verify|verify} messages.
                     * @param message MachineImage message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMachineImage, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MachineImage message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MachineImage
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MachineImage;

                    /**
                     * Decodes a MachineImage message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MachineImage
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MachineImage;

                    /**
                     * Verifies a MachineImage message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MachineImage message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MachineImage
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MachineImage;

                    /**
                     * Creates a plain object from a MachineImage message. Also converts values to other types if specified.
                     * @param message MachineImage
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MachineImage, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MachineImage to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MachineImage
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace MachineImage {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        INVALID = 530283991,
                        READY = 77848963,
                        UPLOADING = 267603489
                    }
                }

                /** Properties of a MachineImageList. */
                interface IMachineImageList {

                    /** MachineImageList id */
                    id?: (string|null);

                    /** MachineImageList items */
                    items?: (google.cloud.compute.v1.IMachineImage[]|null);

                    /** MachineImageList kind */
                    kind?: (string|null);

                    /** MachineImageList nextPageToken */
                    nextPageToken?: (string|null);

                    /** MachineImageList selfLink */
                    selfLink?: (string|null);

                    /** MachineImageList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a MachineImageList. */
                class MachineImageList implements IMachineImageList {

                    /**
                     * Constructs a new MachineImageList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMachineImageList);

                    /** MachineImageList id. */
                    public id?: (string|null);

                    /** MachineImageList items. */
                    public items: google.cloud.compute.v1.IMachineImage[];

                    /** MachineImageList kind. */
                    public kind?: (string|null);

                    /** MachineImageList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** MachineImageList selfLink. */
                    public selfLink?: (string|null);

                    /** MachineImageList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** MachineImageList _id. */
                    public _id?: "id";

                    /** MachineImageList _kind. */
                    public _kind?: "kind";

                    /** MachineImageList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** MachineImageList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** MachineImageList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new MachineImageList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MachineImageList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMachineImageList): google.cloud.compute.v1.MachineImageList;

                    /**
                     * Encodes the specified MachineImageList message. Does not implicitly {@link google.cloud.compute.v1.MachineImageList.verify|verify} messages.
                     * @param message MachineImageList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMachineImageList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MachineImageList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MachineImageList.verify|verify} messages.
                     * @param message MachineImageList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMachineImageList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MachineImageList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MachineImageList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MachineImageList;

                    /**
                     * Decodes a MachineImageList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MachineImageList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MachineImageList;

                    /**
                     * Verifies a MachineImageList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MachineImageList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MachineImageList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MachineImageList;

                    /**
                     * Creates a plain object from a MachineImageList message. Also converts values to other types if specified.
                     * @param message MachineImageList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MachineImageList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MachineImageList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MachineImageList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MachineType. */
                interface IMachineType {

                    /** MachineType accelerators */
                    accelerators?: (google.cloud.compute.v1.IAccelerators[]|null);

                    /** MachineType creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** MachineType deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** MachineType description */
                    description?: (string|null);

                    /** MachineType guestCpus */
                    guestCpus?: (number|null);

                    /** MachineType id */
                    id?: (number|Long|string|null);

                    /** MachineType imageSpaceGb */
                    imageSpaceGb?: (number|null);

                    /** MachineType isSharedCpu */
                    isSharedCpu?: (boolean|null);

                    /** MachineType kind */
                    kind?: (string|null);

                    /** MachineType maximumPersistentDisks */
                    maximumPersistentDisks?: (number|null);

                    /** MachineType maximumPersistentDisksSizeGb */
                    maximumPersistentDisksSizeGb?: (number|Long|string|null);

                    /** MachineType memoryMb */
                    memoryMb?: (number|null);

                    /** MachineType name */
                    name?: (string|null);

                    /** MachineType scratchDisks */
                    scratchDisks?: (google.cloud.compute.v1.IScratchDisks[]|null);

                    /** MachineType selfLink */
                    selfLink?: (string|null);

                    /** MachineType zone */
                    zone?: (string|null);
                }

                /** Represents a MachineType. */
                class MachineType implements IMachineType {

                    /**
                     * Constructs a new MachineType.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMachineType);

                    /** MachineType accelerators. */
                    public accelerators: google.cloud.compute.v1.IAccelerators[];

                    /** MachineType creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** MachineType deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** MachineType description. */
                    public description?: (string|null);

                    /** MachineType guestCpus. */
                    public guestCpus?: (number|null);

                    /** MachineType id. */
                    public id?: (number|Long|string|null);

                    /** MachineType imageSpaceGb. */
                    public imageSpaceGb?: (number|null);

                    /** MachineType isSharedCpu. */
                    public isSharedCpu?: (boolean|null);

                    /** MachineType kind. */
                    public kind?: (string|null);

                    /** MachineType maximumPersistentDisks. */
                    public maximumPersistentDisks?: (number|null);

                    /** MachineType maximumPersistentDisksSizeGb. */
                    public maximumPersistentDisksSizeGb?: (number|Long|string|null);

                    /** MachineType memoryMb. */
                    public memoryMb?: (number|null);

                    /** MachineType name. */
                    public name?: (string|null);

                    /** MachineType scratchDisks. */
                    public scratchDisks: google.cloud.compute.v1.IScratchDisks[];

                    /** MachineType selfLink. */
                    public selfLink?: (string|null);

                    /** MachineType zone. */
                    public zone?: (string|null);

                    /** MachineType _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** MachineType _deprecated. */
                    public _deprecated?: "deprecated";

                    /** MachineType _description. */
                    public _description?: "description";

                    /** MachineType _guestCpus. */
                    public _guestCpus?: "guestCpus";

                    /** MachineType _id. */
                    public _id?: "id";

                    /** MachineType _imageSpaceGb. */
                    public _imageSpaceGb?: "imageSpaceGb";

                    /** MachineType _isSharedCpu. */
                    public _isSharedCpu?: "isSharedCpu";

                    /** MachineType _kind. */
                    public _kind?: "kind";

                    /** MachineType _maximumPersistentDisks. */
                    public _maximumPersistentDisks?: "maximumPersistentDisks";

                    /** MachineType _maximumPersistentDisksSizeGb. */
                    public _maximumPersistentDisksSizeGb?: "maximumPersistentDisksSizeGb";

                    /** MachineType _memoryMb. */
                    public _memoryMb?: "memoryMb";

                    /** MachineType _name. */
                    public _name?: "name";

                    /** MachineType _selfLink. */
                    public _selfLink?: "selfLink";

                    /** MachineType _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new MachineType instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MachineType instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMachineType): google.cloud.compute.v1.MachineType;

                    /**
                     * Encodes the specified MachineType message. Does not implicitly {@link google.cloud.compute.v1.MachineType.verify|verify} messages.
                     * @param message MachineType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMachineType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MachineType message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MachineType.verify|verify} messages.
                     * @param message MachineType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMachineType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MachineType message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MachineType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MachineType;

                    /**
                     * Decodes a MachineType message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MachineType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MachineType;

                    /**
                     * Verifies a MachineType message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MachineType message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MachineType
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MachineType;

                    /**
                     * Creates a plain object from a MachineType message. Also converts values to other types if specified.
                     * @param message MachineType
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MachineType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MachineType to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MachineType
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MachineTypeAggregatedList. */
                interface IMachineTypeAggregatedList {

                    /** MachineTypeAggregatedList id */
                    id?: (string|null);

                    /** MachineTypeAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IMachineTypesScopedList }|null);

                    /** MachineTypeAggregatedList kind */
                    kind?: (string|null);

                    /** MachineTypeAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** MachineTypeAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** MachineTypeAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** MachineTypeAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a MachineTypeAggregatedList. */
                class MachineTypeAggregatedList implements IMachineTypeAggregatedList {

                    /**
                     * Constructs a new MachineTypeAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMachineTypeAggregatedList);

                    /** MachineTypeAggregatedList id. */
                    public id?: (string|null);

                    /** MachineTypeAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IMachineTypesScopedList };

                    /** MachineTypeAggregatedList kind. */
                    public kind?: (string|null);

                    /** MachineTypeAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** MachineTypeAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** MachineTypeAggregatedList unreachables. */
                    public unreachables: string[];

                    /** MachineTypeAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** MachineTypeAggregatedList _id. */
                    public _id?: "id";

                    /** MachineTypeAggregatedList _kind. */
                    public _kind?: "kind";

                    /** MachineTypeAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** MachineTypeAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** MachineTypeAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new MachineTypeAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MachineTypeAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMachineTypeAggregatedList): google.cloud.compute.v1.MachineTypeAggregatedList;

                    /**
                     * Encodes the specified MachineTypeAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.MachineTypeAggregatedList.verify|verify} messages.
                     * @param message MachineTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMachineTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MachineTypeAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MachineTypeAggregatedList.verify|verify} messages.
                     * @param message MachineTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMachineTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MachineTypeAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MachineTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MachineTypeAggregatedList;

                    /**
                     * Decodes a MachineTypeAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MachineTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MachineTypeAggregatedList;

                    /**
                     * Verifies a MachineTypeAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MachineTypeAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MachineTypeAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MachineTypeAggregatedList;

                    /**
                     * Creates a plain object from a MachineTypeAggregatedList message. Also converts values to other types if specified.
                     * @param message MachineTypeAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MachineTypeAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MachineTypeAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MachineTypeAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MachineTypeList. */
                interface IMachineTypeList {

                    /** MachineTypeList id */
                    id?: (string|null);

                    /** MachineTypeList items */
                    items?: (google.cloud.compute.v1.IMachineType[]|null);

                    /** MachineTypeList kind */
                    kind?: (string|null);

                    /** MachineTypeList nextPageToken */
                    nextPageToken?: (string|null);

                    /** MachineTypeList selfLink */
                    selfLink?: (string|null);

                    /** MachineTypeList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a MachineTypeList. */
                class MachineTypeList implements IMachineTypeList {

                    /**
                     * Constructs a new MachineTypeList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMachineTypeList);

                    /** MachineTypeList id. */
                    public id?: (string|null);

                    /** MachineTypeList items. */
                    public items: google.cloud.compute.v1.IMachineType[];

                    /** MachineTypeList kind. */
                    public kind?: (string|null);

                    /** MachineTypeList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** MachineTypeList selfLink. */
                    public selfLink?: (string|null);

                    /** MachineTypeList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** MachineTypeList _id. */
                    public _id?: "id";

                    /** MachineTypeList _kind. */
                    public _kind?: "kind";

                    /** MachineTypeList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** MachineTypeList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** MachineTypeList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new MachineTypeList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MachineTypeList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMachineTypeList): google.cloud.compute.v1.MachineTypeList;

                    /**
                     * Encodes the specified MachineTypeList message. Does not implicitly {@link google.cloud.compute.v1.MachineTypeList.verify|verify} messages.
                     * @param message MachineTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMachineTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MachineTypeList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MachineTypeList.verify|verify} messages.
                     * @param message MachineTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMachineTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MachineTypeList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MachineTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MachineTypeList;

                    /**
                     * Decodes a MachineTypeList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MachineTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MachineTypeList;

                    /**
                     * Verifies a MachineTypeList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MachineTypeList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MachineTypeList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MachineTypeList;

                    /**
                     * Creates a plain object from a MachineTypeList message. Also converts values to other types if specified.
                     * @param message MachineTypeList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MachineTypeList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MachineTypeList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MachineTypeList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MachineTypesScopedList. */
                interface IMachineTypesScopedList {

                    /** MachineTypesScopedList machineTypes */
                    machineTypes?: (google.cloud.compute.v1.IMachineType[]|null);

                    /** MachineTypesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a MachineTypesScopedList. */
                class MachineTypesScopedList implements IMachineTypesScopedList {

                    /**
                     * Constructs a new MachineTypesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMachineTypesScopedList);

                    /** MachineTypesScopedList machineTypes. */
                    public machineTypes: google.cloud.compute.v1.IMachineType[];

                    /** MachineTypesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** MachineTypesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new MachineTypesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MachineTypesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMachineTypesScopedList): google.cloud.compute.v1.MachineTypesScopedList;

                    /**
                     * Encodes the specified MachineTypesScopedList message. Does not implicitly {@link google.cloud.compute.v1.MachineTypesScopedList.verify|verify} messages.
                     * @param message MachineTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMachineTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MachineTypesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MachineTypesScopedList.verify|verify} messages.
                     * @param message MachineTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMachineTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MachineTypesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MachineTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MachineTypesScopedList;

                    /**
                     * Decodes a MachineTypesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MachineTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MachineTypesScopedList;

                    /**
                     * Verifies a MachineTypesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MachineTypesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MachineTypesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MachineTypesScopedList;

                    /**
                     * Creates a plain object from a MachineTypesScopedList message. Also converts values to other types if specified.
                     * @param message MachineTypesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MachineTypesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MachineTypesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MachineTypesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ManagedInstance. */
                interface IManagedInstance {

                    /** ManagedInstance currentAction */
                    currentAction?: (string|null);

                    /** ManagedInstance id */
                    id?: (number|Long|string|null);

                    /** ManagedInstance instance */
                    instance?: (string|null);

                    /** ManagedInstance instanceHealth */
                    instanceHealth?: (google.cloud.compute.v1.IManagedInstanceInstanceHealth[]|null);

                    /** ManagedInstance instanceStatus */
                    instanceStatus?: (string|null);

                    /** ManagedInstance lastAttempt */
                    lastAttempt?: (google.cloud.compute.v1.IManagedInstanceLastAttempt|null);

                    /** ManagedInstance preservedStateFromConfig */
                    preservedStateFromConfig?: (google.cloud.compute.v1.IPreservedState|null);

                    /** ManagedInstance preservedStateFromPolicy */
                    preservedStateFromPolicy?: (google.cloud.compute.v1.IPreservedState|null);

                    /** ManagedInstance version */
                    version?: (google.cloud.compute.v1.IManagedInstanceVersion|null);
                }

                /** Represents a ManagedInstance. */
                class ManagedInstance implements IManagedInstance {

                    /**
                     * Constructs a new ManagedInstance.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IManagedInstance);

                    /** ManagedInstance currentAction. */
                    public currentAction?: (string|null);

                    /** ManagedInstance id. */
                    public id?: (number|Long|string|null);

                    /** ManagedInstance instance. */
                    public instance?: (string|null);

                    /** ManagedInstance instanceHealth. */
                    public instanceHealth: google.cloud.compute.v1.IManagedInstanceInstanceHealth[];

                    /** ManagedInstance instanceStatus. */
                    public instanceStatus?: (string|null);

                    /** ManagedInstance lastAttempt. */
                    public lastAttempt?: (google.cloud.compute.v1.IManagedInstanceLastAttempt|null);

                    /** ManagedInstance preservedStateFromConfig. */
                    public preservedStateFromConfig?: (google.cloud.compute.v1.IPreservedState|null);

                    /** ManagedInstance preservedStateFromPolicy. */
                    public preservedStateFromPolicy?: (google.cloud.compute.v1.IPreservedState|null);

                    /** ManagedInstance version. */
                    public version?: (google.cloud.compute.v1.IManagedInstanceVersion|null);

                    /** ManagedInstance _currentAction. */
                    public _currentAction?: "currentAction";

                    /** ManagedInstance _id. */
                    public _id?: "id";

                    /** ManagedInstance _instance. */
                    public _instance?: "instance";

                    /** ManagedInstance _instanceStatus. */
                    public _instanceStatus?: "instanceStatus";

                    /** ManagedInstance _lastAttempt. */
                    public _lastAttempt?: "lastAttempt";

                    /** ManagedInstance _preservedStateFromConfig. */
                    public _preservedStateFromConfig?: "preservedStateFromConfig";

                    /** ManagedInstance _preservedStateFromPolicy. */
                    public _preservedStateFromPolicy?: "preservedStateFromPolicy";

                    /** ManagedInstance _version. */
                    public _version?: "version";

                    /**
                     * Creates a new ManagedInstance instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ManagedInstance instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IManagedInstance): google.cloud.compute.v1.ManagedInstance;

                    /**
                     * Encodes the specified ManagedInstance message. Does not implicitly {@link google.cloud.compute.v1.ManagedInstance.verify|verify} messages.
                     * @param message ManagedInstance message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IManagedInstance, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ManagedInstance message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ManagedInstance.verify|verify} messages.
                     * @param message ManagedInstance message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IManagedInstance, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ManagedInstance message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ManagedInstance
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ManagedInstance;

                    /**
                     * Decodes a ManagedInstance message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ManagedInstance
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ManagedInstance;

                    /**
                     * Verifies a ManagedInstance message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ManagedInstance message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ManagedInstance
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ManagedInstance;

                    /**
                     * Creates a plain object from a ManagedInstance message. Also converts values to other types if specified.
                     * @param message ManagedInstance
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ManagedInstance, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ManagedInstance to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ManagedInstance
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ManagedInstance {

                    /** CurrentAction enum. */
                    enum CurrentAction {
                        UNDEFINED_CURRENT_ACTION = 0,
                        ABANDONING = 388244813,
                        CREATING = 455564985,
                        CREATING_WITHOUT_RETRIES = 428843785,
                        DELETING = 528602024,
                        NONE = 2402104,
                        RECREATING = 287278572,
                        REFRESHING = 163266343,
                        RESTARTING = 320534387,
                        RESUMING = 446856618,
                        STARTING = 488820800,
                        VERIFYING = 16982185
                    }

                    /** InstanceStatus enum. */
                    enum InstanceStatus {
                        UNDEFINED_INSTANCE_STATUS = 0,
                        DEPROVISIONING = 428935662,
                        PROVISIONING = 290896621,
                        REPAIRING = 413483285,
                        RUNNING = 121282975,
                        STAGING = 431072283,
                        STOPPED = 444276141,
                        STOPPING = 350791796,
                        SUSPENDED = 51223995,
                        SUSPENDING = 514206246,
                        TERMINATED = 250018339
                    }
                }

                /** Properties of a ManagedInstanceInstanceHealth. */
                interface IManagedInstanceInstanceHealth {

                    /** ManagedInstanceInstanceHealth detailedHealthState */
                    detailedHealthState?: (string|null);

                    /** ManagedInstanceInstanceHealth healthCheck */
                    healthCheck?: (string|null);
                }

                /** Represents a ManagedInstanceInstanceHealth. */
                class ManagedInstanceInstanceHealth implements IManagedInstanceInstanceHealth {

                    /**
                     * Constructs a new ManagedInstanceInstanceHealth.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IManagedInstanceInstanceHealth);

                    /** ManagedInstanceInstanceHealth detailedHealthState. */
                    public detailedHealthState?: (string|null);

                    /** ManagedInstanceInstanceHealth healthCheck. */
                    public healthCheck?: (string|null);

                    /** ManagedInstanceInstanceHealth _detailedHealthState. */
                    public _detailedHealthState?: "detailedHealthState";

                    /** ManagedInstanceInstanceHealth _healthCheck. */
                    public _healthCheck?: "healthCheck";

                    /**
                     * Creates a new ManagedInstanceInstanceHealth instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ManagedInstanceInstanceHealth instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IManagedInstanceInstanceHealth): google.cloud.compute.v1.ManagedInstanceInstanceHealth;

                    /**
                     * Encodes the specified ManagedInstanceInstanceHealth message. Does not implicitly {@link google.cloud.compute.v1.ManagedInstanceInstanceHealth.verify|verify} messages.
                     * @param message ManagedInstanceInstanceHealth message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IManagedInstanceInstanceHealth, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ManagedInstanceInstanceHealth message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ManagedInstanceInstanceHealth.verify|verify} messages.
                     * @param message ManagedInstanceInstanceHealth message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IManagedInstanceInstanceHealth, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ManagedInstanceInstanceHealth message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ManagedInstanceInstanceHealth
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ManagedInstanceInstanceHealth;

                    /**
                     * Decodes a ManagedInstanceInstanceHealth message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ManagedInstanceInstanceHealth
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ManagedInstanceInstanceHealth;

                    /**
                     * Verifies a ManagedInstanceInstanceHealth message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ManagedInstanceInstanceHealth message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ManagedInstanceInstanceHealth
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ManagedInstanceInstanceHealth;

                    /**
                     * Creates a plain object from a ManagedInstanceInstanceHealth message. Also converts values to other types if specified.
                     * @param message ManagedInstanceInstanceHealth
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ManagedInstanceInstanceHealth, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ManagedInstanceInstanceHealth to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ManagedInstanceInstanceHealth
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ManagedInstanceInstanceHealth {

                    /** DetailedHealthState enum. */
                    enum DetailedHealthState {
                        UNDEFINED_DETAILED_HEALTH_STATE = 0,
                        DRAINING = 480455402,
                        HEALTHY = 439801213,
                        TIMEOUT = 477813057,
                        UNHEALTHY = 462118084,
                        UNKNOWN = 433141802
                    }
                }

                /** Properties of a ManagedInstanceLastAttempt. */
                interface IManagedInstanceLastAttempt {

                    /** ManagedInstanceLastAttempt errors */
                    errors?: (google.cloud.compute.v1.IErrors|null);
                }

                /** Represents a ManagedInstanceLastAttempt. */
                class ManagedInstanceLastAttempt implements IManagedInstanceLastAttempt {

                    /**
                     * Constructs a new ManagedInstanceLastAttempt.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IManagedInstanceLastAttempt);

                    /** ManagedInstanceLastAttempt errors. */
                    public errors?: (google.cloud.compute.v1.IErrors|null);

                    /** ManagedInstanceLastAttempt _errors. */
                    public _errors?: "errors";

                    /**
                     * Creates a new ManagedInstanceLastAttempt instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ManagedInstanceLastAttempt instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IManagedInstanceLastAttempt): google.cloud.compute.v1.ManagedInstanceLastAttempt;

                    /**
                     * Encodes the specified ManagedInstanceLastAttempt message. Does not implicitly {@link google.cloud.compute.v1.ManagedInstanceLastAttempt.verify|verify} messages.
                     * @param message ManagedInstanceLastAttempt message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IManagedInstanceLastAttempt, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ManagedInstanceLastAttempt message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ManagedInstanceLastAttempt.verify|verify} messages.
                     * @param message ManagedInstanceLastAttempt message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IManagedInstanceLastAttempt, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ManagedInstanceLastAttempt message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ManagedInstanceLastAttempt
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ManagedInstanceLastAttempt;

                    /**
                     * Decodes a ManagedInstanceLastAttempt message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ManagedInstanceLastAttempt
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ManagedInstanceLastAttempt;

                    /**
                     * Verifies a ManagedInstanceLastAttempt message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ManagedInstanceLastAttempt message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ManagedInstanceLastAttempt
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ManagedInstanceLastAttempt;

                    /**
                     * Creates a plain object from a ManagedInstanceLastAttempt message. Also converts values to other types if specified.
                     * @param message ManagedInstanceLastAttempt
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ManagedInstanceLastAttempt, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ManagedInstanceLastAttempt to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ManagedInstanceLastAttempt
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ManagedInstanceVersion. */
                interface IManagedInstanceVersion {

                    /** ManagedInstanceVersion instanceTemplate */
                    instanceTemplate?: (string|null);

                    /** ManagedInstanceVersion name */
                    name?: (string|null);
                }

                /** Represents a ManagedInstanceVersion. */
                class ManagedInstanceVersion implements IManagedInstanceVersion {

                    /**
                     * Constructs a new ManagedInstanceVersion.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IManagedInstanceVersion);

                    /** ManagedInstanceVersion instanceTemplate. */
                    public instanceTemplate?: (string|null);

                    /** ManagedInstanceVersion name. */
                    public name?: (string|null);

                    /** ManagedInstanceVersion _instanceTemplate. */
                    public _instanceTemplate?: "instanceTemplate";

                    /** ManagedInstanceVersion _name. */
                    public _name?: "name";

                    /**
                     * Creates a new ManagedInstanceVersion instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ManagedInstanceVersion instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IManagedInstanceVersion): google.cloud.compute.v1.ManagedInstanceVersion;

                    /**
                     * Encodes the specified ManagedInstanceVersion message. Does not implicitly {@link google.cloud.compute.v1.ManagedInstanceVersion.verify|verify} messages.
                     * @param message ManagedInstanceVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IManagedInstanceVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ManagedInstanceVersion message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ManagedInstanceVersion.verify|verify} messages.
                     * @param message ManagedInstanceVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IManagedInstanceVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ManagedInstanceVersion message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ManagedInstanceVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ManagedInstanceVersion;

                    /**
                     * Decodes a ManagedInstanceVersion message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ManagedInstanceVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ManagedInstanceVersion;

                    /**
                     * Verifies a ManagedInstanceVersion message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ManagedInstanceVersion message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ManagedInstanceVersion
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ManagedInstanceVersion;

                    /**
                     * Creates a plain object from a ManagedInstanceVersion message. Also converts values to other types if specified.
                     * @param message ManagedInstanceVersion
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ManagedInstanceVersion, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ManagedInstanceVersion to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ManagedInstanceVersion
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Metadata. */
                interface IMetadata {

                    /** Metadata fingerprint */
                    fingerprint?: (string|null);

                    /** Metadata items */
                    items?: (google.cloud.compute.v1.IItems[]|null);

                    /** Metadata kind */
                    kind?: (string|null);
                }

                /** Represents a Metadata. */
                class Metadata implements IMetadata {

                    /**
                     * Constructs a new Metadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMetadata);

                    /** Metadata fingerprint. */
                    public fingerprint?: (string|null);

                    /** Metadata items. */
                    public items: google.cloud.compute.v1.IItems[];

                    /** Metadata kind. */
                    public kind?: (string|null);

                    /** Metadata _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** Metadata _kind. */
                    public _kind?: "kind";

                    /**
                     * Creates a new Metadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Metadata instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMetadata): google.cloud.compute.v1.Metadata;

                    /**
                     * Encodes the specified Metadata message. Does not implicitly {@link google.cloud.compute.v1.Metadata.verify|verify} messages.
                     * @param message Metadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Metadata message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Metadata.verify|verify} messages.
                     * @param message Metadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Metadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Metadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Metadata;

                    /**
                     * Decodes a Metadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Metadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Metadata;

                    /**
                     * Verifies a Metadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Metadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Metadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Metadata;

                    /**
                     * Creates a plain object from a Metadata message. Also converts values to other types if specified.
                     * @param message Metadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Metadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Metadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Metadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MetadataFilter. */
                interface IMetadataFilter {

                    /** MetadataFilter filterLabels */
                    filterLabels?: (google.cloud.compute.v1.IMetadataFilterLabelMatch[]|null);

                    /** MetadataFilter filterMatchCriteria */
                    filterMatchCriteria?: (string|null);
                }

                /** Represents a MetadataFilter. */
                class MetadataFilter implements IMetadataFilter {

                    /**
                     * Constructs a new MetadataFilter.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMetadataFilter);

                    /** MetadataFilter filterLabels. */
                    public filterLabels: google.cloud.compute.v1.IMetadataFilterLabelMatch[];

                    /** MetadataFilter filterMatchCriteria. */
                    public filterMatchCriteria?: (string|null);

                    /** MetadataFilter _filterMatchCriteria. */
                    public _filterMatchCriteria?: "filterMatchCriteria";

                    /**
                     * Creates a new MetadataFilter instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MetadataFilter instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMetadataFilter): google.cloud.compute.v1.MetadataFilter;

                    /**
                     * Encodes the specified MetadataFilter message. Does not implicitly {@link google.cloud.compute.v1.MetadataFilter.verify|verify} messages.
                     * @param message MetadataFilter message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMetadataFilter, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MetadataFilter message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MetadataFilter.verify|verify} messages.
                     * @param message MetadataFilter message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMetadataFilter, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MetadataFilter message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MetadataFilter
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MetadataFilter;

                    /**
                     * Decodes a MetadataFilter message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MetadataFilter
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MetadataFilter;

                    /**
                     * Verifies a MetadataFilter message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MetadataFilter message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MetadataFilter
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MetadataFilter;

                    /**
                     * Creates a plain object from a MetadataFilter message. Also converts values to other types if specified.
                     * @param message MetadataFilter
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MetadataFilter, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MetadataFilter to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MetadataFilter
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace MetadataFilter {

                    /** FilterMatchCriteria enum. */
                    enum FilterMatchCriteria {
                        UNDEFINED_FILTER_MATCH_CRITERIA = 0,
                        MATCH_ALL = 180663271,
                        MATCH_ANY = 180663346,
                        NOT_SET = 163646646
                    }
                }

                /** Properties of a MetadataFilterLabelMatch. */
                interface IMetadataFilterLabelMatch {

                    /** MetadataFilterLabelMatch name */
                    name?: (string|null);

                    /** MetadataFilterLabelMatch value */
                    value?: (string|null);
                }

                /** Represents a MetadataFilterLabelMatch. */
                class MetadataFilterLabelMatch implements IMetadataFilterLabelMatch {

                    /**
                     * Constructs a new MetadataFilterLabelMatch.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMetadataFilterLabelMatch);

                    /** MetadataFilterLabelMatch name. */
                    public name?: (string|null);

                    /** MetadataFilterLabelMatch value. */
                    public value?: (string|null);

                    /** MetadataFilterLabelMatch _name. */
                    public _name?: "name";

                    /** MetadataFilterLabelMatch _value. */
                    public _value?: "value";

                    /**
                     * Creates a new MetadataFilterLabelMatch instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MetadataFilterLabelMatch instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMetadataFilterLabelMatch): google.cloud.compute.v1.MetadataFilterLabelMatch;

                    /**
                     * Encodes the specified MetadataFilterLabelMatch message. Does not implicitly {@link google.cloud.compute.v1.MetadataFilterLabelMatch.verify|verify} messages.
                     * @param message MetadataFilterLabelMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMetadataFilterLabelMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MetadataFilterLabelMatch message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MetadataFilterLabelMatch.verify|verify} messages.
                     * @param message MetadataFilterLabelMatch message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMetadataFilterLabelMatch, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MetadataFilterLabelMatch message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MetadataFilterLabelMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MetadataFilterLabelMatch;

                    /**
                     * Decodes a MetadataFilterLabelMatch message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MetadataFilterLabelMatch
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MetadataFilterLabelMatch;

                    /**
                     * Verifies a MetadataFilterLabelMatch message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MetadataFilterLabelMatch message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MetadataFilterLabelMatch
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MetadataFilterLabelMatch;

                    /**
                     * Creates a plain object from a MetadataFilterLabelMatch message. Also converts values to other types if specified.
                     * @param message MetadataFilterLabelMatch
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MetadataFilterLabelMatch, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MetadataFilterLabelMatch to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MetadataFilterLabelMatch
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MoveDiskProjectRequest. */
                interface IMoveDiskProjectRequest {

                    /** MoveDiskProjectRequest diskMoveRequestResource */
                    diskMoveRequestResource?: (google.cloud.compute.v1.IDiskMoveRequest|null);

                    /** MoveDiskProjectRequest project */
                    project?: (string|null);

                    /** MoveDiskProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a MoveDiskProjectRequest. */
                class MoveDiskProjectRequest implements IMoveDiskProjectRequest {

                    /**
                     * Constructs a new MoveDiskProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMoveDiskProjectRequest);

                    /** MoveDiskProjectRequest diskMoveRequestResource. */
                    public diskMoveRequestResource?: (google.cloud.compute.v1.IDiskMoveRequest|null);

                    /** MoveDiskProjectRequest project. */
                    public project: string;

                    /** MoveDiskProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** MoveDiskProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new MoveDiskProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MoveDiskProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMoveDiskProjectRequest): google.cloud.compute.v1.MoveDiskProjectRequest;

                    /**
                     * Encodes the specified MoveDiskProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.MoveDiskProjectRequest.verify|verify} messages.
                     * @param message MoveDiskProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMoveDiskProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MoveDiskProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MoveDiskProjectRequest.verify|verify} messages.
                     * @param message MoveDiskProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMoveDiskProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MoveDiskProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MoveDiskProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MoveDiskProjectRequest;

                    /**
                     * Decodes a MoveDiskProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MoveDiskProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MoveDiskProjectRequest;

                    /**
                     * Verifies a MoveDiskProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MoveDiskProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MoveDiskProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MoveDiskProjectRequest;

                    /**
                     * Creates a plain object from a MoveDiskProjectRequest message. Also converts values to other types if specified.
                     * @param message MoveDiskProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MoveDiskProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MoveDiskProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MoveDiskProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MoveFirewallPolicyRequest. */
                interface IMoveFirewallPolicyRequest {

                    /** MoveFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** MoveFirewallPolicyRequest parentId */
                    parentId?: (string|null);

                    /** MoveFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a MoveFirewallPolicyRequest. */
                class MoveFirewallPolicyRequest implements IMoveFirewallPolicyRequest {

                    /**
                     * Constructs a new MoveFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMoveFirewallPolicyRequest);

                    /** MoveFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** MoveFirewallPolicyRequest parentId. */
                    public parentId: string;

                    /** MoveFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** MoveFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new MoveFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MoveFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMoveFirewallPolicyRequest): google.cloud.compute.v1.MoveFirewallPolicyRequest;

                    /**
                     * Encodes the specified MoveFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.MoveFirewallPolicyRequest.verify|verify} messages.
                     * @param message MoveFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMoveFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MoveFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MoveFirewallPolicyRequest.verify|verify} messages.
                     * @param message MoveFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMoveFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MoveFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MoveFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MoveFirewallPolicyRequest;

                    /**
                     * Decodes a MoveFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MoveFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MoveFirewallPolicyRequest;

                    /**
                     * Verifies a MoveFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MoveFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MoveFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MoveFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a MoveFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message MoveFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MoveFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MoveFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MoveFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a MoveInstanceProjectRequest. */
                interface IMoveInstanceProjectRequest {

                    /** MoveInstanceProjectRequest instanceMoveRequestResource */
                    instanceMoveRequestResource?: (google.cloud.compute.v1.IInstanceMoveRequest|null);

                    /** MoveInstanceProjectRequest project */
                    project?: (string|null);

                    /** MoveInstanceProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a MoveInstanceProjectRequest. */
                class MoveInstanceProjectRequest implements IMoveInstanceProjectRequest {

                    /**
                     * Constructs a new MoveInstanceProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IMoveInstanceProjectRequest);

                    /** MoveInstanceProjectRequest instanceMoveRequestResource. */
                    public instanceMoveRequestResource?: (google.cloud.compute.v1.IInstanceMoveRequest|null);

                    /** MoveInstanceProjectRequest project. */
                    public project: string;

                    /** MoveInstanceProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** MoveInstanceProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new MoveInstanceProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns MoveInstanceProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IMoveInstanceProjectRequest): google.cloud.compute.v1.MoveInstanceProjectRequest;

                    /**
                     * Encodes the specified MoveInstanceProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.MoveInstanceProjectRequest.verify|verify} messages.
                     * @param message MoveInstanceProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IMoveInstanceProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified MoveInstanceProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.MoveInstanceProjectRequest.verify|verify} messages.
                     * @param message MoveInstanceProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IMoveInstanceProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a MoveInstanceProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns MoveInstanceProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.MoveInstanceProjectRequest;

                    /**
                     * Decodes a MoveInstanceProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns MoveInstanceProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.MoveInstanceProjectRequest;

                    /**
                     * Verifies a MoveInstanceProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a MoveInstanceProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns MoveInstanceProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.MoveInstanceProjectRequest;

                    /**
                     * Creates a plain object from a MoveInstanceProjectRequest message. Also converts values to other types if specified.
                     * @param message MoveInstanceProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.MoveInstanceProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this MoveInstanceProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for MoveInstanceProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NamedPort. */
                interface INamedPort {

                    /** NamedPort name */
                    name?: (string|null);

                    /** NamedPort port */
                    port?: (number|null);
                }

                /** Represents a NamedPort. */
                class NamedPort implements INamedPort {

                    /**
                     * Constructs a new NamedPort.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INamedPort);

                    /** NamedPort name. */
                    public name?: (string|null);

                    /** NamedPort port. */
                    public port?: (number|null);

                    /** NamedPort _name. */
                    public _name?: "name";

                    /** NamedPort _port. */
                    public _port?: "port";

                    /**
                     * Creates a new NamedPort instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NamedPort instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INamedPort): google.cloud.compute.v1.NamedPort;

                    /**
                     * Encodes the specified NamedPort message. Does not implicitly {@link google.cloud.compute.v1.NamedPort.verify|verify} messages.
                     * @param message NamedPort message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INamedPort, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NamedPort message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NamedPort.verify|verify} messages.
                     * @param message NamedPort message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INamedPort, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NamedPort message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NamedPort
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NamedPort;

                    /**
                     * Decodes a NamedPort message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NamedPort
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NamedPort;

                    /**
                     * Verifies a NamedPort message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NamedPort message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NamedPort
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NamedPort;

                    /**
                     * Creates a plain object from a NamedPort message. Also converts values to other types if specified.
                     * @param message NamedPort
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NamedPort, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NamedPort to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NamedPort
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Network. */
                interface INetwork {

                    /** Network IPv4Range */
                    IPv4Range?: (string|null);

                    /** Network autoCreateSubnetworks */
                    autoCreateSubnetworks?: (boolean|null);

                    /** Network creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Network description */
                    description?: (string|null);

                    /** Network enableUlaInternalIpv6 */
                    enableUlaInternalIpv6?: (boolean|null);

                    /** Network firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** Network gatewayIPv4 */
                    gatewayIPv4?: (string|null);

                    /** Network id */
                    id?: (number|Long|string|null);

                    /** Network internalIpv6Range */
                    internalIpv6Range?: (string|null);

                    /** Network kind */
                    kind?: (string|null);

                    /** Network mtu */
                    mtu?: (number|null);

                    /** Network name */
                    name?: (string|null);

                    /** Network networkFirewallPolicyEnforcementOrder */
                    networkFirewallPolicyEnforcementOrder?: (string|null);

                    /** Network peerings */
                    peerings?: (google.cloud.compute.v1.INetworkPeering[]|null);

                    /** Network routingConfig */
                    routingConfig?: (google.cloud.compute.v1.INetworkRoutingConfig|null);

                    /** Network selfLink */
                    selfLink?: (string|null);

                    /** Network selfLinkWithId */
                    selfLinkWithId?: (string|null);

                    /** Network subnetworks */
                    subnetworks?: (string[]|null);
                }

                /** Represents a Network. */
                class Network implements INetwork {

                    /**
                     * Constructs a new Network.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetwork);

                    /** Network IPv4Range. */
                    public IPv4Range?: (string|null);

                    /** Network autoCreateSubnetworks. */
                    public autoCreateSubnetworks?: (boolean|null);

                    /** Network creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Network description. */
                    public description?: (string|null);

                    /** Network enableUlaInternalIpv6. */
                    public enableUlaInternalIpv6?: (boolean|null);

                    /** Network firewallPolicy. */
                    public firewallPolicy?: (string|null);

                    /** Network gatewayIPv4. */
                    public gatewayIPv4?: (string|null);

                    /** Network id. */
                    public id?: (number|Long|string|null);

                    /** Network internalIpv6Range. */
                    public internalIpv6Range?: (string|null);

                    /** Network kind. */
                    public kind?: (string|null);

                    /** Network mtu. */
                    public mtu?: (number|null);

                    /** Network name. */
                    public name?: (string|null);

                    /** Network networkFirewallPolicyEnforcementOrder. */
                    public networkFirewallPolicyEnforcementOrder?: (string|null);

                    /** Network peerings. */
                    public peerings: google.cloud.compute.v1.INetworkPeering[];

                    /** Network routingConfig. */
                    public routingConfig?: (google.cloud.compute.v1.INetworkRoutingConfig|null);

                    /** Network selfLink. */
                    public selfLink?: (string|null);

                    /** Network selfLinkWithId. */
                    public selfLinkWithId?: (string|null);

                    /** Network subnetworks. */
                    public subnetworks: string[];

                    /** Network _IPv4Range. */
                    public _IPv4Range?: "IPv4Range";

                    /** Network _autoCreateSubnetworks. */
                    public _autoCreateSubnetworks?: "autoCreateSubnetworks";

                    /** Network _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Network _description. */
                    public _description?: "description";

                    /** Network _enableUlaInternalIpv6. */
                    public _enableUlaInternalIpv6?: "enableUlaInternalIpv6";

                    /** Network _firewallPolicy. */
                    public _firewallPolicy?: "firewallPolicy";

                    /** Network _gatewayIPv4. */
                    public _gatewayIPv4?: "gatewayIPv4";

                    /** Network _id. */
                    public _id?: "id";

                    /** Network _internalIpv6Range. */
                    public _internalIpv6Range?: "internalIpv6Range";

                    /** Network _kind. */
                    public _kind?: "kind";

                    /** Network _mtu. */
                    public _mtu?: "mtu";

                    /** Network _name. */
                    public _name?: "name";

                    /** Network _networkFirewallPolicyEnforcementOrder. */
                    public _networkFirewallPolicyEnforcementOrder?: "networkFirewallPolicyEnforcementOrder";

                    /** Network _routingConfig. */
                    public _routingConfig?: "routingConfig";

                    /** Network _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Network _selfLinkWithId. */
                    public _selfLinkWithId?: "selfLinkWithId";

                    /**
                     * Creates a new Network instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Network instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetwork): google.cloud.compute.v1.Network;

                    /**
                     * Encodes the specified Network message. Does not implicitly {@link google.cloud.compute.v1.Network.verify|verify} messages.
                     * @param message Network message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetwork, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Network message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Network.verify|verify} messages.
                     * @param message Network message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetwork, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Network message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Network
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Network;

                    /**
                     * Decodes a Network message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Network
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Network;

                    /**
                     * Verifies a Network message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Network message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Network
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Network;

                    /**
                     * Creates a plain object from a Network message. Also converts values to other types if specified.
                     * @param message Network
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Network, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Network to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Network
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Network {

                    /** NetworkFirewallPolicyEnforcementOrder enum. */
                    enum NetworkFirewallPolicyEnforcementOrder {
                        UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0,
                        AFTER_CLASSIC_FIREWALL = 154582608,
                        BEFORE_CLASSIC_FIREWALL = 338458349
                    }
                }

                /** Properties of a NetworkEdgeSecurityService. */
                interface INetworkEdgeSecurityService {

                    /** NetworkEdgeSecurityService creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** NetworkEdgeSecurityService description */
                    description?: (string|null);

                    /** NetworkEdgeSecurityService fingerprint */
                    fingerprint?: (string|null);

                    /** NetworkEdgeSecurityService id */
                    id?: (number|Long|string|null);

                    /** NetworkEdgeSecurityService kind */
                    kind?: (string|null);

                    /** NetworkEdgeSecurityService name */
                    name?: (string|null);

                    /** NetworkEdgeSecurityService region */
                    region?: (string|null);

                    /** NetworkEdgeSecurityService securityPolicy */
                    securityPolicy?: (string|null);

                    /** NetworkEdgeSecurityService selfLink */
                    selfLink?: (string|null);

                    /** NetworkEdgeSecurityService selfLinkWithId */
                    selfLinkWithId?: (string|null);
                }

                /** Represents a NetworkEdgeSecurityService. */
                class NetworkEdgeSecurityService implements INetworkEdgeSecurityService {

                    /**
                     * Constructs a new NetworkEdgeSecurityService.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEdgeSecurityService);

                    /** NetworkEdgeSecurityService creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** NetworkEdgeSecurityService description. */
                    public description?: (string|null);

                    /** NetworkEdgeSecurityService fingerprint. */
                    public fingerprint?: (string|null);

                    /** NetworkEdgeSecurityService id. */
                    public id?: (number|Long|string|null);

                    /** NetworkEdgeSecurityService kind. */
                    public kind?: (string|null);

                    /** NetworkEdgeSecurityService name. */
                    public name?: (string|null);

                    /** NetworkEdgeSecurityService region. */
                    public region?: (string|null);

                    /** NetworkEdgeSecurityService securityPolicy. */
                    public securityPolicy?: (string|null);

                    /** NetworkEdgeSecurityService selfLink. */
                    public selfLink?: (string|null);

                    /** NetworkEdgeSecurityService selfLinkWithId. */
                    public selfLinkWithId?: (string|null);

                    /** NetworkEdgeSecurityService _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** NetworkEdgeSecurityService _description. */
                    public _description?: "description";

                    /** NetworkEdgeSecurityService _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** NetworkEdgeSecurityService _id. */
                    public _id?: "id";

                    /** NetworkEdgeSecurityService _kind. */
                    public _kind?: "kind";

                    /** NetworkEdgeSecurityService _name. */
                    public _name?: "name";

                    /** NetworkEdgeSecurityService _region. */
                    public _region?: "region";

                    /** NetworkEdgeSecurityService _securityPolicy. */
                    public _securityPolicy?: "securityPolicy";

                    /** NetworkEdgeSecurityService _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NetworkEdgeSecurityService _selfLinkWithId. */
                    public _selfLinkWithId?: "selfLinkWithId";

                    /**
                     * Creates a new NetworkEdgeSecurityService instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEdgeSecurityService instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEdgeSecurityService): google.cloud.compute.v1.NetworkEdgeSecurityService;

                    /**
                     * Encodes the specified NetworkEdgeSecurityService message. Does not implicitly {@link google.cloud.compute.v1.NetworkEdgeSecurityService.verify|verify} messages.
                     * @param message NetworkEdgeSecurityService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEdgeSecurityService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEdgeSecurityService message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEdgeSecurityService.verify|verify} messages.
                     * @param message NetworkEdgeSecurityService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEdgeSecurityService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEdgeSecurityService message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEdgeSecurityService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEdgeSecurityService;

                    /**
                     * Decodes a NetworkEdgeSecurityService message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEdgeSecurityService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEdgeSecurityService;

                    /**
                     * Verifies a NetworkEdgeSecurityService message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEdgeSecurityService message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEdgeSecurityService
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEdgeSecurityService;

                    /**
                     * Creates a plain object from a NetworkEdgeSecurityService message. Also converts values to other types if specified.
                     * @param message NetworkEdgeSecurityService
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEdgeSecurityService, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEdgeSecurityService to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEdgeSecurityService
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEdgeSecurityServiceAggregatedList. */
                interface INetworkEdgeSecurityServiceAggregatedList {

                    /** NetworkEdgeSecurityServiceAggregatedList etag */
                    etag?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList id */
                    id?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.INetworkEdgeSecurityServicesScopedList }|null);

                    /** NetworkEdgeSecurityServiceAggregatedList kind */
                    kind?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** NetworkEdgeSecurityServiceAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkEdgeSecurityServiceAggregatedList. */
                class NetworkEdgeSecurityServiceAggregatedList implements INetworkEdgeSecurityServiceAggregatedList {

                    /**
                     * Constructs a new NetworkEdgeSecurityServiceAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEdgeSecurityServiceAggregatedList);

                    /** NetworkEdgeSecurityServiceAggregatedList etag. */
                    public etag?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList id. */
                    public id?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.INetworkEdgeSecurityServicesScopedList };

                    /** NetworkEdgeSecurityServiceAggregatedList kind. */
                    public kind?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** NetworkEdgeSecurityServiceAggregatedList unreachables. */
                    public unreachables: string[];

                    /** NetworkEdgeSecurityServiceAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkEdgeSecurityServiceAggregatedList _etag. */
                    public _etag?: "etag";

                    /** NetworkEdgeSecurityServiceAggregatedList _id. */
                    public _id?: "id";

                    /** NetworkEdgeSecurityServiceAggregatedList _kind. */
                    public _kind?: "kind";

                    /** NetworkEdgeSecurityServiceAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NetworkEdgeSecurityServiceAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NetworkEdgeSecurityServiceAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkEdgeSecurityServiceAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEdgeSecurityServiceAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEdgeSecurityServiceAggregatedList): google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList;

                    /**
                     * Encodes the specified NetworkEdgeSecurityServiceAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList.verify|verify} messages.
                     * @param message NetworkEdgeSecurityServiceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEdgeSecurityServiceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEdgeSecurityServiceAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList.verify|verify} messages.
                     * @param message NetworkEdgeSecurityServiceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEdgeSecurityServiceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEdgeSecurityServiceAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEdgeSecurityServiceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList;

                    /**
                     * Decodes a NetworkEdgeSecurityServiceAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEdgeSecurityServiceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList;

                    /**
                     * Verifies a NetworkEdgeSecurityServiceAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEdgeSecurityServiceAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEdgeSecurityServiceAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList;

                    /**
                     * Creates a plain object from a NetworkEdgeSecurityServiceAggregatedList message. Also converts values to other types if specified.
                     * @param message NetworkEdgeSecurityServiceAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEdgeSecurityServiceAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEdgeSecurityServiceAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEdgeSecurityServicesScopedList. */
                interface INetworkEdgeSecurityServicesScopedList {

                    /** NetworkEdgeSecurityServicesScopedList networkEdgeSecurityServices */
                    networkEdgeSecurityServices?: (google.cloud.compute.v1.INetworkEdgeSecurityService[]|null);

                    /** NetworkEdgeSecurityServicesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkEdgeSecurityServicesScopedList. */
                class NetworkEdgeSecurityServicesScopedList implements INetworkEdgeSecurityServicesScopedList {

                    /**
                     * Constructs a new NetworkEdgeSecurityServicesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEdgeSecurityServicesScopedList);

                    /** NetworkEdgeSecurityServicesScopedList networkEdgeSecurityServices. */
                    public networkEdgeSecurityServices: google.cloud.compute.v1.INetworkEdgeSecurityService[];

                    /** NetworkEdgeSecurityServicesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkEdgeSecurityServicesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkEdgeSecurityServicesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEdgeSecurityServicesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEdgeSecurityServicesScopedList): google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList;

                    /**
                     * Encodes the specified NetworkEdgeSecurityServicesScopedList message. Does not implicitly {@link google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList.verify|verify} messages.
                     * @param message NetworkEdgeSecurityServicesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEdgeSecurityServicesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEdgeSecurityServicesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList.verify|verify} messages.
                     * @param message NetworkEdgeSecurityServicesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEdgeSecurityServicesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEdgeSecurityServicesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEdgeSecurityServicesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList;

                    /**
                     * Decodes a NetworkEdgeSecurityServicesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEdgeSecurityServicesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList;

                    /**
                     * Verifies a NetworkEdgeSecurityServicesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEdgeSecurityServicesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEdgeSecurityServicesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList;

                    /**
                     * Creates a plain object from a NetworkEdgeSecurityServicesScopedList message. Also converts values to other types if specified.
                     * @param message NetworkEdgeSecurityServicesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEdgeSecurityServicesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEdgeSecurityServicesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEdgeSecurityServicesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpoint. */
                interface INetworkEndpoint {

                    /** NetworkEndpoint annotations */
                    annotations?: ({ [k: string]: string }|null);

                    /** NetworkEndpoint fqdn */
                    fqdn?: (string|null);

                    /** NetworkEndpoint instance */
                    instance?: (string|null);

                    /** NetworkEndpoint ipAddress */
                    ipAddress?: (string|null);

                    /** NetworkEndpoint port */
                    port?: (number|null);
                }

                /** Represents a NetworkEndpoint. */
                class NetworkEndpoint implements INetworkEndpoint {

                    /**
                     * Constructs a new NetworkEndpoint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpoint);

                    /** NetworkEndpoint annotations. */
                    public annotations: { [k: string]: string };

                    /** NetworkEndpoint fqdn. */
                    public fqdn?: (string|null);

                    /** NetworkEndpoint instance. */
                    public instance?: (string|null);

                    /** NetworkEndpoint ipAddress. */
                    public ipAddress?: (string|null);

                    /** NetworkEndpoint port. */
                    public port?: (number|null);

                    /** NetworkEndpoint _fqdn. */
                    public _fqdn?: "fqdn";

                    /** NetworkEndpoint _instance. */
                    public _instance?: "instance";

                    /** NetworkEndpoint _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /** NetworkEndpoint _port. */
                    public _port?: "port";

                    /**
                     * Creates a new NetworkEndpoint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpoint instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpoint): google.cloud.compute.v1.NetworkEndpoint;

                    /**
                     * Encodes the specified NetworkEndpoint message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpoint.verify|verify} messages.
                     * @param message NetworkEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpoint message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpoint.verify|verify} messages.
                     * @param message NetworkEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpoint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpoint;

                    /**
                     * Decodes a NetworkEndpoint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpoint;

                    /**
                     * Verifies a NetworkEndpoint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpoint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpoint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpoint;

                    /**
                     * Creates a plain object from a NetworkEndpoint message. Also converts values to other types if specified.
                     * @param message NetworkEndpoint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpoint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpoint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpoint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroup. */
                interface INetworkEndpointGroup {

                    /** NetworkEndpointGroup annotations */
                    annotations?: ({ [k: string]: string }|null);

                    /** NetworkEndpointGroup appEngine */
                    appEngine?: (google.cloud.compute.v1.INetworkEndpointGroupAppEngine|null);

                    /** NetworkEndpointGroup cloudFunction */
                    cloudFunction?: (google.cloud.compute.v1.INetworkEndpointGroupCloudFunction|null);

                    /** NetworkEndpointGroup cloudRun */
                    cloudRun?: (google.cloud.compute.v1.INetworkEndpointGroupCloudRun|null);

                    /** NetworkEndpointGroup creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** NetworkEndpointGroup defaultPort */
                    defaultPort?: (number|null);

                    /** NetworkEndpointGroup description */
                    description?: (string|null);

                    /** NetworkEndpointGroup id */
                    id?: (number|Long|string|null);

                    /** NetworkEndpointGroup kind */
                    kind?: (string|null);

                    /** NetworkEndpointGroup name */
                    name?: (string|null);

                    /** NetworkEndpointGroup network */
                    network?: (string|null);

                    /** NetworkEndpointGroup networkEndpointType */
                    networkEndpointType?: (string|null);

                    /** NetworkEndpointGroup pscData */
                    pscData?: (google.cloud.compute.v1.INetworkEndpointGroupPscData|null);

                    /** NetworkEndpointGroup pscTargetService */
                    pscTargetService?: (string|null);

                    /** NetworkEndpointGroup region */
                    region?: (string|null);

                    /** NetworkEndpointGroup selfLink */
                    selfLink?: (string|null);

                    /** NetworkEndpointGroup size */
                    size?: (number|null);

                    /** NetworkEndpointGroup subnetwork */
                    subnetwork?: (string|null);

                    /** NetworkEndpointGroup zone */
                    zone?: (string|null);
                }

                /** Represents a NetworkEndpointGroup. */
                class NetworkEndpointGroup implements INetworkEndpointGroup {

                    /**
                     * Constructs a new NetworkEndpointGroup.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroup);

                    /** NetworkEndpointGroup annotations. */
                    public annotations: { [k: string]: string };

                    /** NetworkEndpointGroup appEngine. */
                    public appEngine?: (google.cloud.compute.v1.INetworkEndpointGroupAppEngine|null);

                    /** NetworkEndpointGroup cloudFunction. */
                    public cloudFunction?: (google.cloud.compute.v1.INetworkEndpointGroupCloudFunction|null);

                    /** NetworkEndpointGroup cloudRun. */
                    public cloudRun?: (google.cloud.compute.v1.INetworkEndpointGroupCloudRun|null);

                    /** NetworkEndpointGroup creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** NetworkEndpointGroup defaultPort. */
                    public defaultPort?: (number|null);

                    /** NetworkEndpointGroup description. */
                    public description?: (string|null);

                    /** NetworkEndpointGroup id. */
                    public id?: (number|Long|string|null);

                    /** NetworkEndpointGroup kind. */
                    public kind?: (string|null);

                    /** NetworkEndpointGroup name. */
                    public name?: (string|null);

                    /** NetworkEndpointGroup network. */
                    public network?: (string|null);

                    /** NetworkEndpointGroup networkEndpointType. */
                    public networkEndpointType?: (string|null);

                    /** NetworkEndpointGroup pscData. */
                    public pscData?: (google.cloud.compute.v1.INetworkEndpointGroupPscData|null);

                    /** NetworkEndpointGroup pscTargetService. */
                    public pscTargetService?: (string|null);

                    /** NetworkEndpointGroup region. */
                    public region?: (string|null);

                    /** NetworkEndpointGroup selfLink. */
                    public selfLink?: (string|null);

                    /** NetworkEndpointGroup size. */
                    public size?: (number|null);

                    /** NetworkEndpointGroup subnetwork. */
                    public subnetwork?: (string|null);

                    /** NetworkEndpointGroup zone. */
                    public zone?: (string|null);

                    /** NetworkEndpointGroup _appEngine. */
                    public _appEngine?: "appEngine";

                    /** NetworkEndpointGroup _cloudFunction. */
                    public _cloudFunction?: "cloudFunction";

                    /** NetworkEndpointGroup _cloudRun. */
                    public _cloudRun?: "cloudRun";

                    /** NetworkEndpointGroup _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** NetworkEndpointGroup _defaultPort. */
                    public _defaultPort?: "defaultPort";

                    /** NetworkEndpointGroup _description. */
                    public _description?: "description";

                    /** NetworkEndpointGroup _id. */
                    public _id?: "id";

                    /** NetworkEndpointGroup _kind. */
                    public _kind?: "kind";

                    /** NetworkEndpointGroup _name. */
                    public _name?: "name";

                    /** NetworkEndpointGroup _network. */
                    public _network?: "network";

                    /** NetworkEndpointGroup _networkEndpointType. */
                    public _networkEndpointType?: "networkEndpointType";

                    /** NetworkEndpointGroup _pscData. */
                    public _pscData?: "pscData";

                    /** NetworkEndpointGroup _pscTargetService. */
                    public _pscTargetService?: "pscTargetService";

                    /** NetworkEndpointGroup _region. */
                    public _region?: "region";

                    /** NetworkEndpointGroup _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NetworkEndpointGroup _size. */
                    public _size?: "size";

                    /** NetworkEndpointGroup _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /** NetworkEndpointGroup _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new NetworkEndpointGroup instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroup instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroup): google.cloud.compute.v1.NetworkEndpointGroup;

                    /**
                     * Encodes the specified NetworkEndpointGroup message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroup.verify|verify} messages.
                     * @param message NetworkEndpointGroup message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroup, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroup message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroup.verify|verify} messages.
                     * @param message NetworkEndpointGroup message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroup, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroup message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroup
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroup;

                    /**
                     * Decodes a NetworkEndpointGroup message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroup
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroup;

                    /**
                     * Verifies a NetworkEndpointGroup message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroup message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroup
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroup;

                    /**
                     * Creates a plain object from a NetworkEndpointGroup message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroup
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroup, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroup to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroup
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkEndpointGroup {

                    /** NetworkEndpointType enum. */
                    enum NetworkEndpointType {
                        UNDEFINED_NETWORK_ENDPOINT_TYPE = 0,
                        GCE_VM_IP = 401880793,
                        GCE_VM_IP_PORT = 501838375,
                        INTERNET_FQDN_PORT = 404154477,
                        INTERNET_IP_PORT = 477719963,
                        NON_GCP_PRIVATE_IP_PORT = 336447968,
                        PRIVATE_SERVICE_CONNECT = 48134724,
                        SERVERLESS = 270492508
                    }
                }

                /** Properties of a NetworkEndpointGroupAggregatedList. */
                interface INetworkEndpointGroupAggregatedList {

                    /** NetworkEndpointGroupAggregatedList id */
                    id?: (string|null);

                    /** NetworkEndpointGroupAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.INetworkEndpointGroupsScopedList }|null);

                    /** NetworkEndpointGroupAggregatedList kind */
                    kind?: (string|null);

                    /** NetworkEndpointGroupAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NetworkEndpointGroupAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** NetworkEndpointGroupAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** NetworkEndpointGroupAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkEndpointGroupAggregatedList. */
                class NetworkEndpointGroupAggregatedList implements INetworkEndpointGroupAggregatedList {

                    /**
                     * Constructs a new NetworkEndpointGroupAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupAggregatedList);

                    /** NetworkEndpointGroupAggregatedList id. */
                    public id?: (string|null);

                    /** NetworkEndpointGroupAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.INetworkEndpointGroupsScopedList };

                    /** NetworkEndpointGroupAggregatedList kind. */
                    public kind?: (string|null);

                    /** NetworkEndpointGroupAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NetworkEndpointGroupAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** NetworkEndpointGroupAggregatedList unreachables. */
                    public unreachables: string[];

                    /** NetworkEndpointGroupAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkEndpointGroupAggregatedList _id. */
                    public _id?: "id";

                    /** NetworkEndpointGroupAggregatedList _kind. */
                    public _kind?: "kind";

                    /** NetworkEndpointGroupAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NetworkEndpointGroupAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NetworkEndpointGroupAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkEndpointGroupAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupAggregatedList): google.cloud.compute.v1.NetworkEndpointGroupAggregatedList;

                    /**
                     * Encodes the specified NetworkEndpointGroupAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupAggregatedList.verify|verify} messages.
                     * @param message NetworkEndpointGroupAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupAggregatedList.verify|verify} messages.
                     * @param message NetworkEndpointGroupAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupAggregatedList;

                    /**
                     * Decodes a NetworkEndpointGroupAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupAggregatedList;

                    /**
                     * Verifies a NetworkEndpointGroupAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupAggregatedList;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupAggregatedList message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupAppEngine. */
                interface INetworkEndpointGroupAppEngine {

                    /** NetworkEndpointGroupAppEngine service */
                    service?: (string|null);

                    /** NetworkEndpointGroupAppEngine urlMask */
                    urlMask?: (string|null);

                    /** NetworkEndpointGroupAppEngine version */
                    version?: (string|null);
                }

                /** Represents a NetworkEndpointGroupAppEngine. */
                class NetworkEndpointGroupAppEngine implements INetworkEndpointGroupAppEngine {

                    /**
                     * Constructs a new NetworkEndpointGroupAppEngine.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupAppEngine);

                    /** NetworkEndpointGroupAppEngine service. */
                    public service?: (string|null);

                    /** NetworkEndpointGroupAppEngine urlMask. */
                    public urlMask?: (string|null);

                    /** NetworkEndpointGroupAppEngine version. */
                    public version?: (string|null);

                    /** NetworkEndpointGroupAppEngine _service. */
                    public _service?: "service";

                    /** NetworkEndpointGroupAppEngine _urlMask. */
                    public _urlMask?: "urlMask";

                    /** NetworkEndpointGroupAppEngine _version. */
                    public _version?: "version";

                    /**
                     * Creates a new NetworkEndpointGroupAppEngine instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupAppEngine instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupAppEngine): google.cloud.compute.v1.NetworkEndpointGroupAppEngine;

                    /**
                     * Encodes the specified NetworkEndpointGroupAppEngine message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupAppEngine.verify|verify} messages.
                     * @param message NetworkEndpointGroupAppEngine message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupAppEngine, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupAppEngine message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupAppEngine.verify|verify} messages.
                     * @param message NetworkEndpointGroupAppEngine message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupAppEngine, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupAppEngine message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupAppEngine
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupAppEngine;

                    /**
                     * Decodes a NetworkEndpointGroupAppEngine message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupAppEngine
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupAppEngine;

                    /**
                     * Verifies a NetworkEndpointGroupAppEngine message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupAppEngine message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupAppEngine
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupAppEngine;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupAppEngine message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupAppEngine
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupAppEngine, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupAppEngine to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupAppEngine
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupCloudFunction. */
                interface INetworkEndpointGroupCloudFunction {

                    /** NetworkEndpointGroupCloudFunction function */
                    "function"?: (string|null);

                    /** NetworkEndpointGroupCloudFunction urlMask */
                    urlMask?: (string|null);
                }

                /** Represents a NetworkEndpointGroupCloudFunction. */
                class NetworkEndpointGroupCloudFunction implements INetworkEndpointGroupCloudFunction {

                    /**
                     * Constructs a new NetworkEndpointGroupCloudFunction.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupCloudFunction);

                    /** NetworkEndpointGroupCloudFunction function. */
                    public function?: (string|null);

                    /** NetworkEndpointGroupCloudFunction urlMask. */
                    public urlMask?: (string|null);

                    /** NetworkEndpointGroupCloudFunction _function. */
                    public _function?: "Function";

                    /** NetworkEndpointGroupCloudFunction _urlMask. */
                    public _urlMask?: "urlMask";

                    /**
                     * Creates a new NetworkEndpointGroupCloudFunction instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupCloudFunction instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupCloudFunction): google.cloud.compute.v1.NetworkEndpointGroupCloudFunction;

                    /**
                     * Encodes the specified NetworkEndpointGroupCloudFunction message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupCloudFunction.verify|verify} messages.
                     * @param message NetworkEndpointGroupCloudFunction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupCloudFunction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupCloudFunction message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupCloudFunction.verify|verify} messages.
                     * @param message NetworkEndpointGroupCloudFunction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupCloudFunction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupCloudFunction message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupCloudFunction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupCloudFunction;

                    /**
                     * Decodes a NetworkEndpointGroupCloudFunction message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupCloudFunction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupCloudFunction;

                    /**
                     * Verifies a NetworkEndpointGroupCloudFunction message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupCloudFunction message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupCloudFunction
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupCloudFunction;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupCloudFunction message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupCloudFunction
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupCloudFunction, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupCloudFunction to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupCloudFunction
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupCloudRun. */
                interface INetworkEndpointGroupCloudRun {

                    /** NetworkEndpointGroupCloudRun service */
                    service?: (string|null);

                    /** NetworkEndpointGroupCloudRun tag */
                    tag?: (string|null);

                    /** NetworkEndpointGroupCloudRun urlMask */
                    urlMask?: (string|null);
                }

                /** Represents a NetworkEndpointGroupCloudRun. */
                class NetworkEndpointGroupCloudRun implements INetworkEndpointGroupCloudRun {

                    /**
                     * Constructs a new NetworkEndpointGroupCloudRun.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupCloudRun);

                    /** NetworkEndpointGroupCloudRun service. */
                    public service?: (string|null);

                    /** NetworkEndpointGroupCloudRun tag. */
                    public tag?: (string|null);

                    /** NetworkEndpointGroupCloudRun urlMask. */
                    public urlMask?: (string|null);

                    /** NetworkEndpointGroupCloudRun _service. */
                    public _service?: "service";

                    /** NetworkEndpointGroupCloudRun _tag. */
                    public _tag?: "tag";

                    /** NetworkEndpointGroupCloudRun _urlMask. */
                    public _urlMask?: "urlMask";

                    /**
                     * Creates a new NetworkEndpointGroupCloudRun instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupCloudRun instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupCloudRun): google.cloud.compute.v1.NetworkEndpointGroupCloudRun;

                    /**
                     * Encodes the specified NetworkEndpointGroupCloudRun message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupCloudRun.verify|verify} messages.
                     * @param message NetworkEndpointGroupCloudRun message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupCloudRun, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupCloudRun message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupCloudRun.verify|verify} messages.
                     * @param message NetworkEndpointGroupCloudRun message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupCloudRun, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupCloudRun message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupCloudRun
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupCloudRun;

                    /**
                     * Decodes a NetworkEndpointGroupCloudRun message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupCloudRun
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupCloudRun;

                    /**
                     * Verifies a NetworkEndpointGroupCloudRun message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupCloudRun message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupCloudRun
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupCloudRun;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupCloudRun message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupCloudRun
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupCloudRun, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupCloudRun to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupCloudRun
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupList. */
                interface INetworkEndpointGroupList {

                    /** NetworkEndpointGroupList id */
                    id?: (string|null);

                    /** NetworkEndpointGroupList items */
                    items?: (google.cloud.compute.v1.INetworkEndpointGroup[]|null);

                    /** NetworkEndpointGroupList kind */
                    kind?: (string|null);

                    /** NetworkEndpointGroupList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NetworkEndpointGroupList selfLink */
                    selfLink?: (string|null);

                    /** NetworkEndpointGroupList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkEndpointGroupList. */
                class NetworkEndpointGroupList implements INetworkEndpointGroupList {

                    /**
                     * Constructs a new NetworkEndpointGroupList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupList);

                    /** NetworkEndpointGroupList id. */
                    public id?: (string|null);

                    /** NetworkEndpointGroupList items. */
                    public items: google.cloud.compute.v1.INetworkEndpointGroup[];

                    /** NetworkEndpointGroupList kind. */
                    public kind?: (string|null);

                    /** NetworkEndpointGroupList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NetworkEndpointGroupList selfLink. */
                    public selfLink?: (string|null);

                    /** NetworkEndpointGroupList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkEndpointGroupList _id. */
                    public _id?: "id";

                    /** NetworkEndpointGroupList _kind. */
                    public _kind?: "kind";

                    /** NetworkEndpointGroupList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NetworkEndpointGroupList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NetworkEndpointGroupList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkEndpointGroupList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupList): google.cloud.compute.v1.NetworkEndpointGroupList;

                    /**
                     * Encodes the specified NetworkEndpointGroupList message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupList.verify|verify} messages.
                     * @param message NetworkEndpointGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupList.verify|verify} messages.
                     * @param message NetworkEndpointGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupList;

                    /**
                     * Decodes a NetworkEndpointGroupList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupList;

                    /**
                     * Verifies a NetworkEndpointGroupList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupList;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupList message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupPscData. */
                interface INetworkEndpointGroupPscData {

                    /** NetworkEndpointGroupPscData consumerPscAddress */
                    consumerPscAddress?: (string|null);

                    /** NetworkEndpointGroupPscData pscConnectionId */
                    pscConnectionId?: (number|Long|string|null);

                    /** NetworkEndpointGroupPscData pscConnectionStatus */
                    pscConnectionStatus?: (string|null);
                }

                /** Represents a NetworkEndpointGroupPscData. */
                class NetworkEndpointGroupPscData implements INetworkEndpointGroupPscData {

                    /**
                     * Constructs a new NetworkEndpointGroupPscData.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupPscData);

                    /** NetworkEndpointGroupPscData consumerPscAddress. */
                    public consumerPscAddress?: (string|null);

                    /** NetworkEndpointGroupPscData pscConnectionId. */
                    public pscConnectionId?: (number|Long|string|null);

                    /** NetworkEndpointGroupPscData pscConnectionStatus. */
                    public pscConnectionStatus?: (string|null);

                    /** NetworkEndpointGroupPscData _consumerPscAddress. */
                    public _consumerPscAddress?: "consumerPscAddress";

                    /** NetworkEndpointGroupPscData _pscConnectionId. */
                    public _pscConnectionId?: "pscConnectionId";

                    /** NetworkEndpointGroupPscData _pscConnectionStatus. */
                    public _pscConnectionStatus?: "pscConnectionStatus";

                    /**
                     * Creates a new NetworkEndpointGroupPscData instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupPscData instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupPscData): google.cloud.compute.v1.NetworkEndpointGroupPscData;

                    /**
                     * Encodes the specified NetworkEndpointGroupPscData message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupPscData.verify|verify} messages.
                     * @param message NetworkEndpointGroupPscData message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupPscData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupPscData message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupPscData.verify|verify} messages.
                     * @param message NetworkEndpointGroupPscData message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupPscData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupPscData message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupPscData
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupPscData;

                    /**
                     * Decodes a NetworkEndpointGroupPscData message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupPscData
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupPscData;

                    /**
                     * Verifies a NetworkEndpointGroupPscData message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupPscData message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupPscData
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupPscData;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupPscData message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupPscData
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupPscData, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupPscData to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupPscData
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkEndpointGroupPscData {

                    /** PscConnectionStatus enum. */
                    enum PscConnectionStatus {
                        UNDEFINED_PSC_CONNECTION_STATUS = 0,
                        ACCEPTED = 246714279,
                        CLOSED = 380163436,
                        NEEDS_ATTENTION = 344491452,
                        PENDING = 35394935,
                        REJECTED = 174130302,
                        STATUS_UNSPECIFIED = 42133066
                    }
                }

                /** Properties of a NetworkEndpointGroupsAttachEndpointsRequest. */
                interface INetworkEndpointGroupsAttachEndpointsRequest {

                    /** NetworkEndpointGroupsAttachEndpointsRequest networkEndpoints */
                    networkEndpoints?: (google.cloud.compute.v1.INetworkEndpoint[]|null);
                }

                /** Represents a NetworkEndpointGroupsAttachEndpointsRequest. */
                class NetworkEndpointGroupsAttachEndpointsRequest implements INetworkEndpointGroupsAttachEndpointsRequest {

                    /**
                     * Constructs a new NetworkEndpointGroupsAttachEndpointsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupsAttachEndpointsRequest);

                    /** NetworkEndpointGroupsAttachEndpointsRequest networkEndpoints. */
                    public networkEndpoints: google.cloud.compute.v1.INetworkEndpoint[];

                    /**
                     * Creates a new NetworkEndpointGroupsAttachEndpointsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupsAttachEndpointsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupsAttachEndpointsRequest): google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Encodes the specified NetworkEndpointGroupsAttachEndpointsRequest message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest.verify|verify} messages.
                     * @param message NetworkEndpointGroupsAttachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupsAttachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupsAttachEndpointsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest.verify|verify} messages.
                     * @param message NetworkEndpointGroupsAttachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupsAttachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupsAttachEndpointsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupsAttachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Decodes a NetworkEndpointGroupsAttachEndpointsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupsAttachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Verifies a NetworkEndpointGroupsAttachEndpointsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupsAttachEndpointsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupsAttachEndpointsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupsAttachEndpointsRequest message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupsAttachEndpointsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupsAttachEndpointsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupsAttachEndpointsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupsAttachEndpointsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupsDetachEndpointsRequest. */
                interface INetworkEndpointGroupsDetachEndpointsRequest {

                    /** NetworkEndpointGroupsDetachEndpointsRequest networkEndpoints */
                    networkEndpoints?: (google.cloud.compute.v1.INetworkEndpoint[]|null);
                }

                /** Represents a NetworkEndpointGroupsDetachEndpointsRequest. */
                class NetworkEndpointGroupsDetachEndpointsRequest implements INetworkEndpointGroupsDetachEndpointsRequest {

                    /**
                     * Constructs a new NetworkEndpointGroupsDetachEndpointsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupsDetachEndpointsRequest);

                    /** NetworkEndpointGroupsDetachEndpointsRequest networkEndpoints. */
                    public networkEndpoints: google.cloud.compute.v1.INetworkEndpoint[];

                    /**
                     * Creates a new NetworkEndpointGroupsDetachEndpointsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupsDetachEndpointsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupsDetachEndpointsRequest): google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Encodes the specified NetworkEndpointGroupsDetachEndpointsRequest message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest.verify|verify} messages.
                     * @param message NetworkEndpointGroupsDetachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupsDetachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupsDetachEndpointsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest.verify|verify} messages.
                     * @param message NetworkEndpointGroupsDetachEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupsDetachEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupsDetachEndpointsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupsDetachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Decodes a NetworkEndpointGroupsDetachEndpointsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupsDetachEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Verifies a NetworkEndpointGroupsDetachEndpointsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupsDetachEndpointsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupsDetachEndpointsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupsDetachEndpointsRequest message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupsDetachEndpointsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupsDetachEndpointsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupsDetachEndpointsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupsDetachEndpointsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupsListEndpointsRequest. */
                interface INetworkEndpointGroupsListEndpointsRequest {

                    /** NetworkEndpointGroupsListEndpointsRequest healthStatus */
                    healthStatus?: (string|null);
                }

                /** Represents a NetworkEndpointGroupsListEndpointsRequest. */
                class NetworkEndpointGroupsListEndpointsRequest implements INetworkEndpointGroupsListEndpointsRequest {

                    /**
                     * Constructs a new NetworkEndpointGroupsListEndpointsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupsListEndpointsRequest);

                    /** NetworkEndpointGroupsListEndpointsRequest healthStatus. */
                    public healthStatus?: (string|null);

                    /** NetworkEndpointGroupsListEndpointsRequest _healthStatus. */
                    public _healthStatus?: "healthStatus";

                    /**
                     * Creates a new NetworkEndpointGroupsListEndpointsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupsListEndpointsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupsListEndpointsRequest): google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest;

                    /**
                     * Encodes the specified NetworkEndpointGroupsListEndpointsRequest message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest.verify|verify} messages.
                     * @param message NetworkEndpointGroupsListEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupsListEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupsListEndpointsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest.verify|verify} messages.
                     * @param message NetworkEndpointGroupsListEndpointsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupsListEndpointsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupsListEndpointsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupsListEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest;

                    /**
                     * Decodes a NetworkEndpointGroupsListEndpointsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupsListEndpointsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest;

                    /**
                     * Verifies a NetworkEndpointGroupsListEndpointsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupsListEndpointsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupsListEndpointsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupsListEndpointsRequest message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupsListEndpointsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupsListEndpointsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupsListEndpointsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupsListEndpointsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkEndpointGroupsListEndpointsRequest {

                    /** HealthStatus enum. */
                    enum HealthStatus {
                        UNDEFINED_HEALTH_STATUS = 0,
                        SHOW = 2544381,
                        SKIP = 2547071
                    }
                }

                /** Properties of a NetworkEndpointGroupsListNetworkEndpoints. */
                interface INetworkEndpointGroupsListNetworkEndpoints {

                    /** NetworkEndpointGroupsListNetworkEndpoints id */
                    id?: (string|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints items */
                    items?: (google.cloud.compute.v1.INetworkEndpointWithHealthStatus[]|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints kind */
                    kind?: (string|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints nextPageToken */
                    nextPageToken?: (string|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkEndpointGroupsListNetworkEndpoints. */
                class NetworkEndpointGroupsListNetworkEndpoints implements INetworkEndpointGroupsListNetworkEndpoints {

                    /**
                     * Constructs a new NetworkEndpointGroupsListNetworkEndpoints.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints);

                    /** NetworkEndpointGroupsListNetworkEndpoints id. */
                    public id?: (string|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints items. */
                    public items: google.cloud.compute.v1.INetworkEndpointWithHealthStatus[];

                    /** NetworkEndpointGroupsListNetworkEndpoints kind. */
                    public kind?: (string|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkEndpointGroupsListNetworkEndpoints _id. */
                    public _id?: "id";

                    /** NetworkEndpointGroupsListNetworkEndpoints _kind. */
                    public _kind?: "kind";

                    /** NetworkEndpointGroupsListNetworkEndpoints _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NetworkEndpointGroupsListNetworkEndpoints _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkEndpointGroupsListNetworkEndpoints instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupsListNetworkEndpoints instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints): google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints;

                    /**
                     * Encodes the specified NetworkEndpointGroupsListNetworkEndpoints message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints.verify|verify} messages.
                     * @param message NetworkEndpointGroupsListNetworkEndpoints message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupsListNetworkEndpoints message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints.verify|verify} messages.
                     * @param message NetworkEndpointGroupsListNetworkEndpoints message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupsListNetworkEndpoints message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupsListNetworkEndpoints
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints;

                    /**
                     * Decodes a NetworkEndpointGroupsListNetworkEndpoints message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupsListNetworkEndpoints
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints;

                    /**
                     * Verifies a NetworkEndpointGroupsListNetworkEndpoints message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupsListNetworkEndpoints message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupsListNetworkEndpoints
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupsListNetworkEndpoints message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupsListNetworkEndpoints
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupsListNetworkEndpoints to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupsListNetworkEndpoints
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointGroupsScopedList. */
                interface INetworkEndpointGroupsScopedList {

                    /** NetworkEndpointGroupsScopedList networkEndpointGroups */
                    networkEndpointGroups?: (google.cloud.compute.v1.INetworkEndpointGroup[]|null);

                    /** NetworkEndpointGroupsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkEndpointGroupsScopedList. */
                class NetworkEndpointGroupsScopedList implements INetworkEndpointGroupsScopedList {

                    /**
                     * Constructs a new NetworkEndpointGroupsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointGroupsScopedList);

                    /** NetworkEndpointGroupsScopedList networkEndpointGroups. */
                    public networkEndpointGroups: google.cloud.compute.v1.INetworkEndpointGroup[];

                    /** NetworkEndpointGroupsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkEndpointGroupsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkEndpointGroupsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointGroupsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointGroupsScopedList): google.cloud.compute.v1.NetworkEndpointGroupsScopedList;

                    /**
                     * Encodes the specified NetworkEndpointGroupsScopedList message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsScopedList.verify|verify} messages.
                     * @param message NetworkEndpointGroupsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointGroupsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointGroupsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointGroupsScopedList.verify|verify} messages.
                     * @param message NetworkEndpointGroupsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointGroupsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointGroupsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointGroupsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointGroupsScopedList;

                    /**
                     * Decodes a NetworkEndpointGroupsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointGroupsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointGroupsScopedList;

                    /**
                     * Verifies a NetworkEndpointGroupsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointGroupsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointGroupsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointGroupsScopedList;

                    /**
                     * Creates a plain object from a NetworkEndpointGroupsScopedList message. Also converts values to other types if specified.
                     * @param message NetworkEndpointGroupsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointGroupsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointGroupsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointGroupsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkEndpointWithHealthStatus. */
                interface INetworkEndpointWithHealthStatus {

                    /** NetworkEndpointWithHealthStatus healths */
                    healths?: (google.cloud.compute.v1.IHealthStatusForNetworkEndpoint[]|null);

                    /** NetworkEndpointWithHealthStatus networkEndpoint */
                    networkEndpoint?: (google.cloud.compute.v1.INetworkEndpoint|null);
                }

                /** Represents a NetworkEndpointWithHealthStatus. */
                class NetworkEndpointWithHealthStatus implements INetworkEndpointWithHealthStatus {

                    /**
                     * Constructs a new NetworkEndpointWithHealthStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkEndpointWithHealthStatus);

                    /** NetworkEndpointWithHealthStatus healths. */
                    public healths: google.cloud.compute.v1.IHealthStatusForNetworkEndpoint[];

                    /** NetworkEndpointWithHealthStatus networkEndpoint. */
                    public networkEndpoint?: (google.cloud.compute.v1.INetworkEndpoint|null);

                    /** NetworkEndpointWithHealthStatus _networkEndpoint. */
                    public _networkEndpoint?: "networkEndpoint";

                    /**
                     * Creates a new NetworkEndpointWithHealthStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkEndpointWithHealthStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkEndpointWithHealthStatus): google.cloud.compute.v1.NetworkEndpointWithHealthStatus;

                    /**
                     * Encodes the specified NetworkEndpointWithHealthStatus message. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointWithHealthStatus.verify|verify} messages.
                     * @param message NetworkEndpointWithHealthStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkEndpointWithHealthStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkEndpointWithHealthStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkEndpointWithHealthStatus.verify|verify} messages.
                     * @param message NetworkEndpointWithHealthStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkEndpointWithHealthStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkEndpointWithHealthStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkEndpointWithHealthStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkEndpointWithHealthStatus;

                    /**
                     * Decodes a NetworkEndpointWithHealthStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkEndpointWithHealthStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkEndpointWithHealthStatus;

                    /**
                     * Verifies a NetworkEndpointWithHealthStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkEndpointWithHealthStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkEndpointWithHealthStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkEndpointWithHealthStatus;

                    /**
                     * Creates a plain object from a NetworkEndpointWithHealthStatus message. Also converts values to other types if specified.
                     * @param message NetworkEndpointWithHealthStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkEndpointWithHealthStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkEndpointWithHealthStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkEndpointWithHealthStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkInterface. */
                interface INetworkInterface {

                    /** NetworkInterface accessConfigs */
                    accessConfigs?: (google.cloud.compute.v1.IAccessConfig[]|null);

                    /** NetworkInterface aliasIpRanges */
                    aliasIpRanges?: (google.cloud.compute.v1.IAliasIpRange[]|null);

                    /** NetworkInterface fingerprint */
                    fingerprint?: (string|null);

                    /** NetworkInterface internalIpv6PrefixLength */
                    internalIpv6PrefixLength?: (number|null);

                    /** NetworkInterface ipv6AccessConfigs */
                    ipv6AccessConfigs?: (google.cloud.compute.v1.IAccessConfig[]|null);

                    /** NetworkInterface ipv6AccessType */
                    ipv6AccessType?: (string|null);

                    /** NetworkInterface ipv6Address */
                    ipv6Address?: (string|null);

                    /** NetworkInterface kind */
                    kind?: (string|null);

                    /** NetworkInterface name */
                    name?: (string|null);

                    /** NetworkInterface network */
                    network?: (string|null);

                    /** NetworkInterface networkIP */
                    networkIP?: (string|null);

                    /** NetworkInterface nicType */
                    nicType?: (string|null);

                    /** NetworkInterface queueCount */
                    queueCount?: (number|null);

                    /** NetworkInterface stackType */
                    stackType?: (string|null);

                    /** NetworkInterface subnetwork */
                    subnetwork?: (string|null);
                }

                /** Represents a NetworkInterface. */
                class NetworkInterface implements INetworkInterface {

                    /**
                     * Constructs a new NetworkInterface.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkInterface);

                    /** NetworkInterface accessConfigs. */
                    public accessConfigs: google.cloud.compute.v1.IAccessConfig[];

                    /** NetworkInterface aliasIpRanges. */
                    public aliasIpRanges: google.cloud.compute.v1.IAliasIpRange[];

                    /** NetworkInterface fingerprint. */
                    public fingerprint?: (string|null);

                    /** NetworkInterface internalIpv6PrefixLength. */
                    public internalIpv6PrefixLength?: (number|null);

                    /** NetworkInterface ipv6AccessConfigs. */
                    public ipv6AccessConfigs: google.cloud.compute.v1.IAccessConfig[];

                    /** NetworkInterface ipv6AccessType. */
                    public ipv6AccessType?: (string|null);

                    /** NetworkInterface ipv6Address. */
                    public ipv6Address?: (string|null);

                    /** NetworkInterface kind. */
                    public kind?: (string|null);

                    /** NetworkInterface name. */
                    public name?: (string|null);

                    /** NetworkInterface network. */
                    public network?: (string|null);

                    /** NetworkInterface networkIP. */
                    public networkIP?: (string|null);

                    /** NetworkInterface nicType. */
                    public nicType?: (string|null);

                    /** NetworkInterface queueCount. */
                    public queueCount?: (number|null);

                    /** NetworkInterface stackType. */
                    public stackType?: (string|null);

                    /** NetworkInterface subnetwork. */
                    public subnetwork?: (string|null);

                    /** NetworkInterface _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** NetworkInterface _internalIpv6PrefixLength. */
                    public _internalIpv6PrefixLength?: "internalIpv6PrefixLength";

                    /** NetworkInterface _ipv6AccessType. */
                    public _ipv6AccessType?: "ipv6AccessType";

                    /** NetworkInterface _ipv6Address. */
                    public _ipv6Address?: "ipv6Address";

                    /** NetworkInterface _kind. */
                    public _kind?: "kind";

                    /** NetworkInterface _name. */
                    public _name?: "name";

                    /** NetworkInterface _network. */
                    public _network?: "network";

                    /** NetworkInterface _networkIP. */
                    public _networkIP?: "networkIP";

                    /** NetworkInterface _nicType. */
                    public _nicType?: "nicType";

                    /** NetworkInterface _queueCount. */
                    public _queueCount?: "queueCount";

                    /** NetworkInterface _stackType. */
                    public _stackType?: "stackType";

                    /** NetworkInterface _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /**
                     * Creates a new NetworkInterface instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkInterface instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkInterface): google.cloud.compute.v1.NetworkInterface;

                    /**
                     * Encodes the specified NetworkInterface message. Does not implicitly {@link google.cloud.compute.v1.NetworkInterface.verify|verify} messages.
                     * @param message NetworkInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkInterface message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkInterface.verify|verify} messages.
                     * @param message NetworkInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkInterface message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkInterface;

                    /**
                     * Decodes a NetworkInterface message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkInterface;

                    /**
                     * Verifies a NetworkInterface message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkInterface message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkInterface
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkInterface;

                    /**
                     * Creates a plain object from a NetworkInterface message. Also converts values to other types if specified.
                     * @param message NetworkInterface
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkInterface, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkInterface to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkInterface
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkInterface {

                    /** Ipv6AccessType enum. */
                    enum Ipv6AccessType {
                        UNDEFINED_IPV6_ACCESS_TYPE = 0,
                        EXTERNAL = 35607499,
                        INTERNAL = 279295677,
                        UNSPECIFIED_IPV6_ACCESS_TYPE = 313080613
                    }

                    /** NicType enum. */
                    enum NicType {
                        UNDEFINED_NIC_TYPE = 0,
                        GVNIC = 68209305,
                        UNSPECIFIED_NIC_TYPE = 67411801,
                        VIRTIO_NET = 452123481
                    }

                    /** StackType enum. */
                    enum StackType {
                        UNDEFINED_STACK_TYPE = 0,
                        IPV4_IPV6 = 22197249,
                        IPV4_ONLY = 22373798,
                        UNSPECIFIED_STACK_TYPE = 298084569
                    }
                }

                /** Properties of a NetworkList. */
                interface INetworkList {

                    /** NetworkList id */
                    id?: (string|null);

                    /** NetworkList items */
                    items?: (google.cloud.compute.v1.INetwork[]|null);

                    /** NetworkList kind */
                    kind?: (string|null);

                    /** NetworkList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NetworkList selfLink */
                    selfLink?: (string|null);

                    /** NetworkList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NetworkList. */
                class NetworkList implements INetworkList {

                    /**
                     * Constructs a new NetworkList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkList);

                    /** NetworkList id. */
                    public id?: (string|null);

                    /** NetworkList items. */
                    public items: google.cloud.compute.v1.INetwork[];

                    /** NetworkList kind. */
                    public kind?: (string|null);

                    /** NetworkList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NetworkList selfLink. */
                    public selfLink?: (string|null);

                    /** NetworkList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NetworkList _id. */
                    public _id?: "id";

                    /** NetworkList _kind. */
                    public _kind?: "kind";

                    /** NetworkList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NetworkList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NetworkList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NetworkList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkList): google.cloud.compute.v1.NetworkList;

                    /**
                     * Encodes the specified NetworkList message. Does not implicitly {@link google.cloud.compute.v1.NetworkList.verify|verify} messages.
                     * @param message NetworkList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkList.verify|verify} messages.
                     * @param message NetworkList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkList;

                    /**
                     * Decodes a NetworkList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkList;

                    /**
                     * Verifies a NetworkList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkList;

                    /**
                     * Creates a plain object from a NetworkList message. Also converts values to other types if specified.
                     * @param message NetworkList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworkPeering. */
                interface INetworkPeering {

                    /** NetworkPeering autoCreateRoutes */
                    autoCreateRoutes?: (boolean|null);

                    /** NetworkPeering exchangeSubnetRoutes */
                    exchangeSubnetRoutes?: (boolean|null);

                    /** NetworkPeering exportCustomRoutes */
                    exportCustomRoutes?: (boolean|null);

                    /** NetworkPeering exportSubnetRoutesWithPublicIp */
                    exportSubnetRoutesWithPublicIp?: (boolean|null);

                    /** NetworkPeering importCustomRoutes */
                    importCustomRoutes?: (boolean|null);

                    /** NetworkPeering importSubnetRoutesWithPublicIp */
                    importSubnetRoutesWithPublicIp?: (boolean|null);

                    /** NetworkPeering name */
                    name?: (string|null);

                    /** NetworkPeering network */
                    network?: (string|null);

                    /** NetworkPeering peerMtu */
                    peerMtu?: (number|null);

                    /** NetworkPeering stackType */
                    stackType?: (string|null);

                    /** NetworkPeering state */
                    state?: (string|null);

                    /** NetworkPeering stateDetails */
                    stateDetails?: (string|null);
                }

                /** Represents a NetworkPeering. */
                class NetworkPeering implements INetworkPeering {

                    /**
                     * Constructs a new NetworkPeering.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkPeering);

                    /** NetworkPeering autoCreateRoutes. */
                    public autoCreateRoutes?: (boolean|null);

                    /** NetworkPeering exchangeSubnetRoutes. */
                    public exchangeSubnetRoutes?: (boolean|null);

                    /** NetworkPeering exportCustomRoutes. */
                    public exportCustomRoutes?: (boolean|null);

                    /** NetworkPeering exportSubnetRoutesWithPublicIp. */
                    public exportSubnetRoutesWithPublicIp?: (boolean|null);

                    /** NetworkPeering importCustomRoutes. */
                    public importCustomRoutes?: (boolean|null);

                    /** NetworkPeering importSubnetRoutesWithPublicIp. */
                    public importSubnetRoutesWithPublicIp?: (boolean|null);

                    /** NetworkPeering name. */
                    public name?: (string|null);

                    /** NetworkPeering network. */
                    public network?: (string|null);

                    /** NetworkPeering peerMtu. */
                    public peerMtu?: (number|null);

                    /** NetworkPeering stackType. */
                    public stackType?: (string|null);

                    /** NetworkPeering state. */
                    public state?: (string|null);

                    /** NetworkPeering stateDetails. */
                    public stateDetails?: (string|null);

                    /** NetworkPeering _autoCreateRoutes. */
                    public _autoCreateRoutes?: "autoCreateRoutes";

                    /** NetworkPeering _exchangeSubnetRoutes. */
                    public _exchangeSubnetRoutes?: "exchangeSubnetRoutes";

                    /** NetworkPeering _exportCustomRoutes. */
                    public _exportCustomRoutes?: "exportCustomRoutes";

                    /** NetworkPeering _exportSubnetRoutesWithPublicIp. */
                    public _exportSubnetRoutesWithPublicIp?: "exportSubnetRoutesWithPublicIp";

                    /** NetworkPeering _importCustomRoutes. */
                    public _importCustomRoutes?: "importCustomRoutes";

                    /** NetworkPeering _importSubnetRoutesWithPublicIp. */
                    public _importSubnetRoutesWithPublicIp?: "importSubnetRoutesWithPublicIp";

                    /** NetworkPeering _name. */
                    public _name?: "name";

                    /** NetworkPeering _network. */
                    public _network?: "network";

                    /** NetworkPeering _peerMtu. */
                    public _peerMtu?: "peerMtu";

                    /** NetworkPeering _stackType. */
                    public _stackType?: "stackType";

                    /** NetworkPeering _state. */
                    public _state?: "state";

                    /** NetworkPeering _stateDetails. */
                    public _stateDetails?: "stateDetails";

                    /**
                     * Creates a new NetworkPeering instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkPeering instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkPeering): google.cloud.compute.v1.NetworkPeering;

                    /**
                     * Encodes the specified NetworkPeering message. Does not implicitly {@link google.cloud.compute.v1.NetworkPeering.verify|verify} messages.
                     * @param message NetworkPeering message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkPeering, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkPeering message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkPeering.verify|verify} messages.
                     * @param message NetworkPeering message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkPeering, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkPeering message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkPeering
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkPeering;

                    /**
                     * Decodes a NetworkPeering message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkPeering
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkPeering;

                    /**
                     * Verifies a NetworkPeering message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkPeering message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkPeering
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkPeering;

                    /**
                     * Creates a plain object from a NetworkPeering message. Also converts values to other types if specified.
                     * @param message NetworkPeering
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkPeering, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkPeering to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkPeering
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkPeering {

                    /** StackType enum. */
                    enum StackType {
                        UNDEFINED_STACK_TYPE = 0,
                        IPV4_IPV6 = 22197249,
                        IPV4_ONLY = 22373798
                    }

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        INACTIVE = 270421099
                    }
                }

                /** Properties of a NetworkPerformanceConfig. */
                interface INetworkPerformanceConfig {

                    /** NetworkPerformanceConfig totalEgressBandwidthTier */
                    totalEgressBandwidthTier?: (string|null);
                }

                /** Represents a NetworkPerformanceConfig. */
                class NetworkPerformanceConfig implements INetworkPerformanceConfig {

                    /**
                     * Constructs a new NetworkPerformanceConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkPerformanceConfig);

                    /** NetworkPerformanceConfig totalEgressBandwidthTier. */
                    public totalEgressBandwidthTier?: (string|null);

                    /** NetworkPerformanceConfig _totalEgressBandwidthTier. */
                    public _totalEgressBandwidthTier?: "totalEgressBandwidthTier";

                    /**
                     * Creates a new NetworkPerformanceConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkPerformanceConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkPerformanceConfig): google.cloud.compute.v1.NetworkPerformanceConfig;

                    /**
                     * Encodes the specified NetworkPerformanceConfig message. Does not implicitly {@link google.cloud.compute.v1.NetworkPerformanceConfig.verify|verify} messages.
                     * @param message NetworkPerformanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkPerformanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkPerformanceConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkPerformanceConfig.verify|verify} messages.
                     * @param message NetworkPerformanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkPerformanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkPerformanceConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkPerformanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkPerformanceConfig;

                    /**
                     * Decodes a NetworkPerformanceConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkPerformanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkPerformanceConfig;

                    /**
                     * Verifies a NetworkPerformanceConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkPerformanceConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkPerformanceConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkPerformanceConfig;

                    /**
                     * Creates a plain object from a NetworkPerformanceConfig message. Also converts values to other types if specified.
                     * @param message NetworkPerformanceConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkPerformanceConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkPerformanceConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkPerformanceConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkPerformanceConfig {

                    /** TotalEgressBandwidthTier enum. */
                    enum TotalEgressBandwidthTier {
                        UNDEFINED_TOTAL_EGRESS_BANDWIDTH_TIER = 0,
                        DEFAULT = 115302945,
                        TIER_1 = 326919444
                    }
                }

                /** Properties of a NetworkRoutingConfig. */
                interface INetworkRoutingConfig {

                    /** NetworkRoutingConfig routingMode */
                    routingMode?: (string|null);
                }

                /** Represents a NetworkRoutingConfig. */
                class NetworkRoutingConfig implements INetworkRoutingConfig {

                    /**
                     * Constructs a new NetworkRoutingConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworkRoutingConfig);

                    /** NetworkRoutingConfig routingMode. */
                    public routingMode?: (string|null);

                    /** NetworkRoutingConfig _routingMode. */
                    public _routingMode?: "routingMode";

                    /**
                     * Creates a new NetworkRoutingConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworkRoutingConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworkRoutingConfig): google.cloud.compute.v1.NetworkRoutingConfig;

                    /**
                     * Encodes the specified NetworkRoutingConfig message. Does not implicitly {@link google.cloud.compute.v1.NetworkRoutingConfig.verify|verify} messages.
                     * @param message NetworkRoutingConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworkRoutingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworkRoutingConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworkRoutingConfig.verify|verify} messages.
                     * @param message NetworkRoutingConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworkRoutingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworkRoutingConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworkRoutingConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworkRoutingConfig;

                    /**
                     * Decodes a NetworkRoutingConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworkRoutingConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworkRoutingConfig;

                    /**
                     * Verifies a NetworkRoutingConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworkRoutingConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworkRoutingConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworkRoutingConfig;

                    /**
                     * Creates a plain object from a NetworkRoutingConfig message. Also converts values to other types if specified.
                     * @param message NetworkRoutingConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworkRoutingConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworkRoutingConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworkRoutingConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworkRoutingConfig {

                    /** RoutingMode enum. */
                    enum RoutingMode {
                        UNDEFINED_ROUTING_MODE = 0,
                        GLOBAL = 494663587,
                        REGIONAL = 92288543
                    }
                }

                /** Properties of a NetworksAddPeeringRequest. */
                interface INetworksAddPeeringRequest {

                    /** NetworksAddPeeringRequest autoCreateRoutes */
                    autoCreateRoutes?: (boolean|null);

                    /** NetworksAddPeeringRequest name */
                    name?: (string|null);

                    /** NetworksAddPeeringRequest networkPeering */
                    networkPeering?: (google.cloud.compute.v1.INetworkPeering|null);

                    /** NetworksAddPeeringRequest peerNetwork */
                    peerNetwork?: (string|null);
                }

                /** Represents a NetworksAddPeeringRequest. */
                class NetworksAddPeeringRequest implements INetworksAddPeeringRequest {

                    /**
                     * Constructs a new NetworksAddPeeringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworksAddPeeringRequest);

                    /** NetworksAddPeeringRequest autoCreateRoutes. */
                    public autoCreateRoutes?: (boolean|null);

                    /** NetworksAddPeeringRequest name. */
                    public name?: (string|null);

                    /** NetworksAddPeeringRequest networkPeering. */
                    public networkPeering?: (google.cloud.compute.v1.INetworkPeering|null);

                    /** NetworksAddPeeringRequest peerNetwork. */
                    public peerNetwork?: (string|null);

                    /** NetworksAddPeeringRequest _autoCreateRoutes. */
                    public _autoCreateRoutes?: "autoCreateRoutes";

                    /** NetworksAddPeeringRequest _name. */
                    public _name?: "name";

                    /** NetworksAddPeeringRequest _networkPeering. */
                    public _networkPeering?: "networkPeering";

                    /** NetworksAddPeeringRequest _peerNetwork. */
                    public _peerNetwork?: "peerNetwork";

                    /**
                     * Creates a new NetworksAddPeeringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworksAddPeeringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworksAddPeeringRequest): google.cloud.compute.v1.NetworksAddPeeringRequest;

                    /**
                     * Encodes the specified NetworksAddPeeringRequest message. Does not implicitly {@link google.cloud.compute.v1.NetworksAddPeeringRequest.verify|verify} messages.
                     * @param message NetworksAddPeeringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworksAddPeeringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworksAddPeeringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworksAddPeeringRequest.verify|verify} messages.
                     * @param message NetworksAddPeeringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworksAddPeeringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworksAddPeeringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworksAddPeeringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworksAddPeeringRequest;

                    /**
                     * Decodes a NetworksAddPeeringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworksAddPeeringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworksAddPeeringRequest;

                    /**
                     * Verifies a NetworksAddPeeringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworksAddPeeringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworksAddPeeringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworksAddPeeringRequest;

                    /**
                     * Creates a plain object from a NetworksAddPeeringRequest message. Also converts values to other types if specified.
                     * @param message NetworksAddPeeringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworksAddPeeringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworksAddPeeringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworksAddPeeringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworksGetEffectiveFirewallsResponse. */
                interface INetworksGetEffectiveFirewallsResponse {

                    /** NetworksGetEffectiveFirewallsResponse firewallPolicys */
                    firewallPolicys?: (google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy[]|null);

                    /** NetworksGetEffectiveFirewallsResponse firewalls */
                    firewalls?: (google.cloud.compute.v1.IFirewall[]|null);
                }

                /** Represents a NetworksGetEffectiveFirewallsResponse. */
                class NetworksGetEffectiveFirewallsResponse implements INetworksGetEffectiveFirewallsResponse {

                    /**
                     * Constructs a new NetworksGetEffectiveFirewallsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponse);

                    /** NetworksGetEffectiveFirewallsResponse firewallPolicys. */
                    public firewallPolicys: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy[];

                    /** NetworksGetEffectiveFirewallsResponse firewalls. */
                    public firewalls: google.cloud.compute.v1.IFirewall[];

                    /**
                     * Creates a new NetworksGetEffectiveFirewallsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworksGetEffectiveFirewallsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponse): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse;

                    /**
                     * Encodes the specified NetworksGetEffectiveFirewallsResponse message. Does not implicitly {@link google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse.verify|verify} messages.
                     * @param message NetworksGetEffectiveFirewallsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworksGetEffectiveFirewallsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse.verify|verify} messages.
                     * @param message NetworksGetEffectiveFirewallsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworksGetEffectiveFirewallsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworksGetEffectiveFirewallsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse;

                    /**
                     * Decodes a NetworksGetEffectiveFirewallsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworksGetEffectiveFirewallsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse;

                    /**
                     * Verifies a NetworksGetEffectiveFirewallsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworksGetEffectiveFirewallsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworksGetEffectiveFirewallsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse;

                    /**
                     * Creates a plain object from a NetworksGetEffectiveFirewallsResponse message. Also converts values to other types if specified.
                     * @param message NetworksGetEffectiveFirewallsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworksGetEffectiveFirewallsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworksGetEffectiveFirewallsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy. */
                interface INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy displayName */
                    displayName?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy name */
                    name?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy rules */
                    rules?: (google.cloud.compute.v1.IFirewallPolicyRule[]|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy shortName */
                    shortName?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy type */
                    type?: (string|null);
                }

                /** Represents a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy. */
                class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy implements INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /**
                     * Constructs a new NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy displayName. */
                    public displayName?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy name. */
                    public name?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy rules. */
                    public rules: google.cloud.compute.v1.IFirewallPolicyRule[];

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy shortName. */
                    public shortName?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy type. */
                    public type?: (string|null);

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy _displayName. */
                    public _displayName?: "displayName";

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy _name. */
                    public _name?: "name";

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy _shortName. */
                    public _shortName?: "shortName";

                    /** NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy _type. */
                    public _type?: "type";

                    /**
                     * Creates a new NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Encodes the specified NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message. Does not implicitly {@link google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.verify|verify} messages.
                     * @param message NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.verify|verify} messages.
                     * @param message NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Decodes a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Verifies a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Creates a plain object from a NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy message. Also converts values to other types if specified.
                     * @param message NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        HIERARCHY = 69902869,
                        NETWORK = 413984270,
                        UNSPECIFIED = 526786327
                    }
                }

                /** Properties of a NetworksRemovePeeringRequest. */
                interface INetworksRemovePeeringRequest {

                    /** NetworksRemovePeeringRequest name */
                    name?: (string|null);
                }

                /** Represents a NetworksRemovePeeringRequest. */
                class NetworksRemovePeeringRequest implements INetworksRemovePeeringRequest {

                    /**
                     * Constructs a new NetworksRemovePeeringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworksRemovePeeringRequest);

                    /** NetworksRemovePeeringRequest name. */
                    public name?: (string|null);

                    /** NetworksRemovePeeringRequest _name. */
                    public _name?: "name";

                    /**
                     * Creates a new NetworksRemovePeeringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworksRemovePeeringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworksRemovePeeringRequest): google.cloud.compute.v1.NetworksRemovePeeringRequest;

                    /**
                     * Encodes the specified NetworksRemovePeeringRequest message. Does not implicitly {@link google.cloud.compute.v1.NetworksRemovePeeringRequest.verify|verify} messages.
                     * @param message NetworksRemovePeeringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworksRemovePeeringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworksRemovePeeringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworksRemovePeeringRequest.verify|verify} messages.
                     * @param message NetworksRemovePeeringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworksRemovePeeringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworksRemovePeeringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworksRemovePeeringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworksRemovePeeringRequest;

                    /**
                     * Decodes a NetworksRemovePeeringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworksRemovePeeringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworksRemovePeeringRequest;

                    /**
                     * Verifies a NetworksRemovePeeringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworksRemovePeeringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworksRemovePeeringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworksRemovePeeringRequest;

                    /**
                     * Creates a plain object from a NetworksRemovePeeringRequest message. Also converts values to other types if specified.
                     * @param message NetworksRemovePeeringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworksRemovePeeringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworksRemovePeeringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworksRemovePeeringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NetworksUpdatePeeringRequest. */
                interface INetworksUpdatePeeringRequest {

                    /** NetworksUpdatePeeringRequest networkPeering */
                    networkPeering?: (google.cloud.compute.v1.INetworkPeering|null);
                }

                /** Represents a NetworksUpdatePeeringRequest. */
                class NetworksUpdatePeeringRequest implements INetworksUpdatePeeringRequest {

                    /**
                     * Constructs a new NetworksUpdatePeeringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INetworksUpdatePeeringRequest);

                    /** NetworksUpdatePeeringRequest networkPeering. */
                    public networkPeering?: (google.cloud.compute.v1.INetworkPeering|null);

                    /** NetworksUpdatePeeringRequest _networkPeering. */
                    public _networkPeering?: "networkPeering";

                    /**
                     * Creates a new NetworksUpdatePeeringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NetworksUpdatePeeringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INetworksUpdatePeeringRequest): google.cloud.compute.v1.NetworksUpdatePeeringRequest;

                    /**
                     * Encodes the specified NetworksUpdatePeeringRequest message. Does not implicitly {@link google.cloud.compute.v1.NetworksUpdatePeeringRequest.verify|verify} messages.
                     * @param message NetworksUpdatePeeringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INetworksUpdatePeeringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NetworksUpdatePeeringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NetworksUpdatePeeringRequest.verify|verify} messages.
                     * @param message NetworksUpdatePeeringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INetworksUpdatePeeringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NetworksUpdatePeeringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NetworksUpdatePeeringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NetworksUpdatePeeringRequest;

                    /**
                     * Decodes a NetworksUpdatePeeringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NetworksUpdatePeeringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NetworksUpdatePeeringRequest;

                    /**
                     * Verifies a NetworksUpdatePeeringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NetworksUpdatePeeringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NetworksUpdatePeeringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NetworksUpdatePeeringRequest;

                    /**
                     * Creates a plain object from a NetworksUpdatePeeringRequest message. Also converts values to other types if specified.
                     * @param message NetworksUpdatePeeringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NetworksUpdatePeeringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NetworksUpdatePeeringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NetworksUpdatePeeringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroup. */
                interface INodeGroup {

                    /** NodeGroup autoscalingPolicy */
                    autoscalingPolicy?: (google.cloud.compute.v1.INodeGroupAutoscalingPolicy|null);

                    /** NodeGroup creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** NodeGroup description */
                    description?: (string|null);

                    /** NodeGroup fingerprint */
                    fingerprint?: (string|null);

                    /** NodeGroup id */
                    id?: (number|Long|string|null);

                    /** NodeGroup kind */
                    kind?: (string|null);

                    /** NodeGroup locationHint */
                    locationHint?: (string|null);

                    /** NodeGroup maintenancePolicy */
                    maintenancePolicy?: (string|null);

                    /** NodeGroup maintenanceWindow */
                    maintenanceWindow?: (google.cloud.compute.v1.INodeGroupMaintenanceWindow|null);

                    /** NodeGroup name */
                    name?: (string|null);

                    /** NodeGroup nodeTemplate */
                    nodeTemplate?: (string|null);

                    /** NodeGroup selfLink */
                    selfLink?: (string|null);

                    /** NodeGroup shareSettings */
                    shareSettings?: (google.cloud.compute.v1.IShareSettings|null);

                    /** NodeGroup size */
                    size?: (number|null);

                    /** NodeGroup status */
                    status?: (string|null);

                    /** NodeGroup zone */
                    zone?: (string|null);
                }

                /** Represents a NodeGroup. */
                class NodeGroup implements INodeGroup {

                    /**
                     * Constructs a new NodeGroup.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroup);

                    /** NodeGroup autoscalingPolicy. */
                    public autoscalingPolicy?: (google.cloud.compute.v1.INodeGroupAutoscalingPolicy|null);

                    /** NodeGroup creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** NodeGroup description. */
                    public description?: (string|null);

                    /** NodeGroup fingerprint. */
                    public fingerprint?: (string|null);

                    /** NodeGroup id. */
                    public id?: (number|Long|string|null);

                    /** NodeGroup kind. */
                    public kind?: (string|null);

                    /** NodeGroup locationHint. */
                    public locationHint?: (string|null);

                    /** NodeGroup maintenancePolicy. */
                    public maintenancePolicy?: (string|null);

                    /** NodeGroup maintenanceWindow. */
                    public maintenanceWindow?: (google.cloud.compute.v1.INodeGroupMaintenanceWindow|null);

                    /** NodeGroup name. */
                    public name?: (string|null);

                    /** NodeGroup nodeTemplate. */
                    public nodeTemplate?: (string|null);

                    /** NodeGroup selfLink. */
                    public selfLink?: (string|null);

                    /** NodeGroup shareSettings. */
                    public shareSettings?: (google.cloud.compute.v1.IShareSettings|null);

                    /** NodeGroup size. */
                    public size?: (number|null);

                    /** NodeGroup status. */
                    public status?: (string|null);

                    /** NodeGroup zone. */
                    public zone?: (string|null);

                    /** NodeGroup _autoscalingPolicy. */
                    public _autoscalingPolicy?: "autoscalingPolicy";

                    /** NodeGroup _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** NodeGroup _description. */
                    public _description?: "description";

                    /** NodeGroup _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** NodeGroup _id. */
                    public _id?: "id";

                    /** NodeGroup _kind. */
                    public _kind?: "kind";

                    /** NodeGroup _locationHint. */
                    public _locationHint?: "locationHint";

                    /** NodeGroup _maintenancePolicy. */
                    public _maintenancePolicy?: "maintenancePolicy";

                    /** NodeGroup _maintenanceWindow. */
                    public _maintenanceWindow?: "maintenanceWindow";

                    /** NodeGroup _name. */
                    public _name?: "name";

                    /** NodeGroup _nodeTemplate. */
                    public _nodeTemplate?: "nodeTemplate";

                    /** NodeGroup _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeGroup _shareSettings. */
                    public _shareSettings?: "shareSettings";

                    /** NodeGroup _size. */
                    public _size?: "size";

                    /** NodeGroup _status. */
                    public _status?: "status";

                    /** NodeGroup _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new NodeGroup instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroup instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroup): google.cloud.compute.v1.NodeGroup;

                    /**
                     * Encodes the specified NodeGroup message. Does not implicitly {@link google.cloud.compute.v1.NodeGroup.verify|verify} messages.
                     * @param message NodeGroup message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroup, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroup message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroup.verify|verify} messages.
                     * @param message NodeGroup message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroup, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroup message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroup
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroup;

                    /**
                     * Decodes a NodeGroup message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroup
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroup;

                    /**
                     * Verifies a NodeGroup message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroup message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroup
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroup;

                    /**
                     * Creates a plain object from a NodeGroup message. Also converts values to other types if specified.
                     * @param message NodeGroup
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroup, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroup to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroup
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NodeGroup {

                    /** MaintenancePolicy enum. */
                    enum MaintenancePolicy {
                        UNDEFINED_MAINTENANCE_POLICY = 0,
                        DEFAULT = 115302945,
                        MAINTENANCE_POLICY_UNSPECIFIED = 72964182,
                        MIGRATE_WITHIN_NODE_GROUP = 153483394,
                        RESTART_IN_PLACE = 228647325
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        INVALID = 530283991,
                        READY = 77848963
                    }
                }

                /** Properties of a NodeGroupAggregatedList. */
                interface INodeGroupAggregatedList {

                    /** NodeGroupAggregatedList id */
                    id?: (string|null);

                    /** NodeGroupAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.INodeGroupsScopedList }|null);

                    /** NodeGroupAggregatedList kind */
                    kind?: (string|null);

                    /** NodeGroupAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeGroupAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** NodeGroupAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** NodeGroupAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeGroupAggregatedList. */
                class NodeGroupAggregatedList implements INodeGroupAggregatedList {

                    /**
                     * Constructs a new NodeGroupAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupAggregatedList);

                    /** NodeGroupAggregatedList id. */
                    public id?: (string|null);

                    /** NodeGroupAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.INodeGroupsScopedList };

                    /** NodeGroupAggregatedList kind. */
                    public kind?: (string|null);

                    /** NodeGroupAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeGroupAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** NodeGroupAggregatedList unreachables. */
                    public unreachables: string[];

                    /** NodeGroupAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeGroupAggregatedList _id. */
                    public _id?: "id";

                    /** NodeGroupAggregatedList _kind. */
                    public _kind?: "kind";

                    /** NodeGroupAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeGroupAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeGroupAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeGroupAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupAggregatedList): google.cloud.compute.v1.NodeGroupAggregatedList;

                    /**
                     * Encodes the specified NodeGroupAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupAggregatedList.verify|verify} messages.
                     * @param message NodeGroupAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupAggregatedList.verify|verify} messages.
                     * @param message NodeGroupAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupAggregatedList;

                    /**
                     * Decodes a NodeGroupAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupAggregatedList;

                    /**
                     * Verifies a NodeGroupAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupAggregatedList;

                    /**
                     * Creates a plain object from a NodeGroupAggregatedList message. Also converts values to other types if specified.
                     * @param message NodeGroupAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupAutoscalingPolicy. */
                interface INodeGroupAutoscalingPolicy {

                    /** NodeGroupAutoscalingPolicy maxNodes */
                    maxNodes?: (number|null);

                    /** NodeGroupAutoscalingPolicy minNodes */
                    minNodes?: (number|null);

                    /** NodeGroupAutoscalingPolicy mode */
                    mode?: (string|null);
                }

                /** Represents a NodeGroupAutoscalingPolicy. */
                class NodeGroupAutoscalingPolicy implements INodeGroupAutoscalingPolicy {

                    /**
                     * Constructs a new NodeGroupAutoscalingPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupAutoscalingPolicy);

                    /** NodeGroupAutoscalingPolicy maxNodes. */
                    public maxNodes?: (number|null);

                    /** NodeGroupAutoscalingPolicy minNodes. */
                    public minNodes?: (number|null);

                    /** NodeGroupAutoscalingPolicy mode. */
                    public mode?: (string|null);

                    /** NodeGroupAutoscalingPolicy _maxNodes. */
                    public _maxNodes?: "maxNodes";

                    /** NodeGroupAutoscalingPolicy _minNodes. */
                    public _minNodes?: "minNodes";

                    /** NodeGroupAutoscalingPolicy _mode. */
                    public _mode?: "mode";

                    /**
                     * Creates a new NodeGroupAutoscalingPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupAutoscalingPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupAutoscalingPolicy): google.cloud.compute.v1.NodeGroupAutoscalingPolicy;

                    /**
                     * Encodes the specified NodeGroupAutoscalingPolicy message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupAutoscalingPolicy.verify|verify} messages.
                     * @param message NodeGroupAutoscalingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupAutoscalingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupAutoscalingPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupAutoscalingPolicy.verify|verify} messages.
                     * @param message NodeGroupAutoscalingPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupAutoscalingPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupAutoscalingPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupAutoscalingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupAutoscalingPolicy;

                    /**
                     * Decodes a NodeGroupAutoscalingPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupAutoscalingPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupAutoscalingPolicy;

                    /**
                     * Verifies a NodeGroupAutoscalingPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupAutoscalingPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupAutoscalingPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupAutoscalingPolicy;

                    /**
                     * Creates a plain object from a NodeGroupAutoscalingPolicy message. Also converts values to other types if specified.
                     * @param message NodeGroupAutoscalingPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupAutoscalingPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupAutoscalingPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupAutoscalingPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NodeGroupAutoscalingPolicy {

                    /** Mode enum. */
                    enum Mode {
                        UNDEFINED_MODE = 0,
                        MODE_UNSPECIFIED = 371348091,
                        OFF = 78159,
                        ON = 2527,
                        ONLY_SCALE_OUT = 152713670
                    }
                }

                /** Properties of a NodeGroupList. */
                interface INodeGroupList {

                    /** NodeGroupList id */
                    id?: (string|null);

                    /** NodeGroupList items */
                    items?: (google.cloud.compute.v1.INodeGroup[]|null);

                    /** NodeGroupList kind */
                    kind?: (string|null);

                    /** NodeGroupList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeGroupList selfLink */
                    selfLink?: (string|null);

                    /** NodeGroupList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeGroupList. */
                class NodeGroupList implements INodeGroupList {

                    /**
                     * Constructs a new NodeGroupList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupList);

                    /** NodeGroupList id. */
                    public id?: (string|null);

                    /** NodeGroupList items. */
                    public items: google.cloud.compute.v1.INodeGroup[];

                    /** NodeGroupList kind. */
                    public kind?: (string|null);

                    /** NodeGroupList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeGroupList selfLink. */
                    public selfLink?: (string|null);

                    /** NodeGroupList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeGroupList _id. */
                    public _id?: "id";

                    /** NodeGroupList _kind. */
                    public _kind?: "kind";

                    /** NodeGroupList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeGroupList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeGroupList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeGroupList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupList): google.cloud.compute.v1.NodeGroupList;

                    /**
                     * Encodes the specified NodeGroupList message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupList.verify|verify} messages.
                     * @param message NodeGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupList.verify|verify} messages.
                     * @param message NodeGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupList;

                    /**
                     * Decodes a NodeGroupList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupList;

                    /**
                     * Verifies a NodeGroupList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupList;

                    /**
                     * Creates a plain object from a NodeGroupList message. Also converts values to other types if specified.
                     * @param message NodeGroupList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupMaintenanceWindow. */
                interface INodeGroupMaintenanceWindow {

                    /** NodeGroupMaintenanceWindow maintenanceDuration */
                    maintenanceDuration?: (google.cloud.compute.v1.IDuration|null);

                    /** NodeGroupMaintenanceWindow startTime */
                    startTime?: (string|null);
                }

                /** Represents a NodeGroupMaintenanceWindow. */
                class NodeGroupMaintenanceWindow implements INodeGroupMaintenanceWindow {

                    /**
                     * Constructs a new NodeGroupMaintenanceWindow.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupMaintenanceWindow);

                    /** NodeGroupMaintenanceWindow maintenanceDuration. */
                    public maintenanceDuration?: (google.cloud.compute.v1.IDuration|null);

                    /** NodeGroupMaintenanceWindow startTime. */
                    public startTime?: (string|null);

                    /** NodeGroupMaintenanceWindow _maintenanceDuration. */
                    public _maintenanceDuration?: "maintenanceDuration";

                    /** NodeGroupMaintenanceWindow _startTime. */
                    public _startTime?: "startTime";

                    /**
                     * Creates a new NodeGroupMaintenanceWindow instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupMaintenanceWindow instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupMaintenanceWindow): google.cloud.compute.v1.NodeGroupMaintenanceWindow;

                    /**
                     * Encodes the specified NodeGroupMaintenanceWindow message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupMaintenanceWindow.verify|verify} messages.
                     * @param message NodeGroupMaintenanceWindow message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupMaintenanceWindow, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupMaintenanceWindow message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupMaintenanceWindow.verify|verify} messages.
                     * @param message NodeGroupMaintenanceWindow message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupMaintenanceWindow, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupMaintenanceWindow message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupMaintenanceWindow
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupMaintenanceWindow;

                    /**
                     * Decodes a NodeGroupMaintenanceWindow message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupMaintenanceWindow
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupMaintenanceWindow;

                    /**
                     * Verifies a NodeGroupMaintenanceWindow message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupMaintenanceWindow message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupMaintenanceWindow
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupMaintenanceWindow;

                    /**
                     * Creates a plain object from a NodeGroupMaintenanceWindow message. Also converts values to other types if specified.
                     * @param message NodeGroupMaintenanceWindow
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupMaintenanceWindow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupMaintenanceWindow to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupMaintenanceWindow
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupNode. */
                interface INodeGroupNode {

                    /** NodeGroupNode accelerators */
                    accelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);

                    /** NodeGroupNode consumedResources */
                    consumedResources?: (google.cloud.compute.v1.IInstanceConsumptionInfo|null);

                    /** NodeGroupNode cpuOvercommitType */
                    cpuOvercommitType?: (string|null);

                    /** NodeGroupNode disks */
                    disks?: (google.cloud.compute.v1.ILocalDisk[]|null);

                    /** NodeGroupNode instanceConsumptionData */
                    instanceConsumptionData?: (google.cloud.compute.v1.IInstanceConsumptionData[]|null);

                    /** NodeGroupNode instances */
                    instances?: (string[]|null);

                    /** NodeGroupNode name */
                    name?: (string|null);

                    /** NodeGroupNode nodeType */
                    nodeType?: (string|null);

                    /** NodeGroupNode satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** NodeGroupNode serverBinding */
                    serverBinding?: (google.cloud.compute.v1.IServerBinding|null);

                    /** NodeGroupNode serverId */
                    serverId?: (string|null);

                    /** NodeGroupNode status */
                    status?: (string|null);

                    /** NodeGroupNode totalResources */
                    totalResources?: (google.cloud.compute.v1.IInstanceConsumptionInfo|null);
                }

                /** Represents a NodeGroupNode. */
                class NodeGroupNode implements INodeGroupNode {

                    /**
                     * Constructs a new NodeGroupNode.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupNode);

                    /** NodeGroupNode accelerators. */
                    public accelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /** NodeGroupNode consumedResources. */
                    public consumedResources?: (google.cloud.compute.v1.IInstanceConsumptionInfo|null);

                    /** NodeGroupNode cpuOvercommitType. */
                    public cpuOvercommitType?: (string|null);

                    /** NodeGroupNode disks. */
                    public disks: google.cloud.compute.v1.ILocalDisk[];

                    /** NodeGroupNode instanceConsumptionData. */
                    public instanceConsumptionData: google.cloud.compute.v1.IInstanceConsumptionData[];

                    /** NodeGroupNode instances. */
                    public instances: string[];

                    /** NodeGroupNode name. */
                    public name?: (string|null);

                    /** NodeGroupNode nodeType. */
                    public nodeType?: (string|null);

                    /** NodeGroupNode satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** NodeGroupNode serverBinding. */
                    public serverBinding?: (google.cloud.compute.v1.IServerBinding|null);

                    /** NodeGroupNode serverId. */
                    public serverId?: (string|null);

                    /** NodeGroupNode status. */
                    public status?: (string|null);

                    /** NodeGroupNode totalResources. */
                    public totalResources?: (google.cloud.compute.v1.IInstanceConsumptionInfo|null);

                    /** NodeGroupNode _consumedResources. */
                    public _consumedResources?: "consumedResources";

                    /** NodeGroupNode _cpuOvercommitType. */
                    public _cpuOvercommitType?: "cpuOvercommitType";

                    /** NodeGroupNode _name. */
                    public _name?: "name";

                    /** NodeGroupNode _nodeType. */
                    public _nodeType?: "nodeType";

                    /** NodeGroupNode _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** NodeGroupNode _serverBinding. */
                    public _serverBinding?: "serverBinding";

                    /** NodeGroupNode _serverId. */
                    public _serverId?: "serverId";

                    /** NodeGroupNode _status. */
                    public _status?: "status";

                    /** NodeGroupNode _totalResources. */
                    public _totalResources?: "totalResources";

                    /**
                     * Creates a new NodeGroupNode instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupNode instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupNode): google.cloud.compute.v1.NodeGroupNode;

                    /**
                     * Encodes the specified NodeGroupNode message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupNode.verify|verify} messages.
                     * @param message NodeGroupNode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupNode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupNode message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupNode.verify|verify} messages.
                     * @param message NodeGroupNode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupNode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupNode message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupNode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupNode;

                    /**
                     * Decodes a NodeGroupNode message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupNode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupNode;

                    /**
                     * Verifies a NodeGroupNode message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupNode message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupNode
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupNode;

                    /**
                     * Creates a plain object from a NodeGroupNode message. Also converts values to other types if specified.
                     * @param message NodeGroupNode
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupNode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupNode to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupNode
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NodeGroupNode {

                    /** CpuOvercommitType enum. */
                    enum CpuOvercommitType {
                        UNDEFINED_CPU_OVERCOMMIT_TYPE = 0,
                        CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615,
                        ENABLED = 182130465,
                        NONE = 2402104
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        INVALID = 530283991,
                        READY = 77848963,
                        REPAIRING = 413483285
                    }
                }

                /** Properties of a NodeGroupsAddNodesRequest. */
                interface INodeGroupsAddNodesRequest {

                    /** NodeGroupsAddNodesRequest additionalNodeCount */
                    additionalNodeCount?: (number|null);
                }

                /** Represents a NodeGroupsAddNodesRequest. */
                class NodeGroupsAddNodesRequest implements INodeGroupsAddNodesRequest {

                    /**
                     * Constructs a new NodeGroupsAddNodesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupsAddNodesRequest);

                    /** NodeGroupsAddNodesRequest additionalNodeCount. */
                    public additionalNodeCount?: (number|null);

                    /** NodeGroupsAddNodesRequest _additionalNodeCount. */
                    public _additionalNodeCount?: "additionalNodeCount";

                    /**
                     * Creates a new NodeGroupsAddNodesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupsAddNodesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupsAddNodesRequest): google.cloud.compute.v1.NodeGroupsAddNodesRequest;

                    /**
                     * Encodes the specified NodeGroupsAddNodesRequest message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsAddNodesRequest.verify|verify} messages.
                     * @param message NodeGroupsAddNodesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupsAddNodesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupsAddNodesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsAddNodesRequest.verify|verify} messages.
                     * @param message NodeGroupsAddNodesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupsAddNodesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupsAddNodesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupsAddNodesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupsAddNodesRequest;

                    /**
                     * Decodes a NodeGroupsAddNodesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupsAddNodesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupsAddNodesRequest;

                    /**
                     * Verifies a NodeGroupsAddNodesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupsAddNodesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupsAddNodesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupsAddNodesRequest;

                    /**
                     * Creates a plain object from a NodeGroupsAddNodesRequest message. Also converts values to other types if specified.
                     * @param message NodeGroupsAddNodesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupsAddNodesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupsAddNodesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupsAddNodesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupsDeleteNodesRequest. */
                interface INodeGroupsDeleteNodesRequest {

                    /** NodeGroupsDeleteNodesRequest nodes */
                    nodes?: (string[]|null);
                }

                /** Represents a NodeGroupsDeleteNodesRequest. */
                class NodeGroupsDeleteNodesRequest implements INodeGroupsDeleteNodesRequest {

                    /**
                     * Constructs a new NodeGroupsDeleteNodesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupsDeleteNodesRequest);

                    /** NodeGroupsDeleteNodesRequest nodes. */
                    public nodes: string[];

                    /**
                     * Creates a new NodeGroupsDeleteNodesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupsDeleteNodesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupsDeleteNodesRequest): google.cloud.compute.v1.NodeGroupsDeleteNodesRequest;

                    /**
                     * Encodes the specified NodeGroupsDeleteNodesRequest message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsDeleteNodesRequest.verify|verify} messages.
                     * @param message NodeGroupsDeleteNodesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupsDeleteNodesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupsDeleteNodesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsDeleteNodesRequest.verify|verify} messages.
                     * @param message NodeGroupsDeleteNodesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupsDeleteNodesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupsDeleteNodesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupsDeleteNodesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupsDeleteNodesRequest;

                    /**
                     * Decodes a NodeGroupsDeleteNodesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupsDeleteNodesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupsDeleteNodesRequest;

                    /**
                     * Verifies a NodeGroupsDeleteNodesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupsDeleteNodesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupsDeleteNodesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupsDeleteNodesRequest;

                    /**
                     * Creates a plain object from a NodeGroupsDeleteNodesRequest message. Also converts values to other types if specified.
                     * @param message NodeGroupsDeleteNodesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupsDeleteNodesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupsDeleteNodesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupsDeleteNodesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupsListNodes. */
                interface INodeGroupsListNodes {

                    /** NodeGroupsListNodes id */
                    id?: (string|null);

                    /** NodeGroupsListNodes items */
                    items?: (google.cloud.compute.v1.INodeGroupNode[]|null);

                    /** NodeGroupsListNodes kind */
                    kind?: (string|null);

                    /** NodeGroupsListNodes nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeGroupsListNodes selfLink */
                    selfLink?: (string|null);

                    /** NodeGroupsListNodes warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeGroupsListNodes. */
                class NodeGroupsListNodes implements INodeGroupsListNodes {

                    /**
                     * Constructs a new NodeGroupsListNodes.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupsListNodes);

                    /** NodeGroupsListNodes id. */
                    public id?: (string|null);

                    /** NodeGroupsListNodes items. */
                    public items: google.cloud.compute.v1.INodeGroupNode[];

                    /** NodeGroupsListNodes kind. */
                    public kind?: (string|null);

                    /** NodeGroupsListNodes nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeGroupsListNodes selfLink. */
                    public selfLink?: (string|null);

                    /** NodeGroupsListNodes warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeGroupsListNodes _id. */
                    public _id?: "id";

                    /** NodeGroupsListNodes _kind. */
                    public _kind?: "kind";

                    /** NodeGroupsListNodes _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeGroupsListNodes _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeGroupsListNodes _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeGroupsListNodes instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupsListNodes instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupsListNodes): google.cloud.compute.v1.NodeGroupsListNodes;

                    /**
                     * Encodes the specified NodeGroupsListNodes message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsListNodes.verify|verify} messages.
                     * @param message NodeGroupsListNodes message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupsListNodes, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupsListNodes message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsListNodes.verify|verify} messages.
                     * @param message NodeGroupsListNodes message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupsListNodes, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupsListNodes message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupsListNodes
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupsListNodes;

                    /**
                     * Decodes a NodeGroupsListNodes message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupsListNodes
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupsListNodes;

                    /**
                     * Verifies a NodeGroupsListNodes message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupsListNodes message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupsListNodes
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupsListNodes;

                    /**
                     * Creates a plain object from a NodeGroupsListNodes message. Also converts values to other types if specified.
                     * @param message NodeGroupsListNodes
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupsListNodes, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupsListNodes to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupsListNodes
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupsScopedList. */
                interface INodeGroupsScopedList {

                    /** NodeGroupsScopedList nodeGroups */
                    nodeGroups?: (google.cloud.compute.v1.INodeGroup[]|null);

                    /** NodeGroupsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeGroupsScopedList. */
                class NodeGroupsScopedList implements INodeGroupsScopedList {

                    /**
                     * Constructs a new NodeGroupsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupsScopedList);

                    /** NodeGroupsScopedList nodeGroups. */
                    public nodeGroups: google.cloud.compute.v1.INodeGroup[];

                    /** NodeGroupsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeGroupsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeGroupsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupsScopedList): google.cloud.compute.v1.NodeGroupsScopedList;

                    /**
                     * Encodes the specified NodeGroupsScopedList message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsScopedList.verify|verify} messages.
                     * @param message NodeGroupsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsScopedList.verify|verify} messages.
                     * @param message NodeGroupsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupsScopedList;

                    /**
                     * Decodes a NodeGroupsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupsScopedList;

                    /**
                     * Verifies a NodeGroupsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupsScopedList;

                    /**
                     * Creates a plain object from a NodeGroupsScopedList message. Also converts values to other types if specified.
                     * @param message NodeGroupsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeGroupsSetNodeTemplateRequest. */
                interface INodeGroupsSetNodeTemplateRequest {

                    /** NodeGroupsSetNodeTemplateRequest nodeTemplate */
                    nodeTemplate?: (string|null);
                }

                /** Represents a NodeGroupsSetNodeTemplateRequest. */
                class NodeGroupsSetNodeTemplateRequest implements INodeGroupsSetNodeTemplateRequest {

                    /**
                     * Constructs a new NodeGroupsSetNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeGroupsSetNodeTemplateRequest);

                    /** NodeGroupsSetNodeTemplateRequest nodeTemplate. */
                    public nodeTemplate?: (string|null);

                    /** NodeGroupsSetNodeTemplateRequest _nodeTemplate. */
                    public _nodeTemplate?: "nodeTemplate";

                    /**
                     * Creates a new NodeGroupsSetNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeGroupsSetNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeGroupsSetNodeTemplateRequest): google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest;

                    /**
                     * Encodes the specified NodeGroupsSetNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest.verify|verify} messages.
                     * @param message NodeGroupsSetNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeGroupsSetNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeGroupsSetNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest.verify|verify} messages.
                     * @param message NodeGroupsSetNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeGroupsSetNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeGroupsSetNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeGroupsSetNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest;

                    /**
                     * Decodes a NodeGroupsSetNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeGroupsSetNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest;

                    /**
                     * Verifies a NodeGroupsSetNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeGroupsSetNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeGroupsSetNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest;

                    /**
                     * Creates a plain object from a NodeGroupsSetNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message NodeGroupsSetNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeGroupsSetNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeGroupsSetNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeGroupsSetNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTemplate. */
                interface INodeTemplate {

                    /** NodeTemplate accelerators */
                    accelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);

                    /** NodeTemplate cpuOvercommitType */
                    cpuOvercommitType?: (string|null);

                    /** NodeTemplate creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** NodeTemplate description */
                    description?: (string|null);

                    /** NodeTemplate disks */
                    disks?: (google.cloud.compute.v1.ILocalDisk[]|null);

                    /** NodeTemplate id */
                    id?: (number|Long|string|null);

                    /** NodeTemplate kind */
                    kind?: (string|null);

                    /** NodeTemplate name */
                    name?: (string|null);

                    /** NodeTemplate nodeAffinityLabels */
                    nodeAffinityLabels?: ({ [k: string]: string }|null);

                    /** NodeTemplate nodeType */
                    nodeType?: (string|null);

                    /** NodeTemplate nodeTypeFlexibility */
                    nodeTypeFlexibility?: (google.cloud.compute.v1.INodeTemplateNodeTypeFlexibility|null);

                    /** NodeTemplate region */
                    region?: (string|null);

                    /** NodeTemplate selfLink */
                    selfLink?: (string|null);

                    /** NodeTemplate serverBinding */
                    serverBinding?: (google.cloud.compute.v1.IServerBinding|null);

                    /** NodeTemplate status */
                    status?: (string|null);

                    /** NodeTemplate statusMessage */
                    statusMessage?: (string|null);
                }

                /** Represents a NodeTemplate. */
                class NodeTemplate implements INodeTemplate {

                    /**
                     * Constructs a new NodeTemplate.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTemplate);

                    /** NodeTemplate accelerators. */
                    public accelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /** NodeTemplate cpuOvercommitType. */
                    public cpuOvercommitType?: (string|null);

                    /** NodeTemplate creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** NodeTemplate description. */
                    public description?: (string|null);

                    /** NodeTemplate disks. */
                    public disks: google.cloud.compute.v1.ILocalDisk[];

                    /** NodeTemplate id. */
                    public id?: (number|Long|string|null);

                    /** NodeTemplate kind. */
                    public kind?: (string|null);

                    /** NodeTemplate name. */
                    public name?: (string|null);

                    /** NodeTemplate nodeAffinityLabels. */
                    public nodeAffinityLabels: { [k: string]: string };

                    /** NodeTemplate nodeType. */
                    public nodeType?: (string|null);

                    /** NodeTemplate nodeTypeFlexibility. */
                    public nodeTypeFlexibility?: (google.cloud.compute.v1.INodeTemplateNodeTypeFlexibility|null);

                    /** NodeTemplate region. */
                    public region?: (string|null);

                    /** NodeTemplate selfLink. */
                    public selfLink?: (string|null);

                    /** NodeTemplate serverBinding. */
                    public serverBinding?: (google.cloud.compute.v1.IServerBinding|null);

                    /** NodeTemplate status. */
                    public status?: (string|null);

                    /** NodeTemplate statusMessage. */
                    public statusMessage?: (string|null);

                    /** NodeTemplate _cpuOvercommitType. */
                    public _cpuOvercommitType?: "cpuOvercommitType";

                    /** NodeTemplate _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** NodeTemplate _description. */
                    public _description?: "description";

                    /** NodeTemplate _id. */
                    public _id?: "id";

                    /** NodeTemplate _kind. */
                    public _kind?: "kind";

                    /** NodeTemplate _name. */
                    public _name?: "name";

                    /** NodeTemplate _nodeType. */
                    public _nodeType?: "nodeType";

                    /** NodeTemplate _nodeTypeFlexibility. */
                    public _nodeTypeFlexibility?: "nodeTypeFlexibility";

                    /** NodeTemplate _region. */
                    public _region?: "region";

                    /** NodeTemplate _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeTemplate _serverBinding. */
                    public _serverBinding?: "serverBinding";

                    /** NodeTemplate _status. */
                    public _status?: "status";

                    /** NodeTemplate _statusMessage. */
                    public _statusMessage?: "statusMessage";

                    /**
                     * Creates a new NodeTemplate instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTemplate instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTemplate): google.cloud.compute.v1.NodeTemplate;

                    /**
                     * Encodes the specified NodeTemplate message. Does not implicitly {@link google.cloud.compute.v1.NodeTemplate.verify|verify} messages.
                     * @param message NodeTemplate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTemplate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTemplate message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTemplate.verify|verify} messages.
                     * @param message NodeTemplate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTemplate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTemplate message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTemplate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTemplate;

                    /**
                     * Decodes a NodeTemplate message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTemplate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTemplate;

                    /**
                     * Verifies a NodeTemplate message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTemplate message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTemplate
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTemplate;

                    /**
                     * Creates a plain object from a NodeTemplate message. Also converts values to other types if specified.
                     * @param message NodeTemplate
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTemplate, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTemplate to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTemplate
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace NodeTemplate {

                    /** CpuOvercommitType enum. */
                    enum CpuOvercommitType {
                        UNDEFINED_CPU_OVERCOMMIT_TYPE = 0,
                        CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615,
                        ENABLED = 182130465,
                        NONE = 2402104
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        INVALID = 530283991,
                        READY = 77848963
                    }
                }

                /** Properties of a NodeTemplateAggregatedList. */
                interface INodeTemplateAggregatedList {

                    /** NodeTemplateAggregatedList id */
                    id?: (string|null);

                    /** NodeTemplateAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.INodeTemplatesScopedList }|null);

                    /** NodeTemplateAggregatedList kind */
                    kind?: (string|null);

                    /** NodeTemplateAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeTemplateAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** NodeTemplateAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** NodeTemplateAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeTemplateAggregatedList. */
                class NodeTemplateAggregatedList implements INodeTemplateAggregatedList {

                    /**
                     * Constructs a new NodeTemplateAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTemplateAggregatedList);

                    /** NodeTemplateAggregatedList id. */
                    public id?: (string|null);

                    /** NodeTemplateAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.INodeTemplatesScopedList };

                    /** NodeTemplateAggregatedList kind. */
                    public kind?: (string|null);

                    /** NodeTemplateAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeTemplateAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** NodeTemplateAggregatedList unreachables. */
                    public unreachables: string[];

                    /** NodeTemplateAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeTemplateAggregatedList _id. */
                    public _id?: "id";

                    /** NodeTemplateAggregatedList _kind. */
                    public _kind?: "kind";

                    /** NodeTemplateAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeTemplateAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeTemplateAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeTemplateAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTemplateAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTemplateAggregatedList): google.cloud.compute.v1.NodeTemplateAggregatedList;

                    /**
                     * Encodes the specified NodeTemplateAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.NodeTemplateAggregatedList.verify|verify} messages.
                     * @param message NodeTemplateAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTemplateAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTemplateAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTemplateAggregatedList.verify|verify} messages.
                     * @param message NodeTemplateAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTemplateAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTemplateAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTemplateAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTemplateAggregatedList;

                    /**
                     * Decodes a NodeTemplateAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTemplateAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTemplateAggregatedList;

                    /**
                     * Verifies a NodeTemplateAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTemplateAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTemplateAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTemplateAggregatedList;

                    /**
                     * Creates a plain object from a NodeTemplateAggregatedList message. Also converts values to other types if specified.
                     * @param message NodeTemplateAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTemplateAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTemplateAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTemplateAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTemplateList. */
                interface INodeTemplateList {

                    /** NodeTemplateList id */
                    id?: (string|null);

                    /** NodeTemplateList items */
                    items?: (google.cloud.compute.v1.INodeTemplate[]|null);

                    /** NodeTemplateList kind */
                    kind?: (string|null);

                    /** NodeTemplateList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeTemplateList selfLink */
                    selfLink?: (string|null);

                    /** NodeTemplateList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeTemplateList. */
                class NodeTemplateList implements INodeTemplateList {

                    /**
                     * Constructs a new NodeTemplateList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTemplateList);

                    /** NodeTemplateList id. */
                    public id?: (string|null);

                    /** NodeTemplateList items. */
                    public items: google.cloud.compute.v1.INodeTemplate[];

                    /** NodeTemplateList kind. */
                    public kind?: (string|null);

                    /** NodeTemplateList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeTemplateList selfLink. */
                    public selfLink?: (string|null);

                    /** NodeTemplateList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeTemplateList _id. */
                    public _id?: "id";

                    /** NodeTemplateList _kind. */
                    public _kind?: "kind";

                    /** NodeTemplateList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeTemplateList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeTemplateList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeTemplateList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTemplateList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTemplateList): google.cloud.compute.v1.NodeTemplateList;

                    /**
                     * Encodes the specified NodeTemplateList message. Does not implicitly {@link google.cloud.compute.v1.NodeTemplateList.verify|verify} messages.
                     * @param message NodeTemplateList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTemplateList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTemplateList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTemplateList.verify|verify} messages.
                     * @param message NodeTemplateList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTemplateList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTemplateList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTemplateList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTemplateList;

                    /**
                     * Decodes a NodeTemplateList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTemplateList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTemplateList;

                    /**
                     * Verifies a NodeTemplateList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTemplateList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTemplateList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTemplateList;

                    /**
                     * Creates a plain object from a NodeTemplateList message. Also converts values to other types if specified.
                     * @param message NodeTemplateList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTemplateList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTemplateList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTemplateList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTemplateNodeTypeFlexibility. */
                interface INodeTemplateNodeTypeFlexibility {

                    /** NodeTemplateNodeTypeFlexibility cpus */
                    cpus?: (string|null);

                    /** NodeTemplateNodeTypeFlexibility localSsd */
                    localSsd?: (string|null);

                    /** NodeTemplateNodeTypeFlexibility memory */
                    memory?: (string|null);
                }

                /** Represents a NodeTemplateNodeTypeFlexibility. */
                class NodeTemplateNodeTypeFlexibility implements INodeTemplateNodeTypeFlexibility {

                    /**
                     * Constructs a new NodeTemplateNodeTypeFlexibility.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTemplateNodeTypeFlexibility);

                    /** NodeTemplateNodeTypeFlexibility cpus. */
                    public cpus?: (string|null);

                    /** NodeTemplateNodeTypeFlexibility localSsd. */
                    public localSsd?: (string|null);

                    /** NodeTemplateNodeTypeFlexibility memory. */
                    public memory?: (string|null);

                    /** NodeTemplateNodeTypeFlexibility _cpus. */
                    public _cpus?: "cpus";

                    /** NodeTemplateNodeTypeFlexibility _localSsd. */
                    public _localSsd?: "localSsd";

                    /** NodeTemplateNodeTypeFlexibility _memory. */
                    public _memory?: "memory";

                    /**
                     * Creates a new NodeTemplateNodeTypeFlexibility instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTemplateNodeTypeFlexibility instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTemplateNodeTypeFlexibility): google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility;

                    /**
                     * Encodes the specified NodeTemplateNodeTypeFlexibility message. Does not implicitly {@link google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility.verify|verify} messages.
                     * @param message NodeTemplateNodeTypeFlexibility message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTemplateNodeTypeFlexibility, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTemplateNodeTypeFlexibility message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility.verify|verify} messages.
                     * @param message NodeTemplateNodeTypeFlexibility message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTemplateNodeTypeFlexibility, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTemplateNodeTypeFlexibility message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTemplateNodeTypeFlexibility
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility;

                    /**
                     * Decodes a NodeTemplateNodeTypeFlexibility message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTemplateNodeTypeFlexibility
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility;

                    /**
                     * Verifies a NodeTemplateNodeTypeFlexibility message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTemplateNodeTypeFlexibility message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTemplateNodeTypeFlexibility
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility;

                    /**
                     * Creates a plain object from a NodeTemplateNodeTypeFlexibility message. Also converts values to other types if specified.
                     * @param message NodeTemplateNodeTypeFlexibility
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTemplateNodeTypeFlexibility, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTemplateNodeTypeFlexibility to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTemplateNodeTypeFlexibility
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTemplatesScopedList. */
                interface INodeTemplatesScopedList {

                    /** NodeTemplatesScopedList nodeTemplates */
                    nodeTemplates?: (google.cloud.compute.v1.INodeTemplate[]|null);

                    /** NodeTemplatesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeTemplatesScopedList. */
                class NodeTemplatesScopedList implements INodeTemplatesScopedList {

                    /**
                     * Constructs a new NodeTemplatesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTemplatesScopedList);

                    /** NodeTemplatesScopedList nodeTemplates. */
                    public nodeTemplates: google.cloud.compute.v1.INodeTemplate[];

                    /** NodeTemplatesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeTemplatesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeTemplatesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTemplatesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTemplatesScopedList): google.cloud.compute.v1.NodeTemplatesScopedList;

                    /**
                     * Encodes the specified NodeTemplatesScopedList message. Does not implicitly {@link google.cloud.compute.v1.NodeTemplatesScopedList.verify|verify} messages.
                     * @param message NodeTemplatesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTemplatesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTemplatesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTemplatesScopedList.verify|verify} messages.
                     * @param message NodeTemplatesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTemplatesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTemplatesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTemplatesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTemplatesScopedList;

                    /**
                     * Decodes a NodeTemplatesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTemplatesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTemplatesScopedList;

                    /**
                     * Verifies a NodeTemplatesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTemplatesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTemplatesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTemplatesScopedList;

                    /**
                     * Creates a plain object from a NodeTemplatesScopedList message. Also converts values to other types if specified.
                     * @param message NodeTemplatesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTemplatesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTemplatesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTemplatesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeType. */
                interface INodeType {

                    /** NodeType cpuPlatform */
                    cpuPlatform?: (string|null);

                    /** NodeType creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** NodeType deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** NodeType description */
                    description?: (string|null);

                    /** NodeType guestCpus */
                    guestCpus?: (number|null);

                    /** NodeType id */
                    id?: (number|Long|string|null);

                    /** NodeType kind */
                    kind?: (string|null);

                    /** NodeType localSsdGb */
                    localSsdGb?: (number|null);

                    /** NodeType memoryMb */
                    memoryMb?: (number|null);

                    /** NodeType name */
                    name?: (string|null);

                    /** NodeType selfLink */
                    selfLink?: (string|null);

                    /** NodeType zone */
                    zone?: (string|null);
                }

                /** Represents a NodeType. */
                class NodeType implements INodeType {

                    /**
                     * Constructs a new NodeType.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeType);

                    /** NodeType cpuPlatform. */
                    public cpuPlatform?: (string|null);

                    /** NodeType creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** NodeType deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** NodeType description. */
                    public description?: (string|null);

                    /** NodeType guestCpus. */
                    public guestCpus?: (number|null);

                    /** NodeType id. */
                    public id?: (number|Long|string|null);

                    /** NodeType kind. */
                    public kind?: (string|null);

                    /** NodeType localSsdGb. */
                    public localSsdGb?: (number|null);

                    /** NodeType memoryMb. */
                    public memoryMb?: (number|null);

                    /** NodeType name. */
                    public name?: (string|null);

                    /** NodeType selfLink. */
                    public selfLink?: (string|null);

                    /** NodeType zone. */
                    public zone?: (string|null);

                    /** NodeType _cpuPlatform. */
                    public _cpuPlatform?: "cpuPlatform";

                    /** NodeType _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** NodeType _deprecated. */
                    public _deprecated?: "deprecated";

                    /** NodeType _description. */
                    public _description?: "description";

                    /** NodeType _guestCpus. */
                    public _guestCpus?: "guestCpus";

                    /** NodeType _id. */
                    public _id?: "id";

                    /** NodeType _kind. */
                    public _kind?: "kind";

                    /** NodeType _localSsdGb. */
                    public _localSsdGb?: "localSsdGb";

                    /** NodeType _memoryMb. */
                    public _memoryMb?: "memoryMb";

                    /** NodeType _name. */
                    public _name?: "name";

                    /** NodeType _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeType _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new NodeType instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeType instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeType): google.cloud.compute.v1.NodeType;

                    /**
                     * Encodes the specified NodeType message. Does not implicitly {@link google.cloud.compute.v1.NodeType.verify|verify} messages.
                     * @param message NodeType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeType message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeType.verify|verify} messages.
                     * @param message NodeType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeType message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeType;

                    /**
                     * Decodes a NodeType message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeType;

                    /**
                     * Verifies a NodeType message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeType message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeType
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeType;

                    /**
                     * Creates a plain object from a NodeType message. Also converts values to other types if specified.
                     * @param message NodeType
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeType to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeType
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTypeAggregatedList. */
                interface INodeTypeAggregatedList {

                    /** NodeTypeAggregatedList id */
                    id?: (string|null);

                    /** NodeTypeAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.INodeTypesScopedList }|null);

                    /** NodeTypeAggregatedList kind */
                    kind?: (string|null);

                    /** NodeTypeAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeTypeAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** NodeTypeAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** NodeTypeAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeTypeAggregatedList. */
                class NodeTypeAggregatedList implements INodeTypeAggregatedList {

                    /**
                     * Constructs a new NodeTypeAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTypeAggregatedList);

                    /** NodeTypeAggregatedList id. */
                    public id?: (string|null);

                    /** NodeTypeAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.INodeTypesScopedList };

                    /** NodeTypeAggregatedList kind. */
                    public kind?: (string|null);

                    /** NodeTypeAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeTypeAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** NodeTypeAggregatedList unreachables. */
                    public unreachables: string[];

                    /** NodeTypeAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeTypeAggregatedList _id. */
                    public _id?: "id";

                    /** NodeTypeAggregatedList _kind. */
                    public _kind?: "kind";

                    /** NodeTypeAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeTypeAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeTypeAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeTypeAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTypeAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTypeAggregatedList): google.cloud.compute.v1.NodeTypeAggregatedList;

                    /**
                     * Encodes the specified NodeTypeAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.NodeTypeAggregatedList.verify|verify} messages.
                     * @param message NodeTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTypeAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTypeAggregatedList.verify|verify} messages.
                     * @param message NodeTypeAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTypeAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTypeAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTypeAggregatedList;

                    /**
                     * Decodes a NodeTypeAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTypeAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTypeAggregatedList;

                    /**
                     * Verifies a NodeTypeAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTypeAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTypeAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTypeAggregatedList;

                    /**
                     * Creates a plain object from a NodeTypeAggregatedList message. Also converts values to other types if specified.
                     * @param message NodeTypeAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTypeAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTypeAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTypeAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTypeList. */
                interface INodeTypeList {

                    /** NodeTypeList id */
                    id?: (string|null);

                    /** NodeTypeList items */
                    items?: (google.cloud.compute.v1.INodeType[]|null);

                    /** NodeTypeList kind */
                    kind?: (string|null);

                    /** NodeTypeList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NodeTypeList selfLink */
                    selfLink?: (string|null);

                    /** NodeTypeList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeTypeList. */
                class NodeTypeList implements INodeTypeList {

                    /**
                     * Constructs a new NodeTypeList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTypeList);

                    /** NodeTypeList id. */
                    public id?: (string|null);

                    /** NodeTypeList items. */
                    public items: google.cloud.compute.v1.INodeType[];

                    /** NodeTypeList kind. */
                    public kind?: (string|null);

                    /** NodeTypeList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NodeTypeList selfLink. */
                    public selfLink?: (string|null);

                    /** NodeTypeList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeTypeList _id. */
                    public _id?: "id";

                    /** NodeTypeList _kind. */
                    public _kind?: "kind";

                    /** NodeTypeList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NodeTypeList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NodeTypeList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeTypeList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTypeList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTypeList): google.cloud.compute.v1.NodeTypeList;

                    /**
                     * Encodes the specified NodeTypeList message. Does not implicitly {@link google.cloud.compute.v1.NodeTypeList.verify|verify} messages.
                     * @param message NodeTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTypeList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTypeList.verify|verify} messages.
                     * @param message NodeTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTypeList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTypeList;

                    /**
                     * Decodes a NodeTypeList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTypeList;

                    /**
                     * Verifies a NodeTypeList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTypeList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTypeList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTypeList;

                    /**
                     * Creates a plain object from a NodeTypeList message. Also converts values to other types if specified.
                     * @param message NodeTypeList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTypeList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTypeList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTypeList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NodeTypesScopedList. */
                interface INodeTypesScopedList {

                    /** NodeTypesScopedList nodeTypes */
                    nodeTypes?: (google.cloud.compute.v1.INodeType[]|null);

                    /** NodeTypesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NodeTypesScopedList. */
                class NodeTypesScopedList implements INodeTypesScopedList {

                    /**
                     * Constructs a new NodeTypesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INodeTypesScopedList);

                    /** NodeTypesScopedList nodeTypes. */
                    public nodeTypes: google.cloud.compute.v1.INodeType[];

                    /** NodeTypesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NodeTypesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NodeTypesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NodeTypesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INodeTypesScopedList): google.cloud.compute.v1.NodeTypesScopedList;

                    /**
                     * Encodes the specified NodeTypesScopedList message. Does not implicitly {@link google.cloud.compute.v1.NodeTypesScopedList.verify|verify} messages.
                     * @param message NodeTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INodeTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NodeTypesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NodeTypesScopedList.verify|verify} messages.
                     * @param message NodeTypesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INodeTypesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NodeTypesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NodeTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NodeTypesScopedList;

                    /**
                     * Decodes a NodeTypesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NodeTypesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NodeTypesScopedList;

                    /**
                     * Verifies a NodeTypesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NodeTypesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NodeTypesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NodeTypesScopedList;

                    /**
                     * Creates a plain object from a NodeTypesScopedList message. Also converts values to other types if specified.
                     * @param message NodeTypesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NodeTypesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NodeTypesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NodeTypesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NotificationEndpoint. */
                interface INotificationEndpoint {

                    /** NotificationEndpoint creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** NotificationEndpoint description */
                    description?: (string|null);

                    /** NotificationEndpoint grpcSettings */
                    grpcSettings?: (google.cloud.compute.v1.INotificationEndpointGrpcSettings|null);

                    /** NotificationEndpoint id */
                    id?: (number|Long|string|null);

                    /** NotificationEndpoint kind */
                    kind?: (string|null);

                    /** NotificationEndpoint name */
                    name?: (string|null);

                    /** NotificationEndpoint region */
                    region?: (string|null);

                    /** NotificationEndpoint selfLink */
                    selfLink?: (string|null);
                }

                /** Represents a NotificationEndpoint. */
                class NotificationEndpoint implements INotificationEndpoint {

                    /**
                     * Constructs a new NotificationEndpoint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INotificationEndpoint);

                    /** NotificationEndpoint creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** NotificationEndpoint description. */
                    public description?: (string|null);

                    /** NotificationEndpoint grpcSettings. */
                    public grpcSettings?: (google.cloud.compute.v1.INotificationEndpointGrpcSettings|null);

                    /** NotificationEndpoint id. */
                    public id?: (number|Long|string|null);

                    /** NotificationEndpoint kind. */
                    public kind?: (string|null);

                    /** NotificationEndpoint name. */
                    public name?: (string|null);

                    /** NotificationEndpoint region. */
                    public region?: (string|null);

                    /** NotificationEndpoint selfLink. */
                    public selfLink?: (string|null);

                    /** NotificationEndpoint _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** NotificationEndpoint _description. */
                    public _description?: "description";

                    /** NotificationEndpoint _grpcSettings. */
                    public _grpcSettings?: "grpcSettings";

                    /** NotificationEndpoint _id. */
                    public _id?: "id";

                    /** NotificationEndpoint _kind. */
                    public _kind?: "kind";

                    /** NotificationEndpoint _name. */
                    public _name?: "name";

                    /** NotificationEndpoint _region. */
                    public _region?: "region";

                    /** NotificationEndpoint _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new NotificationEndpoint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NotificationEndpoint instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INotificationEndpoint): google.cloud.compute.v1.NotificationEndpoint;

                    /**
                     * Encodes the specified NotificationEndpoint message. Does not implicitly {@link google.cloud.compute.v1.NotificationEndpoint.verify|verify} messages.
                     * @param message NotificationEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INotificationEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NotificationEndpoint message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NotificationEndpoint.verify|verify} messages.
                     * @param message NotificationEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INotificationEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NotificationEndpoint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NotificationEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NotificationEndpoint;

                    /**
                     * Decodes a NotificationEndpoint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NotificationEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NotificationEndpoint;

                    /**
                     * Verifies a NotificationEndpoint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NotificationEndpoint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NotificationEndpoint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NotificationEndpoint;

                    /**
                     * Creates a plain object from a NotificationEndpoint message. Also converts values to other types if specified.
                     * @param message NotificationEndpoint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NotificationEndpoint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NotificationEndpoint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NotificationEndpoint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NotificationEndpointGrpcSettings. */
                interface INotificationEndpointGrpcSettings {

                    /** NotificationEndpointGrpcSettings authority */
                    authority?: (string|null);

                    /** NotificationEndpointGrpcSettings endpoint */
                    endpoint?: (string|null);

                    /** NotificationEndpointGrpcSettings payloadName */
                    payloadName?: (string|null);

                    /** NotificationEndpointGrpcSettings resendInterval */
                    resendInterval?: (google.cloud.compute.v1.IDuration|null);

                    /** NotificationEndpointGrpcSettings retryDurationSec */
                    retryDurationSec?: (number|null);
                }

                /** Represents a NotificationEndpointGrpcSettings. */
                class NotificationEndpointGrpcSettings implements INotificationEndpointGrpcSettings {

                    /**
                     * Constructs a new NotificationEndpointGrpcSettings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INotificationEndpointGrpcSettings);

                    /** NotificationEndpointGrpcSettings authority. */
                    public authority?: (string|null);

                    /** NotificationEndpointGrpcSettings endpoint. */
                    public endpoint?: (string|null);

                    /** NotificationEndpointGrpcSettings payloadName. */
                    public payloadName?: (string|null);

                    /** NotificationEndpointGrpcSettings resendInterval. */
                    public resendInterval?: (google.cloud.compute.v1.IDuration|null);

                    /** NotificationEndpointGrpcSettings retryDurationSec. */
                    public retryDurationSec?: (number|null);

                    /** NotificationEndpointGrpcSettings _authority. */
                    public _authority?: "authority";

                    /** NotificationEndpointGrpcSettings _endpoint. */
                    public _endpoint?: "endpoint";

                    /** NotificationEndpointGrpcSettings _payloadName. */
                    public _payloadName?: "payloadName";

                    /** NotificationEndpointGrpcSettings _resendInterval. */
                    public _resendInterval?: "resendInterval";

                    /** NotificationEndpointGrpcSettings _retryDurationSec. */
                    public _retryDurationSec?: "retryDurationSec";

                    /**
                     * Creates a new NotificationEndpointGrpcSettings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NotificationEndpointGrpcSettings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INotificationEndpointGrpcSettings): google.cloud.compute.v1.NotificationEndpointGrpcSettings;

                    /**
                     * Encodes the specified NotificationEndpointGrpcSettings message. Does not implicitly {@link google.cloud.compute.v1.NotificationEndpointGrpcSettings.verify|verify} messages.
                     * @param message NotificationEndpointGrpcSettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INotificationEndpointGrpcSettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NotificationEndpointGrpcSettings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NotificationEndpointGrpcSettings.verify|verify} messages.
                     * @param message NotificationEndpointGrpcSettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INotificationEndpointGrpcSettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NotificationEndpointGrpcSettings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NotificationEndpointGrpcSettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NotificationEndpointGrpcSettings;

                    /**
                     * Decodes a NotificationEndpointGrpcSettings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NotificationEndpointGrpcSettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NotificationEndpointGrpcSettings;

                    /**
                     * Verifies a NotificationEndpointGrpcSettings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NotificationEndpointGrpcSettings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NotificationEndpointGrpcSettings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NotificationEndpointGrpcSettings;

                    /**
                     * Creates a plain object from a NotificationEndpointGrpcSettings message. Also converts values to other types if specified.
                     * @param message NotificationEndpointGrpcSettings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NotificationEndpointGrpcSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NotificationEndpointGrpcSettings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NotificationEndpointGrpcSettings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NotificationEndpointList. */
                interface INotificationEndpointList {

                    /** NotificationEndpointList id */
                    id?: (string|null);

                    /** NotificationEndpointList items */
                    items?: (google.cloud.compute.v1.INotificationEndpoint[]|null);

                    /** NotificationEndpointList kind */
                    kind?: (string|null);

                    /** NotificationEndpointList nextPageToken */
                    nextPageToken?: (string|null);

                    /** NotificationEndpointList selfLink */
                    selfLink?: (string|null);

                    /** NotificationEndpointList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a NotificationEndpointList. */
                class NotificationEndpointList implements INotificationEndpointList {

                    /**
                     * Constructs a new NotificationEndpointList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.INotificationEndpointList);

                    /** NotificationEndpointList id. */
                    public id?: (string|null);

                    /** NotificationEndpointList items. */
                    public items: google.cloud.compute.v1.INotificationEndpoint[];

                    /** NotificationEndpointList kind. */
                    public kind?: (string|null);

                    /** NotificationEndpointList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** NotificationEndpointList selfLink. */
                    public selfLink?: (string|null);

                    /** NotificationEndpointList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** NotificationEndpointList _id. */
                    public _id?: "id";

                    /** NotificationEndpointList _kind. */
                    public _kind?: "kind";

                    /** NotificationEndpointList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** NotificationEndpointList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** NotificationEndpointList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new NotificationEndpointList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NotificationEndpointList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.INotificationEndpointList): google.cloud.compute.v1.NotificationEndpointList;

                    /**
                     * Encodes the specified NotificationEndpointList message. Does not implicitly {@link google.cloud.compute.v1.NotificationEndpointList.verify|verify} messages.
                     * @param message NotificationEndpointList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.INotificationEndpointList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NotificationEndpointList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.NotificationEndpointList.verify|verify} messages.
                     * @param message NotificationEndpointList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.INotificationEndpointList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NotificationEndpointList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NotificationEndpointList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.NotificationEndpointList;

                    /**
                     * Decodes a NotificationEndpointList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NotificationEndpointList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.NotificationEndpointList;

                    /**
                     * Verifies a NotificationEndpointList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NotificationEndpointList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NotificationEndpointList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.NotificationEndpointList;

                    /**
                     * Creates a plain object from a NotificationEndpointList message. Also converts values to other types if specified.
                     * @param message NotificationEndpointList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.NotificationEndpointList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NotificationEndpointList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NotificationEndpointList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Operation. */
                interface IOperation {

                    /** Operation clientOperationId */
                    clientOperationId?: (string|null);

                    /** Operation creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Operation description */
                    description?: (string|null);

                    /** Operation endTime */
                    endTime?: (string|null);

                    /** Operation error */
                    error?: (google.cloud.compute.v1.IError|null);

                    /** Operation httpErrorMessage */
                    httpErrorMessage?: (string|null);

                    /** Operation httpErrorStatusCode */
                    httpErrorStatusCode?: (number|null);

                    /** Operation id */
                    id?: (number|Long|string|null);

                    /** Operation insertTime */
                    insertTime?: (string|null);

                    /** Operation kind */
                    kind?: (string|null);

                    /** Operation name */
                    name?: (string|null);

                    /** Operation operationGroupId */
                    operationGroupId?: (string|null);

                    /** Operation operationType */
                    operationType?: (string|null);

                    /** Operation progress */
                    progress?: (number|null);

                    /** Operation region */
                    region?: (string|null);

                    /** Operation selfLink */
                    selfLink?: (string|null);

                    /** Operation startTime */
                    startTime?: (string|null);

                    /** Operation status */
                    status?: (google.cloud.compute.v1.Operation.Status|keyof typeof google.cloud.compute.v1.Operation.Status|null);

                    /** Operation statusMessage */
                    statusMessage?: (string|null);

                    /** Operation targetId */
                    targetId?: (number|Long|string|null);

                    /** Operation targetLink */
                    targetLink?: (string|null);

                    /** Operation user */
                    user?: (string|null);

                    /** Operation warnings */
                    warnings?: (google.cloud.compute.v1.IWarnings[]|null);

                    /** Operation zone */
                    zone?: (string|null);
                }

                /** Represents an Operation. */
                class Operation implements IOperation {

                    /**
                     * Constructs a new Operation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IOperation);

                    /** Operation clientOperationId. */
                    public clientOperationId?: (string|null);

                    /** Operation creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Operation description. */
                    public description?: (string|null);

                    /** Operation endTime. */
                    public endTime?: (string|null);

                    /** Operation error. */
                    public error?: (google.cloud.compute.v1.IError|null);

                    /** Operation httpErrorMessage. */
                    public httpErrorMessage?: (string|null);

                    /** Operation httpErrorStatusCode. */
                    public httpErrorStatusCode?: (number|null);

                    /** Operation id. */
                    public id?: (number|Long|string|null);

                    /** Operation insertTime. */
                    public insertTime?: (string|null);

                    /** Operation kind. */
                    public kind?: (string|null);

                    /** Operation name. */
                    public name?: (string|null);

                    /** Operation operationGroupId. */
                    public operationGroupId?: (string|null);

                    /** Operation operationType. */
                    public operationType?: (string|null);

                    /** Operation progress. */
                    public progress?: (number|null);

                    /** Operation region. */
                    public region?: (string|null);

                    /** Operation selfLink. */
                    public selfLink?: (string|null);

                    /** Operation startTime. */
                    public startTime?: (string|null);

                    /** Operation status. */
                    public status?: (google.cloud.compute.v1.Operation.Status|keyof typeof google.cloud.compute.v1.Operation.Status|null);

                    /** Operation statusMessage. */
                    public statusMessage?: (string|null);

                    /** Operation targetId. */
                    public targetId?: (number|Long|string|null);

                    /** Operation targetLink. */
                    public targetLink?: (string|null);

                    /** Operation user. */
                    public user?: (string|null);

                    /** Operation warnings. */
                    public warnings: google.cloud.compute.v1.IWarnings[];

                    /** Operation zone. */
                    public zone?: (string|null);

                    /** Operation _clientOperationId. */
                    public _clientOperationId?: "clientOperationId";

                    /** Operation _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Operation _description. */
                    public _description?: "description";

                    /** Operation _endTime. */
                    public _endTime?: "endTime";

                    /** Operation _error. */
                    public _error?: "error";

                    /** Operation _httpErrorMessage. */
                    public _httpErrorMessage?: "httpErrorMessage";

                    /** Operation _httpErrorStatusCode. */
                    public _httpErrorStatusCode?: "httpErrorStatusCode";

                    /** Operation _id. */
                    public _id?: "id";

                    /** Operation _insertTime. */
                    public _insertTime?: "insertTime";

                    /** Operation _kind. */
                    public _kind?: "kind";

                    /** Operation _name. */
                    public _name?: "name";

                    /** Operation _operationGroupId. */
                    public _operationGroupId?: "operationGroupId";

                    /** Operation _operationType. */
                    public _operationType?: "operationType";

                    /** Operation _progress. */
                    public _progress?: "progress";

                    /** Operation _region. */
                    public _region?: "region";

                    /** Operation _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Operation _startTime. */
                    public _startTime?: "startTime";

                    /** Operation _status. */
                    public _status?: "status";

                    /** Operation _statusMessage. */
                    public _statusMessage?: "statusMessage";

                    /** Operation _targetId. */
                    public _targetId?: "targetId";

                    /** Operation _targetLink. */
                    public _targetLink?: "targetLink";

                    /** Operation _user. */
                    public _user?: "user";

                    /** Operation _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new Operation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Operation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IOperation): google.cloud.compute.v1.Operation;

                    /**
                     * Encodes the specified Operation message. Does not implicitly {@link google.cloud.compute.v1.Operation.verify|verify} messages.
                     * @param message Operation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IOperation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Operation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Operation.verify|verify} messages.
                     * @param message Operation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IOperation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Operation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Operation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Operation;

                    /**
                     * Decodes an Operation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Operation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Operation;

                    /**
                     * Verifies an Operation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Operation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Operation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Operation;

                    /**
                     * Creates a plain object from an Operation message. Also converts values to other types if specified.
                     * @param message Operation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Operation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Operation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Operation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Operation {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DONE = 2104194,
                        PENDING = 35394935,
                        RUNNING = 121282975
                    }
                }

                /** Properties of an OperationAggregatedList. */
                interface IOperationAggregatedList {

                    /** OperationAggregatedList id */
                    id?: (string|null);

                    /** OperationAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IOperationsScopedList }|null);

                    /** OperationAggregatedList kind */
                    kind?: (string|null);

                    /** OperationAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** OperationAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** OperationAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** OperationAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an OperationAggregatedList. */
                class OperationAggregatedList implements IOperationAggregatedList {

                    /**
                     * Constructs a new OperationAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IOperationAggregatedList);

                    /** OperationAggregatedList id. */
                    public id?: (string|null);

                    /** OperationAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IOperationsScopedList };

                    /** OperationAggregatedList kind. */
                    public kind?: (string|null);

                    /** OperationAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** OperationAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** OperationAggregatedList unreachables. */
                    public unreachables: string[];

                    /** OperationAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** OperationAggregatedList _id. */
                    public _id?: "id";

                    /** OperationAggregatedList _kind. */
                    public _kind?: "kind";

                    /** OperationAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** OperationAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** OperationAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new OperationAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OperationAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IOperationAggregatedList): google.cloud.compute.v1.OperationAggregatedList;

                    /**
                     * Encodes the specified OperationAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.OperationAggregatedList.verify|verify} messages.
                     * @param message OperationAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IOperationAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OperationAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.OperationAggregatedList.verify|verify} messages.
                     * @param message OperationAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IOperationAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OperationAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OperationAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.OperationAggregatedList;

                    /**
                     * Decodes an OperationAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OperationAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.OperationAggregatedList;

                    /**
                     * Verifies an OperationAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OperationAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OperationAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.OperationAggregatedList;

                    /**
                     * Creates a plain object from an OperationAggregatedList message. Also converts values to other types if specified.
                     * @param message OperationAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.OperationAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OperationAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OperationAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OperationList. */
                interface IOperationList {

                    /** OperationList id */
                    id?: (string|null);

                    /** OperationList items */
                    items?: (google.cloud.compute.v1.IOperation[]|null);

                    /** OperationList kind */
                    kind?: (string|null);

                    /** OperationList nextPageToken */
                    nextPageToken?: (string|null);

                    /** OperationList selfLink */
                    selfLink?: (string|null);

                    /** OperationList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an OperationList. */
                class OperationList implements IOperationList {

                    /**
                     * Constructs a new OperationList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IOperationList);

                    /** OperationList id. */
                    public id?: (string|null);

                    /** OperationList items. */
                    public items: google.cloud.compute.v1.IOperation[];

                    /** OperationList kind. */
                    public kind?: (string|null);

                    /** OperationList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** OperationList selfLink. */
                    public selfLink?: (string|null);

                    /** OperationList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** OperationList _id. */
                    public _id?: "id";

                    /** OperationList _kind. */
                    public _kind?: "kind";

                    /** OperationList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** OperationList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** OperationList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new OperationList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OperationList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IOperationList): google.cloud.compute.v1.OperationList;

                    /**
                     * Encodes the specified OperationList message. Does not implicitly {@link google.cloud.compute.v1.OperationList.verify|verify} messages.
                     * @param message OperationList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IOperationList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OperationList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.OperationList.verify|verify} messages.
                     * @param message OperationList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IOperationList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OperationList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OperationList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.OperationList;

                    /**
                     * Decodes an OperationList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OperationList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.OperationList;

                    /**
                     * Verifies an OperationList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OperationList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OperationList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.OperationList;

                    /**
                     * Creates a plain object from an OperationList message. Also converts values to other types if specified.
                     * @param message OperationList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.OperationList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OperationList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OperationList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OperationsScopedList. */
                interface IOperationsScopedList {

                    /** OperationsScopedList operations */
                    operations?: (google.cloud.compute.v1.IOperation[]|null);

                    /** OperationsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an OperationsScopedList. */
                class OperationsScopedList implements IOperationsScopedList {

                    /**
                     * Constructs a new OperationsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IOperationsScopedList);

                    /** OperationsScopedList operations. */
                    public operations: google.cloud.compute.v1.IOperation[];

                    /** OperationsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** OperationsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new OperationsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OperationsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IOperationsScopedList): google.cloud.compute.v1.OperationsScopedList;

                    /**
                     * Encodes the specified OperationsScopedList message. Does not implicitly {@link google.cloud.compute.v1.OperationsScopedList.verify|verify} messages.
                     * @param message OperationsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IOperationsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OperationsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.OperationsScopedList.verify|verify} messages.
                     * @param message OperationsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IOperationsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OperationsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OperationsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.OperationsScopedList;

                    /**
                     * Decodes an OperationsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OperationsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.OperationsScopedList;

                    /**
                     * Verifies an OperationsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OperationsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OperationsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.OperationsScopedList;

                    /**
                     * Creates a plain object from an OperationsScopedList message. Also converts values to other types if specified.
                     * @param message OperationsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.OperationsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OperationsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OperationsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OutlierDetection. */
                interface IOutlierDetection {

                    /** OutlierDetection baseEjectionTime */
                    baseEjectionTime?: (google.cloud.compute.v1.IDuration|null);

                    /** OutlierDetection consecutiveErrors */
                    consecutiveErrors?: (number|null);

                    /** OutlierDetection consecutiveGatewayFailure */
                    consecutiveGatewayFailure?: (number|null);

                    /** OutlierDetection enforcingConsecutiveErrors */
                    enforcingConsecutiveErrors?: (number|null);

                    /** OutlierDetection enforcingConsecutiveGatewayFailure */
                    enforcingConsecutiveGatewayFailure?: (number|null);

                    /** OutlierDetection enforcingSuccessRate */
                    enforcingSuccessRate?: (number|null);

                    /** OutlierDetection interval */
                    interval?: (google.cloud.compute.v1.IDuration|null);

                    /** OutlierDetection maxEjectionPercent */
                    maxEjectionPercent?: (number|null);

                    /** OutlierDetection successRateMinimumHosts */
                    successRateMinimumHosts?: (number|null);

                    /** OutlierDetection successRateRequestVolume */
                    successRateRequestVolume?: (number|null);

                    /** OutlierDetection successRateStdevFactor */
                    successRateStdevFactor?: (number|null);
                }

                /** Represents an OutlierDetection. */
                class OutlierDetection implements IOutlierDetection {

                    /**
                     * Constructs a new OutlierDetection.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IOutlierDetection);

                    /** OutlierDetection baseEjectionTime. */
                    public baseEjectionTime?: (google.cloud.compute.v1.IDuration|null);

                    /** OutlierDetection consecutiveErrors. */
                    public consecutiveErrors?: (number|null);

                    /** OutlierDetection consecutiveGatewayFailure. */
                    public consecutiveGatewayFailure?: (number|null);

                    /** OutlierDetection enforcingConsecutiveErrors. */
                    public enforcingConsecutiveErrors?: (number|null);

                    /** OutlierDetection enforcingConsecutiveGatewayFailure. */
                    public enforcingConsecutiveGatewayFailure?: (number|null);

                    /** OutlierDetection enforcingSuccessRate. */
                    public enforcingSuccessRate?: (number|null);

                    /** OutlierDetection interval. */
                    public interval?: (google.cloud.compute.v1.IDuration|null);

                    /** OutlierDetection maxEjectionPercent. */
                    public maxEjectionPercent?: (number|null);

                    /** OutlierDetection successRateMinimumHosts. */
                    public successRateMinimumHosts?: (number|null);

                    /** OutlierDetection successRateRequestVolume. */
                    public successRateRequestVolume?: (number|null);

                    /** OutlierDetection successRateStdevFactor. */
                    public successRateStdevFactor?: (number|null);

                    /** OutlierDetection _baseEjectionTime. */
                    public _baseEjectionTime?: "baseEjectionTime";

                    /** OutlierDetection _consecutiveErrors. */
                    public _consecutiveErrors?: "consecutiveErrors";

                    /** OutlierDetection _consecutiveGatewayFailure. */
                    public _consecutiveGatewayFailure?: "consecutiveGatewayFailure";

                    /** OutlierDetection _enforcingConsecutiveErrors. */
                    public _enforcingConsecutiveErrors?: "enforcingConsecutiveErrors";

                    /** OutlierDetection _enforcingConsecutiveGatewayFailure. */
                    public _enforcingConsecutiveGatewayFailure?: "enforcingConsecutiveGatewayFailure";

                    /** OutlierDetection _enforcingSuccessRate. */
                    public _enforcingSuccessRate?: "enforcingSuccessRate";

                    /** OutlierDetection _interval. */
                    public _interval?: "interval";

                    /** OutlierDetection _maxEjectionPercent. */
                    public _maxEjectionPercent?: "maxEjectionPercent";

                    /** OutlierDetection _successRateMinimumHosts. */
                    public _successRateMinimumHosts?: "successRateMinimumHosts";

                    /** OutlierDetection _successRateRequestVolume. */
                    public _successRateRequestVolume?: "successRateRequestVolume";

                    /** OutlierDetection _successRateStdevFactor. */
                    public _successRateStdevFactor?: "successRateStdevFactor";

                    /**
                     * Creates a new OutlierDetection instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OutlierDetection instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IOutlierDetection): google.cloud.compute.v1.OutlierDetection;

                    /**
                     * Encodes the specified OutlierDetection message. Does not implicitly {@link google.cloud.compute.v1.OutlierDetection.verify|verify} messages.
                     * @param message OutlierDetection message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IOutlierDetection, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OutlierDetection message, length delimited. Does not implicitly {@link google.cloud.compute.v1.OutlierDetection.verify|verify} messages.
                     * @param message OutlierDetection message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IOutlierDetection, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OutlierDetection message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OutlierDetection
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.OutlierDetection;

                    /**
                     * Decodes an OutlierDetection message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OutlierDetection
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.OutlierDetection;

                    /**
                     * Verifies an OutlierDetection message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OutlierDetection message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OutlierDetection
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.OutlierDetection;

                    /**
                     * Creates a plain object from an OutlierDetection message. Also converts values to other types if specified.
                     * @param message OutlierDetection
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.OutlierDetection, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OutlierDetection to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OutlierDetection
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketIntervals. */
                interface IPacketIntervals {

                    /** PacketIntervals avgMs */
                    avgMs?: (number|Long|string|null);

                    /** PacketIntervals duration */
                    duration?: (string|null);

                    /** PacketIntervals maxMs */
                    maxMs?: (number|Long|string|null);

                    /** PacketIntervals minMs */
                    minMs?: (number|Long|string|null);

                    /** PacketIntervals numIntervals */
                    numIntervals?: (number|Long|string|null);

                    /** PacketIntervals type */
                    type?: (string|null);
                }

                /** Represents a PacketIntervals. */
                class PacketIntervals implements IPacketIntervals {

                    /**
                     * Constructs a new PacketIntervals.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketIntervals);

                    /** PacketIntervals avgMs. */
                    public avgMs?: (number|Long|string|null);

                    /** PacketIntervals duration. */
                    public duration?: (string|null);

                    /** PacketIntervals maxMs. */
                    public maxMs?: (number|Long|string|null);

                    /** PacketIntervals minMs. */
                    public minMs?: (number|Long|string|null);

                    /** PacketIntervals numIntervals. */
                    public numIntervals?: (number|Long|string|null);

                    /** PacketIntervals type. */
                    public type?: (string|null);

                    /** PacketIntervals _avgMs. */
                    public _avgMs?: "avgMs";

                    /** PacketIntervals _duration. */
                    public _duration?: "duration";

                    /** PacketIntervals _maxMs. */
                    public _maxMs?: "maxMs";

                    /** PacketIntervals _minMs. */
                    public _minMs?: "minMs";

                    /** PacketIntervals _numIntervals. */
                    public _numIntervals?: "numIntervals";

                    /** PacketIntervals _type. */
                    public _type?: "type";

                    /**
                     * Creates a new PacketIntervals instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketIntervals instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketIntervals): google.cloud.compute.v1.PacketIntervals;

                    /**
                     * Encodes the specified PacketIntervals message. Does not implicitly {@link google.cloud.compute.v1.PacketIntervals.verify|verify} messages.
                     * @param message PacketIntervals message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketIntervals, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketIntervals message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketIntervals.verify|verify} messages.
                     * @param message PacketIntervals message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketIntervals, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketIntervals message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketIntervals
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketIntervals;

                    /**
                     * Decodes a PacketIntervals message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketIntervals
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketIntervals;

                    /**
                     * Verifies a PacketIntervals message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketIntervals message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketIntervals
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketIntervals;

                    /**
                     * Creates a plain object from a PacketIntervals message. Also converts values to other types if specified.
                     * @param message PacketIntervals
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketIntervals, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketIntervals to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketIntervals
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PacketIntervals {

                    /** Duration enum. */
                    enum Duration {
                        UNDEFINED_DURATION = 0,
                        DURATION_UNSPECIFIED = 529071340,
                        HOUR = 2223588,
                        MAX = 76100,
                        MINUTE = 126786068
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        LOOPBACK = 356174219,
                        RECEIVE = 189660867,
                        TRANSMIT = 452903600,
                        TYPE_UNSPECIFIED = 437714322
                    }
                }

                /** Properties of a PacketMirroring. */
                interface IPacketMirroring {

                    /** PacketMirroring collectorIlb */
                    collectorIlb?: (google.cloud.compute.v1.IPacketMirroringForwardingRuleInfo|null);

                    /** PacketMirroring creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** PacketMirroring description */
                    description?: (string|null);

                    /** PacketMirroring enable */
                    enable?: (string|null);

                    /** PacketMirroring filter */
                    filter?: (google.cloud.compute.v1.IPacketMirroringFilter|null);

                    /** PacketMirroring id */
                    id?: (number|Long|string|null);

                    /** PacketMirroring kind */
                    kind?: (string|null);

                    /** PacketMirroring mirroredResources */
                    mirroredResources?: (google.cloud.compute.v1.IPacketMirroringMirroredResourceInfo|null);

                    /** PacketMirroring name */
                    name?: (string|null);

                    /** PacketMirroring network */
                    network?: (google.cloud.compute.v1.IPacketMirroringNetworkInfo|null);

                    /** PacketMirroring priority */
                    priority?: (number|null);

                    /** PacketMirroring region */
                    region?: (string|null);

                    /** PacketMirroring selfLink */
                    selfLink?: (string|null);
                }

                /** Represents a PacketMirroring. */
                class PacketMirroring implements IPacketMirroring {

                    /**
                     * Constructs a new PacketMirroring.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroring);

                    /** PacketMirroring collectorIlb. */
                    public collectorIlb?: (google.cloud.compute.v1.IPacketMirroringForwardingRuleInfo|null);

                    /** PacketMirroring creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** PacketMirroring description. */
                    public description?: (string|null);

                    /** PacketMirroring enable. */
                    public enable?: (string|null);

                    /** PacketMirroring filter. */
                    public filter?: (google.cloud.compute.v1.IPacketMirroringFilter|null);

                    /** PacketMirroring id. */
                    public id?: (number|Long|string|null);

                    /** PacketMirroring kind. */
                    public kind?: (string|null);

                    /** PacketMirroring mirroredResources. */
                    public mirroredResources?: (google.cloud.compute.v1.IPacketMirroringMirroredResourceInfo|null);

                    /** PacketMirroring name. */
                    public name?: (string|null);

                    /** PacketMirroring network. */
                    public network?: (google.cloud.compute.v1.IPacketMirroringNetworkInfo|null);

                    /** PacketMirroring priority. */
                    public priority?: (number|null);

                    /** PacketMirroring region. */
                    public region?: (string|null);

                    /** PacketMirroring selfLink. */
                    public selfLink?: (string|null);

                    /** PacketMirroring _collectorIlb. */
                    public _collectorIlb?: "collectorIlb";

                    /** PacketMirroring _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** PacketMirroring _description. */
                    public _description?: "description";

                    /** PacketMirroring _enable. */
                    public _enable?: "enable";

                    /** PacketMirroring _filter. */
                    public _filter?: "filter";

                    /** PacketMirroring _id. */
                    public _id?: "id";

                    /** PacketMirroring _kind. */
                    public _kind?: "kind";

                    /** PacketMirroring _mirroredResources. */
                    public _mirroredResources?: "mirroredResources";

                    /** PacketMirroring _name. */
                    public _name?: "name";

                    /** PacketMirroring _network. */
                    public _network?: "network";

                    /** PacketMirroring _priority. */
                    public _priority?: "priority";

                    /** PacketMirroring _region. */
                    public _region?: "region";

                    /** PacketMirroring _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new PacketMirroring instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroring instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroring): google.cloud.compute.v1.PacketMirroring;

                    /**
                     * Encodes the specified PacketMirroring message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroring.verify|verify} messages.
                     * @param message PacketMirroring message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroring, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroring message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroring.verify|verify} messages.
                     * @param message PacketMirroring message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroring, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroring message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroring
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroring;

                    /**
                     * Decodes a PacketMirroring message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroring
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroring;

                    /**
                     * Verifies a PacketMirroring message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroring message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroring
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroring;

                    /**
                     * Creates a plain object from a PacketMirroring message. Also converts values to other types if specified.
                     * @param message PacketMirroring
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroring, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroring to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroring
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PacketMirroring {

                    /** Enable enum. */
                    enum Enable {
                        UNDEFINED_ENABLE = 0,
                        FALSE = 66658563,
                        TRUE = 2583950
                    }
                }

                /** Properties of a PacketMirroringAggregatedList. */
                interface IPacketMirroringAggregatedList {

                    /** PacketMirroringAggregatedList id */
                    id?: (string|null);

                    /** PacketMirroringAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IPacketMirroringsScopedList }|null);

                    /** PacketMirroringAggregatedList kind */
                    kind?: (string|null);

                    /** PacketMirroringAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** PacketMirroringAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** PacketMirroringAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** PacketMirroringAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PacketMirroringAggregatedList. */
                class PacketMirroringAggregatedList implements IPacketMirroringAggregatedList {

                    /**
                     * Constructs a new PacketMirroringAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringAggregatedList);

                    /** PacketMirroringAggregatedList id. */
                    public id?: (string|null);

                    /** PacketMirroringAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IPacketMirroringsScopedList };

                    /** PacketMirroringAggregatedList kind. */
                    public kind?: (string|null);

                    /** PacketMirroringAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** PacketMirroringAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** PacketMirroringAggregatedList unreachables. */
                    public unreachables: string[];

                    /** PacketMirroringAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PacketMirroringAggregatedList _id. */
                    public _id?: "id";

                    /** PacketMirroringAggregatedList _kind. */
                    public _kind?: "kind";

                    /** PacketMirroringAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** PacketMirroringAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PacketMirroringAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PacketMirroringAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringAggregatedList): google.cloud.compute.v1.PacketMirroringAggregatedList;

                    /**
                     * Encodes the specified PacketMirroringAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringAggregatedList.verify|verify} messages.
                     * @param message PacketMirroringAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringAggregatedList.verify|verify} messages.
                     * @param message PacketMirroringAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringAggregatedList;

                    /**
                     * Decodes a PacketMirroringAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringAggregatedList;

                    /**
                     * Verifies a PacketMirroringAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringAggregatedList;

                    /**
                     * Creates a plain object from a PacketMirroringAggregatedList message. Also converts values to other types if specified.
                     * @param message PacketMirroringAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringFilter. */
                interface IPacketMirroringFilter {

                    /** PacketMirroringFilter IPProtocols */
                    IPProtocols?: (string[]|null);

                    /** PacketMirroringFilter cidrRanges */
                    cidrRanges?: (string[]|null);

                    /** PacketMirroringFilter direction */
                    direction?: (string|null);
                }

                /** Represents a PacketMirroringFilter. */
                class PacketMirroringFilter implements IPacketMirroringFilter {

                    /**
                     * Constructs a new PacketMirroringFilter.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringFilter);

                    /** PacketMirroringFilter IPProtocols. */
                    public IPProtocols: string[];

                    /** PacketMirroringFilter cidrRanges. */
                    public cidrRanges: string[];

                    /** PacketMirroringFilter direction. */
                    public direction?: (string|null);

                    /** PacketMirroringFilter _direction. */
                    public _direction?: "direction";

                    /**
                     * Creates a new PacketMirroringFilter instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringFilter instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringFilter): google.cloud.compute.v1.PacketMirroringFilter;

                    /**
                     * Encodes the specified PacketMirroringFilter message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringFilter.verify|verify} messages.
                     * @param message PacketMirroringFilter message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringFilter, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringFilter message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringFilter.verify|verify} messages.
                     * @param message PacketMirroringFilter message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringFilter, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringFilter message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringFilter
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringFilter;

                    /**
                     * Decodes a PacketMirroringFilter message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringFilter
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringFilter;

                    /**
                     * Verifies a PacketMirroringFilter message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringFilter message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringFilter
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringFilter;

                    /**
                     * Creates a plain object from a PacketMirroringFilter message. Also converts values to other types if specified.
                     * @param message PacketMirroringFilter
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringFilter, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringFilter to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringFilter
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PacketMirroringFilter {

                    /** Direction enum. */
                    enum Direction {
                        UNDEFINED_DIRECTION = 0,
                        BOTH = 2044801,
                        EGRESS = 432880501,
                        INGRESS = 516931221
                    }
                }

                /** Properties of a PacketMirroringForwardingRuleInfo. */
                interface IPacketMirroringForwardingRuleInfo {

                    /** PacketMirroringForwardingRuleInfo canonicalUrl */
                    canonicalUrl?: (string|null);

                    /** PacketMirroringForwardingRuleInfo url */
                    url?: (string|null);
                }

                /** Represents a PacketMirroringForwardingRuleInfo. */
                class PacketMirroringForwardingRuleInfo implements IPacketMirroringForwardingRuleInfo {

                    /**
                     * Constructs a new PacketMirroringForwardingRuleInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringForwardingRuleInfo);

                    /** PacketMirroringForwardingRuleInfo canonicalUrl. */
                    public canonicalUrl?: (string|null);

                    /** PacketMirroringForwardingRuleInfo url. */
                    public url?: (string|null);

                    /** PacketMirroringForwardingRuleInfo _canonicalUrl. */
                    public _canonicalUrl?: "canonicalUrl";

                    /** PacketMirroringForwardingRuleInfo _url. */
                    public _url?: "url";

                    /**
                     * Creates a new PacketMirroringForwardingRuleInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringForwardingRuleInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringForwardingRuleInfo): google.cloud.compute.v1.PacketMirroringForwardingRuleInfo;

                    /**
                     * Encodes the specified PacketMirroringForwardingRuleInfo message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringForwardingRuleInfo.verify|verify} messages.
                     * @param message PacketMirroringForwardingRuleInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringForwardingRuleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringForwardingRuleInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringForwardingRuleInfo.verify|verify} messages.
                     * @param message PacketMirroringForwardingRuleInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringForwardingRuleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringForwardingRuleInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringForwardingRuleInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringForwardingRuleInfo;

                    /**
                     * Decodes a PacketMirroringForwardingRuleInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringForwardingRuleInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringForwardingRuleInfo;

                    /**
                     * Verifies a PacketMirroringForwardingRuleInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringForwardingRuleInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringForwardingRuleInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringForwardingRuleInfo;

                    /**
                     * Creates a plain object from a PacketMirroringForwardingRuleInfo message. Also converts values to other types if specified.
                     * @param message PacketMirroringForwardingRuleInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringForwardingRuleInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringForwardingRuleInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringForwardingRuleInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringList. */
                interface IPacketMirroringList {

                    /** PacketMirroringList id */
                    id?: (string|null);

                    /** PacketMirroringList items */
                    items?: (google.cloud.compute.v1.IPacketMirroring[]|null);

                    /** PacketMirroringList kind */
                    kind?: (string|null);

                    /** PacketMirroringList nextPageToken */
                    nextPageToken?: (string|null);

                    /** PacketMirroringList selfLink */
                    selfLink?: (string|null);

                    /** PacketMirroringList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PacketMirroringList. */
                class PacketMirroringList implements IPacketMirroringList {

                    /**
                     * Constructs a new PacketMirroringList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringList);

                    /** PacketMirroringList id. */
                    public id?: (string|null);

                    /** PacketMirroringList items. */
                    public items: google.cloud.compute.v1.IPacketMirroring[];

                    /** PacketMirroringList kind. */
                    public kind?: (string|null);

                    /** PacketMirroringList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** PacketMirroringList selfLink. */
                    public selfLink?: (string|null);

                    /** PacketMirroringList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PacketMirroringList _id. */
                    public _id?: "id";

                    /** PacketMirroringList _kind. */
                    public _kind?: "kind";

                    /** PacketMirroringList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** PacketMirroringList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PacketMirroringList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PacketMirroringList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringList): google.cloud.compute.v1.PacketMirroringList;

                    /**
                     * Encodes the specified PacketMirroringList message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringList.verify|verify} messages.
                     * @param message PacketMirroringList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringList.verify|verify} messages.
                     * @param message PacketMirroringList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringList;

                    /**
                     * Decodes a PacketMirroringList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringList;

                    /**
                     * Verifies a PacketMirroringList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringList;

                    /**
                     * Creates a plain object from a PacketMirroringList message. Also converts values to other types if specified.
                     * @param message PacketMirroringList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringMirroredResourceInfo. */
                interface IPacketMirroringMirroredResourceInfo {

                    /** PacketMirroringMirroredResourceInfo instances */
                    instances?: (google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoInstanceInfo[]|null);

                    /** PacketMirroringMirroredResourceInfo subnetworks */
                    subnetworks?: (google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoSubnetInfo[]|null);

                    /** PacketMirroringMirroredResourceInfo tags */
                    tags?: (string[]|null);
                }

                /** Represents a PacketMirroringMirroredResourceInfo. */
                class PacketMirroringMirroredResourceInfo implements IPacketMirroringMirroredResourceInfo {

                    /**
                     * Constructs a new PacketMirroringMirroredResourceInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfo);

                    /** PacketMirroringMirroredResourceInfo instances. */
                    public instances: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoInstanceInfo[];

                    /** PacketMirroringMirroredResourceInfo subnetworks. */
                    public subnetworks: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoSubnetInfo[];

                    /** PacketMirroringMirroredResourceInfo tags. */
                    public tags: string[];

                    /**
                     * Creates a new PacketMirroringMirroredResourceInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringMirroredResourceInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfo): google.cloud.compute.v1.PacketMirroringMirroredResourceInfo;

                    /**
                     * Encodes the specified PacketMirroringMirroredResourceInfo message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringMirroredResourceInfo.verify|verify} messages.
                     * @param message PacketMirroringMirroredResourceInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringMirroredResourceInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringMirroredResourceInfo.verify|verify} messages.
                     * @param message PacketMirroringMirroredResourceInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringMirroredResourceInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringMirroredResourceInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringMirroredResourceInfo;

                    /**
                     * Decodes a PacketMirroringMirroredResourceInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringMirroredResourceInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringMirroredResourceInfo;

                    /**
                     * Verifies a PacketMirroringMirroredResourceInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringMirroredResourceInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringMirroredResourceInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringMirroredResourceInfo;

                    /**
                     * Creates a plain object from a PacketMirroringMirroredResourceInfo message. Also converts values to other types if specified.
                     * @param message PacketMirroringMirroredResourceInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringMirroredResourceInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringMirroredResourceInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringMirroredResourceInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringMirroredResourceInfoInstanceInfo. */
                interface IPacketMirroringMirroredResourceInfoInstanceInfo {

                    /** PacketMirroringMirroredResourceInfoInstanceInfo canonicalUrl */
                    canonicalUrl?: (string|null);

                    /** PacketMirroringMirroredResourceInfoInstanceInfo url */
                    url?: (string|null);
                }

                /** Represents a PacketMirroringMirroredResourceInfoInstanceInfo. */
                class PacketMirroringMirroredResourceInfoInstanceInfo implements IPacketMirroringMirroredResourceInfoInstanceInfo {

                    /**
                     * Constructs a new PacketMirroringMirroredResourceInfoInstanceInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoInstanceInfo);

                    /** PacketMirroringMirroredResourceInfoInstanceInfo canonicalUrl. */
                    public canonicalUrl?: (string|null);

                    /** PacketMirroringMirroredResourceInfoInstanceInfo url. */
                    public url?: (string|null);

                    /** PacketMirroringMirroredResourceInfoInstanceInfo _canonicalUrl. */
                    public _canonicalUrl?: "canonicalUrl";

                    /** PacketMirroringMirroredResourceInfoInstanceInfo _url. */
                    public _url?: "url";

                    /**
                     * Creates a new PacketMirroringMirroredResourceInfoInstanceInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringMirroredResourceInfoInstanceInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoInstanceInfo): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo;

                    /**
                     * Encodes the specified PacketMirroringMirroredResourceInfoInstanceInfo message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo.verify|verify} messages.
                     * @param message PacketMirroringMirroredResourceInfoInstanceInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoInstanceInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringMirroredResourceInfoInstanceInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo.verify|verify} messages.
                     * @param message PacketMirroringMirroredResourceInfoInstanceInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoInstanceInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringMirroredResourceInfoInstanceInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringMirroredResourceInfoInstanceInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo;

                    /**
                     * Decodes a PacketMirroringMirroredResourceInfoInstanceInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringMirroredResourceInfoInstanceInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo;

                    /**
                     * Verifies a PacketMirroringMirroredResourceInfoInstanceInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringMirroredResourceInfoInstanceInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringMirroredResourceInfoInstanceInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo;

                    /**
                     * Creates a plain object from a PacketMirroringMirroredResourceInfoInstanceInfo message. Also converts values to other types if specified.
                     * @param message PacketMirroringMirroredResourceInfoInstanceInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringMirroredResourceInfoInstanceInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringMirroredResourceInfoInstanceInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringMirroredResourceInfoInstanceInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringMirroredResourceInfoSubnetInfo. */
                interface IPacketMirroringMirroredResourceInfoSubnetInfo {

                    /** PacketMirroringMirroredResourceInfoSubnetInfo canonicalUrl */
                    canonicalUrl?: (string|null);

                    /** PacketMirroringMirroredResourceInfoSubnetInfo url */
                    url?: (string|null);
                }

                /** Represents a PacketMirroringMirroredResourceInfoSubnetInfo. */
                class PacketMirroringMirroredResourceInfoSubnetInfo implements IPacketMirroringMirroredResourceInfoSubnetInfo {

                    /**
                     * Constructs a new PacketMirroringMirroredResourceInfoSubnetInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoSubnetInfo);

                    /** PacketMirroringMirroredResourceInfoSubnetInfo canonicalUrl. */
                    public canonicalUrl?: (string|null);

                    /** PacketMirroringMirroredResourceInfoSubnetInfo url. */
                    public url?: (string|null);

                    /** PacketMirroringMirroredResourceInfoSubnetInfo _canonicalUrl. */
                    public _canonicalUrl?: "canonicalUrl";

                    /** PacketMirroringMirroredResourceInfoSubnetInfo _url. */
                    public _url?: "url";

                    /**
                     * Creates a new PacketMirroringMirroredResourceInfoSubnetInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringMirroredResourceInfoSubnetInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoSubnetInfo): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo;

                    /**
                     * Encodes the specified PacketMirroringMirroredResourceInfoSubnetInfo message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo.verify|verify} messages.
                     * @param message PacketMirroringMirroredResourceInfoSubnetInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoSubnetInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringMirroredResourceInfoSubnetInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo.verify|verify} messages.
                     * @param message PacketMirroringMirroredResourceInfoSubnetInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringMirroredResourceInfoSubnetInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringMirroredResourceInfoSubnetInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringMirroredResourceInfoSubnetInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo;

                    /**
                     * Decodes a PacketMirroringMirroredResourceInfoSubnetInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringMirroredResourceInfoSubnetInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo;

                    /**
                     * Verifies a PacketMirroringMirroredResourceInfoSubnetInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringMirroredResourceInfoSubnetInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringMirroredResourceInfoSubnetInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo;

                    /**
                     * Creates a plain object from a PacketMirroringMirroredResourceInfoSubnetInfo message. Also converts values to other types if specified.
                     * @param message PacketMirroringMirroredResourceInfoSubnetInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringMirroredResourceInfoSubnetInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringMirroredResourceInfoSubnetInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringMirroredResourceInfoSubnetInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringNetworkInfo. */
                interface IPacketMirroringNetworkInfo {

                    /** PacketMirroringNetworkInfo canonicalUrl */
                    canonicalUrl?: (string|null);

                    /** PacketMirroringNetworkInfo url */
                    url?: (string|null);
                }

                /** Represents a PacketMirroringNetworkInfo. */
                class PacketMirroringNetworkInfo implements IPacketMirroringNetworkInfo {

                    /**
                     * Constructs a new PacketMirroringNetworkInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringNetworkInfo);

                    /** PacketMirroringNetworkInfo canonicalUrl. */
                    public canonicalUrl?: (string|null);

                    /** PacketMirroringNetworkInfo url. */
                    public url?: (string|null);

                    /** PacketMirroringNetworkInfo _canonicalUrl. */
                    public _canonicalUrl?: "canonicalUrl";

                    /** PacketMirroringNetworkInfo _url. */
                    public _url?: "url";

                    /**
                     * Creates a new PacketMirroringNetworkInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringNetworkInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringNetworkInfo): google.cloud.compute.v1.PacketMirroringNetworkInfo;

                    /**
                     * Encodes the specified PacketMirroringNetworkInfo message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringNetworkInfo.verify|verify} messages.
                     * @param message PacketMirroringNetworkInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringNetworkInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringNetworkInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringNetworkInfo.verify|verify} messages.
                     * @param message PacketMirroringNetworkInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringNetworkInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringNetworkInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringNetworkInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringNetworkInfo;

                    /**
                     * Decodes a PacketMirroringNetworkInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringNetworkInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringNetworkInfo;

                    /**
                     * Verifies a PacketMirroringNetworkInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringNetworkInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringNetworkInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringNetworkInfo;

                    /**
                     * Creates a plain object from a PacketMirroringNetworkInfo message. Also converts values to other types if specified.
                     * @param message PacketMirroringNetworkInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringNetworkInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringNetworkInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringNetworkInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PacketMirroringsScopedList. */
                interface IPacketMirroringsScopedList {

                    /** PacketMirroringsScopedList packetMirrorings */
                    packetMirrorings?: (google.cloud.compute.v1.IPacketMirroring[]|null);

                    /** PacketMirroringsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PacketMirroringsScopedList. */
                class PacketMirroringsScopedList implements IPacketMirroringsScopedList {

                    /**
                     * Constructs a new PacketMirroringsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPacketMirroringsScopedList);

                    /** PacketMirroringsScopedList packetMirrorings. */
                    public packetMirrorings: google.cloud.compute.v1.IPacketMirroring[];

                    /** PacketMirroringsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PacketMirroringsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PacketMirroringsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PacketMirroringsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPacketMirroringsScopedList): google.cloud.compute.v1.PacketMirroringsScopedList;

                    /**
                     * Encodes the specified PacketMirroringsScopedList message. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringsScopedList.verify|verify} messages.
                     * @param message PacketMirroringsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPacketMirroringsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PacketMirroringsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PacketMirroringsScopedList.verify|verify} messages.
                     * @param message PacketMirroringsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPacketMirroringsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PacketMirroringsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PacketMirroringsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PacketMirroringsScopedList;

                    /**
                     * Decodes a PacketMirroringsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PacketMirroringsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PacketMirroringsScopedList;

                    /**
                     * Verifies a PacketMirroringsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PacketMirroringsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PacketMirroringsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PacketMirroringsScopedList;

                    /**
                     * Creates a plain object from a PacketMirroringsScopedList message. Also converts values to other types if specified.
                     * @param message PacketMirroringsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PacketMirroringsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PacketMirroringsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PacketMirroringsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchAutoscalerRequest. */
                interface IPatchAutoscalerRequest {

                    /** PatchAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** PatchAutoscalerRequest autoscalerResource */
                    autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** PatchAutoscalerRequest project */
                    project?: (string|null);

                    /** PatchAutoscalerRequest requestId */
                    requestId?: (string|null);

                    /** PatchAutoscalerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a PatchAutoscalerRequest. */
                class PatchAutoscalerRequest implements IPatchAutoscalerRequest {

                    /**
                     * Constructs a new PatchAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchAutoscalerRequest);

                    /** PatchAutoscalerRequest autoscaler. */
                    public autoscaler?: (string|null);

                    /** PatchAutoscalerRequest autoscalerResource. */
                    public autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** PatchAutoscalerRequest project. */
                    public project: string;

                    /** PatchAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchAutoscalerRequest zone. */
                    public zone: string;

                    /** PatchAutoscalerRequest _autoscaler. */
                    public _autoscaler?: "autoscaler";

                    /** PatchAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchAutoscalerRequest): google.cloud.compute.v1.PatchAutoscalerRequest;

                    /**
                     * Encodes the specified PatchAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchAutoscalerRequest.verify|verify} messages.
                     * @param message PatchAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchAutoscalerRequest.verify|verify} messages.
                     * @param message PatchAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchAutoscalerRequest;

                    /**
                     * Decodes a PatchAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchAutoscalerRequest;

                    /**
                     * Verifies a PatchAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchAutoscalerRequest;

                    /**
                     * Creates a plain object from a PatchAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message PatchAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchBackendBucketRequest. */
                interface IPatchBackendBucketRequest {

                    /** PatchBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** PatchBackendBucketRequest backendBucketResource */
                    backendBucketResource?: (google.cloud.compute.v1.IBackendBucket|null);

                    /** PatchBackendBucketRequest project */
                    project?: (string|null);

                    /** PatchBackendBucketRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchBackendBucketRequest. */
                class PatchBackendBucketRequest implements IPatchBackendBucketRequest {

                    /**
                     * Constructs a new PatchBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchBackendBucketRequest);

                    /** PatchBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** PatchBackendBucketRequest backendBucketResource. */
                    public backendBucketResource?: (google.cloud.compute.v1.IBackendBucket|null);

                    /** PatchBackendBucketRequest project. */
                    public project: string;

                    /** PatchBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchBackendBucketRequest): google.cloud.compute.v1.PatchBackendBucketRequest;

                    /**
                     * Encodes the specified PatchBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchBackendBucketRequest.verify|verify} messages.
                     * @param message PatchBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchBackendBucketRequest.verify|verify} messages.
                     * @param message PatchBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchBackendBucketRequest;

                    /**
                     * Decodes a PatchBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchBackendBucketRequest;

                    /**
                     * Verifies a PatchBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchBackendBucketRequest;

                    /**
                     * Creates a plain object from a PatchBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message PatchBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchBackendServiceRequest. */
                interface IPatchBackendServiceRequest {

                    /** PatchBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** PatchBackendServiceRequest backendServiceResource */
                    backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** PatchBackendServiceRequest project */
                    project?: (string|null);

                    /** PatchBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchBackendServiceRequest. */
                class PatchBackendServiceRequest implements IPatchBackendServiceRequest {

                    /**
                     * Constructs a new PatchBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchBackendServiceRequest);

                    /** PatchBackendServiceRequest backendService. */
                    public backendService: string;

                    /** PatchBackendServiceRequest backendServiceResource. */
                    public backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** PatchBackendServiceRequest project. */
                    public project: string;

                    /** PatchBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchBackendServiceRequest): google.cloud.compute.v1.PatchBackendServiceRequest;

                    /**
                     * Encodes the specified PatchBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchBackendServiceRequest.verify|verify} messages.
                     * @param message PatchBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchBackendServiceRequest.verify|verify} messages.
                     * @param message PatchBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchBackendServiceRequest;

                    /**
                     * Decodes a PatchBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchBackendServiceRequest;

                    /**
                     * Verifies a PatchBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchBackendServiceRequest;

                    /**
                     * Creates a plain object from a PatchBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message PatchBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchFirewallPolicyRequest. */
                interface IPatchFirewallPolicyRequest {

                    /** PatchFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** PatchFirewallPolicyRequest firewallPolicyResource */
                    firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** PatchFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchFirewallPolicyRequest. */
                class PatchFirewallPolicyRequest implements IPatchFirewallPolicyRequest {

                    /**
                     * Constructs a new PatchFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchFirewallPolicyRequest);

                    /** PatchFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** PatchFirewallPolicyRequest firewallPolicyResource. */
                    public firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** PatchFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchFirewallPolicyRequest): google.cloud.compute.v1.PatchFirewallPolicyRequest;

                    /**
                     * Encodes the specified PatchFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchFirewallPolicyRequest;

                    /**
                     * Decodes a PatchFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchFirewallPolicyRequest;

                    /**
                     * Verifies a PatchFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a PatchFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchFirewallRequest. */
                interface IPatchFirewallRequest {

                    /** PatchFirewallRequest firewall */
                    firewall?: (string|null);

                    /** PatchFirewallRequest firewallResource */
                    firewallResource?: (google.cloud.compute.v1.IFirewall|null);

                    /** PatchFirewallRequest project */
                    project?: (string|null);

                    /** PatchFirewallRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchFirewallRequest. */
                class PatchFirewallRequest implements IPatchFirewallRequest {

                    /**
                     * Constructs a new PatchFirewallRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchFirewallRequest);

                    /** PatchFirewallRequest firewall. */
                    public firewall: string;

                    /** PatchFirewallRequest firewallResource. */
                    public firewallResource?: (google.cloud.compute.v1.IFirewall|null);

                    /** PatchFirewallRequest project. */
                    public project: string;

                    /** PatchFirewallRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchFirewallRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchFirewallRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchFirewallRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchFirewallRequest): google.cloud.compute.v1.PatchFirewallRequest;

                    /**
                     * Encodes the specified PatchFirewallRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchFirewallRequest.verify|verify} messages.
                     * @param message PatchFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchFirewallRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchFirewallRequest.verify|verify} messages.
                     * @param message PatchFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchFirewallRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchFirewallRequest;

                    /**
                     * Decodes a PatchFirewallRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchFirewallRequest;

                    /**
                     * Verifies a PatchFirewallRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchFirewallRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchFirewallRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchFirewallRequest;

                    /**
                     * Creates a plain object from a PatchFirewallRequest message. Also converts values to other types if specified.
                     * @param message PatchFirewallRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchFirewallRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchFirewallRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchFirewallRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchForwardingRuleRequest. */
                interface IPatchForwardingRuleRequest {

                    /** PatchForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** PatchForwardingRuleRequest forwardingRuleResource */
                    forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** PatchForwardingRuleRequest project */
                    project?: (string|null);

                    /** PatchForwardingRuleRequest region */
                    region?: (string|null);

                    /** PatchForwardingRuleRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchForwardingRuleRequest. */
                class PatchForwardingRuleRequest implements IPatchForwardingRuleRequest {

                    /**
                     * Constructs a new PatchForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchForwardingRuleRequest);

                    /** PatchForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** PatchForwardingRuleRequest forwardingRuleResource. */
                    public forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** PatchForwardingRuleRequest project. */
                    public project: string;

                    /** PatchForwardingRuleRequest region. */
                    public region: string;

                    /** PatchForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchForwardingRuleRequest): google.cloud.compute.v1.PatchForwardingRuleRequest;

                    /**
                     * Encodes the specified PatchForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchForwardingRuleRequest.verify|verify} messages.
                     * @param message PatchForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchForwardingRuleRequest.verify|verify} messages.
                     * @param message PatchForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchForwardingRuleRequest;

                    /**
                     * Decodes a PatchForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchForwardingRuleRequest;

                    /**
                     * Verifies a PatchForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchForwardingRuleRequest;

                    /**
                     * Creates a plain object from a PatchForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message PatchForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchGlobalForwardingRuleRequest. */
                interface IPatchGlobalForwardingRuleRequest {

                    /** PatchGlobalForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** PatchGlobalForwardingRuleRequest forwardingRuleResource */
                    forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** PatchGlobalForwardingRuleRequest project */
                    project?: (string|null);

                    /** PatchGlobalForwardingRuleRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchGlobalForwardingRuleRequest. */
                class PatchGlobalForwardingRuleRequest implements IPatchGlobalForwardingRuleRequest {

                    /**
                     * Constructs a new PatchGlobalForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchGlobalForwardingRuleRequest);

                    /** PatchGlobalForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** PatchGlobalForwardingRuleRequest forwardingRuleResource. */
                    public forwardingRuleResource?: (google.cloud.compute.v1.IForwardingRule|null);

                    /** PatchGlobalForwardingRuleRequest project. */
                    public project: string;

                    /** PatchGlobalForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchGlobalForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchGlobalForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchGlobalForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchGlobalForwardingRuleRequest): google.cloud.compute.v1.PatchGlobalForwardingRuleRequest;

                    /**
                     * Encodes the specified PatchGlobalForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message PatchGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchGlobalForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message PatchGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchGlobalForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchGlobalForwardingRuleRequest;

                    /**
                     * Decodes a PatchGlobalForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchGlobalForwardingRuleRequest;

                    /**
                     * Verifies a PatchGlobalForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchGlobalForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchGlobalForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchGlobalForwardingRuleRequest;

                    /**
                     * Creates a plain object from a PatchGlobalForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message PatchGlobalForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchGlobalForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchGlobalForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchGlobalForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchGlobalPublicDelegatedPrefixeRequest. */
                interface IPatchGlobalPublicDelegatedPrefixeRequest {

                    /** PatchGlobalPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** PatchGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefix */
                    publicDelegatedPrefix?: (string|null);

                    /** PatchGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefixResource */
                    publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** PatchGlobalPublicDelegatedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchGlobalPublicDelegatedPrefixeRequest. */
                class PatchGlobalPublicDelegatedPrefixeRequest implements IPatchGlobalPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new PatchGlobalPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchGlobalPublicDelegatedPrefixeRequest);

                    /** PatchGlobalPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** PatchGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefix. */
                    public publicDelegatedPrefix: string;

                    /** PatchGlobalPublicDelegatedPrefixeRequest publicDelegatedPrefixResource. */
                    public publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** PatchGlobalPublicDelegatedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchGlobalPublicDelegatedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchGlobalPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchGlobalPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchGlobalPublicDelegatedPrefixeRequest): google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified PatchGlobalPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message PatchGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchGlobalPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message PatchGlobalPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchGlobalPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes a PatchGlobalPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchGlobalPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies a PatchGlobalPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchGlobalPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchGlobalPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from a PatchGlobalPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message PatchGlobalPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchGlobalPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchGlobalPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchGlobalPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchHealthCheckRequest. */
                interface IPatchHealthCheckRequest {

                    /** PatchHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** PatchHealthCheckRequest healthCheckResource */
                    healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** PatchHealthCheckRequest project */
                    project?: (string|null);

                    /** PatchHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchHealthCheckRequest. */
                class PatchHealthCheckRequest implements IPatchHealthCheckRequest {

                    /**
                     * Constructs a new PatchHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchHealthCheckRequest);

                    /** PatchHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** PatchHealthCheckRequest healthCheckResource. */
                    public healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** PatchHealthCheckRequest project. */
                    public project: string;

                    /** PatchHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchHealthCheckRequest): google.cloud.compute.v1.PatchHealthCheckRequest;

                    /**
                     * Encodes the specified PatchHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchHealthCheckRequest.verify|verify} messages.
                     * @param message PatchHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchHealthCheckRequest.verify|verify} messages.
                     * @param message PatchHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchHealthCheckRequest;

                    /**
                     * Decodes a PatchHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchHealthCheckRequest;

                    /**
                     * Verifies a PatchHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchHealthCheckRequest;

                    /**
                     * Creates a plain object from a PatchHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message PatchHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchImageRequest. */
                interface IPatchImageRequest {

                    /** PatchImageRequest image */
                    image?: (string|null);

                    /** PatchImageRequest imageResource */
                    imageResource?: (google.cloud.compute.v1.IImage|null);

                    /** PatchImageRequest project */
                    project?: (string|null);

                    /** PatchImageRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchImageRequest. */
                class PatchImageRequest implements IPatchImageRequest {

                    /**
                     * Constructs a new PatchImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchImageRequest);

                    /** PatchImageRequest image. */
                    public image: string;

                    /** PatchImageRequest imageResource. */
                    public imageResource?: (google.cloud.compute.v1.IImage|null);

                    /** PatchImageRequest project. */
                    public project: string;

                    /** PatchImageRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchImageRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchImageRequest): google.cloud.compute.v1.PatchImageRequest;

                    /**
                     * Encodes the specified PatchImageRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchImageRequest.verify|verify} messages.
                     * @param message PatchImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchImageRequest.verify|verify} messages.
                     * @param message PatchImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchImageRequest;

                    /**
                     * Decodes a PatchImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchImageRequest;

                    /**
                     * Verifies a PatchImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchImageRequest;

                    /**
                     * Creates a plain object from a PatchImageRequest message. Also converts values to other types if specified.
                     * @param message PatchImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchInstanceGroupManagerRequest. */
                interface IPatchInstanceGroupManagerRequest {

                    /** PatchInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** PatchInstanceGroupManagerRequest instanceGroupManagerResource */
                    instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** PatchInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** PatchInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** PatchInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a PatchInstanceGroupManagerRequest. */
                class PatchInstanceGroupManagerRequest implements IPatchInstanceGroupManagerRequest {

                    /**
                     * Constructs a new PatchInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchInstanceGroupManagerRequest);

                    /** PatchInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** PatchInstanceGroupManagerRequest instanceGroupManagerResource. */
                    public instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** PatchInstanceGroupManagerRequest project. */
                    public project: string;

                    /** PatchInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** PatchInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchInstanceGroupManagerRequest): google.cloud.compute.v1.PatchInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified PatchInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchInstanceGroupManagerRequest;

                    /**
                     * Decodes a PatchInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchInstanceGroupManagerRequest;

                    /**
                     * Verifies a PatchInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a PatchInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message PatchInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchInterconnectAttachmentRequest. */
                interface IPatchInterconnectAttachmentRequest {

                    /** PatchInterconnectAttachmentRequest interconnectAttachment */
                    interconnectAttachment?: (string|null);

                    /** PatchInterconnectAttachmentRequest interconnectAttachmentResource */
                    interconnectAttachmentResource?: (google.cloud.compute.v1.IInterconnectAttachment|null);

                    /** PatchInterconnectAttachmentRequest project */
                    project?: (string|null);

                    /** PatchInterconnectAttachmentRequest region */
                    region?: (string|null);

                    /** PatchInterconnectAttachmentRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchInterconnectAttachmentRequest. */
                class PatchInterconnectAttachmentRequest implements IPatchInterconnectAttachmentRequest {

                    /**
                     * Constructs a new PatchInterconnectAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchInterconnectAttachmentRequest);

                    /** PatchInterconnectAttachmentRequest interconnectAttachment. */
                    public interconnectAttachment: string;

                    /** PatchInterconnectAttachmentRequest interconnectAttachmentResource. */
                    public interconnectAttachmentResource?: (google.cloud.compute.v1.IInterconnectAttachment|null);

                    /** PatchInterconnectAttachmentRequest project. */
                    public project: string;

                    /** PatchInterconnectAttachmentRequest region. */
                    public region: string;

                    /** PatchInterconnectAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchInterconnectAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchInterconnectAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchInterconnectAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchInterconnectAttachmentRequest): google.cloud.compute.v1.PatchInterconnectAttachmentRequest;

                    /**
                     * Encodes the specified PatchInterconnectAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message PatchInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchInterconnectAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message PatchInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchInterconnectAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchInterconnectAttachmentRequest;

                    /**
                     * Decodes a PatchInterconnectAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchInterconnectAttachmentRequest;

                    /**
                     * Verifies a PatchInterconnectAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchInterconnectAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchInterconnectAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchInterconnectAttachmentRequest;

                    /**
                     * Creates a plain object from a PatchInterconnectAttachmentRequest message. Also converts values to other types if specified.
                     * @param message PatchInterconnectAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchInterconnectAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchInterconnectAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchInterconnectAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchInterconnectRequest. */
                interface IPatchInterconnectRequest {

                    /** PatchInterconnectRequest interconnect */
                    interconnect?: (string|null);

                    /** PatchInterconnectRequest interconnectResource */
                    interconnectResource?: (google.cloud.compute.v1.IInterconnect|null);

                    /** PatchInterconnectRequest project */
                    project?: (string|null);

                    /** PatchInterconnectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchInterconnectRequest. */
                class PatchInterconnectRequest implements IPatchInterconnectRequest {

                    /**
                     * Constructs a new PatchInterconnectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchInterconnectRequest);

                    /** PatchInterconnectRequest interconnect. */
                    public interconnect: string;

                    /** PatchInterconnectRequest interconnectResource. */
                    public interconnectResource?: (google.cloud.compute.v1.IInterconnect|null);

                    /** PatchInterconnectRequest project. */
                    public project: string;

                    /** PatchInterconnectRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchInterconnectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchInterconnectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchInterconnectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchInterconnectRequest): google.cloud.compute.v1.PatchInterconnectRequest;

                    /**
                     * Encodes the specified PatchInterconnectRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchInterconnectRequest.verify|verify} messages.
                     * @param message PatchInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchInterconnectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchInterconnectRequest.verify|verify} messages.
                     * @param message PatchInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchInterconnectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchInterconnectRequest;

                    /**
                     * Decodes a PatchInterconnectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchInterconnectRequest;

                    /**
                     * Verifies a PatchInterconnectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchInterconnectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchInterconnectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchInterconnectRequest;

                    /**
                     * Creates a plain object from a PatchInterconnectRequest message. Also converts values to other types if specified.
                     * @param message PatchInterconnectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchInterconnectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchInterconnectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchInterconnectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchNetworkEdgeSecurityServiceRequest. */
                interface IPatchNetworkEdgeSecurityServiceRequest {

                    /** PatchNetworkEdgeSecurityServiceRequest networkEdgeSecurityService */
                    networkEdgeSecurityService?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest networkEdgeSecurityServiceResource */
                    networkEdgeSecurityServiceResource?: (google.cloud.compute.v1.INetworkEdgeSecurityService|null);

                    /** PatchNetworkEdgeSecurityServiceRequest paths */
                    paths?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest project */
                    project?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest region */
                    region?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest requestId */
                    requestId?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest updateMask */
                    updateMask?: (string|null);
                }

                /** Represents a PatchNetworkEdgeSecurityServiceRequest. */
                class PatchNetworkEdgeSecurityServiceRequest implements IPatchNetworkEdgeSecurityServiceRequest {

                    /**
                     * Constructs a new PatchNetworkEdgeSecurityServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchNetworkEdgeSecurityServiceRequest);

                    /** PatchNetworkEdgeSecurityServiceRequest networkEdgeSecurityService. */
                    public networkEdgeSecurityService: string;

                    /** PatchNetworkEdgeSecurityServiceRequest networkEdgeSecurityServiceResource. */
                    public networkEdgeSecurityServiceResource?: (google.cloud.compute.v1.INetworkEdgeSecurityService|null);

                    /** PatchNetworkEdgeSecurityServiceRequest paths. */
                    public paths?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest project. */
                    public project: string;

                    /** PatchNetworkEdgeSecurityServiceRequest region. */
                    public region: string;

                    /** PatchNetworkEdgeSecurityServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest updateMask. */
                    public updateMask?: (string|null);

                    /** PatchNetworkEdgeSecurityServiceRequest _paths. */
                    public _paths?: "paths";

                    /** PatchNetworkEdgeSecurityServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /** PatchNetworkEdgeSecurityServiceRequest _updateMask. */
                    public _updateMask?: "updateMask";

                    /**
                     * Creates a new PatchNetworkEdgeSecurityServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchNetworkEdgeSecurityServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchNetworkEdgeSecurityServiceRequest): google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest;

                    /**
                     * Encodes the specified PatchNetworkEdgeSecurityServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message PatchNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchNetworkEdgeSecurityServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest.verify|verify} messages.
                     * @param message PatchNetworkEdgeSecurityServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchNetworkEdgeSecurityServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchNetworkEdgeSecurityServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest;

                    /**
                     * Decodes a PatchNetworkEdgeSecurityServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchNetworkEdgeSecurityServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest;

                    /**
                     * Verifies a PatchNetworkEdgeSecurityServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchNetworkEdgeSecurityServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchNetworkEdgeSecurityServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest;

                    /**
                     * Creates a plain object from a PatchNetworkEdgeSecurityServiceRequest message. Also converts values to other types if specified.
                     * @param message PatchNetworkEdgeSecurityServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchNetworkEdgeSecurityServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchNetworkEdgeSecurityServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchNetworkEdgeSecurityServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchNetworkFirewallPolicyRequest. */
                interface IPatchNetworkFirewallPolicyRequest {

                    /** PatchNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** PatchNetworkFirewallPolicyRequest firewallPolicyResource */
                    firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** PatchNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** PatchNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchNetworkFirewallPolicyRequest. */
                class PatchNetworkFirewallPolicyRequest implements IPatchNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new PatchNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchNetworkFirewallPolicyRequest);

                    /** PatchNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** PatchNetworkFirewallPolicyRequest firewallPolicyResource. */
                    public firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** PatchNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** PatchNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchNetworkFirewallPolicyRequest): google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified PatchNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a PatchNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a PatchNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a PatchNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchNetworkRequest. */
                interface IPatchNetworkRequest {

                    /** PatchNetworkRequest network */
                    network?: (string|null);

                    /** PatchNetworkRequest networkResource */
                    networkResource?: (google.cloud.compute.v1.INetwork|null);

                    /** PatchNetworkRequest project */
                    project?: (string|null);

                    /** PatchNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchNetworkRequest. */
                class PatchNetworkRequest implements IPatchNetworkRequest {

                    /**
                     * Constructs a new PatchNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchNetworkRequest);

                    /** PatchNetworkRequest network. */
                    public network: string;

                    /** PatchNetworkRequest networkResource. */
                    public networkResource?: (google.cloud.compute.v1.INetwork|null);

                    /** PatchNetworkRequest project. */
                    public project: string;

                    /** PatchNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchNetworkRequest): google.cloud.compute.v1.PatchNetworkRequest;

                    /**
                     * Encodes the specified PatchNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchNetworkRequest.verify|verify} messages.
                     * @param message PatchNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchNetworkRequest.verify|verify} messages.
                     * @param message PatchNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchNetworkRequest;

                    /**
                     * Decodes a PatchNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchNetworkRequest;

                    /**
                     * Verifies a PatchNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchNetworkRequest;

                    /**
                     * Creates a plain object from a PatchNetworkRequest message. Also converts values to other types if specified.
                     * @param message PatchNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchNodeGroupRequest. */
                interface IPatchNodeGroupRequest {

                    /** PatchNodeGroupRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** PatchNodeGroupRequest nodeGroupResource */
                    nodeGroupResource?: (google.cloud.compute.v1.INodeGroup|null);

                    /** PatchNodeGroupRequest project */
                    project?: (string|null);

                    /** PatchNodeGroupRequest requestId */
                    requestId?: (string|null);

                    /** PatchNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a PatchNodeGroupRequest. */
                class PatchNodeGroupRequest implements IPatchNodeGroupRequest {

                    /**
                     * Constructs a new PatchNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchNodeGroupRequest);

                    /** PatchNodeGroupRequest nodeGroup. */
                    public nodeGroup: string;

                    /** PatchNodeGroupRequest nodeGroupResource. */
                    public nodeGroupResource?: (google.cloud.compute.v1.INodeGroup|null);

                    /** PatchNodeGroupRequest project. */
                    public project: string;

                    /** PatchNodeGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchNodeGroupRequest zone. */
                    public zone: string;

                    /** PatchNodeGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchNodeGroupRequest): google.cloud.compute.v1.PatchNodeGroupRequest;

                    /**
                     * Encodes the specified PatchNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchNodeGroupRequest.verify|verify} messages.
                     * @param message PatchNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchNodeGroupRequest.verify|verify} messages.
                     * @param message PatchNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchNodeGroupRequest;

                    /**
                     * Decodes a PatchNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchNodeGroupRequest;

                    /**
                     * Verifies a PatchNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchNodeGroupRequest;

                    /**
                     * Creates a plain object from a PatchNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message PatchNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchPacketMirroringRequest. */
                interface IPatchPacketMirroringRequest {

                    /** PatchPacketMirroringRequest packetMirroring */
                    packetMirroring?: (string|null);

                    /** PatchPacketMirroringRequest packetMirroringResource */
                    packetMirroringResource?: (google.cloud.compute.v1.IPacketMirroring|null);

                    /** PatchPacketMirroringRequest project */
                    project?: (string|null);

                    /** PatchPacketMirroringRequest region */
                    region?: (string|null);

                    /** PatchPacketMirroringRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchPacketMirroringRequest. */
                class PatchPacketMirroringRequest implements IPatchPacketMirroringRequest {

                    /**
                     * Constructs a new PatchPacketMirroringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchPacketMirroringRequest);

                    /** PatchPacketMirroringRequest packetMirroring. */
                    public packetMirroring: string;

                    /** PatchPacketMirroringRequest packetMirroringResource. */
                    public packetMirroringResource?: (google.cloud.compute.v1.IPacketMirroring|null);

                    /** PatchPacketMirroringRequest project. */
                    public project: string;

                    /** PatchPacketMirroringRequest region. */
                    public region: string;

                    /** PatchPacketMirroringRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchPacketMirroringRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchPacketMirroringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchPacketMirroringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchPacketMirroringRequest): google.cloud.compute.v1.PatchPacketMirroringRequest;

                    /**
                     * Encodes the specified PatchPacketMirroringRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchPacketMirroringRequest.verify|verify} messages.
                     * @param message PatchPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchPacketMirroringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchPacketMirroringRequest.verify|verify} messages.
                     * @param message PatchPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchPacketMirroringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchPacketMirroringRequest;

                    /**
                     * Decodes a PatchPacketMirroringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchPacketMirroringRequest;

                    /**
                     * Verifies a PatchPacketMirroringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchPacketMirroringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchPacketMirroringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchPacketMirroringRequest;

                    /**
                     * Creates a plain object from a PatchPacketMirroringRequest message. Also converts values to other types if specified.
                     * @param message PatchPacketMirroringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchPacketMirroringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchPacketMirroringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchPacketMirroringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchPerInstanceConfigsInstanceGroupManagerRequest. */
                interface IPatchPerInstanceConfigsInstanceGroupManagerRequest {

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest instanceGroupManagersPatchPerInstanceConfigsReqResource */
                    instanceGroupManagersPatchPerInstanceConfigsReqResource?: (google.cloud.compute.v1.IInstanceGroupManagersPatchPerInstanceConfigsReq|null);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a PatchPerInstanceConfigsInstanceGroupManagerRequest. */
                class PatchPerInstanceConfigsInstanceGroupManagerRequest implements IPatchPerInstanceConfigsInstanceGroupManagerRequest {

                    /**
                     * Constructs a new PatchPerInstanceConfigsInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest instanceGroupManagersPatchPerInstanceConfigsReqResource. */
                    public instanceGroupManagersPatchPerInstanceConfigsReqResource?: (google.cloud.compute.v1.IInstanceGroupManagersPatchPerInstanceConfigsReq|null);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest project. */
                    public project: string;

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** PatchPerInstanceConfigsInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchPerInstanceConfigsInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchPerInstanceConfigsInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest): google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified PatchPerInstanceConfigsInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchPerInstanceConfigsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchPerInstanceConfigsInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchPerInstanceConfigsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchPerInstanceConfigsInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchPerInstanceConfigsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Decodes a PatchPerInstanceConfigsInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchPerInstanceConfigsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Verifies a PatchPerInstanceConfigsInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchPerInstanceConfigsInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchPerInstanceConfigsInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a PatchPerInstanceConfigsInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message PatchPerInstanceConfigsInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchPerInstanceConfigsInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchPerInstanceConfigsInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchPerInstanceConfigsInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest. */
                interface IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest {

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest regionInstanceGroupManagerPatchInstanceConfigReqResource */
                    regionInstanceGroupManagerPatchInstanceConfigReqResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagerPatchInstanceConfigReq|null);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest. */
                class PatchPerInstanceConfigsRegionInstanceGroupManagerRequest implements IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new PatchPerInstanceConfigsRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest regionInstanceGroupManagerPatchInstanceConfigReqResource. */
                    public regionInstanceGroupManagerPatchInstanceConfigReqResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagerPatchInstanceConfigReq|null);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchPerInstanceConfigsRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchPerInstanceConfigsRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchPerInstanceConfigsRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest): google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchPerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchPerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchPerInstanceConfigsRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message PatchPerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchPerInstanceConfigsRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchPerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchPublicAdvertisedPrefixeRequest. */
                interface IPatchPublicAdvertisedPrefixeRequest {

                    /** PatchPublicAdvertisedPrefixeRequest project */
                    project?: (string|null);

                    /** PatchPublicAdvertisedPrefixeRequest publicAdvertisedPrefix */
                    publicAdvertisedPrefix?: (string|null);

                    /** PatchPublicAdvertisedPrefixeRequest publicAdvertisedPrefixResource */
                    publicAdvertisedPrefixResource?: (google.cloud.compute.v1.IPublicAdvertisedPrefix|null);

                    /** PatchPublicAdvertisedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchPublicAdvertisedPrefixeRequest. */
                class PatchPublicAdvertisedPrefixeRequest implements IPatchPublicAdvertisedPrefixeRequest {

                    /**
                     * Constructs a new PatchPublicAdvertisedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchPublicAdvertisedPrefixeRequest);

                    /** PatchPublicAdvertisedPrefixeRequest project. */
                    public project: string;

                    /** PatchPublicAdvertisedPrefixeRequest publicAdvertisedPrefix. */
                    public publicAdvertisedPrefix: string;

                    /** PatchPublicAdvertisedPrefixeRequest publicAdvertisedPrefixResource. */
                    public publicAdvertisedPrefixResource?: (google.cloud.compute.v1.IPublicAdvertisedPrefix|null);

                    /** PatchPublicAdvertisedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchPublicAdvertisedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchPublicAdvertisedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchPublicAdvertisedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchPublicAdvertisedPrefixeRequest): google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest;

                    /**
                     * Encodes the specified PatchPublicAdvertisedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message PatchPublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchPublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchPublicAdvertisedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest.verify|verify} messages.
                     * @param message PatchPublicAdvertisedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchPublicAdvertisedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchPublicAdvertisedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchPublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest;

                    /**
                     * Decodes a PatchPublicAdvertisedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchPublicAdvertisedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest;

                    /**
                     * Verifies a PatchPublicAdvertisedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchPublicAdvertisedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchPublicAdvertisedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest;

                    /**
                     * Creates a plain object from a PatchPublicAdvertisedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message PatchPublicAdvertisedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchPublicAdvertisedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchPublicAdvertisedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchPublicAdvertisedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchPublicDelegatedPrefixeRequest. */
                interface IPatchPublicDelegatedPrefixeRequest {

                    /** PatchPublicDelegatedPrefixeRequest project */
                    project?: (string|null);

                    /** PatchPublicDelegatedPrefixeRequest publicDelegatedPrefix */
                    publicDelegatedPrefix?: (string|null);

                    /** PatchPublicDelegatedPrefixeRequest publicDelegatedPrefixResource */
                    publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** PatchPublicDelegatedPrefixeRequest region */
                    region?: (string|null);

                    /** PatchPublicDelegatedPrefixeRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchPublicDelegatedPrefixeRequest. */
                class PatchPublicDelegatedPrefixeRequest implements IPatchPublicDelegatedPrefixeRequest {

                    /**
                     * Constructs a new PatchPublicDelegatedPrefixeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchPublicDelegatedPrefixeRequest);

                    /** PatchPublicDelegatedPrefixeRequest project. */
                    public project: string;

                    /** PatchPublicDelegatedPrefixeRequest publicDelegatedPrefix. */
                    public publicDelegatedPrefix: string;

                    /** PatchPublicDelegatedPrefixeRequest publicDelegatedPrefixResource. */
                    public publicDelegatedPrefixResource?: (google.cloud.compute.v1.IPublicDelegatedPrefix|null);

                    /** PatchPublicDelegatedPrefixeRequest region. */
                    public region: string;

                    /** PatchPublicDelegatedPrefixeRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchPublicDelegatedPrefixeRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchPublicDelegatedPrefixeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchPublicDelegatedPrefixeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchPublicDelegatedPrefixeRequest): google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest;

                    /**
                     * Encodes the specified PatchPublicDelegatedPrefixeRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message PatchPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchPublicDelegatedPrefixeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest.verify|verify} messages.
                     * @param message PatchPublicDelegatedPrefixeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchPublicDelegatedPrefixeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchPublicDelegatedPrefixeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest;

                    /**
                     * Decodes a PatchPublicDelegatedPrefixeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchPublicDelegatedPrefixeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest;

                    /**
                     * Verifies a PatchPublicDelegatedPrefixeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchPublicDelegatedPrefixeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchPublicDelegatedPrefixeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest;

                    /**
                     * Creates a plain object from a PatchPublicDelegatedPrefixeRequest message. Also converts values to other types if specified.
                     * @param message PatchPublicDelegatedPrefixeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchPublicDelegatedPrefixeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchPublicDelegatedPrefixeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchPublicDelegatedPrefixeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionAutoscalerRequest. */
                interface IPatchRegionAutoscalerRequest {

                    /** PatchRegionAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** PatchRegionAutoscalerRequest autoscalerResource */
                    autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** PatchRegionAutoscalerRequest project */
                    project?: (string|null);

                    /** PatchRegionAutoscalerRequest region */
                    region?: (string|null);

                    /** PatchRegionAutoscalerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRegionAutoscalerRequest. */
                class PatchRegionAutoscalerRequest implements IPatchRegionAutoscalerRequest {

                    /**
                     * Constructs a new PatchRegionAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionAutoscalerRequest);

                    /** PatchRegionAutoscalerRequest autoscaler. */
                    public autoscaler?: (string|null);

                    /** PatchRegionAutoscalerRequest autoscalerResource. */
                    public autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** PatchRegionAutoscalerRequest project. */
                    public project: string;

                    /** PatchRegionAutoscalerRequest region. */
                    public region: string;

                    /** PatchRegionAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionAutoscalerRequest _autoscaler. */
                    public _autoscaler?: "autoscaler";

                    /** PatchRegionAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionAutoscalerRequest): google.cloud.compute.v1.PatchRegionAutoscalerRequest;

                    /**
                     * Encodes the specified PatchRegionAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionAutoscalerRequest.verify|verify} messages.
                     * @param message PatchRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionAutoscalerRequest.verify|verify} messages.
                     * @param message PatchRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionAutoscalerRequest;

                    /**
                     * Decodes a PatchRegionAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionAutoscalerRequest;

                    /**
                     * Verifies a PatchRegionAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionAutoscalerRequest;

                    /**
                     * Creates a plain object from a PatchRegionAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionBackendServiceRequest. */
                interface IPatchRegionBackendServiceRequest {

                    /** PatchRegionBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** PatchRegionBackendServiceRequest backendServiceResource */
                    backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** PatchRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** PatchRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** PatchRegionBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRegionBackendServiceRequest. */
                class PatchRegionBackendServiceRequest implements IPatchRegionBackendServiceRequest {

                    /**
                     * Constructs a new PatchRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionBackendServiceRequest);

                    /** PatchRegionBackendServiceRequest backendService. */
                    public backendService: string;

                    /** PatchRegionBackendServiceRequest backendServiceResource. */
                    public backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** PatchRegionBackendServiceRequest project. */
                    public project: string;

                    /** PatchRegionBackendServiceRequest region. */
                    public region: string;

                    /** PatchRegionBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionBackendServiceRequest): google.cloud.compute.v1.PatchRegionBackendServiceRequest;

                    /**
                     * Encodes the specified PatchRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionBackendServiceRequest.verify|verify} messages.
                     * @param message PatchRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionBackendServiceRequest.verify|verify} messages.
                     * @param message PatchRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionBackendServiceRequest;

                    /**
                     * Decodes a PatchRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionBackendServiceRequest;

                    /**
                     * Verifies a PatchRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from a PatchRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionHealthCheckRequest. */
                interface IPatchRegionHealthCheckRequest {

                    /** PatchRegionHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** PatchRegionHealthCheckRequest healthCheckResource */
                    healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** PatchRegionHealthCheckRequest project */
                    project?: (string|null);

                    /** PatchRegionHealthCheckRequest region */
                    region?: (string|null);

                    /** PatchRegionHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRegionHealthCheckRequest. */
                class PatchRegionHealthCheckRequest implements IPatchRegionHealthCheckRequest {

                    /**
                     * Constructs a new PatchRegionHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionHealthCheckRequest);

                    /** PatchRegionHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** PatchRegionHealthCheckRequest healthCheckResource. */
                    public healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** PatchRegionHealthCheckRequest project. */
                    public project: string;

                    /** PatchRegionHealthCheckRequest region. */
                    public region: string;

                    /** PatchRegionHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionHealthCheckRequest): google.cloud.compute.v1.PatchRegionHealthCheckRequest;

                    /**
                     * Encodes the specified PatchRegionHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionHealthCheckRequest.verify|verify} messages.
                     * @param message PatchRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionHealthCheckRequest.verify|verify} messages.
                     * @param message PatchRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionHealthCheckRequest;

                    /**
                     * Decodes a PatchRegionHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionHealthCheckRequest;

                    /**
                     * Verifies a PatchRegionHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionHealthCheckRequest;

                    /**
                     * Creates a plain object from a PatchRegionHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionHealthCheckServiceRequest. */
                interface IPatchRegionHealthCheckServiceRequest {

                    /** PatchRegionHealthCheckServiceRequest healthCheckService */
                    healthCheckService?: (string|null);

                    /** PatchRegionHealthCheckServiceRequest healthCheckServiceResource */
                    healthCheckServiceResource?: (google.cloud.compute.v1.IHealthCheckService|null);

                    /** PatchRegionHealthCheckServiceRequest project */
                    project?: (string|null);

                    /** PatchRegionHealthCheckServiceRequest region */
                    region?: (string|null);

                    /** PatchRegionHealthCheckServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRegionHealthCheckServiceRequest. */
                class PatchRegionHealthCheckServiceRequest implements IPatchRegionHealthCheckServiceRequest {

                    /**
                     * Constructs a new PatchRegionHealthCheckServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionHealthCheckServiceRequest);

                    /** PatchRegionHealthCheckServiceRequest healthCheckService. */
                    public healthCheckService: string;

                    /** PatchRegionHealthCheckServiceRequest healthCheckServiceResource. */
                    public healthCheckServiceResource?: (google.cloud.compute.v1.IHealthCheckService|null);

                    /** PatchRegionHealthCheckServiceRequest project. */
                    public project: string;

                    /** PatchRegionHealthCheckServiceRequest region. */
                    public region: string;

                    /** PatchRegionHealthCheckServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionHealthCheckServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionHealthCheckServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionHealthCheckServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionHealthCheckServiceRequest): google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest;

                    /**
                     * Encodes the specified PatchRegionHealthCheckServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message PatchRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionHealthCheckServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest.verify|verify} messages.
                     * @param message PatchRegionHealthCheckServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionHealthCheckServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionHealthCheckServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest;

                    /**
                     * Decodes a PatchRegionHealthCheckServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionHealthCheckServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest;

                    /**
                     * Verifies a PatchRegionHealthCheckServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionHealthCheckServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionHealthCheckServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest;

                    /**
                     * Creates a plain object from a PatchRegionHealthCheckServiceRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionHealthCheckServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionHealthCheckServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionHealthCheckServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionHealthCheckServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionInstanceGroupManagerRequest. */
                interface IPatchRegionInstanceGroupManagerRequest {

                    /** PatchRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** PatchRegionInstanceGroupManagerRequest instanceGroupManagerResource */
                    instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** PatchRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** PatchRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** PatchRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRegionInstanceGroupManagerRequest. */
                class PatchRegionInstanceGroupManagerRequest implements IPatchRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new PatchRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest);

                    /** PatchRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** PatchRegionInstanceGroupManagerRequest instanceGroupManagerResource. */
                    public instanceGroupManagerResource?: (google.cloud.compute.v1.IInstanceGroupManager|null);

                    /** PatchRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** PatchRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** PatchRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest): google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified PatchRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message PatchRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a PatchRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a PatchRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a PatchRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionNetworkFirewallPolicyRequest. */
                interface IPatchRegionNetworkFirewallPolicyRequest {

                    /** PatchRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** PatchRegionNetworkFirewallPolicyRequest firewallPolicyResource */
                    firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** PatchRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** PatchRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** PatchRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRegionNetworkFirewallPolicyRequest. */
                class PatchRegionNetworkFirewallPolicyRequest implements IPatchRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new PatchRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionNetworkFirewallPolicyRequest);

                    /** PatchRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** PatchRegionNetworkFirewallPolicyRequest firewallPolicyResource. */
                    public firewallPolicyResource?: (google.cloud.compute.v1.IFirewallPolicy|null);

                    /** PatchRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** PatchRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** PatchRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified PatchRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a PatchRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a PatchRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionSecurityPolicyRequest. */
                interface IPatchRegionSecurityPolicyRequest {

                    /** PatchRegionSecurityPolicyRequest project */
                    project?: (string|null);

                    /** PatchRegionSecurityPolicyRequest region */
                    region?: (string|null);

                    /** PatchRegionSecurityPolicyRequest requestId */
                    requestId?: (string|null);

                    /** PatchRegionSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);

                    /** PatchRegionSecurityPolicyRequest securityPolicyResource */
                    securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);
                }

                /** Represents a PatchRegionSecurityPolicyRequest. */
                class PatchRegionSecurityPolicyRequest implements IPatchRegionSecurityPolicyRequest {

                    /**
                     * Constructs a new PatchRegionSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionSecurityPolicyRequest);

                    /** PatchRegionSecurityPolicyRequest project. */
                    public project: string;

                    /** PatchRegionSecurityPolicyRequest region. */
                    public region: string;

                    /** PatchRegionSecurityPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** PatchRegionSecurityPolicyRequest securityPolicyResource. */
                    public securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);

                    /** PatchRegionSecurityPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionSecurityPolicyRequest): google.cloud.compute.v1.PatchRegionSecurityPolicyRequest;

                    /**
                     * Encodes the specified PatchRegionSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message PatchRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionSecurityPolicyRequest.verify|verify} messages.
                     * @param message PatchRegionSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionSecurityPolicyRequest;

                    /**
                     * Decodes a PatchRegionSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionSecurityPolicyRequest;

                    /**
                     * Verifies a PatchRegionSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRegionSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionSslPolicyRequest. */
                interface IPatchRegionSslPolicyRequest {

                    /** PatchRegionSslPolicyRequest project */
                    project?: (string|null);

                    /** PatchRegionSslPolicyRequest region */
                    region?: (string|null);

                    /** PatchRegionSslPolicyRequest requestId */
                    requestId?: (string|null);

                    /** PatchRegionSslPolicyRequest sslPolicy */
                    sslPolicy?: (string|null);

                    /** PatchRegionSslPolicyRequest sslPolicyResource */
                    sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);
                }

                /** Represents a PatchRegionSslPolicyRequest. */
                class PatchRegionSslPolicyRequest implements IPatchRegionSslPolicyRequest {

                    /**
                     * Constructs a new PatchRegionSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionSslPolicyRequest);

                    /** PatchRegionSslPolicyRequest project. */
                    public project: string;

                    /** PatchRegionSslPolicyRequest region. */
                    public region: string;

                    /** PatchRegionSslPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionSslPolicyRequest sslPolicy. */
                    public sslPolicy: string;

                    /** PatchRegionSslPolicyRequest sslPolicyResource. */
                    public sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);

                    /** PatchRegionSslPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionSslPolicyRequest): google.cloud.compute.v1.PatchRegionSslPolicyRequest;

                    /**
                     * Encodes the specified PatchRegionSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionSslPolicyRequest.verify|verify} messages.
                     * @param message PatchRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionSslPolicyRequest.verify|verify} messages.
                     * @param message PatchRegionSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionSslPolicyRequest;

                    /**
                     * Decodes a PatchRegionSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionSslPolicyRequest;

                    /**
                     * Verifies a PatchRegionSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionSslPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRegionSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionTargetHttpsProxyRequest. */
                interface IPatchRegionTargetHttpsProxyRequest {

                    /** PatchRegionTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** PatchRegionTargetHttpsProxyRequest region */
                    region?: (string|null);

                    /** PatchRegionTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** PatchRegionTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);

                    /** PatchRegionTargetHttpsProxyRequest targetHttpsProxyResource */
                    targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);
                }

                /** Represents a PatchRegionTargetHttpsProxyRequest. */
                class PatchRegionTargetHttpsProxyRequest implements IPatchRegionTargetHttpsProxyRequest {

                    /**
                     * Constructs a new PatchRegionTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionTargetHttpsProxyRequest);

                    /** PatchRegionTargetHttpsProxyRequest project. */
                    public project: string;

                    /** PatchRegionTargetHttpsProxyRequest region. */
                    public region: string;

                    /** PatchRegionTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** PatchRegionTargetHttpsProxyRequest targetHttpsProxyResource. */
                    public targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);

                    /** PatchRegionTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionTargetHttpsProxyRequest): google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified PatchRegionTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message PatchRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message PatchRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest;

                    /**
                     * Decodes a PatchRegionTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest;

                    /**
                     * Verifies a PatchRegionTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a PatchRegionTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRegionUrlMapRequest. */
                interface IPatchRegionUrlMapRequest {

                    /** PatchRegionUrlMapRequest project */
                    project?: (string|null);

                    /** PatchRegionUrlMapRequest region */
                    region?: (string|null);

                    /** PatchRegionUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** PatchRegionUrlMapRequest urlMap */
                    urlMap?: (string|null);

                    /** PatchRegionUrlMapRequest urlMapResource */
                    urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents a PatchRegionUrlMapRequest. */
                class PatchRegionUrlMapRequest implements IPatchRegionUrlMapRequest {

                    /**
                     * Constructs a new PatchRegionUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRegionUrlMapRequest);

                    /** PatchRegionUrlMapRequest project. */
                    public project: string;

                    /** PatchRegionUrlMapRequest region. */
                    public region: string;

                    /** PatchRegionUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRegionUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** PatchRegionUrlMapRequest urlMapResource. */
                    public urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** PatchRegionUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRegionUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRegionUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRegionUrlMapRequest): google.cloud.compute.v1.PatchRegionUrlMapRequest;

                    /**
                     * Encodes the specified PatchRegionUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRegionUrlMapRequest.verify|verify} messages.
                     * @param message PatchRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRegionUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRegionUrlMapRequest.verify|verify} messages.
                     * @param message PatchRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRegionUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRegionUrlMapRequest;

                    /**
                     * Decodes a PatchRegionUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRegionUrlMapRequest;

                    /**
                     * Verifies a PatchRegionUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRegionUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRegionUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRegionUrlMapRequest;

                    /**
                     * Creates a plain object from a PatchRegionUrlMapRequest message. Also converts values to other types if specified.
                     * @param message PatchRegionUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRegionUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRegionUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRegionUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRouterRequest. */
                interface IPatchRouterRequest {

                    /** PatchRouterRequest project */
                    project?: (string|null);

                    /** PatchRouterRequest region */
                    region?: (string|null);

                    /** PatchRouterRequest requestId */
                    requestId?: (string|null);

                    /** PatchRouterRequest router */
                    router?: (string|null);

                    /** PatchRouterRequest routerResource */
                    routerResource?: (google.cloud.compute.v1.IRouter|null);
                }

                /** Represents a PatchRouterRequest. */
                class PatchRouterRequest implements IPatchRouterRequest {

                    /**
                     * Constructs a new PatchRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRouterRequest);

                    /** PatchRouterRequest project. */
                    public project: string;

                    /** PatchRouterRequest region. */
                    public region: string;

                    /** PatchRouterRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRouterRequest router. */
                    public router: string;

                    /** PatchRouterRequest routerResource. */
                    public routerResource?: (google.cloud.compute.v1.IRouter|null);

                    /** PatchRouterRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRouterRequest): google.cloud.compute.v1.PatchRouterRequest;

                    /**
                     * Encodes the specified PatchRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRouterRequest.verify|verify} messages.
                     * @param message PatchRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRouterRequest.verify|verify} messages.
                     * @param message PatchRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRouterRequest;

                    /**
                     * Decodes a PatchRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRouterRequest;

                    /**
                     * Verifies a PatchRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRouterRequest;

                    /**
                     * Creates a plain object from a PatchRouterRequest message. Also converts values to other types if specified.
                     * @param message PatchRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRuleFirewallPolicyRequest. */
                interface IPatchRuleFirewallPolicyRequest {

                    /** PatchRuleFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** PatchRuleFirewallPolicyRequest firewallPolicyRuleResource */
                    firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** PatchRuleFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** PatchRuleFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRuleFirewallPolicyRequest. */
                class PatchRuleFirewallPolicyRequest implements IPatchRuleFirewallPolicyRequest {

                    /**
                     * Constructs a new PatchRuleFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRuleFirewallPolicyRequest);

                    /** PatchRuleFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** PatchRuleFirewallPolicyRequest firewallPolicyRuleResource. */
                    public firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** PatchRuleFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** PatchRuleFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRuleFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** PatchRuleFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRuleFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRuleFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRuleFirewallPolicyRequest): google.cloud.compute.v1.PatchRuleFirewallPolicyRequest;

                    /**
                     * Encodes the specified PatchRuleFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRuleFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRuleFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRuleFirewallPolicyRequest;

                    /**
                     * Decodes a PatchRuleFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRuleFirewallPolicyRequest;

                    /**
                     * Verifies a PatchRuleFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRuleFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRuleFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRuleFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRuleFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRuleFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRuleFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRuleFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRuleFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRuleNetworkFirewallPolicyRequest. */
                interface IPatchRuleNetworkFirewallPolicyRequest {

                    /** PatchRuleNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** PatchRuleNetworkFirewallPolicyRequest firewallPolicyRuleResource */
                    firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** PatchRuleNetworkFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** PatchRuleNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** PatchRuleNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRuleNetworkFirewallPolicyRequest. */
                class PatchRuleNetworkFirewallPolicyRequest implements IPatchRuleNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new PatchRuleNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRuleNetworkFirewallPolicyRequest);

                    /** PatchRuleNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** PatchRuleNetworkFirewallPolicyRequest firewallPolicyRuleResource. */
                    public firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** PatchRuleNetworkFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** PatchRuleNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** PatchRuleNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRuleNetworkFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** PatchRuleNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRuleNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRuleNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRuleNetworkFirewallPolicyRequest): google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified PatchRuleNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRuleNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRuleNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a PatchRuleNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a PatchRuleNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRuleNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRuleNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRuleNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRuleNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRuleNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRuleNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRuleNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRuleRegionNetworkFirewallPolicyRequest. */
                interface IPatchRuleRegionNetworkFirewallPolicyRequest {

                    /** PatchRuleRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest firewallPolicyRuleResource */
                    firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a PatchRuleRegionNetworkFirewallPolicyRequest. */
                class PatchRuleRegionNetworkFirewallPolicyRequest implements IPatchRuleRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new PatchRuleRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRuleRegionNetworkFirewallPolicyRequest);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** PatchRuleRegionNetworkFirewallPolicyRequest firewallPolicyRuleResource. */
                    public firewallPolicyRuleResource?: (google.cloud.compute.v1.IFirewallPolicyRule|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** PatchRuleRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** PatchRuleRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchRuleRegionNetworkFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** PatchRuleRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchRuleRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRuleRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRuleRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified PatchRuleRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRuleRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a PatchRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a PatchRuleRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRuleRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRuleRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRuleRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRuleRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRuleRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRuleRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRuleRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchRuleSecurityPolicyRequest. */
                interface IPatchRuleSecurityPolicyRequest {

                    /** PatchRuleSecurityPolicyRequest priority */
                    priority?: (number|null);

                    /** PatchRuleSecurityPolicyRequest project */
                    project?: (string|null);

                    /** PatchRuleSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);

                    /** PatchRuleSecurityPolicyRequest securityPolicyRuleResource */
                    securityPolicyRuleResource?: (google.cloud.compute.v1.ISecurityPolicyRule|null);

                    /** PatchRuleSecurityPolicyRequest validateOnly */
                    validateOnly?: (boolean|null);
                }

                /** Represents a PatchRuleSecurityPolicyRequest. */
                class PatchRuleSecurityPolicyRequest implements IPatchRuleSecurityPolicyRequest {

                    /**
                     * Constructs a new PatchRuleSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchRuleSecurityPolicyRequest);

                    /** PatchRuleSecurityPolicyRequest priority. */
                    public priority?: (number|null);

                    /** PatchRuleSecurityPolicyRequest project. */
                    public project: string;

                    /** PatchRuleSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** PatchRuleSecurityPolicyRequest securityPolicyRuleResource. */
                    public securityPolicyRuleResource?: (google.cloud.compute.v1.ISecurityPolicyRule|null);

                    /** PatchRuleSecurityPolicyRequest validateOnly. */
                    public validateOnly?: (boolean|null);

                    /** PatchRuleSecurityPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** PatchRuleSecurityPolicyRequest _validateOnly. */
                    public _validateOnly?: "validateOnly";

                    /**
                     * Creates a new PatchRuleSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchRuleSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchRuleSecurityPolicyRequest): google.cloud.compute.v1.PatchRuleSecurityPolicyRequest;

                    /**
                     * Encodes the specified PatchRuleSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchRuleSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message PatchRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchRuleSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchRuleSecurityPolicyRequest;

                    /**
                     * Decodes a PatchRuleSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchRuleSecurityPolicyRequest;

                    /**
                     * Verifies a PatchRuleSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchRuleSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchRuleSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchRuleSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a PatchRuleSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchRuleSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchRuleSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchRuleSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchRuleSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchSecurityPolicyRequest. */
                interface IPatchSecurityPolicyRequest {

                    /** PatchSecurityPolicyRequest project */
                    project?: (string|null);

                    /** PatchSecurityPolicyRequest requestId */
                    requestId?: (string|null);

                    /** PatchSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);

                    /** PatchSecurityPolicyRequest securityPolicyResource */
                    securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);
                }

                /** Represents a PatchSecurityPolicyRequest. */
                class PatchSecurityPolicyRequest implements IPatchSecurityPolicyRequest {

                    /**
                     * Constructs a new PatchSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchSecurityPolicyRequest);

                    /** PatchSecurityPolicyRequest project. */
                    public project: string;

                    /** PatchSecurityPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** PatchSecurityPolicyRequest securityPolicyResource. */
                    public securityPolicyResource?: (google.cloud.compute.v1.ISecurityPolicy|null);

                    /** PatchSecurityPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchSecurityPolicyRequest): google.cloud.compute.v1.PatchSecurityPolicyRequest;

                    /**
                     * Encodes the specified PatchSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchSecurityPolicyRequest.verify|verify} messages.
                     * @param message PatchSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchSecurityPolicyRequest.verify|verify} messages.
                     * @param message PatchSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchSecurityPolicyRequest;

                    /**
                     * Decodes a PatchSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchSecurityPolicyRequest;

                    /**
                     * Verifies a PatchSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a PatchSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchServiceAttachmentRequest. */
                interface IPatchServiceAttachmentRequest {

                    /** PatchServiceAttachmentRequest project */
                    project?: (string|null);

                    /** PatchServiceAttachmentRequest region */
                    region?: (string|null);

                    /** PatchServiceAttachmentRequest requestId */
                    requestId?: (string|null);

                    /** PatchServiceAttachmentRequest serviceAttachment */
                    serviceAttachment?: (string|null);

                    /** PatchServiceAttachmentRequest serviceAttachmentResource */
                    serviceAttachmentResource?: (google.cloud.compute.v1.IServiceAttachment|null);
                }

                /** Represents a PatchServiceAttachmentRequest. */
                class PatchServiceAttachmentRequest implements IPatchServiceAttachmentRequest {

                    /**
                     * Constructs a new PatchServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchServiceAttachmentRequest);

                    /** PatchServiceAttachmentRequest project. */
                    public project: string;

                    /** PatchServiceAttachmentRequest region. */
                    public region: string;

                    /** PatchServiceAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchServiceAttachmentRequest serviceAttachment. */
                    public serviceAttachment: string;

                    /** PatchServiceAttachmentRequest serviceAttachmentResource. */
                    public serviceAttachmentResource?: (google.cloud.compute.v1.IServiceAttachment|null);

                    /** PatchServiceAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchServiceAttachmentRequest): google.cloud.compute.v1.PatchServiceAttachmentRequest;

                    /**
                     * Encodes the specified PatchServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchServiceAttachmentRequest.verify|verify} messages.
                     * @param message PatchServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchServiceAttachmentRequest.verify|verify} messages.
                     * @param message PatchServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchServiceAttachmentRequest;

                    /**
                     * Decodes a PatchServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchServiceAttachmentRequest;

                    /**
                     * Verifies a PatchServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchServiceAttachmentRequest;

                    /**
                     * Creates a plain object from a PatchServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message PatchServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchSslPolicyRequest. */
                interface IPatchSslPolicyRequest {

                    /** PatchSslPolicyRequest project */
                    project?: (string|null);

                    /** PatchSslPolicyRequest requestId */
                    requestId?: (string|null);

                    /** PatchSslPolicyRequest sslPolicy */
                    sslPolicy?: (string|null);

                    /** PatchSslPolicyRequest sslPolicyResource */
                    sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);
                }

                /** Represents a PatchSslPolicyRequest. */
                class PatchSslPolicyRequest implements IPatchSslPolicyRequest {

                    /**
                     * Constructs a new PatchSslPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchSslPolicyRequest);

                    /** PatchSslPolicyRequest project. */
                    public project: string;

                    /** PatchSslPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchSslPolicyRequest sslPolicy. */
                    public sslPolicy: string;

                    /** PatchSslPolicyRequest sslPolicyResource. */
                    public sslPolicyResource?: (google.cloud.compute.v1.ISslPolicy|null);

                    /** PatchSslPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchSslPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchSslPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchSslPolicyRequest): google.cloud.compute.v1.PatchSslPolicyRequest;

                    /**
                     * Encodes the specified PatchSslPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchSslPolicyRequest.verify|verify} messages.
                     * @param message PatchSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchSslPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchSslPolicyRequest.verify|verify} messages.
                     * @param message PatchSslPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchSslPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchSslPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchSslPolicyRequest;

                    /**
                     * Decodes a PatchSslPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchSslPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchSslPolicyRequest;

                    /**
                     * Verifies a PatchSslPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchSslPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchSslPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchSslPolicyRequest;

                    /**
                     * Creates a plain object from a PatchSslPolicyRequest message. Also converts values to other types if specified.
                     * @param message PatchSslPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchSslPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchSslPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchSslPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchSubnetworkRequest. */
                interface IPatchSubnetworkRequest {

                    /** PatchSubnetworkRequest drainTimeoutSeconds */
                    drainTimeoutSeconds?: (number|null);

                    /** PatchSubnetworkRequest project */
                    project?: (string|null);

                    /** PatchSubnetworkRequest region */
                    region?: (string|null);

                    /** PatchSubnetworkRequest requestId */
                    requestId?: (string|null);

                    /** PatchSubnetworkRequest subnetwork */
                    subnetwork?: (string|null);

                    /** PatchSubnetworkRequest subnetworkResource */
                    subnetworkResource?: (google.cloud.compute.v1.ISubnetwork|null);
                }

                /** Represents a PatchSubnetworkRequest. */
                class PatchSubnetworkRequest implements IPatchSubnetworkRequest {

                    /**
                     * Constructs a new PatchSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchSubnetworkRequest);

                    /** PatchSubnetworkRequest drainTimeoutSeconds. */
                    public drainTimeoutSeconds?: (number|null);

                    /** PatchSubnetworkRequest project. */
                    public project: string;

                    /** PatchSubnetworkRequest region. */
                    public region: string;

                    /** PatchSubnetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchSubnetworkRequest subnetwork. */
                    public subnetwork: string;

                    /** PatchSubnetworkRequest subnetworkResource. */
                    public subnetworkResource?: (google.cloud.compute.v1.ISubnetwork|null);

                    /** PatchSubnetworkRequest _drainTimeoutSeconds. */
                    public _drainTimeoutSeconds?: "drainTimeoutSeconds";

                    /** PatchSubnetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchSubnetworkRequest): google.cloud.compute.v1.PatchSubnetworkRequest;

                    /**
                     * Encodes the specified PatchSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchSubnetworkRequest.verify|verify} messages.
                     * @param message PatchSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchSubnetworkRequest.verify|verify} messages.
                     * @param message PatchSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchSubnetworkRequest;

                    /**
                     * Decodes a PatchSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchSubnetworkRequest;

                    /**
                     * Verifies a PatchSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchSubnetworkRequest;

                    /**
                     * Creates a plain object from a PatchSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message PatchSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchTargetGrpcProxyRequest. */
                interface IPatchTargetGrpcProxyRequest {

                    /** PatchTargetGrpcProxyRequest project */
                    project?: (string|null);

                    /** PatchTargetGrpcProxyRequest requestId */
                    requestId?: (string|null);

                    /** PatchTargetGrpcProxyRequest targetGrpcProxy */
                    targetGrpcProxy?: (string|null);

                    /** PatchTargetGrpcProxyRequest targetGrpcProxyResource */
                    targetGrpcProxyResource?: (google.cloud.compute.v1.ITargetGrpcProxy|null);
                }

                /** Represents a PatchTargetGrpcProxyRequest. */
                class PatchTargetGrpcProxyRequest implements IPatchTargetGrpcProxyRequest {

                    /**
                     * Constructs a new PatchTargetGrpcProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchTargetGrpcProxyRequest);

                    /** PatchTargetGrpcProxyRequest project. */
                    public project: string;

                    /** PatchTargetGrpcProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchTargetGrpcProxyRequest targetGrpcProxy. */
                    public targetGrpcProxy: string;

                    /** PatchTargetGrpcProxyRequest targetGrpcProxyResource. */
                    public targetGrpcProxyResource?: (google.cloud.compute.v1.ITargetGrpcProxy|null);

                    /** PatchTargetGrpcProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchTargetGrpcProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchTargetGrpcProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchTargetGrpcProxyRequest): google.cloud.compute.v1.PatchTargetGrpcProxyRequest;

                    /**
                     * Encodes the specified PatchTargetGrpcProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message PatchTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchTargetGrpcProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchTargetGrpcProxyRequest.verify|verify} messages.
                     * @param message PatchTargetGrpcProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchTargetGrpcProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchTargetGrpcProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchTargetGrpcProxyRequest;

                    /**
                     * Decodes a PatchTargetGrpcProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchTargetGrpcProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchTargetGrpcProxyRequest;

                    /**
                     * Verifies a PatchTargetGrpcProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchTargetGrpcProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchTargetGrpcProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchTargetGrpcProxyRequest;

                    /**
                     * Creates a plain object from a PatchTargetGrpcProxyRequest message. Also converts values to other types if specified.
                     * @param message PatchTargetGrpcProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchTargetGrpcProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchTargetGrpcProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchTargetGrpcProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchTargetHttpProxyRequest. */
                interface IPatchTargetHttpProxyRequest {

                    /** PatchTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** PatchTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** PatchTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);

                    /** PatchTargetHttpProxyRequest targetHttpProxyResource */
                    targetHttpProxyResource?: (google.cloud.compute.v1.ITargetHttpProxy|null);
                }

                /** Represents a PatchTargetHttpProxyRequest. */
                class PatchTargetHttpProxyRequest implements IPatchTargetHttpProxyRequest {

                    /**
                     * Constructs a new PatchTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchTargetHttpProxyRequest);

                    /** PatchTargetHttpProxyRequest project. */
                    public project: string;

                    /** PatchTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /** PatchTargetHttpProxyRequest targetHttpProxyResource. */
                    public targetHttpProxyResource?: (google.cloud.compute.v1.ITargetHttpProxy|null);

                    /** PatchTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchTargetHttpProxyRequest): google.cloud.compute.v1.PatchTargetHttpProxyRequest;

                    /**
                     * Encodes the specified PatchTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchTargetHttpProxyRequest.verify|verify} messages.
                     * @param message PatchTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchTargetHttpProxyRequest.verify|verify} messages.
                     * @param message PatchTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchTargetHttpProxyRequest;

                    /**
                     * Decodes a PatchTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchTargetHttpProxyRequest;

                    /**
                     * Verifies a PatchTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a PatchTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message PatchTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchTargetHttpsProxyRequest. */
                interface IPatchTargetHttpsProxyRequest {

                    /** PatchTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** PatchTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** PatchTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);

                    /** PatchTargetHttpsProxyRequest targetHttpsProxyResource */
                    targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);
                }

                /** Represents a PatchTargetHttpsProxyRequest. */
                class PatchTargetHttpsProxyRequest implements IPatchTargetHttpsProxyRequest {

                    /**
                     * Constructs a new PatchTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchTargetHttpsProxyRequest);

                    /** PatchTargetHttpsProxyRequest project. */
                    public project: string;

                    /** PatchTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** PatchTargetHttpsProxyRequest targetHttpsProxyResource. */
                    public targetHttpsProxyResource?: (google.cloud.compute.v1.ITargetHttpsProxy|null);

                    /** PatchTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchTargetHttpsProxyRequest): google.cloud.compute.v1.PatchTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified PatchTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message PatchTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message PatchTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchTargetHttpsProxyRequest;

                    /**
                     * Decodes a PatchTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchTargetHttpsProxyRequest;

                    /**
                     * Verifies a PatchTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a PatchTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message PatchTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PatchUrlMapRequest. */
                interface IPatchUrlMapRequest {

                    /** PatchUrlMapRequest project */
                    project?: (string|null);

                    /** PatchUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** PatchUrlMapRequest urlMap */
                    urlMap?: (string|null);

                    /** PatchUrlMapRequest urlMapResource */
                    urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents a PatchUrlMapRequest. */
                class PatchUrlMapRequest implements IPatchUrlMapRequest {

                    /**
                     * Constructs a new PatchUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPatchUrlMapRequest);

                    /** PatchUrlMapRequest project. */
                    public project: string;

                    /** PatchUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** PatchUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** PatchUrlMapRequest urlMapResource. */
                    public urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** PatchUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new PatchUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PatchUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPatchUrlMapRequest): google.cloud.compute.v1.PatchUrlMapRequest;

                    /**
                     * Encodes the specified PatchUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.PatchUrlMapRequest.verify|verify} messages.
                     * @param message PatchUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPatchUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PatchUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PatchUrlMapRequest.verify|verify} messages.
                     * @param message PatchUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPatchUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PatchUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PatchUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PatchUrlMapRequest;

                    /**
                     * Decodes a PatchUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PatchUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PatchUrlMapRequest;

                    /**
                     * Verifies a PatchUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PatchUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PatchUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PatchUrlMapRequest;

                    /**
                     * Creates a plain object from a PatchUrlMapRequest message. Also converts values to other types if specified.
                     * @param message PatchUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PatchUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PatchUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PatchUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PathMatcher. */
                interface IPathMatcher {

                    /** PathMatcher defaultRouteAction */
                    defaultRouteAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** PathMatcher defaultService */
                    defaultService?: (string|null);

                    /** PathMatcher defaultUrlRedirect */
                    defaultUrlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);

                    /** PathMatcher description */
                    description?: (string|null);

                    /** PathMatcher headerAction */
                    headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** PathMatcher name */
                    name?: (string|null);

                    /** PathMatcher pathRules */
                    pathRules?: (google.cloud.compute.v1.IPathRule[]|null);

                    /** PathMatcher routeRules */
                    routeRules?: (google.cloud.compute.v1.IHttpRouteRule[]|null);
                }

                /** Represents a PathMatcher. */
                class PathMatcher implements IPathMatcher {

                    /**
                     * Constructs a new PathMatcher.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPathMatcher);

                    /** PathMatcher defaultRouteAction. */
                    public defaultRouteAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** PathMatcher defaultService. */
                    public defaultService?: (string|null);

                    /** PathMatcher defaultUrlRedirect. */
                    public defaultUrlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);

                    /** PathMatcher description. */
                    public description?: (string|null);

                    /** PathMatcher headerAction. */
                    public headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** PathMatcher name. */
                    public name?: (string|null);

                    /** PathMatcher pathRules. */
                    public pathRules: google.cloud.compute.v1.IPathRule[];

                    /** PathMatcher routeRules. */
                    public routeRules: google.cloud.compute.v1.IHttpRouteRule[];

                    /** PathMatcher _defaultRouteAction. */
                    public _defaultRouteAction?: "defaultRouteAction";

                    /** PathMatcher _defaultService. */
                    public _defaultService?: "defaultService";

                    /** PathMatcher _defaultUrlRedirect. */
                    public _defaultUrlRedirect?: "defaultUrlRedirect";

                    /** PathMatcher _description. */
                    public _description?: "description";

                    /** PathMatcher _headerAction. */
                    public _headerAction?: "headerAction";

                    /** PathMatcher _name. */
                    public _name?: "name";

                    /**
                     * Creates a new PathMatcher instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PathMatcher instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPathMatcher): google.cloud.compute.v1.PathMatcher;

                    /**
                     * Encodes the specified PathMatcher message. Does not implicitly {@link google.cloud.compute.v1.PathMatcher.verify|verify} messages.
                     * @param message PathMatcher message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPathMatcher, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PathMatcher message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PathMatcher.verify|verify} messages.
                     * @param message PathMatcher message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPathMatcher, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PathMatcher message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PathMatcher
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PathMatcher;

                    /**
                     * Decodes a PathMatcher message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PathMatcher
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PathMatcher;

                    /**
                     * Verifies a PathMatcher message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PathMatcher message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PathMatcher
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PathMatcher;

                    /**
                     * Creates a plain object from a PathMatcher message. Also converts values to other types if specified.
                     * @param message PathMatcher
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PathMatcher, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PathMatcher to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PathMatcher
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PathRule. */
                interface IPathRule {

                    /** PathRule paths */
                    paths?: (string[]|null);

                    /** PathRule routeAction */
                    routeAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** PathRule service */
                    service?: (string|null);

                    /** PathRule urlRedirect */
                    urlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);
                }

                /** Represents a PathRule. */
                class PathRule implements IPathRule {

                    /**
                     * Constructs a new PathRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPathRule);

                    /** PathRule paths. */
                    public paths: string[];

                    /** PathRule routeAction. */
                    public routeAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** PathRule service. */
                    public service?: (string|null);

                    /** PathRule urlRedirect. */
                    public urlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);

                    /** PathRule _routeAction. */
                    public _routeAction?: "routeAction";

                    /** PathRule _service. */
                    public _service?: "service";

                    /** PathRule _urlRedirect. */
                    public _urlRedirect?: "urlRedirect";

                    /**
                     * Creates a new PathRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PathRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPathRule): google.cloud.compute.v1.PathRule;

                    /**
                     * Encodes the specified PathRule message. Does not implicitly {@link google.cloud.compute.v1.PathRule.verify|verify} messages.
                     * @param message PathRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPathRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PathRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PathRule.verify|verify} messages.
                     * @param message PathRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPathRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PathRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PathRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PathRule;

                    /**
                     * Decodes a PathRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PathRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PathRule;

                    /**
                     * Verifies a PathRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PathRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PathRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PathRule;

                    /**
                     * Creates a plain object from a PathRule message. Also converts values to other types if specified.
                     * @param message PathRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PathRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PathRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PathRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PerInstanceConfig. */
                interface IPerInstanceConfig {

                    /** PerInstanceConfig fingerprint */
                    fingerprint?: (string|null);

                    /** PerInstanceConfig name */
                    name?: (string|null);

                    /** PerInstanceConfig preservedState */
                    preservedState?: (google.cloud.compute.v1.IPreservedState|null);

                    /** PerInstanceConfig status */
                    status?: (string|null);
                }

                /** Represents a PerInstanceConfig. */
                class PerInstanceConfig implements IPerInstanceConfig {

                    /**
                     * Constructs a new PerInstanceConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPerInstanceConfig);

                    /** PerInstanceConfig fingerprint. */
                    public fingerprint?: (string|null);

                    /** PerInstanceConfig name. */
                    public name?: (string|null);

                    /** PerInstanceConfig preservedState. */
                    public preservedState?: (google.cloud.compute.v1.IPreservedState|null);

                    /** PerInstanceConfig status. */
                    public status?: (string|null);

                    /** PerInstanceConfig _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** PerInstanceConfig _name. */
                    public _name?: "name";

                    /** PerInstanceConfig _preservedState. */
                    public _preservedState?: "preservedState";

                    /** PerInstanceConfig _status. */
                    public _status?: "status";

                    /**
                     * Creates a new PerInstanceConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PerInstanceConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPerInstanceConfig): google.cloud.compute.v1.PerInstanceConfig;

                    /**
                     * Encodes the specified PerInstanceConfig message. Does not implicitly {@link google.cloud.compute.v1.PerInstanceConfig.verify|verify} messages.
                     * @param message PerInstanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPerInstanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PerInstanceConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PerInstanceConfig.verify|verify} messages.
                     * @param message PerInstanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPerInstanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PerInstanceConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PerInstanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PerInstanceConfig;

                    /**
                     * Decodes a PerInstanceConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PerInstanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PerInstanceConfig;

                    /**
                     * Verifies a PerInstanceConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PerInstanceConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PerInstanceConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PerInstanceConfig;

                    /**
                     * Creates a plain object from a PerInstanceConfig message. Also converts values to other types if specified.
                     * @param message PerInstanceConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PerInstanceConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PerInstanceConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PerInstanceConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PerInstanceConfig {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        APPLYING = 352003508,
                        DELETING = 528602024,
                        EFFECTIVE = 244201863,
                        NONE = 2402104,
                        UNAPPLIED = 483935140,
                        UNAPPLIED_DELETION = 313956873
                    }
                }

                /** Properties of a Policy. */
                interface IPolicy {

                    /** Policy auditConfigs */
                    auditConfigs?: (google.cloud.compute.v1.IAuditConfig[]|null);

                    /** Policy bindings */
                    bindings?: (google.cloud.compute.v1.IBinding[]|null);

                    /** Policy etag */
                    etag?: (string|null);

                    /** Policy iamOwned */
                    iamOwned?: (boolean|null);

                    /** Policy rules */
                    rules?: (google.cloud.compute.v1.IRule[]|null);

                    /** Policy version */
                    version?: (number|null);
                }

                /** Represents a Policy. */
                class Policy implements IPolicy {

                    /**
                     * Constructs a new Policy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPolicy);

                    /** Policy auditConfigs. */
                    public auditConfigs: google.cloud.compute.v1.IAuditConfig[];

                    /** Policy bindings. */
                    public bindings: google.cloud.compute.v1.IBinding[];

                    /** Policy etag. */
                    public etag?: (string|null);

                    /** Policy iamOwned. */
                    public iamOwned?: (boolean|null);

                    /** Policy rules. */
                    public rules: google.cloud.compute.v1.IRule[];

                    /** Policy version. */
                    public version?: (number|null);

                    /** Policy _etag. */
                    public _etag?: "etag";

                    /** Policy _iamOwned. */
                    public _iamOwned?: "iamOwned";

                    /** Policy _version. */
                    public _version?: "version";

                    /**
                     * Creates a new Policy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Policy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPolicy): google.cloud.compute.v1.Policy;

                    /**
                     * Encodes the specified Policy message. Does not implicitly {@link google.cloud.compute.v1.Policy.verify|verify} messages.
                     * @param message Policy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Policy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Policy.verify|verify} messages.
                     * @param message Policy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Policy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Policy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Policy;

                    /**
                     * Decodes a Policy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Policy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Policy;

                    /**
                     * Verifies a Policy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Policy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Policy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Policy;

                    /**
                     * Creates a plain object from a Policy message. Also converts values to other types if specified.
                     * @param message Policy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Policy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Policy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Policy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PreconfiguredWafSet. */
                interface IPreconfiguredWafSet {

                    /** PreconfiguredWafSet expressionSets */
                    expressionSets?: (google.cloud.compute.v1.IWafExpressionSet[]|null);
                }

                /** Represents a PreconfiguredWafSet. */
                class PreconfiguredWafSet implements IPreconfiguredWafSet {

                    /**
                     * Constructs a new PreconfiguredWafSet.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPreconfiguredWafSet);

                    /** PreconfiguredWafSet expressionSets. */
                    public expressionSets: google.cloud.compute.v1.IWafExpressionSet[];

                    /**
                     * Creates a new PreconfiguredWafSet instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PreconfiguredWafSet instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPreconfiguredWafSet): google.cloud.compute.v1.PreconfiguredWafSet;

                    /**
                     * Encodes the specified PreconfiguredWafSet message. Does not implicitly {@link google.cloud.compute.v1.PreconfiguredWafSet.verify|verify} messages.
                     * @param message PreconfiguredWafSet message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPreconfiguredWafSet, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PreconfiguredWafSet message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PreconfiguredWafSet.verify|verify} messages.
                     * @param message PreconfiguredWafSet message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPreconfiguredWafSet, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PreconfiguredWafSet message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PreconfiguredWafSet
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PreconfiguredWafSet;

                    /**
                     * Decodes a PreconfiguredWafSet message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PreconfiguredWafSet
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PreconfiguredWafSet;

                    /**
                     * Verifies a PreconfiguredWafSet message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PreconfiguredWafSet message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PreconfiguredWafSet
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PreconfiguredWafSet;

                    /**
                     * Creates a plain object from a PreconfiguredWafSet message. Also converts values to other types if specified.
                     * @param message PreconfiguredWafSet
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PreconfiguredWafSet, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PreconfiguredWafSet to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PreconfiguredWafSet
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PreservedState. */
                interface IPreservedState {

                    /** PreservedState disks */
                    disks?: ({ [k: string]: google.cloud.compute.v1.IPreservedStatePreservedDisk }|null);

                    /** PreservedState metadata */
                    metadata?: ({ [k: string]: string }|null);
                }

                /** Represents a PreservedState. */
                class PreservedState implements IPreservedState {

                    /**
                     * Constructs a new PreservedState.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPreservedState);

                    /** PreservedState disks. */
                    public disks: { [k: string]: google.cloud.compute.v1.IPreservedStatePreservedDisk };

                    /** PreservedState metadata. */
                    public metadata: { [k: string]: string };

                    /**
                     * Creates a new PreservedState instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PreservedState instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPreservedState): google.cloud.compute.v1.PreservedState;

                    /**
                     * Encodes the specified PreservedState message. Does not implicitly {@link google.cloud.compute.v1.PreservedState.verify|verify} messages.
                     * @param message PreservedState message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPreservedState, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PreservedState message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PreservedState.verify|verify} messages.
                     * @param message PreservedState message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPreservedState, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PreservedState message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PreservedState
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PreservedState;

                    /**
                     * Decodes a PreservedState message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PreservedState
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PreservedState;

                    /**
                     * Verifies a PreservedState message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PreservedState message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PreservedState
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PreservedState;

                    /**
                     * Creates a plain object from a PreservedState message. Also converts values to other types if specified.
                     * @param message PreservedState
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PreservedState, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PreservedState to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PreservedState
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PreservedStatePreservedDisk. */
                interface IPreservedStatePreservedDisk {

                    /** PreservedStatePreservedDisk autoDelete */
                    autoDelete?: (string|null);

                    /** PreservedStatePreservedDisk mode */
                    mode?: (string|null);

                    /** PreservedStatePreservedDisk source */
                    source?: (string|null);
                }

                /** Represents a PreservedStatePreservedDisk. */
                class PreservedStatePreservedDisk implements IPreservedStatePreservedDisk {

                    /**
                     * Constructs a new PreservedStatePreservedDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPreservedStatePreservedDisk);

                    /** PreservedStatePreservedDisk autoDelete. */
                    public autoDelete?: (string|null);

                    /** PreservedStatePreservedDisk mode. */
                    public mode?: (string|null);

                    /** PreservedStatePreservedDisk source. */
                    public source?: (string|null);

                    /** PreservedStatePreservedDisk _autoDelete. */
                    public _autoDelete?: "autoDelete";

                    /** PreservedStatePreservedDisk _mode. */
                    public _mode?: "mode";

                    /** PreservedStatePreservedDisk _source. */
                    public _source?: "source";

                    /**
                     * Creates a new PreservedStatePreservedDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PreservedStatePreservedDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPreservedStatePreservedDisk): google.cloud.compute.v1.PreservedStatePreservedDisk;

                    /**
                     * Encodes the specified PreservedStatePreservedDisk message. Does not implicitly {@link google.cloud.compute.v1.PreservedStatePreservedDisk.verify|verify} messages.
                     * @param message PreservedStatePreservedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPreservedStatePreservedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PreservedStatePreservedDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PreservedStatePreservedDisk.verify|verify} messages.
                     * @param message PreservedStatePreservedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPreservedStatePreservedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PreservedStatePreservedDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PreservedStatePreservedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PreservedStatePreservedDisk;

                    /**
                     * Decodes a PreservedStatePreservedDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PreservedStatePreservedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PreservedStatePreservedDisk;

                    /**
                     * Verifies a PreservedStatePreservedDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PreservedStatePreservedDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PreservedStatePreservedDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PreservedStatePreservedDisk;

                    /**
                     * Creates a plain object from a PreservedStatePreservedDisk message. Also converts values to other types if specified.
                     * @param message PreservedStatePreservedDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PreservedStatePreservedDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PreservedStatePreservedDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PreservedStatePreservedDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PreservedStatePreservedDisk {

                    /** AutoDelete enum. */
                    enum AutoDelete {
                        UNDEFINED_AUTO_DELETE = 0,
                        NEVER = 74175084,
                        ON_PERMANENT_INSTANCE_DELETION = 95727719
                    }

                    /** Mode enum. */
                    enum Mode {
                        UNDEFINED_MODE = 0,
                        READ_ONLY = 91950261,
                        READ_WRITE = 173607894
                    }
                }

                /** Properties of a PreviewRouterRequest. */
                interface IPreviewRouterRequest {

                    /** PreviewRouterRequest project */
                    project?: (string|null);

                    /** PreviewRouterRequest region */
                    region?: (string|null);

                    /** PreviewRouterRequest router */
                    router?: (string|null);

                    /** PreviewRouterRequest routerResource */
                    routerResource?: (google.cloud.compute.v1.IRouter|null);
                }

                /** Represents a PreviewRouterRequest. */
                class PreviewRouterRequest implements IPreviewRouterRequest {

                    /**
                     * Constructs a new PreviewRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPreviewRouterRequest);

                    /** PreviewRouterRequest project. */
                    public project: string;

                    /** PreviewRouterRequest region. */
                    public region: string;

                    /** PreviewRouterRequest router. */
                    public router: string;

                    /** PreviewRouterRequest routerResource. */
                    public routerResource?: (google.cloud.compute.v1.IRouter|null);

                    /**
                     * Creates a new PreviewRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PreviewRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPreviewRouterRequest): google.cloud.compute.v1.PreviewRouterRequest;

                    /**
                     * Encodes the specified PreviewRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.PreviewRouterRequest.verify|verify} messages.
                     * @param message PreviewRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPreviewRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PreviewRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PreviewRouterRequest.verify|verify} messages.
                     * @param message PreviewRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPreviewRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PreviewRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PreviewRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PreviewRouterRequest;

                    /**
                     * Decodes a PreviewRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PreviewRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PreviewRouterRequest;

                    /**
                     * Verifies a PreviewRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PreviewRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PreviewRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PreviewRouterRequest;

                    /**
                     * Creates a plain object from a PreviewRouterRequest message. Also converts values to other types if specified.
                     * @param message PreviewRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PreviewRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PreviewRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PreviewRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Project. */
                interface IProject {

                    /** Project commonInstanceMetadata */
                    commonInstanceMetadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** Project creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Project defaultNetworkTier */
                    defaultNetworkTier?: (string|null);

                    /** Project defaultServiceAccount */
                    defaultServiceAccount?: (string|null);

                    /** Project description */
                    description?: (string|null);

                    /** Project enabledFeatures */
                    enabledFeatures?: (string[]|null);

                    /** Project id */
                    id?: (number|Long|string|null);

                    /** Project kind */
                    kind?: (string|null);

                    /** Project name */
                    name?: (string|null);

                    /** Project quotas */
                    quotas?: (google.cloud.compute.v1.IQuota[]|null);

                    /** Project selfLink */
                    selfLink?: (string|null);

                    /** Project usageExportLocation */
                    usageExportLocation?: (google.cloud.compute.v1.IUsageExportLocation|null);

                    /** Project xpnProjectStatus */
                    xpnProjectStatus?: (string|null);
                }

                /** Represents a Project. */
                class Project implements IProject {

                    /**
                     * Constructs a new Project.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IProject);

                    /** Project commonInstanceMetadata. */
                    public commonInstanceMetadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** Project creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Project defaultNetworkTier. */
                    public defaultNetworkTier?: (string|null);

                    /** Project defaultServiceAccount. */
                    public defaultServiceAccount?: (string|null);

                    /** Project description. */
                    public description?: (string|null);

                    /** Project enabledFeatures. */
                    public enabledFeatures: string[];

                    /** Project id. */
                    public id?: (number|Long|string|null);

                    /** Project kind. */
                    public kind?: (string|null);

                    /** Project name. */
                    public name?: (string|null);

                    /** Project quotas. */
                    public quotas: google.cloud.compute.v1.IQuota[];

                    /** Project selfLink. */
                    public selfLink?: (string|null);

                    /** Project usageExportLocation. */
                    public usageExportLocation?: (google.cloud.compute.v1.IUsageExportLocation|null);

                    /** Project xpnProjectStatus. */
                    public xpnProjectStatus?: (string|null);

                    /** Project _commonInstanceMetadata. */
                    public _commonInstanceMetadata?: "commonInstanceMetadata";

                    /** Project _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Project _defaultNetworkTier. */
                    public _defaultNetworkTier?: "defaultNetworkTier";

                    /** Project _defaultServiceAccount. */
                    public _defaultServiceAccount?: "defaultServiceAccount";

                    /** Project _description. */
                    public _description?: "description";

                    /** Project _id. */
                    public _id?: "id";

                    /** Project _kind. */
                    public _kind?: "kind";

                    /** Project _name. */
                    public _name?: "name";

                    /** Project _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Project _usageExportLocation. */
                    public _usageExportLocation?: "usageExportLocation";

                    /** Project _xpnProjectStatus. */
                    public _xpnProjectStatus?: "xpnProjectStatus";

                    /**
                     * Creates a new Project instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Project instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IProject): google.cloud.compute.v1.Project;

                    /**
                     * Encodes the specified Project message. Does not implicitly {@link google.cloud.compute.v1.Project.verify|verify} messages.
                     * @param message Project message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IProject, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Project message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Project.verify|verify} messages.
                     * @param message Project message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IProject, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Project message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Project
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Project;

                    /**
                     * Decodes a Project message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Project
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Project;

                    /**
                     * Verifies a Project message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Project message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Project
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Project;

                    /**
                     * Creates a plain object from a Project message. Also converts values to other types if specified.
                     * @param message Project
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Project, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Project to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Project
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Project {

                    /** DefaultNetworkTier enum. */
                    enum DefaultNetworkTier {
                        UNDEFINED_DEFAULT_NETWORK_TIER = 0,
                        FIXED_STANDARD = 310464328,
                        PREMIUM = 399530551,
                        STANDARD = 484642493,
                        STANDARD_OVERRIDES_FIXED_STANDARD = 465847234
                    }

                    /** XpnProjectStatus enum. */
                    enum XpnProjectStatus {
                        UNDEFINED_XPN_PROJECT_STATUS = 0,
                        HOST = 2223528,
                        UNSPECIFIED_XPN_PROJECT_STATUS = 340393257
                    }
                }

                /** Properties of a ProjectsDisableXpnResourceRequest. */
                interface IProjectsDisableXpnResourceRequest {

                    /** ProjectsDisableXpnResourceRequest xpnResource */
                    xpnResource?: (google.cloud.compute.v1.IXpnResourceId|null);
                }

                /** Represents a ProjectsDisableXpnResourceRequest. */
                class ProjectsDisableXpnResourceRequest implements IProjectsDisableXpnResourceRequest {

                    /**
                     * Constructs a new ProjectsDisableXpnResourceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IProjectsDisableXpnResourceRequest);

                    /** ProjectsDisableXpnResourceRequest xpnResource. */
                    public xpnResource?: (google.cloud.compute.v1.IXpnResourceId|null);

                    /** ProjectsDisableXpnResourceRequest _xpnResource. */
                    public _xpnResource?: "xpnResource";

                    /**
                     * Creates a new ProjectsDisableXpnResourceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProjectsDisableXpnResourceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IProjectsDisableXpnResourceRequest): google.cloud.compute.v1.ProjectsDisableXpnResourceRequest;

                    /**
                     * Encodes the specified ProjectsDisableXpnResourceRequest message. Does not implicitly {@link google.cloud.compute.v1.ProjectsDisableXpnResourceRequest.verify|verify} messages.
                     * @param message ProjectsDisableXpnResourceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IProjectsDisableXpnResourceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProjectsDisableXpnResourceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ProjectsDisableXpnResourceRequest.verify|verify} messages.
                     * @param message ProjectsDisableXpnResourceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IProjectsDisableXpnResourceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProjectsDisableXpnResourceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProjectsDisableXpnResourceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ProjectsDisableXpnResourceRequest;

                    /**
                     * Decodes a ProjectsDisableXpnResourceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProjectsDisableXpnResourceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ProjectsDisableXpnResourceRequest;

                    /**
                     * Verifies a ProjectsDisableXpnResourceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProjectsDisableXpnResourceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProjectsDisableXpnResourceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ProjectsDisableXpnResourceRequest;

                    /**
                     * Creates a plain object from a ProjectsDisableXpnResourceRequest message. Also converts values to other types if specified.
                     * @param message ProjectsDisableXpnResourceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ProjectsDisableXpnResourceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProjectsDisableXpnResourceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProjectsDisableXpnResourceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProjectsEnableXpnResourceRequest. */
                interface IProjectsEnableXpnResourceRequest {

                    /** ProjectsEnableXpnResourceRequest xpnResource */
                    xpnResource?: (google.cloud.compute.v1.IXpnResourceId|null);
                }

                /** Represents a ProjectsEnableXpnResourceRequest. */
                class ProjectsEnableXpnResourceRequest implements IProjectsEnableXpnResourceRequest {

                    /**
                     * Constructs a new ProjectsEnableXpnResourceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IProjectsEnableXpnResourceRequest);

                    /** ProjectsEnableXpnResourceRequest xpnResource. */
                    public xpnResource?: (google.cloud.compute.v1.IXpnResourceId|null);

                    /** ProjectsEnableXpnResourceRequest _xpnResource. */
                    public _xpnResource?: "xpnResource";

                    /**
                     * Creates a new ProjectsEnableXpnResourceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProjectsEnableXpnResourceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IProjectsEnableXpnResourceRequest): google.cloud.compute.v1.ProjectsEnableXpnResourceRequest;

                    /**
                     * Encodes the specified ProjectsEnableXpnResourceRequest message. Does not implicitly {@link google.cloud.compute.v1.ProjectsEnableXpnResourceRequest.verify|verify} messages.
                     * @param message ProjectsEnableXpnResourceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IProjectsEnableXpnResourceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProjectsEnableXpnResourceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ProjectsEnableXpnResourceRequest.verify|verify} messages.
                     * @param message ProjectsEnableXpnResourceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IProjectsEnableXpnResourceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProjectsEnableXpnResourceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProjectsEnableXpnResourceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ProjectsEnableXpnResourceRequest;

                    /**
                     * Decodes a ProjectsEnableXpnResourceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProjectsEnableXpnResourceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ProjectsEnableXpnResourceRequest;

                    /**
                     * Verifies a ProjectsEnableXpnResourceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProjectsEnableXpnResourceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProjectsEnableXpnResourceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ProjectsEnableXpnResourceRequest;

                    /**
                     * Creates a plain object from a ProjectsEnableXpnResourceRequest message. Also converts values to other types if specified.
                     * @param message ProjectsEnableXpnResourceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ProjectsEnableXpnResourceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProjectsEnableXpnResourceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProjectsEnableXpnResourceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProjectsGetXpnResources. */
                interface IProjectsGetXpnResources {

                    /** ProjectsGetXpnResources kind */
                    kind?: (string|null);

                    /** ProjectsGetXpnResources nextPageToken */
                    nextPageToken?: (string|null);

                    /** ProjectsGetXpnResources resources */
                    resources?: (google.cloud.compute.v1.IXpnResourceId[]|null);
                }

                /** Represents a ProjectsGetXpnResources. */
                class ProjectsGetXpnResources implements IProjectsGetXpnResources {

                    /**
                     * Constructs a new ProjectsGetXpnResources.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IProjectsGetXpnResources);

                    /** ProjectsGetXpnResources kind. */
                    public kind?: (string|null);

                    /** ProjectsGetXpnResources nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ProjectsGetXpnResources resources. */
                    public resources: google.cloud.compute.v1.IXpnResourceId[];

                    /** ProjectsGetXpnResources _kind. */
                    public _kind?: "kind";

                    /** ProjectsGetXpnResources _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /**
                     * Creates a new ProjectsGetXpnResources instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProjectsGetXpnResources instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IProjectsGetXpnResources): google.cloud.compute.v1.ProjectsGetXpnResources;

                    /**
                     * Encodes the specified ProjectsGetXpnResources message. Does not implicitly {@link google.cloud.compute.v1.ProjectsGetXpnResources.verify|verify} messages.
                     * @param message ProjectsGetXpnResources message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IProjectsGetXpnResources, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProjectsGetXpnResources message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ProjectsGetXpnResources.verify|verify} messages.
                     * @param message ProjectsGetXpnResources message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IProjectsGetXpnResources, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProjectsGetXpnResources message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProjectsGetXpnResources
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ProjectsGetXpnResources;

                    /**
                     * Decodes a ProjectsGetXpnResources message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProjectsGetXpnResources
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ProjectsGetXpnResources;

                    /**
                     * Verifies a ProjectsGetXpnResources message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProjectsGetXpnResources message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProjectsGetXpnResources
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ProjectsGetXpnResources;

                    /**
                     * Creates a plain object from a ProjectsGetXpnResources message. Also converts values to other types if specified.
                     * @param message ProjectsGetXpnResources
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ProjectsGetXpnResources, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProjectsGetXpnResources to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProjectsGetXpnResources
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProjectsListXpnHostsRequest. */
                interface IProjectsListXpnHostsRequest {

                    /** ProjectsListXpnHostsRequest organization */
                    organization?: (string|null);
                }

                /** Represents a ProjectsListXpnHostsRequest. */
                class ProjectsListXpnHostsRequest implements IProjectsListXpnHostsRequest {

                    /**
                     * Constructs a new ProjectsListXpnHostsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IProjectsListXpnHostsRequest);

                    /** ProjectsListXpnHostsRequest organization. */
                    public organization?: (string|null);

                    /** ProjectsListXpnHostsRequest _organization. */
                    public _organization?: "organization";

                    /**
                     * Creates a new ProjectsListXpnHostsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProjectsListXpnHostsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IProjectsListXpnHostsRequest): google.cloud.compute.v1.ProjectsListXpnHostsRequest;

                    /**
                     * Encodes the specified ProjectsListXpnHostsRequest message. Does not implicitly {@link google.cloud.compute.v1.ProjectsListXpnHostsRequest.verify|verify} messages.
                     * @param message ProjectsListXpnHostsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IProjectsListXpnHostsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProjectsListXpnHostsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ProjectsListXpnHostsRequest.verify|verify} messages.
                     * @param message ProjectsListXpnHostsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IProjectsListXpnHostsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProjectsListXpnHostsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProjectsListXpnHostsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ProjectsListXpnHostsRequest;

                    /**
                     * Decodes a ProjectsListXpnHostsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProjectsListXpnHostsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ProjectsListXpnHostsRequest;

                    /**
                     * Verifies a ProjectsListXpnHostsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProjectsListXpnHostsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProjectsListXpnHostsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ProjectsListXpnHostsRequest;

                    /**
                     * Creates a plain object from a ProjectsListXpnHostsRequest message. Also converts values to other types if specified.
                     * @param message ProjectsListXpnHostsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ProjectsListXpnHostsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProjectsListXpnHostsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProjectsListXpnHostsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProjectsSetDefaultNetworkTierRequest. */
                interface IProjectsSetDefaultNetworkTierRequest {

                    /** ProjectsSetDefaultNetworkTierRequest networkTier */
                    networkTier?: (string|null);
                }

                /** Represents a ProjectsSetDefaultNetworkTierRequest. */
                class ProjectsSetDefaultNetworkTierRequest implements IProjectsSetDefaultNetworkTierRequest {

                    /**
                     * Constructs a new ProjectsSetDefaultNetworkTierRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IProjectsSetDefaultNetworkTierRequest);

                    /** ProjectsSetDefaultNetworkTierRequest networkTier. */
                    public networkTier?: (string|null);

                    /** ProjectsSetDefaultNetworkTierRequest _networkTier. */
                    public _networkTier?: "networkTier";

                    /**
                     * Creates a new ProjectsSetDefaultNetworkTierRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProjectsSetDefaultNetworkTierRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IProjectsSetDefaultNetworkTierRequest): google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest;

                    /**
                     * Encodes the specified ProjectsSetDefaultNetworkTierRequest message. Does not implicitly {@link google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest.verify|verify} messages.
                     * @param message ProjectsSetDefaultNetworkTierRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IProjectsSetDefaultNetworkTierRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProjectsSetDefaultNetworkTierRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest.verify|verify} messages.
                     * @param message ProjectsSetDefaultNetworkTierRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IProjectsSetDefaultNetworkTierRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProjectsSetDefaultNetworkTierRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProjectsSetDefaultNetworkTierRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest;

                    /**
                     * Decodes a ProjectsSetDefaultNetworkTierRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProjectsSetDefaultNetworkTierRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest;

                    /**
                     * Verifies a ProjectsSetDefaultNetworkTierRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProjectsSetDefaultNetworkTierRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProjectsSetDefaultNetworkTierRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest;

                    /**
                     * Creates a plain object from a ProjectsSetDefaultNetworkTierRequest message. Also converts values to other types if specified.
                     * @param message ProjectsSetDefaultNetworkTierRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ProjectsSetDefaultNetworkTierRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProjectsSetDefaultNetworkTierRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProjectsSetDefaultNetworkTierRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProjectsSetDefaultNetworkTierRequest {

                    /** NetworkTier enum. */
                    enum NetworkTier {
                        UNDEFINED_NETWORK_TIER = 0,
                        FIXED_STANDARD = 310464328,
                        PREMIUM = 399530551,
                        STANDARD = 484642493,
                        STANDARD_OVERRIDES_FIXED_STANDARD = 465847234
                    }
                }

                /** Properties of a PublicAdvertisedPrefix. */
                interface IPublicAdvertisedPrefix {

                    /** PublicAdvertisedPrefix creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** PublicAdvertisedPrefix description */
                    description?: (string|null);

                    /** PublicAdvertisedPrefix dnsVerificationIp */
                    dnsVerificationIp?: (string|null);

                    /** PublicAdvertisedPrefix fingerprint */
                    fingerprint?: (string|null);

                    /** PublicAdvertisedPrefix id */
                    id?: (number|Long|string|null);

                    /** PublicAdvertisedPrefix ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** PublicAdvertisedPrefix kind */
                    kind?: (string|null);

                    /** PublicAdvertisedPrefix name */
                    name?: (string|null);

                    /** PublicAdvertisedPrefix publicDelegatedPrefixs */
                    publicDelegatedPrefixs?: (google.cloud.compute.v1.IPublicAdvertisedPrefixPublicDelegatedPrefix[]|null);

                    /** PublicAdvertisedPrefix selfLink */
                    selfLink?: (string|null);

                    /** PublicAdvertisedPrefix sharedSecret */
                    sharedSecret?: (string|null);

                    /** PublicAdvertisedPrefix status */
                    status?: (string|null);
                }

                /** Represents a PublicAdvertisedPrefix. */
                class PublicAdvertisedPrefix implements IPublicAdvertisedPrefix {

                    /**
                     * Constructs a new PublicAdvertisedPrefix.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicAdvertisedPrefix);

                    /** PublicAdvertisedPrefix creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** PublicAdvertisedPrefix description. */
                    public description?: (string|null);

                    /** PublicAdvertisedPrefix dnsVerificationIp. */
                    public dnsVerificationIp?: (string|null);

                    /** PublicAdvertisedPrefix fingerprint. */
                    public fingerprint?: (string|null);

                    /** PublicAdvertisedPrefix id. */
                    public id?: (number|Long|string|null);

                    /** PublicAdvertisedPrefix ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** PublicAdvertisedPrefix kind. */
                    public kind?: (string|null);

                    /** PublicAdvertisedPrefix name. */
                    public name?: (string|null);

                    /** PublicAdvertisedPrefix publicDelegatedPrefixs. */
                    public publicDelegatedPrefixs: google.cloud.compute.v1.IPublicAdvertisedPrefixPublicDelegatedPrefix[];

                    /** PublicAdvertisedPrefix selfLink. */
                    public selfLink?: (string|null);

                    /** PublicAdvertisedPrefix sharedSecret. */
                    public sharedSecret?: (string|null);

                    /** PublicAdvertisedPrefix status. */
                    public status?: (string|null);

                    /** PublicAdvertisedPrefix _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** PublicAdvertisedPrefix _description. */
                    public _description?: "description";

                    /** PublicAdvertisedPrefix _dnsVerificationIp. */
                    public _dnsVerificationIp?: "dnsVerificationIp";

                    /** PublicAdvertisedPrefix _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** PublicAdvertisedPrefix _id. */
                    public _id?: "id";

                    /** PublicAdvertisedPrefix _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** PublicAdvertisedPrefix _kind. */
                    public _kind?: "kind";

                    /** PublicAdvertisedPrefix _name. */
                    public _name?: "name";

                    /** PublicAdvertisedPrefix _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PublicAdvertisedPrefix _sharedSecret. */
                    public _sharedSecret?: "sharedSecret";

                    /** PublicAdvertisedPrefix _status. */
                    public _status?: "status";

                    /**
                     * Creates a new PublicAdvertisedPrefix instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicAdvertisedPrefix instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicAdvertisedPrefix): google.cloud.compute.v1.PublicAdvertisedPrefix;

                    /**
                     * Encodes the specified PublicAdvertisedPrefix message. Does not implicitly {@link google.cloud.compute.v1.PublicAdvertisedPrefix.verify|verify} messages.
                     * @param message PublicAdvertisedPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicAdvertisedPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicAdvertisedPrefix message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicAdvertisedPrefix.verify|verify} messages.
                     * @param message PublicAdvertisedPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicAdvertisedPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicAdvertisedPrefix message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicAdvertisedPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicAdvertisedPrefix;

                    /**
                     * Decodes a PublicAdvertisedPrefix message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicAdvertisedPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicAdvertisedPrefix;

                    /**
                     * Verifies a PublicAdvertisedPrefix message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicAdvertisedPrefix message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicAdvertisedPrefix
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicAdvertisedPrefix;

                    /**
                     * Creates a plain object from a PublicAdvertisedPrefix message. Also converts values to other types if specified.
                     * @param message PublicAdvertisedPrefix
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicAdvertisedPrefix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicAdvertisedPrefix to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicAdvertisedPrefix
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PublicAdvertisedPrefix {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        INITIAL = 518841124,
                        PREFIX_CONFIGURATION_COMPLETE = 480889551,
                        PREFIX_CONFIGURATION_IN_PROGRESS = 378550961,
                        PREFIX_REMOVAL_IN_PROGRESS = 284375783,
                        PTR_CONFIGURED = 513497167,
                        REVERSE_DNS_LOOKUP_FAILED = 295755183,
                        VALIDATED = 66197998
                    }
                }

                /** Properties of a PublicAdvertisedPrefixList. */
                interface IPublicAdvertisedPrefixList {

                    /** PublicAdvertisedPrefixList id */
                    id?: (string|null);

                    /** PublicAdvertisedPrefixList items */
                    items?: (google.cloud.compute.v1.IPublicAdvertisedPrefix[]|null);

                    /** PublicAdvertisedPrefixList kind */
                    kind?: (string|null);

                    /** PublicAdvertisedPrefixList nextPageToken */
                    nextPageToken?: (string|null);

                    /** PublicAdvertisedPrefixList selfLink */
                    selfLink?: (string|null);

                    /** PublicAdvertisedPrefixList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PublicAdvertisedPrefixList. */
                class PublicAdvertisedPrefixList implements IPublicAdvertisedPrefixList {

                    /**
                     * Constructs a new PublicAdvertisedPrefixList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicAdvertisedPrefixList);

                    /** PublicAdvertisedPrefixList id. */
                    public id?: (string|null);

                    /** PublicAdvertisedPrefixList items. */
                    public items: google.cloud.compute.v1.IPublicAdvertisedPrefix[];

                    /** PublicAdvertisedPrefixList kind. */
                    public kind?: (string|null);

                    /** PublicAdvertisedPrefixList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** PublicAdvertisedPrefixList selfLink. */
                    public selfLink?: (string|null);

                    /** PublicAdvertisedPrefixList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PublicAdvertisedPrefixList _id. */
                    public _id?: "id";

                    /** PublicAdvertisedPrefixList _kind. */
                    public _kind?: "kind";

                    /** PublicAdvertisedPrefixList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** PublicAdvertisedPrefixList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PublicAdvertisedPrefixList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PublicAdvertisedPrefixList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicAdvertisedPrefixList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicAdvertisedPrefixList): google.cloud.compute.v1.PublicAdvertisedPrefixList;

                    /**
                     * Encodes the specified PublicAdvertisedPrefixList message. Does not implicitly {@link google.cloud.compute.v1.PublicAdvertisedPrefixList.verify|verify} messages.
                     * @param message PublicAdvertisedPrefixList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicAdvertisedPrefixList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicAdvertisedPrefixList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicAdvertisedPrefixList.verify|verify} messages.
                     * @param message PublicAdvertisedPrefixList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicAdvertisedPrefixList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicAdvertisedPrefixList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicAdvertisedPrefixList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicAdvertisedPrefixList;

                    /**
                     * Decodes a PublicAdvertisedPrefixList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicAdvertisedPrefixList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicAdvertisedPrefixList;

                    /**
                     * Verifies a PublicAdvertisedPrefixList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicAdvertisedPrefixList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicAdvertisedPrefixList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicAdvertisedPrefixList;

                    /**
                     * Creates a plain object from a PublicAdvertisedPrefixList message. Also converts values to other types if specified.
                     * @param message PublicAdvertisedPrefixList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicAdvertisedPrefixList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicAdvertisedPrefixList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicAdvertisedPrefixList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PublicAdvertisedPrefixPublicDelegatedPrefix. */
                interface IPublicAdvertisedPrefixPublicDelegatedPrefix {

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix ipRange */
                    ipRange?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix name */
                    name?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix project */
                    project?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix region */
                    region?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix status */
                    status?: (string|null);
                }

                /** Represents a PublicAdvertisedPrefixPublicDelegatedPrefix. */
                class PublicAdvertisedPrefixPublicDelegatedPrefix implements IPublicAdvertisedPrefixPublicDelegatedPrefix {

                    /**
                     * Constructs a new PublicAdvertisedPrefixPublicDelegatedPrefix.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicAdvertisedPrefixPublicDelegatedPrefix);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix ipRange. */
                    public ipRange?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix name. */
                    public name?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix project. */
                    public project?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix region. */
                    public region?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix status. */
                    public status?: (string|null);

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix _ipRange. */
                    public _ipRange?: "ipRange";

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix _name. */
                    public _name?: "name";

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix _project. */
                    public _project?: "project";

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix _region. */
                    public _region?: "region";

                    /** PublicAdvertisedPrefixPublicDelegatedPrefix _status. */
                    public _status?: "status";

                    /**
                     * Creates a new PublicAdvertisedPrefixPublicDelegatedPrefix instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicAdvertisedPrefixPublicDelegatedPrefix instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicAdvertisedPrefixPublicDelegatedPrefix): google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix;

                    /**
                     * Encodes the specified PublicAdvertisedPrefixPublicDelegatedPrefix message. Does not implicitly {@link google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix.verify|verify} messages.
                     * @param message PublicAdvertisedPrefixPublicDelegatedPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicAdvertisedPrefixPublicDelegatedPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicAdvertisedPrefixPublicDelegatedPrefix message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix.verify|verify} messages.
                     * @param message PublicAdvertisedPrefixPublicDelegatedPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicAdvertisedPrefixPublicDelegatedPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicAdvertisedPrefixPublicDelegatedPrefix message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicAdvertisedPrefixPublicDelegatedPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix;

                    /**
                     * Decodes a PublicAdvertisedPrefixPublicDelegatedPrefix message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicAdvertisedPrefixPublicDelegatedPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix;

                    /**
                     * Verifies a PublicAdvertisedPrefixPublicDelegatedPrefix message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicAdvertisedPrefixPublicDelegatedPrefix message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicAdvertisedPrefixPublicDelegatedPrefix
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix;

                    /**
                     * Creates a plain object from a PublicAdvertisedPrefixPublicDelegatedPrefix message. Also converts values to other types if specified.
                     * @param message PublicAdvertisedPrefixPublicDelegatedPrefix
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicAdvertisedPrefixPublicDelegatedPrefix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicAdvertisedPrefixPublicDelegatedPrefix to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicAdvertisedPrefixPublicDelegatedPrefix
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PublicDelegatedPrefix. */
                interface IPublicDelegatedPrefix {

                    /** PublicDelegatedPrefix creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** PublicDelegatedPrefix description */
                    description?: (string|null);

                    /** PublicDelegatedPrefix fingerprint */
                    fingerprint?: (string|null);

                    /** PublicDelegatedPrefix id */
                    id?: (number|Long|string|null);

                    /** PublicDelegatedPrefix ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** PublicDelegatedPrefix isLiveMigration */
                    isLiveMigration?: (boolean|null);

                    /** PublicDelegatedPrefix kind */
                    kind?: (string|null);

                    /** PublicDelegatedPrefix name */
                    name?: (string|null);

                    /** PublicDelegatedPrefix parentPrefix */
                    parentPrefix?: (string|null);

                    /** PublicDelegatedPrefix publicDelegatedSubPrefixs */
                    publicDelegatedSubPrefixs?: (google.cloud.compute.v1.IPublicDelegatedPrefixPublicDelegatedSubPrefix[]|null);

                    /** PublicDelegatedPrefix region */
                    region?: (string|null);

                    /** PublicDelegatedPrefix selfLink */
                    selfLink?: (string|null);

                    /** PublicDelegatedPrefix status */
                    status?: (string|null);
                }

                /** Represents a PublicDelegatedPrefix. */
                class PublicDelegatedPrefix implements IPublicDelegatedPrefix {

                    /**
                     * Constructs a new PublicDelegatedPrefix.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicDelegatedPrefix);

                    /** PublicDelegatedPrefix creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** PublicDelegatedPrefix description. */
                    public description?: (string|null);

                    /** PublicDelegatedPrefix fingerprint. */
                    public fingerprint?: (string|null);

                    /** PublicDelegatedPrefix id. */
                    public id?: (number|Long|string|null);

                    /** PublicDelegatedPrefix ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** PublicDelegatedPrefix isLiveMigration. */
                    public isLiveMigration?: (boolean|null);

                    /** PublicDelegatedPrefix kind. */
                    public kind?: (string|null);

                    /** PublicDelegatedPrefix name. */
                    public name?: (string|null);

                    /** PublicDelegatedPrefix parentPrefix. */
                    public parentPrefix?: (string|null);

                    /** PublicDelegatedPrefix publicDelegatedSubPrefixs. */
                    public publicDelegatedSubPrefixs: google.cloud.compute.v1.IPublicDelegatedPrefixPublicDelegatedSubPrefix[];

                    /** PublicDelegatedPrefix region. */
                    public region?: (string|null);

                    /** PublicDelegatedPrefix selfLink. */
                    public selfLink?: (string|null);

                    /** PublicDelegatedPrefix status. */
                    public status?: (string|null);

                    /** PublicDelegatedPrefix _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** PublicDelegatedPrefix _description. */
                    public _description?: "description";

                    /** PublicDelegatedPrefix _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** PublicDelegatedPrefix _id. */
                    public _id?: "id";

                    /** PublicDelegatedPrefix _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** PublicDelegatedPrefix _isLiveMigration. */
                    public _isLiveMigration?: "isLiveMigration";

                    /** PublicDelegatedPrefix _kind. */
                    public _kind?: "kind";

                    /** PublicDelegatedPrefix _name. */
                    public _name?: "name";

                    /** PublicDelegatedPrefix _parentPrefix. */
                    public _parentPrefix?: "parentPrefix";

                    /** PublicDelegatedPrefix _region. */
                    public _region?: "region";

                    /** PublicDelegatedPrefix _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PublicDelegatedPrefix _status. */
                    public _status?: "status";

                    /**
                     * Creates a new PublicDelegatedPrefix instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicDelegatedPrefix instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicDelegatedPrefix): google.cloud.compute.v1.PublicDelegatedPrefix;

                    /**
                     * Encodes the specified PublicDelegatedPrefix message. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefix.verify|verify} messages.
                     * @param message PublicDelegatedPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicDelegatedPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicDelegatedPrefix message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefix.verify|verify} messages.
                     * @param message PublicDelegatedPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicDelegatedPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicDelegatedPrefix message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicDelegatedPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicDelegatedPrefix;

                    /**
                     * Decodes a PublicDelegatedPrefix message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicDelegatedPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicDelegatedPrefix;

                    /**
                     * Verifies a PublicDelegatedPrefix message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicDelegatedPrefix message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicDelegatedPrefix
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicDelegatedPrefix;

                    /**
                     * Creates a plain object from a PublicDelegatedPrefix message. Also converts values to other types if specified.
                     * @param message PublicDelegatedPrefix
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicDelegatedPrefix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicDelegatedPrefix to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicDelegatedPrefix
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PublicDelegatedPrefix {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ANNOUNCED = 365103355,
                        DELETING = 528602024,
                        INITIALIZING = 306588749,
                        READY_TO_ANNOUNCE = 64641265
                    }
                }

                /** Properties of a PublicDelegatedPrefixAggregatedList. */
                interface IPublicDelegatedPrefixAggregatedList {

                    /** PublicDelegatedPrefixAggregatedList id */
                    id?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IPublicDelegatedPrefixesScopedList }|null);

                    /** PublicDelegatedPrefixAggregatedList kind */
                    kind?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** PublicDelegatedPrefixAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PublicDelegatedPrefixAggregatedList. */
                class PublicDelegatedPrefixAggregatedList implements IPublicDelegatedPrefixAggregatedList {

                    /**
                     * Constructs a new PublicDelegatedPrefixAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixAggregatedList);

                    /** PublicDelegatedPrefixAggregatedList id. */
                    public id?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IPublicDelegatedPrefixesScopedList };

                    /** PublicDelegatedPrefixAggregatedList kind. */
                    public kind?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** PublicDelegatedPrefixAggregatedList unreachables. */
                    public unreachables: string[];

                    /** PublicDelegatedPrefixAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PublicDelegatedPrefixAggregatedList _id. */
                    public _id?: "id";

                    /** PublicDelegatedPrefixAggregatedList _kind. */
                    public _kind?: "kind";

                    /** PublicDelegatedPrefixAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** PublicDelegatedPrefixAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PublicDelegatedPrefixAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PublicDelegatedPrefixAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicDelegatedPrefixAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixAggregatedList): google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList;

                    /**
                     * Encodes the specified PublicDelegatedPrefixAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList.verify|verify} messages.
                     * @param message PublicDelegatedPrefixAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicDelegatedPrefixAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicDelegatedPrefixAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList.verify|verify} messages.
                     * @param message PublicDelegatedPrefixAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicDelegatedPrefixAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicDelegatedPrefixAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicDelegatedPrefixAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList;

                    /**
                     * Decodes a PublicDelegatedPrefixAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicDelegatedPrefixAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList;

                    /**
                     * Verifies a PublicDelegatedPrefixAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicDelegatedPrefixAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicDelegatedPrefixAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList;

                    /**
                     * Creates a plain object from a PublicDelegatedPrefixAggregatedList message. Also converts values to other types if specified.
                     * @param message PublicDelegatedPrefixAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicDelegatedPrefixAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicDelegatedPrefixAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PublicDelegatedPrefixList. */
                interface IPublicDelegatedPrefixList {

                    /** PublicDelegatedPrefixList id */
                    id?: (string|null);

                    /** PublicDelegatedPrefixList items */
                    items?: (google.cloud.compute.v1.IPublicDelegatedPrefix[]|null);

                    /** PublicDelegatedPrefixList kind */
                    kind?: (string|null);

                    /** PublicDelegatedPrefixList nextPageToken */
                    nextPageToken?: (string|null);

                    /** PublicDelegatedPrefixList selfLink */
                    selfLink?: (string|null);

                    /** PublicDelegatedPrefixList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PublicDelegatedPrefixList. */
                class PublicDelegatedPrefixList implements IPublicDelegatedPrefixList {

                    /**
                     * Constructs a new PublicDelegatedPrefixList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixList);

                    /** PublicDelegatedPrefixList id. */
                    public id?: (string|null);

                    /** PublicDelegatedPrefixList items. */
                    public items: google.cloud.compute.v1.IPublicDelegatedPrefix[];

                    /** PublicDelegatedPrefixList kind. */
                    public kind?: (string|null);

                    /** PublicDelegatedPrefixList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** PublicDelegatedPrefixList selfLink. */
                    public selfLink?: (string|null);

                    /** PublicDelegatedPrefixList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PublicDelegatedPrefixList _id. */
                    public _id?: "id";

                    /** PublicDelegatedPrefixList _kind. */
                    public _kind?: "kind";

                    /** PublicDelegatedPrefixList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** PublicDelegatedPrefixList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** PublicDelegatedPrefixList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PublicDelegatedPrefixList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicDelegatedPrefixList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixList): google.cloud.compute.v1.PublicDelegatedPrefixList;

                    /**
                     * Encodes the specified PublicDelegatedPrefixList message. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixList.verify|verify} messages.
                     * @param message PublicDelegatedPrefixList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicDelegatedPrefixList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicDelegatedPrefixList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixList.verify|verify} messages.
                     * @param message PublicDelegatedPrefixList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicDelegatedPrefixList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicDelegatedPrefixList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicDelegatedPrefixList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicDelegatedPrefixList;

                    /**
                     * Decodes a PublicDelegatedPrefixList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicDelegatedPrefixList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicDelegatedPrefixList;

                    /**
                     * Verifies a PublicDelegatedPrefixList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicDelegatedPrefixList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicDelegatedPrefixList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicDelegatedPrefixList;

                    /**
                     * Creates a plain object from a PublicDelegatedPrefixList message. Also converts values to other types if specified.
                     * @param message PublicDelegatedPrefixList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicDelegatedPrefixList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicDelegatedPrefixList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicDelegatedPrefixList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PublicDelegatedPrefixPublicDelegatedSubPrefix. */
                interface IPublicDelegatedPrefixPublicDelegatedSubPrefix {

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix delegateeProject */
                    delegateeProject?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix description */
                    description?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix isAddress */
                    isAddress?: (boolean|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix name */
                    name?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix region */
                    region?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix status */
                    status?: (string|null);
                }

                /** Represents a PublicDelegatedPrefixPublicDelegatedSubPrefix. */
                class PublicDelegatedPrefixPublicDelegatedSubPrefix implements IPublicDelegatedPrefixPublicDelegatedSubPrefix {

                    /**
                     * Constructs a new PublicDelegatedPrefixPublicDelegatedSubPrefix.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixPublicDelegatedSubPrefix);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix delegateeProject. */
                    public delegateeProject?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix description. */
                    public description?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix isAddress. */
                    public isAddress?: (boolean|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix name. */
                    public name?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix region. */
                    public region?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix status. */
                    public status?: (string|null);

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _delegateeProject. */
                    public _delegateeProject?: "delegateeProject";

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _description. */
                    public _description?: "description";

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _isAddress. */
                    public _isAddress?: "isAddress";

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _name. */
                    public _name?: "name";

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _region. */
                    public _region?: "region";

                    /** PublicDelegatedPrefixPublicDelegatedSubPrefix _status. */
                    public _status?: "status";

                    /**
                     * Creates a new PublicDelegatedPrefixPublicDelegatedSubPrefix instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicDelegatedPrefixPublicDelegatedSubPrefix instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixPublicDelegatedSubPrefix): google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix;

                    /**
                     * Encodes the specified PublicDelegatedPrefixPublicDelegatedSubPrefix message. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix.verify|verify} messages.
                     * @param message PublicDelegatedPrefixPublicDelegatedSubPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicDelegatedPrefixPublicDelegatedSubPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicDelegatedPrefixPublicDelegatedSubPrefix message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix.verify|verify} messages.
                     * @param message PublicDelegatedPrefixPublicDelegatedSubPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicDelegatedPrefixPublicDelegatedSubPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicDelegatedPrefixPublicDelegatedSubPrefix message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicDelegatedPrefixPublicDelegatedSubPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix;

                    /**
                     * Decodes a PublicDelegatedPrefixPublicDelegatedSubPrefix message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicDelegatedPrefixPublicDelegatedSubPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix;

                    /**
                     * Verifies a PublicDelegatedPrefixPublicDelegatedSubPrefix message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicDelegatedPrefixPublicDelegatedSubPrefix message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicDelegatedPrefixPublicDelegatedSubPrefix
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix;

                    /**
                     * Creates a plain object from a PublicDelegatedPrefixPublicDelegatedSubPrefix message. Also converts values to other types if specified.
                     * @param message PublicDelegatedPrefixPublicDelegatedSubPrefix
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicDelegatedPrefixPublicDelegatedSubPrefix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicDelegatedPrefixPublicDelegatedSubPrefix to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicDelegatedPrefixPublicDelegatedSubPrefix
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace PublicDelegatedPrefixPublicDelegatedSubPrefix {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ACTIVE = 314733318,
                        INACTIVE = 270421099
                    }
                }

                /** Properties of a PublicDelegatedPrefixesScopedList. */
                interface IPublicDelegatedPrefixesScopedList {

                    /** PublicDelegatedPrefixesScopedList publicDelegatedPrefixes */
                    publicDelegatedPrefixes?: (google.cloud.compute.v1.IPublicDelegatedPrefix[]|null);

                    /** PublicDelegatedPrefixesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a PublicDelegatedPrefixesScopedList. */
                class PublicDelegatedPrefixesScopedList implements IPublicDelegatedPrefixesScopedList {

                    /**
                     * Constructs a new PublicDelegatedPrefixesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixesScopedList);

                    /** PublicDelegatedPrefixesScopedList publicDelegatedPrefixes. */
                    public publicDelegatedPrefixes: google.cloud.compute.v1.IPublicDelegatedPrefix[];

                    /** PublicDelegatedPrefixesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** PublicDelegatedPrefixesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new PublicDelegatedPrefixesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PublicDelegatedPrefixesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IPublicDelegatedPrefixesScopedList): google.cloud.compute.v1.PublicDelegatedPrefixesScopedList;

                    /**
                     * Encodes the specified PublicDelegatedPrefixesScopedList message. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixesScopedList.verify|verify} messages.
                     * @param message PublicDelegatedPrefixesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IPublicDelegatedPrefixesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PublicDelegatedPrefixesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.PublicDelegatedPrefixesScopedList.verify|verify} messages.
                     * @param message PublicDelegatedPrefixesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IPublicDelegatedPrefixesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PublicDelegatedPrefixesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PublicDelegatedPrefixesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.PublicDelegatedPrefixesScopedList;

                    /**
                     * Decodes a PublicDelegatedPrefixesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PublicDelegatedPrefixesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.PublicDelegatedPrefixesScopedList;

                    /**
                     * Verifies a PublicDelegatedPrefixesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PublicDelegatedPrefixesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PublicDelegatedPrefixesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.PublicDelegatedPrefixesScopedList;

                    /**
                     * Creates a plain object from a PublicDelegatedPrefixesScopedList message. Also converts values to other types if specified.
                     * @param message PublicDelegatedPrefixesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.PublicDelegatedPrefixesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PublicDelegatedPrefixesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PublicDelegatedPrefixesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Quota. */
                interface IQuota {

                    /** Quota limit */
                    limit?: (number|null);

                    /** Quota metric */
                    metric?: (string|null);

                    /** Quota owner */
                    owner?: (string|null);

                    /** Quota usage */
                    usage?: (number|null);
                }

                /** Represents a Quota. */
                class Quota implements IQuota {

                    /**
                     * Constructs a new Quota.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IQuota);

                    /** Quota limit. */
                    public limit?: (number|null);

                    /** Quota metric. */
                    public metric?: (string|null);

                    /** Quota owner. */
                    public owner?: (string|null);

                    /** Quota usage. */
                    public usage?: (number|null);

                    /** Quota _limit. */
                    public _limit?: "limit";

                    /** Quota _metric. */
                    public _metric?: "metric";

                    /** Quota _owner. */
                    public _owner?: "owner";

                    /** Quota _usage. */
                    public _usage?: "usage";

                    /**
                     * Creates a new Quota instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Quota instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IQuota): google.cloud.compute.v1.Quota;

                    /**
                     * Encodes the specified Quota message. Does not implicitly {@link google.cloud.compute.v1.Quota.verify|verify} messages.
                     * @param message Quota message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IQuota, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Quota message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Quota.verify|verify} messages.
                     * @param message Quota message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IQuota, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Quota message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Quota
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Quota;

                    /**
                     * Decodes a Quota message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Quota
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Quota;

                    /**
                     * Verifies a Quota message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Quota message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Quota
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Quota;

                    /**
                     * Creates a plain object from a Quota message. Also converts values to other types if specified.
                     * @param message Quota
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Quota, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Quota to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Quota
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Quota {

                    /** Metric enum. */
                    enum Metric {
                        UNDEFINED_METRIC = 0,
                        A2_CPUS = 153206585,
                        AFFINITY_GROUPS = 108303563,
                        AUTOSCALERS = 471248988,
                        BACKEND_BUCKETS = 137626846,
                        BACKEND_SERVICES = 269623753,
                        C2D_CPUS = 508182517,
                        C2_CPUS = 317601211,
                        C3_CPUS = 346230362,
                        COMMITMENTS = 456141790,
                        COMMITTED_A2_CPUS = 59330902,
                        COMMITTED_C2D_CPUS = 282390904,
                        COMMITTED_C2_CPUS = 223725528,
                        COMMITTED_C3_CPUS = 252354679,
                        COMMITTED_CPUS = 292394702,
                        COMMITTED_E2_CPUS = 388120154,
                        COMMITTED_LICENSES = 357606869,
                        COMMITTED_LOCAL_SSD_TOTAL_GB = 308393480,
                        COMMITTED_M3_CPUS = 585985,
                        COMMITTED_MEMORY_OPTIMIZED_CPUS = 489057886,
                        COMMITTED_N2A_CPUS = 40064304,
                        COMMITTED_N2D_CPUS = 125951757,
                        COMMITTED_N2_CPUS = 322589603,
                        COMMITTED_NVIDIA_A100_80GB_GPUS = 464326565,
                        COMMITTED_NVIDIA_A100_GPUS = 375799445,
                        COMMITTED_NVIDIA_K80_GPUS = 3857188,
                        COMMITTED_NVIDIA_P100_GPUS = 107528100,
                        COMMITTED_NVIDIA_P4_GPUS = 347952897,
                        COMMITTED_NVIDIA_T4_GPUS = 139871237,
                        COMMITTED_NVIDIA_V100_GPUS = 219562,
                        COMMITTED_T2A_CPUS = 296378986,
                        COMMITTED_T2D_CPUS = 382266439,
                        CPUS = 2075595,
                        CPUS_ALL_REGIONS = 470911149,
                        DISKS_TOTAL_GB = 353520543,
                        E2_CPUS = 481995837,
                        EXTERNAL_MANAGED_FORWARDING_RULES = 150790089,
                        EXTERNAL_NETWORK_LB_FORWARDING_RULES = 374298265,
                        EXTERNAL_PROTOCOL_FORWARDING_RULES = 63478888,
                        EXTERNAL_VPN_GATEWAYS = 272457134,
                        FIREWALLS = 374485843,
                        FORWARDING_RULES = 432668949,
                        GLOBAL_EXTERNAL_MANAGED_FORWARDING_RULES = 327611949,
                        GLOBAL_INTERNAL_ADDRESSES = 42738332,
                        GPUS_ALL_REGIONS = 39387177,
                        HEALTH_CHECKS = 289347502,
                        IMAGES = 15562360,
                        INSTANCES = 131337822,
                        INSTANCE_GROUPS = 355919038,
                        INSTANCE_GROUP_MANAGERS = 101798192,
                        INSTANCE_TEMPLATES = 226188271,
                        INTERCONNECTS = 415204741,
                        INTERCONNECT_ATTACHMENTS_PER_REGION = 159968086,
                        INTERCONNECT_ATTACHMENTS_TOTAL_MBPS = 425090419,
                        INTERCONNECT_TOTAL_GBPS = 285341866,
                        INTERNAL_ADDRESSES = 197899392,
                        INTERNAL_TRAFFIC_DIRECTOR_FORWARDING_RULES = 266433668,
                        IN_PLACE_SNAPSHOTS = 151359133,
                        IN_USE_ADDRESSES = 402125072,
                        IN_USE_BACKUP_SCHEDULES = 32786705,
                        IN_USE_SNAPSHOT_SCHEDULES = 462104083,
                        LOCAL_SSD_TOTAL_GB = 330878021,
                        M1_CPUS = 37203366,
                        M2_CPUS = 65832517,
                        M3_CPUS = 94461668,
                        MACHINE_IMAGES = 446986640,
                        N2A_CPUS = 265855917,
                        N2D_CPUS = 351743370,
                        N2_CPUS = 416465286,
                        NETWORKS = 485481477,
                        NETWORK_ENDPOINT_GROUPS = 102144909,
                        NETWORK_FIREWALL_POLICIES = 101117374,
                        NODE_GROUPS = 24624817,
                        NODE_TEMPLATES = 474896668,
                        NVIDIA_A100_80GB_GPUS = 286389320,
                        NVIDIA_A100_GPUS = 504872978,
                        NVIDIA_K80_GPUS = 163886599,
                        NVIDIA_P100_GPUS = 236601633,
                        NVIDIA_P100_VWS_GPUS = 213970574,
                        NVIDIA_P4_GPUS = 283841470,
                        NVIDIA_P4_VWS_GPUS = 528296619,
                        NVIDIA_T4_GPUS = 75759810,
                        NVIDIA_T4_VWS_GPUS = 319813039,
                        NVIDIA_V100_GPUS = 129293095,
                        PACKET_MIRRORINGS = 15578407,
                        PD_EXTREME_TOTAL_PROVISIONED_IOPS = 69593965,
                        PREEMPTIBLE_CPUS = 251184841,
                        PREEMPTIBLE_LOCAL_SSD_GB = 260819336,
                        PREEMPTIBLE_NVIDIA_A100_80GB_GPUS = 151942410,
                        PREEMPTIBLE_NVIDIA_A100_GPUS = 68832784,
                        PREEMPTIBLE_NVIDIA_K80_GPUS = 374960201,
                        PREEMPTIBLE_NVIDIA_P100_GPUS = 337432351,
                        PREEMPTIBLE_NVIDIA_P100_VWS_GPUS = 313544076,
                        PREEMPTIBLE_NVIDIA_P4_GPUS = 429197628,
                        PREEMPTIBLE_NVIDIA_P4_VWS_GPUS = 252981545,
                        PREEMPTIBLE_NVIDIA_T4_GPUS = 221115968,
                        PREEMPTIBLE_NVIDIA_T4_VWS_GPUS = 44497965,
                        PREEMPTIBLE_NVIDIA_V100_GPUS = 230123813,
                        PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK = 231164291,
                        PSC_INTERNAL_LB_FORWARDING_RULES = 169005435,
                        PUBLIC_ADVERTISED_PREFIXES = 471371980,
                        PUBLIC_DELEGATED_PREFIXES = 532465974,
                        REGIONAL_AUTOSCALERS = 29363772,
                        REGIONAL_INSTANCE_GROUP_MANAGERS = 37543696,
                        RESERVATIONS = 32644647,
                        RESOURCE_POLICIES = 83955297,
                        ROUTERS = 493018666,
                        ROUTES = 275680074,
                        SECURITY_POLICIES = 189518703,
                        SECURITY_POLICIES_PER_REGION = 249041734,
                        SECURITY_POLICY_CEVAL_RULES = 470815689,
                        SECURITY_POLICY_RULES = 203549225,
                        SECURITY_POLICY_RULES_PER_REGION = 126510156,
                        SERVICE_ATTACHMENTS = 471521510,
                        SNAPSHOTS = 343405327,
                        SSD_TOTAL_GB = 161732561,
                        SSL_CERTIFICATES = 378372399,
                        STATIC_ADDRESSES = 93624049,
                        STATIC_BYOIP_ADDRESSES = 275809649,
                        STATIC_EXTERNAL_IPV6_ADDRESS_RANGES = 472346774,
                        SUBNETWORKS = 421330469,
                        T2A_CPUS = 522170599,
                        T2D_CPUS = 71187140,
                        TARGET_HTTPS_PROXIES = 219522506,
                        TARGET_HTTP_PROXIES = 164117155,
                        TARGET_INSTANCES = 284519728,
                        TARGET_POOLS = 348261257,
                        TARGET_SSL_PROXIES = 159216235,
                        TARGET_TCP_PROXIES = 182243136,
                        TARGET_VPN_GATEWAYS = 75029928,
                        URL_MAPS = 378660743,
                        VPN_GATEWAYS = 35620282,
                        VPN_TUNNELS = 104327296,
                        XPN_SERVICE_PROJECTS = 95191981
                    }
                }

                /** Properties of a QuotaExceededInfo. */
                interface IQuotaExceededInfo {

                    /** QuotaExceededInfo dimensions */
                    dimensions?: ({ [k: string]: string }|null);

                    /** QuotaExceededInfo limit */
                    limit?: (number|null);

                    /** QuotaExceededInfo limitName */
                    limitName?: (string|null);

                    /** QuotaExceededInfo metricName */
                    metricName?: (string|null);
                }

                /** Represents a QuotaExceededInfo. */
                class QuotaExceededInfo implements IQuotaExceededInfo {

                    /**
                     * Constructs a new QuotaExceededInfo.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IQuotaExceededInfo);

                    /** QuotaExceededInfo dimensions. */
                    public dimensions: { [k: string]: string };

                    /** QuotaExceededInfo limit. */
                    public limit?: (number|null);

                    /** QuotaExceededInfo limitName. */
                    public limitName?: (string|null);

                    /** QuotaExceededInfo metricName. */
                    public metricName?: (string|null);

                    /** QuotaExceededInfo _limit. */
                    public _limit?: "limit";

                    /** QuotaExceededInfo _limitName. */
                    public _limitName?: "limitName";

                    /** QuotaExceededInfo _metricName. */
                    public _metricName?: "metricName";

                    /**
                     * Creates a new QuotaExceededInfo instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns QuotaExceededInfo instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IQuotaExceededInfo): google.cloud.compute.v1.QuotaExceededInfo;

                    /**
                     * Encodes the specified QuotaExceededInfo message. Does not implicitly {@link google.cloud.compute.v1.QuotaExceededInfo.verify|verify} messages.
                     * @param message QuotaExceededInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IQuotaExceededInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified QuotaExceededInfo message, length delimited. Does not implicitly {@link google.cloud.compute.v1.QuotaExceededInfo.verify|verify} messages.
                     * @param message QuotaExceededInfo message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IQuotaExceededInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a QuotaExceededInfo message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns QuotaExceededInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.QuotaExceededInfo;

                    /**
                     * Decodes a QuotaExceededInfo message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns QuotaExceededInfo
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.QuotaExceededInfo;

                    /**
                     * Verifies a QuotaExceededInfo message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a QuotaExceededInfo message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns QuotaExceededInfo
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.QuotaExceededInfo;

                    /**
                     * Creates a plain object from a QuotaExceededInfo message. Also converts values to other types if specified.
                     * @param message QuotaExceededInfo
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.QuotaExceededInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this QuotaExceededInfo to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for QuotaExceededInfo
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RawDisk. */
                interface IRawDisk {

                    /** RawDisk containerType */
                    containerType?: (string|null);

                    /** RawDisk sha1Checksum */
                    sha1Checksum?: (string|null);

                    /** RawDisk source */
                    source?: (string|null);
                }

                /** Represents a RawDisk. */
                class RawDisk implements IRawDisk {

                    /**
                     * Constructs a new RawDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRawDisk);

                    /** RawDisk containerType. */
                    public containerType?: (string|null);

                    /** RawDisk sha1Checksum. */
                    public sha1Checksum?: (string|null);

                    /** RawDisk source. */
                    public source?: (string|null);

                    /** RawDisk _containerType. */
                    public _containerType?: "containerType";

                    /** RawDisk _sha1Checksum. */
                    public _sha1Checksum?: "sha1Checksum";

                    /** RawDisk _source. */
                    public _source?: "source";

                    /**
                     * Creates a new RawDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RawDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRawDisk): google.cloud.compute.v1.RawDisk;

                    /**
                     * Encodes the specified RawDisk message. Does not implicitly {@link google.cloud.compute.v1.RawDisk.verify|verify} messages.
                     * @param message RawDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRawDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RawDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RawDisk.verify|verify} messages.
                     * @param message RawDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRawDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RawDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RawDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RawDisk;

                    /**
                     * Decodes a RawDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RawDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RawDisk;

                    /**
                     * Verifies a RawDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RawDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RawDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RawDisk;

                    /**
                     * Creates a plain object from a RawDisk message. Also converts values to other types if specified.
                     * @param message RawDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RawDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RawDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RawDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RawDisk {

                    /** ContainerType enum. */
                    enum ContainerType {
                        UNDEFINED_CONTAINER_TYPE = 0,
                        TAR = 82821
                    }
                }

                /** Properties of a RecreateInstancesInstanceGroupManagerRequest. */
                interface IRecreateInstancesInstanceGroupManagerRequest {

                    /** RecreateInstancesInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** RecreateInstancesInstanceGroupManagerRequest instanceGroupManagersRecreateInstancesRequestResource */
                    instanceGroupManagersRecreateInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersRecreateInstancesRequest|null);

                    /** RecreateInstancesInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** RecreateInstancesInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** RecreateInstancesInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a RecreateInstancesInstanceGroupManagerRequest. */
                class RecreateInstancesInstanceGroupManagerRequest implements IRecreateInstancesInstanceGroupManagerRequest {

                    /**
                     * Constructs a new RecreateInstancesInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest);

                    /** RecreateInstancesInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** RecreateInstancesInstanceGroupManagerRequest instanceGroupManagersRecreateInstancesRequestResource. */
                    public instanceGroupManagersRecreateInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersRecreateInstancesRequest|null);

                    /** RecreateInstancesInstanceGroupManagerRequest project. */
                    public project: string;

                    /** RecreateInstancesInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** RecreateInstancesInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** RecreateInstancesInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RecreateInstancesInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RecreateInstancesInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest): google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified RecreateInstancesInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message RecreateInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RecreateInstancesInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message RecreateInstancesInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RecreateInstancesInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RecreateInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Decodes a RecreateInstancesInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RecreateInstancesInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Verifies a RecreateInstancesInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RecreateInstancesInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RecreateInstancesInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a RecreateInstancesInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message RecreateInstancesInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RecreateInstancesInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RecreateInstancesInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RecreateInstancesInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RecreateInstancesRegionInstanceGroupManagerRequest. */
                interface IRecreateInstancesRegionInstanceGroupManagerRequest {

                    /** RecreateInstancesRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersRecreateRequestResource */
                    regionInstanceGroupManagersRecreateRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersRecreateRequest|null);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RecreateInstancesRegionInstanceGroupManagerRequest. */
                class RecreateInstancesRegionInstanceGroupManagerRequest implements IRecreateInstancesRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new RecreateInstancesRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** RecreateInstancesRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** RecreateInstancesRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** RecreateInstancesRegionInstanceGroupManagerRequest regionInstanceGroupManagersRecreateRequestResource. */
                    public regionInstanceGroupManagersRecreateRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersRecreateRequest|null);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** RecreateInstancesRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RecreateInstancesRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RecreateInstancesRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest): google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified RecreateInstancesRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message RecreateInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RecreateInstancesRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message RecreateInstancesRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RecreateInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RecreateInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a RecreateInstancesRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RecreateInstancesRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a RecreateInstancesRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RecreateInstancesRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RecreateInstancesRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a RecreateInstancesRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message RecreateInstancesRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RecreateInstancesRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RecreateInstancesRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RecreateInstancesRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Reference. */
                interface IReference {

                    /** Reference kind */
                    kind?: (string|null);

                    /** Reference referenceType */
                    referenceType?: (string|null);

                    /** Reference referrer */
                    referrer?: (string|null);

                    /** Reference target */
                    target?: (string|null);
                }

                /** Represents a Reference. */
                class Reference implements IReference {

                    /**
                     * Constructs a new Reference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReference);

                    /** Reference kind. */
                    public kind?: (string|null);

                    /** Reference referenceType. */
                    public referenceType?: (string|null);

                    /** Reference referrer. */
                    public referrer?: (string|null);

                    /** Reference target. */
                    public target?: (string|null);

                    /** Reference _kind. */
                    public _kind?: "kind";

                    /** Reference _referenceType. */
                    public _referenceType?: "referenceType";

                    /** Reference _referrer. */
                    public _referrer?: "referrer";

                    /** Reference _target. */
                    public _target?: "target";

                    /**
                     * Creates a new Reference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Reference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReference): google.cloud.compute.v1.Reference;

                    /**
                     * Encodes the specified Reference message. Does not implicitly {@link google.cloud.compute.v1.Reference.verify|verify} messages.
                     * @param message Reference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Reference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Reference.verify|verify} messages.
                     * @param message Reference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Reference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Reference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Reference;

                    /**
                     * Decodes a Reference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Reference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Reference;

                    /**
                     * Verifies a Reference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Reference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Reference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Reference;

                    /**
                     * Creates a plain object from a Reference message. Also converts values to other types if specified.
                     * @param message Reference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Reference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Reference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Reference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Region. */
                interface IRegion {

                    /** Region creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Region deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** Region description */
                    description?: (string|null);

                    /** Region id */
                    id?: (number|Long|string|null);

                    /** Region kind */
                    kind?: (string|null);

                    /** Region name */
                    name?: (string|null);

                    /** Region quotas */
                    quotas?: (google.cloud.compute.v1.IQuota[]|null);

                    /** Region selfLink */
                    selfLink?: (string|null);

                    /** Region status */
                    status?: (string|null);

                    /** Region supportsPzs */
                    supportsPzs?: (boolean|null);

                    /** Region zones */
                    zones?: (string[]|null);
                }

                /** Represents a Region. */
                class Region implements IRegion {

                    /**
                     * Constructs a new Region.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegion);

                    /** Region creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Region deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** Region description. */
                    public description?: (string|null);

                    /** Region id. */
                    public id?: (number|Long|string|null);

                    /** Region kind. */
                    public kind?: (string|null);

                    /** Region name. */
                    public name?: (string|null);

                    /** Region quotas. */
                    public quotas: google.cloud.compute.v1.IQuota[];

                    /** Region selfLink. */
                    public selfLink?: (string|null);

                    /** Region status. */
                    public status?: (string|null);

                    /** Region supportsPzs. */
                    public supportsPzs?: (boolean|null);

                    /** Region zones. */
                    public zones: string[];

                    /** Region _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Region _deprecated. */
                    public _deprecated?: "deprecated";

                    /** Region _description. */
                    public _description?: "description";

                    /** Region _id. */
                    public _id?: "id";

                    /** Region _kind. */
                    public _kind?: "kind";

                    /** Region _name. */
                    public _name?: "name";

                    /** Region _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Region _status. */
                    public _status?: "status";

                    /** Region _supportsPzs. */
                    public _supportsPzs?: "supportsPzs";

                    /**
                     * Creates a new Region instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Region instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegion): google.cloud.compute.v1.Region;

                    /**
                     * Encodes the specified Region message. Does not implicitly {@link google.cloud.compute.v1.Region.verify|verify} messages.
                     * @param message Region message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Region message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Region.verify|verify} messages.
                     * @param message Region message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Region message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Region
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Region;

                    /**
                     * Decodes a Region message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Region
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Region;

                    /**
                     * Verifies a Region message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Region message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Region
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Region;

                    /**
                     * Creates a plain object from a Region message. Also converts values to other types if specified.
                     * @param message Region
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Region, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Region to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Region
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Region {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DOWN = 2104482,
                        UP = 2715
                    }
                }

                /** Properties of a RegionAutoscalerList. */
                interface IRegionAutoscalerList {

                    /** RegionAutoscalerList id */
                    id?: (string|null);

                    /** RegionAutoscalerList items */
                    items?: (google.cloud.compute.v1.IAutoscaler[]|null);

                    /** RegionAutoscalerList kind */
                    kind?: (string|null);

                    /** RegionAutoscalerList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionAutoscalerList selfLink */
                    selfLink?: (string|null);

                    /** RegionAutoscalerList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionAutoscalerList. */
                class RegionAutoscalerList implements IRegionAutoscalerList {

                    /**
                     * Constructs a new RegionAutoscalerList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionAutoscalerList);

                    /** RegionAutoscalerList id. */
                    public id?: (string|null);

                    /** RegionAutoscalerList items. */
                    public items: google.cloud.compute.v1.IAutoscaler[];

                    /** RegionAutoscalerList kind. */
                    public kind?: (string|null);

                    /** RegionAutoscalerList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionAutoscalerList selfLink. */
                    public selfLink?: (string|null);

                    /** RegionAutoscalerList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionAutoscalerList _id. */
                    public _id?: "id";

                    /** RegionAutoscalerList _kind. */
                    public _kind?: "kind";

                    /** RegionAutoscalerList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionAutoscalerList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RegionAutoscalerList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionAutoscalerList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionAutoscalerList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionAutoscalerList): google.cloud.compute.v1.RegionAutoscalerList;

                    /**
                     * Encodes the specified RegionAutoscalerList message. Does not implicitly {@link google.cloud.compute.v1.RegionAutoscalerList.verify|verify} messages.
                     * @param message RegionAutoscalerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionAutoscalerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionAutoscalerList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionAutoscalerList.verify|verify} messages.
                     * @param message RegionAutoscalerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionAutoscalerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionAutoscalerList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionAutoscalerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionAutoscalerList;

                    /**
                     * Decodes a RegionAutoscalerList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionAutoscalerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionAutoscalerList;

                    /**
                     * Verifies a RegionAutoscalerList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionAutoscalerList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionAutoscalerList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionAutoscalerList;

                    /**
                     * Creates a plain object from a RegionAutoscalerList message. Also converts values to other types if specified.
                     * @param message RegionAutoscalerList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionAutoscalerList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionAutoscalerList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionAutoscalerList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionDiskTypeList. */
                interface IRegionDiskTypeList {

                    /** RegionDiskTypeList id */
                    id?: (string|null);

                    /** RegionDiskTypeList items */
                    items?: (google.cloud.compute.v1.IDiskType[]|null);

                    /** RegionDiskTypeList kind */
                    kind?: (string|null);

                    /** RegionDiskTypeList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionDiskTypeList selfLink */
                    selfLink?: (string|null);

                    /** RegionDiskTypeList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionDiskTypeList. */
                class RegionDiskTypeList implements IRegionDiskTypeList {

                    /**
                     * Constructs a new RegionDiskTypeList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionDiskTypeList);

                    /** RegionDiskTypeList id. */
                    public id?: (string|null);

                    /** RegionDiskTypeList items. */
                    public items: google.cloud.compute.v1.IDiskType[];

                    /** RegionDiskTypeList kind. */
                    public kind?: (string|null);

                    /** RegionDiskTypeList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionDiskTypeList selfLink. */
                    public selfLink?: (string|null);

                    /** RegionDiskTypeList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionDiskTypeList _id. */
                    public _id?: "id";

                    /** RegionDiskTypeList _kind. */
                    public _kind?: "kind";

                    /** RegionDiskTypeList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionDiskTypeList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RegionDiskTypeList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionDiskTypeList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionDiskTypeList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionDiskTypeList): google.cloud.compute.v1.RegionDiskTypeList;

                    /**
                     * Encodes the specified RegionDiskTypeList message. Does not implicitly {@link google.cloud.compute.v1.RegionDiskTypeList.verify|verify} messages.
                     * @param message RegionDiskTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionDiskTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionDiskTypeList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionDiskTypeList.verify|verify} messages.
                     * @param message RegionDiskTypeList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionDiskTypeList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionDiskTypeList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionDiskTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionDiskTypeList;

                    /**
                     * Decodes a RegionDiskTypeList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionDiskTypeList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionDiskTypeList;

                    /**
                     * Verifies a RegionDiskTypeList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionDiskTypeList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionDiskTypeList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionDiskTypeList;

                    /**
                     * Creates a plain object from a RegionDiskTypeList message. Also converts values to other types if specified.
                     * @param message RegionDiskTypeList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionDiskTypeList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionDiskTypeList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionDiskTypeList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionDisksAddResourcePoliciesRequest. */
                interface IRegionDisksAddResourcePoliciesRequest {

                    /** RegionDisksAddResourcePoliciesRequest resourcePolicies */
                    resourcePolicies?: (string[]|null);
                }

                /** Represents a RegionDisksAddResourcePoliciesRequest. */
                class RegionDisksAddResourcePoliciesRequest implements IRegionDisksAddResourcePoliciesRequest {

                    /**
                     * Constructs a new RegionDisksAddResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionDisksAddResourcePoliciesRequest);

                    /** RegionDisksAddResourcePoliciesRequest resourcePolicies. */
                    public resourcePolicies: string[];

                    /**
                     * Creates a new RegionDisksAddResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionDisksAddResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionDisksAddResourcePoliciesRequest): google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest;

                    /**
                     * Encodes the specified RegionDisksAddResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest.verify|verify} messages.
                     * @param message RegionDisksAddResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionDisksAddResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionDisksAddResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest.verify|verify} messages.
                     * @param message RegionDisksAddResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionDisksAddResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionDisksAddResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionDisksAddResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest;

                    /**
                     * Decodes a RegionDisksAddResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionDisksAddResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest;

                    /**
                     * Verifies a RegionDisksAddResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionDisksAddResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionDisksAddResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest;

                    /**
                     * Creates a plain object from a RegionDisksAddResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message RegionDisksAddResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionDisksAddResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionDisksAddResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionDisksAddResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionDisksRemoveResourcePoliciesRequest. */
                interface IRegionDisksRemoveResourcePoliciesRequest {

                    /** RegionDisksRemoveResourcePoliciesRequest resourcePolicies */
                    resourcePolicies?: (string[]|null);
                }

                /** Represents a RegionDisksRemoveResourcePoliciesRequest. */
                class RegionDisksRemoveResourcePoliciesRequest implements IRegionDisksRemoveResourcePoliciesRequest {

                    /**
                     * Constructs a new RegionDisksRemoveResourcePoliciesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionDisksRemoveResourcePoliciesRequest);

                    /** RegionDisksRemoveResourcePoliciesRequest resourcePolicies. */
                    public resourcePolicies: string[];

                    /**
                     * Creates a new RegionDisksRemoveResourcePoliciesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionDisksRemoveResourcePoliciesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionDisksRemoveResourcePoliciesRequest): google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest;

                    /**
                     * Encodes the specified RegionDisksRemoveResourcePoliciesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest.verify|verify} messages.
                     * @param message RegionDisksRemoveResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionDisksRemoveResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionDisksRemoveResourcePoliciesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest.verify|verify} messages.
                     * @param message RegionDisksRemoveResourcePoliciesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionDisksRemoveResourcePoliciesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionDisksRemoveResourcePoliciesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionDisksRemoveResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest;

                    /**
                     * Decodes a RegionDisksRemoveResourcePoliciesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionDisksRemoveResourcePoliciesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest;

                    /**
                     * Verifies a RegionDisksRemoveResourcePoliciesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionDisksRemoveResourcePoliciesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionDisksRemoveResourcePoliciesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest;

                    /**
                     * Creates a plain object from a RegionDisksRemoveResourcePoliciesRequest message. Also converts values to other types if specified.
                     * @param message RegionDisksRemoveResourcePoliciesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionDisksRemoveResourcePoliciesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionDisksRemoveResourcePoliciesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionDisksRemoveResourcePoliciesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionDisksResizeRequest. */
                interface IRegionDisksResizeRequest {

                    /** RegionDisksResizeRequest sizeGb */
                    sizeGb?: (number|Long|string|null);
                }

                /** Represents a RegionDisksResizeRequest. */
                class RegionDisksResizeRequest implements IRegionDisksResizeRequest {

                    /**
                     * Constructs a new RegionDisksResizeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionDisksResizeRequest);

                    /** RegionDisksResizeRequest sizeGb. */
                    public sizeGb?: (number|Long|string|null);

                    /** RegionDisksResizeRequest _sizeGb. */
                    public _sizeGb?: "sizeGb";

                    /**
                     * Creates a new RegionDisksResizeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionDisksResizeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionDisksResizeRequest): google.cloud.compute.v1.RegionDisksResizeRequest;

                    /**
                     * Encodes the specified RegionDisksResizeRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionDisksResizeRequest.verify|verify} messages.
                     * @param message RegionDisksResizeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionDisksResizeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionDisksResizeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionDisksResizeRequest.verify|verify} messages.
                     * @param message RegionDisksResizeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionDisksResizeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionDisksResizeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionDisksResizeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionDisksResizeRequest;

                    /**
                     * Decodes a RegionDisksResizeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionDisksResizeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionDisksResizeRequest;

                    /**
                     * Verifies a RegionDisksResizeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionDisksResizeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionDisksResizeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionDisksResizeRequest;

                    /**
                     * Creates a plain object from a RegionDisksResizeRequest message. Also converts values to other types if specified.
                     * @param message RegionDisksResizeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionDisksResizeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionDisksResizeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionDisksResizeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupList. */
                interface IRegionInstanceGroupList {

                    /** RegionInstanceGroupList id */
                    id?: (string|null);

                    /** RegionInstanceGroupList items */
                    items?: (google.cloud.compute.v1.IInstanceGroup[]|null);

                    /** RegionInstanceGroupList kind */
                    kind?: (string|null);

                    /** RegionInstanceGroupList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionInstanceGroupList selfLink */
                    selfLink?: (string|null);

                    /** RegionInstanceGroupList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionInstanceGroupList. */
                class RegionInstanceGroupList implements IRegionInstanceGroupList {

                    /**
                     * Constructs a new RegionInstanceGroupList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupList);

                    /** RegionInstanceGroupList id. */
                    public id?: (string|null);

                    /** RegionInstanceGroupList items. */
                    public items: google.cloud.compute.v1.IInstanceGroup[];

                    /** RegionInstanceGroupList kind. */
                    public kind?: (string|null);

                    /** RegionInstanceGroupList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionInstanceGroupList selfLink. */
                    public selfLink?: (string|null);

                    /** RegionInstanceGroupList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionInstanceGroupList _id. */
                    public _id?: "id";

                    /** RegionInstanceGroupList _kind. */
                    public _kind?: "kind";

                    /** RegionInstanceGroupList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionInstanceGroupList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RegionInstanceGroupList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionInstanceGroupList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupList): google.cloud.compute.v1.RegionInstanceGroupList;

                    /**
                     * Encodes the specified RegionInstanceGroupList message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupList.verify|verify} messages.
                     * @param message RegionInstanceGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupList.verify|verify} messages.
                     * @param message RegionInstanceGroupList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupList;

                    /**
                     * Decodes a RegionInstanceGroupList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupList;

                    /**
                     * Verifies a RegionInstanceGroupList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupList;

                    /**
                     * Creates a plain object from a RegionInstanceGroupList message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagerDeleteInstanceConfigReq. */
                interface IRegionInstanceGroupManagerDeleteInstanceConfigReq {

                    /** RegionInstanceGroupManagerDeleteInstanceConfigReq names */
                    names?: (string[]|null);
                }

                /** Represents a RegionInstanceGroupManagerDeleteInstanceConfigReq. */
                class RegionInstanceGroupManagerDeleteInstanceConfigReq implements IRegionInstanceGroupManagerDeleteInstanceConfigReq {

                    /**
                     * Constructs a new RegionInstanceGroupManagerDeleteInstanceConfigReq.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerDeleteInstanceConfigReq);

                    /** RegionInstanceGroupManagerDeleteInstanceConfigReq names. */
                    public names: string[];

                    /**
                     * Creates a new RegionInstanceGroupManagerDeleteInstanceConfigReq instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagerDeleteInstanceConfigReq instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerDeleteInstanceConfigReq): google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerDeleteInstanceConfigReq message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerDeleteInstanceConfigReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagerDeleteInstanceConfigReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerDeleteInstanceConfigReq message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerDeleteInstanceConfigReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagerDeleteInstanceConfigReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagerDeleteInstanceConfigReq message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagerDeleteInstanceConfigReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq;

                    /**
                     * Decodes a RegionInstanceGroupManagerDeleteInstanceConfigReq message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagerDeleteInstanceConfigReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq;

                    /**
                     * Verifies a RegionInstanceGroupManagerDeleteInstanceConfigReq message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagerDeleteInstanceConfigReq message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagerDeleteInstanceConfigReq
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagerDeleteInstanceConfigReq message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagerDeleteInstanceConfigReq
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagerDeleteInstanceConfigReq, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagerDeleteInstanceConfigReq to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagerDeleteInstanceConfigReq
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagerList. */
                interface IRegionInstanceGroupManagerList {

                    /** RegionInstanceGroupManagerList id */
                    id?: (string|null);

                    /** RegionInstanceGroupManagerList items */
                    items?: (google.cloud.compute.v1.IInstanceGroupManager[]|null);

                    /** RegionInstanceGroupManagerList kind */
                    kind?: (string|null);

                    /** RegionInstanceGroupManagerList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionInstanceGroupManagerList selfLink */
                    selfLink?: (string|null);

                    /** RegionInstanceGroupManagerList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionInstanceGroupManagerList. */
                class RegionInstanceGroupManagerList implements IRegionInstanceGroupManagerList {

                    /**
                     * Constructs a new RegionInstanceGroupManagerList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerList);

                    /** RegionInstanceGroupManagerList id. */
                    public id?: (string|null);

                    /** RegionInstanceGroupManagerList items. */
                    public items: google.cloud.compute.v1.IInstanceGroupManager[];

                    /** RegionInstanceGroupManagerList kind. */
                    public kind?: (string|null);

                    /** RegionInstanceGroupManagerList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionInstanceGroupManagerList selfLink. */
                    public selfLink?: (string|null);

                    /** RegionInstanceGroupManagerList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionInstanceGroupManagerList _id. */
                    public _id?: "id";

                    /** RegionInstanceGroupManagerList _kind. */
                    public _kind?: "kind";

                    /** RegionInstanceGroupManagerList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionInstanceGroupManagerList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RegionInstanceGroupManagerList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionInstanceGroupManagerList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagerList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerList): google.cloud.compute.v1.RegionInstanceGroupManagerList;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerList message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerList.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerList.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagerList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagerList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagerList;

                    /**
                     * Decodes a RegionInstanceGroupManagerList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagerList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagerList;

                    /**
                     * Verifies a RegionInstanceGroupManagerList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagerList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagerList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagerList;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagerList message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagerList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagerList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagerList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagerList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagerPatchInstanceConfigReq. */
                interface IRegionInstanceGroupManagerPatchInstanceConfigReq {

                    /** RegionInstanceGroupManagerPatchInstanceConfigReq perInstanceConfigs */
                    perInstanceConfigs?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);
                }

                /** Represents a RegionInstanceGroupManagerPatchInstanceConfigReq. */
                class RegionInstanceGroupManagerPatchInstanceConfigReq implements IRegionInstanceGroupManagerPatchInstanceConfigReq {

                    /**
                     * Constructs a new RegionInstanceGroupManagerPatchInstanceConfigReq.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerPatchInstanceConfigReq);

                    /** RegionInstanceGroupManagerPatchInstanceConfigReq perInstanceConfigs. */
                    public perInstanceConfigs: google.cloud.compute.v1.IPerInstanceConfig[];

                    /**
                     * Creates a new RegionInstanceGroupManagerPatchInstanceConfigReq instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagerPatchInstanceConfigReq instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerPatchInstanceConfigReq): google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerPatchInstanceConfigReq message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerPatchInstanceConfigReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagerPatchInstanceConfigReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerPatchInstanceConfigReq message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerPatchInstanceConfigReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagerPatchInstanceConfigReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagerPatchInstanceConfigReq message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagerPatchInstanceConfigReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq;

                    /**
                     * Decodes a RegionInstanceGroupManagerPatchInstanceConfigReq message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagerPatchInstanceConfigReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq;

                    /**
                     * Verifies a RegionInstanceGroupManagerPatchInstanceConfigReq message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagerPatchInstanceConfigReq message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagerPatchInstanceConfigReq
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagerPatchInstanceConfigReq message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagerPatchInstanceConfigReq
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagerPatchInstanceConfigReq, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagerPatchInstanceConfigReq to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagerPatchInstanceConfigReq
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagerUpdateInstanceConfigReq. */
                interface IRegionInstanceGroupManagerUpdateInstanceConfigReq {

                    /** RegionInstanceGroupManagerUpdateInstanceConfigReq perInstanceConfigs */
                    perInstanceConfigs?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);
                }

                /** Represents a RegionInstanceGroupManagerUpdateInstanceConfigReq. */
                class RegionInstanceGroupManagerUpdateInstanceConfigReq implements IRegionInstanceGroupManagerUpdateInstanceConfigReq {

                    /**
                     * Constructs a new RegionInstanceGroupManagerUpdateInstanceConfigReq.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerUpdateInstanceConfigReq);

                    /** RegionInstanceGroupManagerUpdateInstanceConfigReq perInstanceConfigs. */
                    public perInstanceConfigs: google.cloud.compute.v1.IPerInstanceConfig[];

                    /**
                     * Creates a new RegionInstanceGroupManagerUpdateInstanceConfigReq instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagerUpdateInstanceConfigReq instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagerUpdateInstanceConfigReq): google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerUpdateInstanceConfigReq message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerUpdateInstanceConfigReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagerUpdateInstanceConfigReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagerUpdateInstanceConfigReq message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq.verify|verify} messages.
                     * @param message RegionInstanceGroupManagerUpdateInstanceConfigReq message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagerUpdateInstanceConfigReq, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagerUpdateInstanceConfigReq message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagerUpdateInstanceConfigReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq;

                    /**
                     * Decodes a RegionInstanceGroupManagerUpdateInstanceConfigReq message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagerUpdateInstanceConfigReq
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq;

                    /**
                     * Verifies a RegionInstanceGroupManagerUpdateInstanceConfigReq message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagerUpdateInstanceConfigReq message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagerUpdateInstanceConfigReq
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagerUpdateInstanceConfigReq message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagerUpdateInstanceConfigReq
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagerUpdateInstanceConfigReq, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagerUpdateInstanceConfigReq to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagerUpdateInstanceConfigReq
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersAbandonInstancesRequest. */
                interface IRegionInstanceGroupManagersAbandonInstancesRequest {

                    /** RegionInstanceGroupManagersAbandonInstancesRequest instances */
                    instances?: (string[]|null);
                }

                /** Represents a RegionInstanceGroupManagersAbandonInstancesRequest. */
                class RegionInstanceGroupManagersAbandonInstancesRequest implements IRegionInstanceGroupManagersAbandonInstancesRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersAbandonInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersAbandonInstancesRequest);

                    /** RegionInstanceGroupManagersAbandonInstancesRequest instances. */
                    public instances: string[];

                    /**
                     * Creates a new RegionInstanceGroupManagersAbandonInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersAbandonInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersAbandonInstancesRequest): google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersAbandonInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersAbandonInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersAbandonInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersAbandonInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersAbandonInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersAbandonInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersAbandonInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersAbandonInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersAbandonInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersAbandonInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersAbandonInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersAbandonInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersAbandonInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersAbandonInstancesRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersAbandonInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersAbandonInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersAbandonInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersAbandonInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersApplyUpdatesRequest. */
                interface IRegionInstanceGroupManagersApplyUpdatesRequest {

                    /** RegionInstanceGroupManagersApplyUpdatesRequest allInstances */
                    allInstances?: (boolean|null);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest instances */
                    instances?: (string[]|null);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest minimalAction */
                    minimalAction?: (string|null);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest mostDisruptiveAllowedAction */
                    mostDisruptiveAllowedAction?: (string|null);
                }

                /** Represents a RegionInstanceGroupManagersApplyUpdatesRequest. */
                class RegionInstanceGroupManagersApplyUpdatesRequest implements IRegionInstanceGroupManagersApplyUpdatesRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersApplyUpdatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersApplyUpdatesRequest);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest allInstances. */
                    public allInstances?: (boolean|null);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest instances. */
                    public instances: string[];

                    /** RegionInstanceGroupManagersApplyUpdatesRequest minimalAction. */
                    public minimalAction?: (string|null);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest mostDisruptiveAllowedAction. */
                    public mostDisruptiveAllowedAction?: (string|null);

                    /** RegionInstanceGroupManagersApplyUpdatesRequest _allInstances. */
                    public _allInstances?: "allInstances";

                    /** RegionInstanceGroupManagersApplyUpdatesRequest _minimalAction. */
                    public _minimalAction?: "minimalAction";

                    /** RegionInstanceGroupManagersApplyUpdatesRequest _mostDisruptiveAllowedAction. */
                    public _mostDisruptiveAllowedAction?: "mostDisruptiveAllowedAction";

                    /**
                     * Creates a new RegionInstanceGroupManagersApplyUpdatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersApplyUpdatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersApplyUpdatesRequest): google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersApplyUpdatesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersApplyUpdatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersApplyUpdatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersApplyUpdatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersApplyUpdatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersApplyUpdatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersApplyUpdatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersApplyUpdatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersApplyUpdatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersApplyUpdatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersApplyUpdatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersApplyUpdatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersApplyUpdatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersApplyUpdatesRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersApplyUpdatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersApplyUpdatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersApplyUpdatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersApplyUpdatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RegionInstanceGroupManagersApplyUpdatesRequest {

                    /** MinimalAction enum. */
                    enum MinimalAction {
                        UNDEFINED_MINIMAL_ACTION = 0
                    }

                    /** MostDisruptiveAllowedAction enum. */
                    enum MostDisruptiveAllowedAction {
                        UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
                    }
                }

                /** Properties of a RegionInstanceGroupManagersCreateInstancesRequest. */
                interface IRegionInstanceGroupManagersCreateInstancesRequest {

                    /** RegionInstanceGroupManagersCreateInstancesRequest instances */
                    instances?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);
                }

                /** Represents a RegionInstanceGroupManagersCreateInstancesRequest. */
                class RegionInstanceGroupManagersCreateInstancesRequest implements IRegionInstanceGroupManagersCreateInstancesRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersCreateInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersCreateInstancesRequest);

                    /** RegionInstanceGroupManagersCreateInstancesRequest instances. */
                    public instances: google.cloud.compute.v1.IPerInstanceConfig[];

                    /**
                     * Creates a new RegionInstanceGroupManagersCreateInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersCreateInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersCreateInstancesRequest): google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersCreateInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersCreateInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersCreateInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersCreateInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersCreateInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersCreateInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersCreateInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersCreateInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersCreateInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersCreateInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersCreateInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersCreateInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersCreateInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersCreateInstancesRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersCreateInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersCreateInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersCreateInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersCreateInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersDeleteInstancesRequest. */
                interface IRegionInstanceGroupManagersDeleteInstancesRequest {

                    /** RegionInstanceGroupManagersDeleteInstancesRequest instances */
                    instances?: (string[]|null);

                    /** RegionInstanceGroupManagersDeleteInstancesRequest skipInstancesOnValidationError */
                    skipInstancesOnValidationError?: (boolean|null);
                }

                /** Represents a RegionInstanceGroupManagersDeleteInstancesRequest. */
                class RegionInstanceGroupManagersDeleteInstancesRequest implements IRegionInstanceGroupManagersDeleteInstancesRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersDeleteInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersDeleteInstancesRequest);

                    /** RegionInstanceGroupManagersDeleteInstancesRequest instances. */
                    public instances: string[];

                    /** RegionInstanceGroupManagersDeleteInstancesRequest skipInstancesOnValidationError. */
                    public skipInstancesOnValidationError?: (boolean|null);

                    /** RegionInstanceGroupManagersDeleteInstancesRequest _skipInstancesOnValidationError. */
                    public _skipInstancesOnValidationError?: "skipInstancesOnValidationError";

                    /**
                     * Creates a new RegionInstanceGroupManagersDeleteInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersDeleteInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersDeleteInstancesRequest): google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersDeleteInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersDeleteInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersDeleteInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersDeleteInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersDeleteInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersDeleteInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersDeleteInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersDeleteInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersDeleteInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersDeleteInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersDeleteInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersDeleteInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersDeleteInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersDeleteInstancesRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersDeleteInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersDeleteInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersDeleteInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersDeleteInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersListErrorsResponse. */
                interface IRegionInstanceGroupManagersListErrorsResponse {

                    /** RegionInstanceGroupManagersListErrorsResponse items */
                    items?: (google.cloud.compute.v1.IInstanceManagedByIgmError[]|null);

                    /** RegionInstanceGroupManagersListErrorsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a RegionInstanceGroupManagersListErrorsResponse. */
                class RegionInstanceGroupManagersListErrorsResponse implements IRegionInstanceGroupManagersListErrorsResponse {

                    /**
                     * Constructs a new RegionInstanceGroupManagersListErrorsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse);

                    /** RegionInstanceGroupManagersListErrorsResponse items. */
                    public items: google.cloud.compute.v1.IInstanceManagedByIgmError[];

                    /** RegionInstanceGroupManagersListErrorsResponse nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionInstanceGroupManagersListErrorsResponse _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /**
                     * Creates a new RegionInstanceGroupManagersListErrorsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersListErrorsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse): google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersListErrorsResponse message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersListErrorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersListErrorsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersListErrorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersListErrorsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersListErrorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse;

                    /**
                     * Decodes a RegionInstanceGroupManagersListErrorsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersListErrorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse;

                    /**
                     * Verifies a RegionInstanceGroupManagersListErrorsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersListErrorsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersListErrorsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersListErrorsResponse message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersListErrorsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersListErrorsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersListErrorsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersListInstanceConfigsResp. */
                interface IRegionInstanceGroupManagersListInstanceConfigsResp {

                    /** RegionInstanceGroupManagersListInstanceConfigsResp items */
                    items?: (google.cloud.compute.v1.IPerInstanceConfig[]|null);

                    /** RegionInstanceGroupManagersListInstanceConfigsResp nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionInstanceGroupManagersListInstanceConfigsResp warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionInstanceGroupManagersListInstanceConfigsResp. */
                class RegionInstanceGroupManagersListInstanceConfigsResp implements IRegionInstanceGroupManagersListInstanceConfigsResp {

                    /**
                     * Constructs a new RegionInstanceGroupManagersListInstanceConfigsResp.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp);

                    /** RegionInstanceGroupManagersListInstanceConfigsResp items. */
                    public items: google.cloud.compute.v1.IPerInstanceConfig[];

                    /** RegionInstanceGroupManagersListInstanceConfigsResp nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionInstanceGroupManagersListInstanceConfigsResp warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionInstanceGroupManagersListInstanceConfigsResp _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionInstanceGroupManagersListInstanceConfigsResp _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionInstanceGroupManagersListInstanceConfigsResp instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersListInstanceConfigsResp instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp): google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersListInstanceConfigsResp message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersListInstanceConfigsResp message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersListInstanceConfigsResp message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersListInstanceConfigsResp message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersListInstanceConfigsResp message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersListInstanceConfigsResp
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp;

                    /**
                     * Decodes a RegionInstanceGroupManagersListInstanceConfigsResp message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersListInstanceConfigsResp
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp;

                    /**
                     * Verifies a RegionInstanceGroupManagersListInstanceConfigsResp message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersListInstanceConfigsResp message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersListInstanceConfigsResp
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersListInstanceConfigsResp message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersListInstanceConfigsResp
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersListInstanceConfigsResp to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersListInstanceConfigsResp
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersListInstancesResponse. */
                interface IRegionInstanceGroupManagersListInstancesResponse {

                    /** RegionInstanceGroupManagersListInstancesResponse managedInstances */
                    managedInstances?: (google.cloud.compute.v1.IManagedInstance[]|null);

                    /** RegionInstanceGroupManagersListInstancesResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a RegionInstanceGroupManagersListInstancesResponse. */
                class RegionInstanceGroupManagersListInstancesResponse implements IRegionInstanceGroupManagersListInstancesResponse {

                    /**
                     * Constructs a new RegionInstanceGroupManagersListInstancesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse);

                    /** RegionInstanceGroupManagersListInstancesResponse managedInstances. */
                    public managedInstances: google.cloud.compute.v1.IManagedInstance[];

                    /** RegionInstanceGroupManagersListInstancesResponse nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionInstanceGroupManagersListInstancesResponse _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /**
                     * Creates a new RegionInstanceGroupManagersListInstancesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersListInstancesResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse): google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersListInstancesResponse message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersListInstancesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersListInstancesResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersListInstancesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersListInstancesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersListInstancesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse;

                    /**
                     * Decodes a RegionInstanceGroupManagersListInstancesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersListInstancesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse;

                    /**
                     * Verifies a RegionInstanceGroupManagersListInstancesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersListInstancesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersListInstancesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersListInstancesResponse message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersListInstancesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersListInstancesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersListInstancesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersRecreateRequest. */
                interface IRegionInstanceGroupManagersRecreateRequest {

                    /** RegionInstanceGroupManagersRecreateRequest instances */
                    instances?: (string[]|null);
                }

                /** Represents a RegionInstanceGroupManagersRecreateRequest. */
                class RegionInstanceGroupManagersRecreateRequest implements IRegionInstanceGroupManagersRecreateRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersRecreateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersRecreateRequest);

                    /** RegionInstanceGroupManagersRecreateRequest instances. */
                    public instances: string[];

                    /**
                     * Creates a new RegionInstanceGroupManagersRecreateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersRecreateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersRecreateRequest): google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersRecreateRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersRecreateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersRecreateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersRecreateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersRecreateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersRecreateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersRecreateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersRecreateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersRecreateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersRecreateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersRecreateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersRecreateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersRecreateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersRecreateRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersRecreateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersRecreateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersRecreateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersRecreateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersSetTargetPoolsRequest. */
                interface IRegionInstanceGroupManagersSetTargetPoolsRequest {

                    /** RegionInstanceGroupManagersSetTargetPoolsRequest fingerprint */
                    fingerprint?: (string|null);

                    /** RegionInstanceGroupManagersSetTargetPoolsRequest targetPools */
                    targetPools?: (string[]|null);
                }

                /** Represents a RegionInstanceGroupManagersSetTargetPoolsRequest. */
                class RegionInstanceGroupManagersSetTargetPoolsRequest implements IRegionInstanceGroupManagersSetTargetPoolsRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersSetTargetPoolsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTargetPoolsRequest);

                    /** RegionInstanceGroupManagersSetTargetPoolsRequest fingerprint. */
                    public fingerprint?: (string|null);

                    /** RegionInstanceGroupManagersSetTargetPoolsRequest targetPools. */
                    public targetPools: string[];

                    /** RegionInstanceGroupManagersSetTargetPoolsRequest _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /**
                     * Creates a new RegionInstanceGroupManagersSetTargetPoolsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersSetTargetPoolsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTargetPoolsRequest): google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersSetTargetPoolsRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersSetTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersSetTargetPoolsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersSetTargetPoolsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTargetPoolsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersSetTargetPoolsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersSetTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersSetTargetPoolsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersSetTargetPoolsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersSetTargetPoolsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersSetTargetPoolsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersSetTargetPoolsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersSetTargetPoolsRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersSetTargetPoolsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersSetTargetPoolsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersSetTargetPoolsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersSetTargetPoolsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupManagersSetTemplateRequest. */
                interface IRegionInstanceGroupManagersSetTemplateRequest {

                    /** RegionInstanceGroupManagersSetTemplateRequest instanceTemplate */
                    instanceTemplate?: (string|null);
                }

                /** Represents a RegionInstanceGroupManagersSetTemplateRequest. */
                class RegionInstanceGroupManagersSetTemplateRequest implements IRegionInstanceGroupManagersSetTemplateRequest {

                    /**
                     * Constructs a new RegionInstanceGroupManagersSetTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTemplateRequest);

                    /** RegionInstanceGroupManagersSetTemplateRequest instanceTemplate. */
                    public instanceTemplate?: (string|null);

                    /** RegionInstanceGroupManagersSetTemplateRequest _instanceTemplate. */
                    public _instanceTemplate?: "instanceTemplate";

                    /**
                     * Creates a new RegionInstanceGroupManagersSetTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupManagersSetTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTemplateRequest): google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersSetTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersSetTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupManagersSetTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupManagersSetTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupManagersSetTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupManagersSetTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupManagersSetTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest;

                    /**
                     * Decodes a RegionInstanceGroupManagersSetTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupManagersSetTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest;

                    /**
                     * Verifies a RegionInstanceGroupManagersSetTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupManagersSetTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupManagersSetTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupManagersSetTemplateRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupManagersSetTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupManagersSetTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupManagersSetTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupManagersSetTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupsListInstances. */
                interface IRegionInstanceGroupsListInstances {

                    /** RegionInstanceGroupsListInstances id */
                    id?: (string|null);

                    /** RegionInstanceGroupsListInstances items */
                    items?: (google.cloud.compute.v1.IInstanceWithNamedPorts[]|null);

                    /** RegionInstanceGroupsListInstances kind */
                    kind?: (string|null);

                    /** RegionInstanceGroupsListInstances nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionInstanceGroupsListInstances selfLink */
                    selfLink?: (string|null);

                    /** RegionInstanceGroupsListInstances warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionInstanceGroupsListInstances. */
                class RegionInstanceGroupsListInstances implements IRegionInstanceGroupsListInstances {

                    /**
                     * Constructs a new RegionInstanceGroupsListInstances.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupsListInstances);

                    /** RegionInstanceGroupsListInstances id. */
                    public id?: (string|null);

                    /** RegionInstanceGroupsListInstances items. */
                    public items: google.cloud.compute.v1.IInstanceWithNamedPorts[];

                    /** RegionInstanceGroupsListInstances kind. */
                    public kind?: (string|null);

                    /** RegionInstanceGroupsListInstances nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionInstanceGroupsListInstances selfLink. */
                    public selfLink?: (string|null);

                    /** RegionInstanceGroupsListInstances warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionInstanceGroupsListInstances _id. */
                    public _id?: "id";

                    /** RegionInstanceGroupsListInstances _kind. */
                    public _kind?: "kind";

                    /** RegionInstanceGroupsListInstances _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionInstanceGroupsListInstances _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RegionInstanceGroupsListInstances _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionInstanceGroupsListInstances instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupsListInstances instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupsListInstances): google.cloud.compute.v1.RegionInstanceGroupsListInstances;

                    /**
                     * Encodes the specified RegionInstanceGroupsListInstances message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupsListInstances.verify|verify} messages.
                     * @param message RegionInstanceGroupsListInstances message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupsListInstances, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupsListInstances message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupsListInstances.verify|verify} messages.
                     * @param message RegionInstanceGroupsListInstances message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupsListInstances, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupsListInstances message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupsListInstances
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupsListInstances;

                    /**
                     * Decodes a RegionInstanceGroupsListInstances message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupsListInstances
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupsListInstances;

                    /**
                     * Verifies a RegionInstanceGroupsListInstances message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupsListInstances message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupsListInstances
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupsListInstances;

                    /**
                     * Creates a plain object from a RegionInstanceGroupsListInstances message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupsListInstances
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupsListInstances, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupsListInstances to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupsListInstances
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionInstanceGroupsListInstancesRequest. */
                interface IRegionInstanceGroupsListInstancesRequest {

                    /** RegionInstanceGroupsListInstancesRequest instanceState */
                    instanceState?: (string|null);

                    /** RegionInstanceGroupsListInstancesRequest portName */
                    portName?: (string|null);
                }

                /** Represents a RegionInstanceGroupsListInstancesRequest. */
                class RegionInstanceGroupsListInstancesRequest implements IRegionInstanceGroupsListInstancesRequest {

                    /**
                     * Constructs a new RegionInstanceGroupsListInstancesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupsListInstancesRequest);

                    /** RegionInstanceGroupsListInstancesRequest instanceState. */
                    public instanceState?: (string|null);

                    /** RegionInstanceGroupsListInstancesRequest portName. */
                    public portName?: (string|null);

                    /** RegionInstanceGroupsListInstancesRequest _instanceState. */
                    public _instanceState?: "instanceState";

                    /** RegionInstanceGroupsListInstancesRequest _portName. */
                    public _portName?: "portName";

                    /**
                     * Creates a new RegionInstanceGroupsListInstancesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupsListInstancesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupsListInstancesRequest): google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupsListInstancesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupsListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupsListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupsListInstancesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupsListInstancesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupsListInstancesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupsListInstancesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupsListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest;

                    /**
                     * Decodes a RegionInstanceGroupsListInstancesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupsListInstancesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest;

                    /**
                     * Verifies a RegionInstanceGroupsListInstancesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupsListInstancesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupsListInstancesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupsListInstancesRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupsListInstancesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupsListInstancesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupsListInstancesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupsListInstancesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RegionInstanceGroupsListInstancesRequest {

                    /** InstanceState enum. */
                    enum InstanceState {
                        UNDEFINED_INSTANCE_STATE = 0,
                        ALL = 64897,
                        RUNNING = 121282975
                    }
                }

                /** Properties of a RegionInstanceGroupsSetNamedPortsRequest. */
                interface IRegionInstanceGroupsSetNamedPortsRequest {

                    /** RegionInstanceGroupsSetNamedPortsRequest fingerprint */
                    fingerprint?: (string|null);

                    /** RegionInstanceGroupsSetNamedPortsRequest namedPorts */
                    namedPorts?: (google.cloud.compute.v1.INamedPort[]|null);
                }

                /** Represents a RegionInstanceGroupsSetNamedPortsRequest. */
                class RegionInstanceGroupsSetNamedPortsRequest implements IRegionInstanceGroupsSetNamedPortsRequest {

                    /**
                     * Constructs a new RegionInstanceGroupsSetNamedPortsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionInstanceGroupsSetNamedPortsRequest);

                    /** RegionInstanceGroupsSetNamedPortsRequest fingerprint. */
                    public fingerprint?: (string|null);

                    /** RegionInstanceGroupsSetNamedPortsRequest namedPorts. */
                    public namedPorts: google.cloud.compute.v1.INamedPort[];

                    /** RegionInstanceGroupsSetNamedPortsRequest _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /**
                     * Creates a new RegionInstanceGroupsSetNamedPortsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionInstanceGroupsSetNamedPortsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionInstanceGroupsSetNamedPortsRequest): google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest;

                    /**
                     * Encodes the specified RegionInstanceGroupsSetNamedPortsRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupsSetNamedPortsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionInstanceGroupsSetNamedPortsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionInstanceGroupsSetNamedPortsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest.verify|verify} messages.
                     * @param message RegionInstanceGroupsSetNamedPortsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionInstanceGroupsSetNamedPortsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionInstanceGroupsSetNamedPortsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionInstanceGroupsSetNamedPortsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest;

                    /**
                     * Decodes a RegionInstanceGroupsSetNamedPortsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionInstanceGroupsSetNamedPortsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest;

                    /**
                     * Verifies a RegionInstanceGroupsSetNamedPortsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionInstanceGroupsSetNamedPortsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionInstanceGroupsSetNamedPortsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest;

                    /**
                     * Creates a plain object from a RegionInstanceGroupsSetNamedPortsRequest message. Also converts values to other types if specified.
                     * @param message RegionInstanceGroupsSetNamedPortsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionInstanceGroupsSetNamedPortsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionInstanceGroupsSetNamedPortsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionInstanceGroupsSetNamedPortsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionList. */
                interface IRegionList {

                    /** RegionList id */
                    id?: (string|null);

                    /** RegionList items */
                    items?: (google.cloud.compute.v1.IRegion[]|null);

                    /** RegionList kind */
                    kind?: (string|null);

                    /** RegionList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RegionList selfLink */
                    selfLink?: (string|null);

                    /** RegionList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RegionList. */
                class RegionList implements IRegionList {

                    /**
                     * Constructs a new RegionList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionList);

                    /** RegionList id. */
                    public id?: (string|null);

                    /** RegionList items. */
                    public items: google.cloud.compute.v1.IRegion[];

                    /** RegionList kind. */
                    public kind?: (string|null);

                    /** RegionList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RegionList selfLink. */
                    public selfLink?: (string|null);

                    /** RegionList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RegionList _id. */
                    public _id?: "id";

                    /** RegionList _kind. */
                    public _kind?: "kind";

                    /** RegionList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RegionList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RegionList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RegionList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionList): google.cloud.compute.v1.RegionList;

                    /**
                     * Encodes the specified RegionList message. Does not implicitly {@link google.cloud.compute.v1.RegionList.verify|verify} messages.
                     * @param message RegionList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionList.verify|verify} messages.
                     * @param message RegionList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionList;

                    /**
                     * Decodes a RegionList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionList;

                    /**
                     * Verifies a RegionList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionList;

                    /**
                     * Creates a plain object from a RegionList message. Also converts values to other types if specified.
                     * @param message RegionList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse. */
                interface IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse {

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse firewallPolicys */
                    firewallPolicys?: (google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy[]|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse firewalls */
                    firewalls?: (google.cloud.compute.v1.IFirewall[]|null);
                }

                /** Represents a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse. */
                class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse implements IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse {

                    /**
                     * Constructs a new RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse firewallPolicys. */
                    public firewallPolicys: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy[];

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse firewalls. */
                    public firewalls: google.cloud.compute.v1.IFirewall[];

                    /**
                     * Creates a new RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse;

                    /**
                     * Encodes the specified RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message. Does not implicitly {@link google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.verify|verify} messages.
                     * @param message RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.verify|verify} messages.
                     * @param message RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse;

                    /**
                     * Decodes a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse;

                    /**
                     * Verifies a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse;

                    /**
                     * Creates a plain object from a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse message. Also converts values to other types if specified.
                     * @param message RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy. */
                interface IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy displayName */
                    displayName?: (string|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy name */
                    name?: (string|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy rules */
                    rules?: (google.cloud.compute.v1.IFirewallPolicyRule[]|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy type */
                    type?: (string|null);
                }

                /** Represents a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy. */
                class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy implements IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /**
                     * Constructs a new RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy displayName. */
                    public displayName?: (string|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy name. */
                    public name?: (string|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy rules. */
                    public rules: google.cloud.compute.v1.IFirewallPolicyRule[];

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy type. */
                    public type?: (string|null);

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _displayName. */
                    public _displayName?: "displayName";

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _name. */
                    public _name?: "name";

                    /** RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy _type. */
                    public _type?: "type";

                    /**
                     * Creates a new RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Encodes the specified RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message. Does not implicitly {@link google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.verify|verify} messages.
                     * @param message RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.verify|verify} messages.
                     * @param message RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Decodes a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Verifies a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy;

                    /**
                     * Creates a plain object from a RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy message. Also converts values to other types if specified.
                     * @param message RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        HIERARCHY = 69902869,
                        NETWORK = 413984270,
                        NETWORK_REGIONAL = 190804272,
                        UNSPECIFIED = 526786327
                    }
                }

                /** Properties of a RegionSetLabelsRequest. */
                interface IRegionSetLabelsRequest {

                    /** RegionSetLabelsRequest labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** RegionSetLabelsRequest labels */
                    labels?: ({ [k: string]: string }|null);
                }

                /** Represents a RegionSetLabelsRequest. */
                class RegionSetLabelsRequest implements IRegionSetLabelsRequest {

                    /**
                     * Constructs a new RegionSetLabelsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionSetLabelsRequest);

                    /** RegionSetLabelsRequest labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** RegionSetLabelsRequest labels. */
                    public labels: { [k: string]: string };

                    /** RegionSetLabelsRequest _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /**
                     * Creates a new RegionSetLabelsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionSetLabelsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionSetLabelsRequest): google.cloud.compute.v1.RegionSetLabelsRequest;

                    /**
                     * Encodes the specified RegionSetLabelsRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionSetLabelsRequest.verify|verify} messages.
                     * @param message RegionSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionSetLabelsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionSetLabelsRequest.verify|verify} messages.
                     * @param message RegionSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionSetLabelsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionSetLabelsRequest;

                    /**
                     * Decodes a RegionSetLabelsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionSetLabelsRequest;

                    /**
                     * Verifies a RegionSetLabelsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionSetLabelsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionSetLabelsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionSetLabelsRequest;

                    /**
                     * Creates a plain object from a RegionSetLabelsRequest message. Also converts values to other types if specified.
                     * @param message RegionSetLabelsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionSetLabelsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionSetLabelsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionSetLabelsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionSetPolicyRequest. */
                interface IRegionSetPolicyRequest {

                    /** RegionSetPolicyRequest bindings */
                    bindings?: (google.cloud.compute.v1.IBinding[]|null);

                    /** RegionSetPolicyRequest etag */
                    etag?: (string|null);

                    /** RegionSetPolicyRequest policy */
                    policy?: (google.cloud.compute.v1.IPolicy|null);
                }

                /** Represents a RegionSetPolicyRequest. */
                class RegionSetPolicyRequest implements IRegionSetPolicyRequest {

                    /**
                     * Constructs a new RegionSetPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionSetPolicyRequest);

                    /** RegionSetPolicyRequest bindings. */
                    public bindings: google.cloud.compute.v1.IBinding[];

                    /** RegionSetPolicyRequest etag. */
                    public etag?: (string|null);

                    /** RegionSetPolicyRequest policy. */
                    public policy?: (google.cloud.compute.v1.IPolicy|null);

                    /** RegionSetPolicyRequest _etag. */
                    public _etag?: "etag";

                    /** RegionSetPolicyRequest _policy. */
                    public _policy?: "policy";

                    /**
                     * Creates a new RegionSetPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionSetPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionSetPolicyRequest): google.cloud.compute.v1.RegionSetPolicyRequest;

                    /**
                     * Encodes the specified RegionSetPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionSetPolicyRequest.verify|verify} messages.
                     * @param message RegionSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionSetPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionSetPolicyRequest.verify|verify} messages.
                     * @param message RegionSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionSetPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionSetPolicyRequest;

                    /**
                     * Decodes a RegionSetPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionSetPolicyRequest;

                    /**
                     * Verifies a RegionSetPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionSetPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionSetPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionSetPolicyRequest;

                    /**
                     * Creates a plain object from a RegionSetPolicyRequest message. Also converts values to other types if specified.
                     * @param message RegionSetPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionSetPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionSetPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionSetPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionTargetHttpsProxiesSetSslCertificatesRequest. */
                interface IRegionTargetHttpsProxiesSetSslCertificatesRequest {

                    /** RegionTargetHttpsProxiesSetSslCertificatesRequest sslCertificates */
                    sslCertificates?: (string[]|null);
                }

                /** Represents a RegionTargetHttpsProxiesSetSslCertificatesRequest. */
                class RegionTargetHttpsProxiesSetSslCertificatesRequest implements IRegionTargetHttpsProxiesSetSslCertificatesRequest {

                    /**
                     * Constructs a new RegionTargetHttpsProxiesSetSslCertificatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionTargetHttpsProxiesSetSslCertificatesRequest);

                    /** RegionTargetHttpsProxiesSetSslCertificatesRequest sslCertificates. */
                    public sslCertificates: string[];

                    /**
                     * Creates a new RegionTargetHttpsProxiesSetSslCertificatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionTargetHttpsProxiesSetSslCertificatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionTargetHttpsProxiesSetSslCertificatesRequest): google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Encodes the specified RegionTargetHttpsProxiesSetSslCertificatesRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest.verify|verify} messages.
                     * @param message RegionTargetHttpsProxiesSetSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionTargetHttpsProxiesSetSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionTargetHttpsProxiesSetSslCertificatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest.verify|verify} messages.
                     * @param message RegionTargetHttpsProxiesSetSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionTargetHttpsProxiesSetSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionTargetHttpsProxiesSetSslCertificatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionTargetHttpsProxiesSetSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Decodes a RegionTargetHttpsProxiesSetSslCertificatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionTargetHttpsProxiesSetSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Verifies a RegionTargetHttpsProxiesSetSslCertificatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionTargetHttpsProxiesSetSslCertificatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionTargetHttpsProxiesSetSslCertificatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Creates a plain object from a RegionTargetHttpsProxiesSetSslCertificatesRequest message. Also converts values to other types if specified.
                     * @param message RegionTargetHttpsProxiesSetSslCertificatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionTargetHttpsProxiesSetSslCertificatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionTargetHttpsProxiesSetSslCertificatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionTargetHttpsProxiesSetSslCertificatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RegionUrlMapsValidateRequest. */
                interface IRegionUrlMapsValidateRequest {

                    /** RegionUrlMapsValidateRequest resource */
                    resource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents a RegionUrlMapsValidateRequest. */
                class RegionUrlMapsValidateRequest implements IRegionUrlMapsValidateRequest {

                    /**
                     * Constructs a new RegionUrlMapsValidateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRegionUrlMapsValidateRequest);

                    /** RegionUrlMapsValidateRequest resource. */
                    public resource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** RegionUrlMapsValidateRequest _resource. */
                    public _resource?: "resource";

                    /**
                     * Creates a new RegionUrlMapsValidateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RegionUrlMapsValidateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRegionUrlMapsValidateRequest): google.cloud.compute.v1.RegionUrlMapsValidateRequest;

                    /**
                     * Encodes the specified RegionUrlMapsValidateRequest message. Does not implicitly {@link google.cloud.compute.v1.RegionUrlMapsValidateRequest.verify|verify} messages.
                     * @param message RegionUrlMapsValidateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRegionUrlMapsValidateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RegionUrlMapsValidateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RegionUrlMapsValidateRequest.verify|verify} messages.
                     * @param message RegionUrlMapsValidateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRegionUrlMapsValidateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RegionUrlMapsValidateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RegionUrlMapsValidateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RegionUrlMapsValidateRequest;

                    /**
                     * Decodes a RegionUrlMapsValidateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RegionUrlMapsValidateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RegionUrlMapsValidateRequest;

                    /**
                     * Verifies a RegionUrlMapsValidateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RegionUrlMapsValidateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RegionUrlMapsValidateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RegionUrlMapsValidateRequest;

                    /**
                     * Creates a plain object from a RegionUrlMapsValidateRequest message. Also converts values to other types if specified.
                     * @param message RegionUrlMapsValidateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RegionUrlMapsValidateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RegionUrlMapsValidateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RegionUrlMapsValidateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveAssociationFirewallPolicyRequest. */
                interface IRemoveAssociationFirewallPolicyRequest {

                    /** RemoveAssociationFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** RemoveAssociationFirewallPolicyRequest name */
                    name?: (string|null);

                    /** RemoveAssociationFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveAssociationFirewallPolicyRequest. */
                class RemoveAssociationFirewallPolicyRequest implements IRemoveAssociationFirewallPolicyRequest {

                    /**
                     * Constructs a new RemoveAssociationFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveAssociationFirewallPolicyRequest);

                    /** RemoveAssociationFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** RemoveAssociationFirewallPolicyRequest name. */
                    public name?: (string|null);

                    /** RemoveAssociationFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveAssociationFirewallPolicyRequest _name. */
                    public _name?: "name";

                    /** RemoveAssociationFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveAssociationFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveAssociationFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveAssociationFirewallPolicyRequest): google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest;

                    /**
                     * Encodes the specified RemoveAssociationFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveAssociationFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveAssociationFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveAssociationFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveAssociationFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveAssociationFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveAssociationFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveAssociationFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest;

                    /**
                     * Decodes a RemoveAssociationFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveAssociationFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest;

                    /**
                     * Verifies a RemoveAssociationFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveAssociationFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveAssociationFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveAssociationFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveAssociationFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveAssociationFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveAssociationFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveAssociationFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveAssociationNetworkFirewallPolicyRequest. */
                interface IRemoveAssociationNetworkFirewallPolicyRequest {

                    /** RemoveAssociationNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** RemoveAssociationNetworkFirewallPolicyRequest name */
                    name?: (string|null);

                    /** RemoveAssociationNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** RemoveAssociationNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveAssociationNetworkFirewallPolicyRequest. */
                class RemoveAssociationNetworkFirewallPolicyRequest implements IRemoveAssociationNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new RemoveAssociationNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveAssociationNetworkFirewallPolicyRequest);

                    /** RemoveAssociationNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** RemoveAssociationNetworkFirewallPolicyRequest name. */
                    public name?: (string|null);

                    /** RemoveAssociationNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** RemoveAssociationNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveAssociationNetworkFirewallPolicyRequest _name. */
                    public _name?: "name";

                    /** RemoveAssociationNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveAssociationNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveAssociationNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveAssociationNetworkFirewallPolicyRequest): google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified RemoveAssociationNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveAssociationNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveAssociationNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveAssociationNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveAssociationNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveAssociationNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveAssociationNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveAssociationNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a RemoveAssociationNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveAssociationNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a RemoveAssociationNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveAssociationNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveAssociationNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveAssociationNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveAssociationNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveAssociationNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveAssociationNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveAssociationNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveAssociationRegionNetworkFirewallPolicyRequest. */
                interface IRemoveAssociationRegionNetworkFirewallPolicyRequest {

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest name */
                    name?: (string|null);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveAssociationRegionNetworkFirewallPolicyRequest. */
                class RemoveAssociationRegionNetworkFirewallPolicyRequest implements IRemoveAssociationRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new RemoveAssociationRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveAssociationRegionNetworkFirewallPolicyRequest);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest name. */
                    public name?: (string|null);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest _name. */
                    public _name?: "name";

                    /** RemoveAssociationRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveAssociationRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveAssociationRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveAssociationRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified RemoveAssociationRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveAssociationRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveAssociationRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveAssociationRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveAssociationRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveAssociationRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveAssociationRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveAssociationRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a RemoveAssociationRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveAssociationRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a RemoveAssociationRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveAssociationRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveAssociationRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveAssociationRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveAssociationRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveAssociationRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveAssociationRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveAssociationRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveHealthCheckTargetPoolRequest. */
                interface IRemoveHealthCheckTargetPoolRequest {

                    /** RemoveHealthCheckTargetPoolRequest project */
                    project?: (string|null);

                    /** RemoveHealthCheckTargetPoolRequest region */
                    region?: (string|null);

                    /** RemoveHealthCheckTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** RemoveHealthCheckTargetPoolRequest targetPool */
                    targetPool?: (string|null);

                    /** RemoveHealthCheckTargetPoolRequest targetPoolsRemoveHealthCheckRequestResource */
                    targetPoolsRemoveHealthCheckRequestResource?: (google.cloud.compute.v1.ITargetPoolsRemoveHealthCheckRequest|null);
                }

                /** Represents a RemoveHealthCheckTargetPoolRequest. */
                class RemoveHealthCheckTargetPoolRequest implements IRemoveHealthCheckTargetPoolRequest {

                    /**
                     * Constructs a new RemoveHealthCheckTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveHealthCheckTargetPoolRequest);

                    /** RemoveHealthCheckTargetPoolRequest project. */
                    public project: string;

                    /** RemoveHealthCheckTargetPoolRequest region. */
                    public region: string;

                    /** RemoveHealthCheckTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveHealthCheckTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /** RemoveHealthCheckTargetPoolRequest targetPoolsRemoveHealthCheckRequestResource. */
                    public targetPoolsRemoveHealthCheckRequestResource?: (google.cloud.compute.v1.ITargetPoolsRemoveHealthCheckRequest|null);

                    /** RemoveHealthCheckTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveHealthCheckTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveHealthCheckTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveHealthCheckTargetPoolRequest): google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest;

                    /**
                     * Encodes the specified RemoveHealthCheckTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest.verify|verify} messages.
                     * @param message RemoveHealthCheckTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveHealthCheckTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveHealthCheckTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest.verify|verify} messages.
                     * @param message RemoveHealthCheckTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveHealthCheckTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveHealthCheckTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveHealthCheckTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest;

                    /**
                     * Decodes a RemoveHealthCheckTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveHealthCheckTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest;

                    /**
                     * Verifies a RemoveHealthCheckTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveHealthCheckTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveHealthCheckTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest;

                    /**
                     * Creates a plain object from a RemoveHealthCheckTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message RemoveHealthCheckTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveHealthCheckTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveHealthCheckTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveHealthCheckTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveInstanceTargetPoolRequest. */
                interface IRemoveInstanceTargetPoolRequest {

                    /** RemoveInstanceTargetPoolRequest project */
                    project?: (string|null);

                    /** RemoveInstanceTargetPoolRequest region */
                    region?: (string|null);

                    /** RemoveInstanceTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** RemoveInstanceTargetPoolRequest targetPool */
                    targetPool?: (string|null);

                    /** RemoveInstanceTargetPoolRequest targetPoolsRemoveInstanceRequestResource */
                    targetPoolsRemoveInstanceRequestResource?: (google.cloud.compute.v1.ITargetPoolsRemoveInstanceRequest|null);
                }

                /** Represents a RemoveInstanceTargetPoolRequest. */
                class RemoveInstanceTargetPoolRequest implements IRemoveInstanceTargetPoolRequest {

                    /**
                     * Constructs a new RemoveInstanceTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveInstanceTargetPoolRequest);

                    /** RemoveInstanceTargetPoolRequest project. */
                    public project: string;

                    /** RemoveInstanceTargetPoolRequest region. */
                    public region: string;

                    /** RemoveInstanceTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveInstanceTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /** RemoveInstanceTargetPoolRequest targetPoolsRemoveInstanceRequestResource. */
                    public targetPoolsRemoveInstanceRequestResource?: (google.cloud.compute.v1.ITargetPoolsRemoveInstanceRequest|null);

                    /** RemoveInstanceTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveInstanceTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveInstanceTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveInstanceTargetPoolRequest): google.cloud.compute.v1.RemoveInstanceTargetPoolRequest;

                    /**
                     * Encodes the specified RemoveInstanceTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveInstanceTargetPoolRequest.verify|verify} messages.
                     * @param message RemoveInstanceTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveInstanceTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveInstanceTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveInstanceTargetPoolRequest.verify|verify} messages.
                     * @param message RemoveInstanceTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveInstanceTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveInstanceTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveInstanceTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveInstanceTargetPoolRequest;

                    /**
                     * Decodes a RemoveInstanceTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveInstanceTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveInstanceTargetPoolRequest;

                    /**
                     * Verifies a RemoveInstanceTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveInstanceTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveInstanceTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveInstanceTargetPoolRequest;

                    /**
                     * Creates a plain object from a RemoveInstanceTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message RemoveInstanceTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveInstanceTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveInstanceTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveInstanceTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveInstancesInstanceGroupRequest. */
                interface IRemoveInstancesInstanceGroupRequest {

                    /** RemoveInstancesInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** RemoveInstancesInstanceGroupRequest instanceGroupsRemoveInstancesRequestResource */
                    instanceGroupsRemoveInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupsRemoveInstancesRequest|null);

                    /** RemoveInstancesInstanceGroupRequest project */
                    project?: (string|null);

                    /** RemoveInstancesInstanceGroupRequest requestId */
                    requestId?: (string|null);

                    /** RemoveInstancesInstanceGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a RemoveInstancesInstanceGroupRequest. */
                class RemoveInstancesInstanceGroupRequest implements IRemoveInstancesInstanceGroupRequest {

                    /**
                     * Constructs a new RemoveInstancesInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveInstancesInstanceGroupRequest);

                    /** RemoveInstancesInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** RemoveInstancesInstanceGroupRequest instanceGroupsRemoveInstancesRequestResource. */
                    public instanceGroupsRemoveInstancesRequestResource?: (google.cloud.compute.v1.IInstanceGroupsRemoveInstancesRequest|null);

                    /** RemoveInstancesInstanceGroupRequest project. */
                    public project: string;

                    /** RemoveInstancesInstanceGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveInstancesInstanceGroupRequest zone. */
                    public zone: string;

                    /** RemoveInstancesInstanceGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveInstancesInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveInstancesInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveInstancesInstanceGroupRequest): google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest;

                    /**
                     * Encodes the specified RemoveInstancesInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest.verify|verify} messages.
                     * @param message RemoveInstancesInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveInstancesInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveInstancesInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest.verify|verify} messages.
                     * @param message RemoveInstancesInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveInstancesInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveInstancesInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveInstancesInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest;

                    /**
                     * Decodes a RemoveInstancesInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveInstancesInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest;

                    /**
                     * Verifies a RemoveInstancesInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveInstancesInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveInstancesInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest;

                    /**
                     * Creates a plain object from a RemoveInstancesInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message RemoveInstancesInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveInstancesInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveInstancesInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveInstancesInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemovePeeringNetworkRequest. */
                interface IRemovePeeringNetworkRequest {

                    /** RemovePeeringNetworkRequest network */
                    network?: (string|null);

                    /** RemovePeeringNetworkRequest networksRemovePeeringRequestResource */
                    networksRemovePeeringRequestResource?: (google.cloud.compute.v1.INetworksRemovePeeringRequest|null);

                    /** RemovePeeringNetworkRequest project */
                    project?: (string|null);

                    /** RemovePeeringNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemovePeeringNetworkRequest. */
                class RemovePeeringNetworkRequest implements IRemovePeeringNetworkRequest {

                    /**
                     * Constructs a new RemovePeeringNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemovePeeringNetworkRequest);

                    /** RemovePeeringNetworkRequest network. */
                    public network: string;

                    /** RemovePeeringNetworkRequest networksRemovePeeringRequestResource. */
                    public networksRemovePeeringRequestResource?: (google.cloud.compute.v1.INetworksRemovePeeringRequest|null);

                    /** RemovePeeringNetworkRequest project. */
                    public project: string;

                    /** RemovePeeringNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** RemovePeeringNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemovePeeringNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemovePeeringNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemovePeeringNetworkRequest): google.cloud.compute.v1.RemovePeeringNetworkRequest;

                    /**
                     * Encodes the specified RemovePeeringNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.RemovePeeringNetworkRequest.verify|verify} messages.
                     * @param message RemovePeeringNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemovePeeringNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemovePeeringNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemovePeeringNetworkRequest.verify|verify} messages.
                     * @param message RemovePeeringNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemovePeeringNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemovePeeringNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemovePeeringNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemovePeeringNetworkRequest;

                    /**
                     * Decodes a RemovePeeringNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemovePeeringNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemovePeeringNetworkRequest;

                    /**
                     * Verifies a RemovePeeringNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemovePeeringNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemovePeeringNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemovePeeringNetworkRequest;

                    /**
                     * Creates a plain object from a RemovePeeringNetworkRequest message. Also converts values to other types if specified.
                     * @param message RemovePeeringNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemovePeeringNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemovePeeringNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemovePeeringNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveResourcePoliciesDiskRequest. */
                interface IRemoveResourcePoliciesDiskRequest {

                    /** RemoveResourcePoliciesDiskRequest disk */
                    disk?: (string|null);

                    /** RemoveResourcePoliciesDiskRequest disksRemoveResourcePoliciesRequestResource */
                    disksRemoveResourcePoliciesRequestResource?: (google.cloud.compute.v1.IDisksRemoveResourcePoliciesRequest|null);

                    /** RemoveResourcePoliciesDiskRequest project */
                    project?: (string|null);

                    /** RemoveResourcePoliciesDiskRequest requestId */
                    requestId?: (string|null);

                    /** RemoveResourcePoliciesDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a RemoveResourcePoliciesDiskRequest. */
                class RemoveResourcePoliciesDiskRequest implements IRemoveResourcePoliciesDiskRequest {

                    /**
                     * Constructs a new RemoveResourcePoliciesDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest);

                    /** RemoveResourcePoliciesDiskRequest disk. */
                    public disk: string;

                    /** RemoveResourcePoliciesDiskRequest disksRemoveResourcePoliciesRequestResource. */
                    public disksRemoveResourcePoliciesRequestResource?: (google.cloud.compute.v1.IDisksRemoveResourcePoliciesRequest|null);

                    /** RemoveResourcePoliciesDiskRequest project. */
                    public project: string;

                    /** RemoveResourcePoliciesDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveResourcePoliciesDiskRequest zone. */
                    public zone: string;

                    /** RemoveResourcePoliciesDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveResourcePoliciesDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveResourcePoliciesDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest): google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest;

                    /**
                     * Encodes the specified RemoveResourcePoliciesDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest.verify|verify} messages.
                     * @param message RemoveResourcePoliciesDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveResourcePoliciesDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest.verify|verify} messages.
                     * @param message RemoveResourcePoliciesDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveResourcePoliciesDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveResourcePoliciesDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest;

                    /**
                     * Decodes a RemoveResourcePoliciesDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveResourcePoliciesDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest;

                    /**
                     * Verifies a RemoveResourcePoliciesDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveResourcePoliciesDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveResourcePoliciesDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest;

                    /**
                     * Creates a plain object from a RemoveResourcePoliciesDiskRequest message. Also converts values to other types if specified.
                     * @param message RemoveResourcePoliciesDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveResourcePoliciesDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveResourcePoliciesDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveResourcePoliciesDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveResourcePoliciesInstanceRequest. */
                interface IRemoveResourcePoliciesInstanceRequest {

                    /** RemoveResourcePoliciesInstanceRequest instance */
                    instance?: (string|null);

                    /** RemoveResourcePoliciesInstanceRequest instancesRemoveResourcePoliciesRequestResource */
                    instancesRemoveResourcePoliciesRequestResource?: (google.cloud.compute.v1.IInstancesRemoveResourcePoliciesRequest|null);

                    /** RemoveResourcePoliciesInstanceRequest project */
                    project?: (string|null);

                    /** RemoveResourcePoliciesInstanceRequest requestId */
                    requestId?: (string|null);

                    /** RemoveResourcePoliciesInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a RemoveResourcePoliciesInstanceRequest. */
                class RemoveResourcePoliciesInstanceRequest implements IRemoveResourcePoliciesInstanceRequest {

                    /**
                     * Constructs a new RemoveResourcePoliciesInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveResourcePoliciesInstanceRequest);

                    /** RemoveResourcePoliciesInstanceRequest instance. */
                    public instance: string;

                    /** RemoveResourcePoliciesInstanceRequest instancesRemoveResourcePoliciesRequestResource. */
                    public instancesRemoveResourcePoliciesRequestResource?: (google.cloud.compute.v1.IInstancesRemoveResourcePoliciesRequest|null);

                    /** RemoveResourcePoliciesInstanceRequest project. */
                    public project: string;

                    /** RemoveResourcePoliciesInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveResourcePoliciesInstanceRequest zone. */
                    public zone: string;

                    /** RemoveResourcePoliciesInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveResourcePoliciesInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveResourcePoliciesInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveResourcePoliciesInstanceRequest): google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest;

                    /**
                     * Encodes the specified RemoveResourcePoliciesInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest.verify|verify} messages.
                     * @param message RemoveResourcePoliciesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveResourcePoliciesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveResourcePoliciesInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest.verify|verify} messages.
                     * @param message RemoveResourcePoliciesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveResourcePoliciesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveResourcePoliciesInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveResourcePoliciesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest;

                    /**
                     * Decodes a RemoveResourcePoliciesInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveResourcePoliciesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest;

                    /**
                     * Verifies a RemoveResourcePoliciesInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveResourcePoliciesInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveResourcePoliciesInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest;

                    /**
                     * Creates a plain object from a RemoveResourcePoliciesInstanceRequest message. Also converts values to other types if specified.
                     * @param message RemoveResourcePoliciesInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveResourcePoliciesInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveResourcePoliciesInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveResourcePoliciesInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveResourcePoliciesRegionDiskRequest. */
                interface IRemoveResourcePoliciesRegionDiskRequest {

                    /** RemoveResourcePoliciesRegionDiskRequest disk */
                    disk?: (string|null);

                    /** RemoveResourcePoliciesRegionDiskRequest project */
                    project?: (string|null);

                    /** RemoveResourcePoliciesRegionDiskRequest region */
                    region?: (string|null);

                    /** RemoveResourcePoliciesRegionDiskRequest regionDisksRemoveResourcePoliciesRequestResource */
                    regionDisksRemoveResourcePoliciesRequestResource?: (google.cloud.compute.v1.IRegionDisksRemoveResourcePoliciesRequest|null);

                    /** RemoveResourcePoliciesRegionDiskRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveResourcePoliciesRegionDiskRequest. */
                class RemoveResourcePoliciesRegionDiskRequest implements IRemoveResourcePoliciesRegionDiskRequest {

                    /**
                     * Constructs a new RemoveResourcePoliciesRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveResourcePoliciesRegionDiskRequest);

                    /** RemoveResourcePoliciesRegionDiskRequest disk. */
                    public disk: string;

                    /** RemoveResourcePoliciesRegionDiskRequest project. */
                    public project: string;

                    /** RemoveResourcePoliciesRegionDiskRequest region. */
                    public region: string;

                    /** RemoveResourcePoliciesRegionDiskRequest regionDisksRemoveResourcePoliciesRequestResource. */
                    public regionDisksRemoveResourcePoliciesRequestResource?: (google.cloud.compute.v1.IRegionDisksRemoveResourcePoliciesRequest|null);

                    /** RemoveResourcePoliciesRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveResourcePoliciesRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveResourcePoliciesRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveResourcePoliciesRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveResourcePoliciesRegionDiskRequest): google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest;

                    /**
                     * Encodes the specified RemoveResourcePoliciesRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest.verify|verify} messages.
                     * @param message RemoveResourcePoliciesRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveResourcePoliciesRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveResourcePoliciesRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest.verify|verify} messages.
                     * @param message RemoveResourcePoliciesRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveResourcePoliciesRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveResourcePoliciesRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveResourcePoliciesRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest;

                    /**
                     * Decodes a RemoveResourcePoliciesRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveResourcePoliciesRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest;

                    /**
                     * Verifies a RemoveResourcePoliciesRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveResourcePoliciesRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveResourcePoliciesRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest;

                    /**
                     * Creates a plain object from a RemoveResourcePoliciesRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message RemoveResourcePoliciesRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveResourcePoliciesRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveResourcePoliciesRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveResourcePoliciesRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveRuleFirewallPolicyRequest. */
                interface IRemoveRuleFirewallPolicyRequest {

                    /** RemoveRuleFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** RemoveRuleFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** RemoveRuleFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveRuleFirewallPolicyRequest. */
                class RemoveRuleFirewallPolicyRequest implements IRemoveRuleFirewallPolicyRequest {

                    /**
                     * Constructs a new RemoveRuleFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveRuleFirewallPolicyRequest);

                    /** RemoveRuleFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** RemoveRuleFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** RemoveRuleFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveRuleFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** RemoveRuleFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveRuleFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveRuleFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveRuleFirewallPolicyRequest): google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest;

                    /**
                     * Encodes the specified RemoveRuleFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveRuleFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveRuleFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveRuleFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest;

                    /**
                     * Decodes a RemoveRuleFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveRuleFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest;

                    /**
                     * Verifies a RemoveRuleFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveRuleFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveRuleFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveRuleFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveRuleFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveRuleFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveRuleFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveRuleFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveRuleNetworkFirewallPolicyRequest. */
                interface IRemoveRuleNetworkFirewallPolicyRequest {

                    /** RemoveRuleNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** RemoveRuleNetworkFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** RemoveRuleNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** RemoveRuleNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveRuleNetworkFirewallPolicyRequest. */
                class RemoveRuleNetworkFirewallPolicyRequest implements IRemoveRuleNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new RemoveRuleNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveRuleNetworkFirewallPolicyRequest);

                    /** RemoveRuleNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** RemoveRuleNetworkFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** RemoveRuleNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** RemoveRuleNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveRuleNetworkFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** RemoveRuleNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveRuleNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveRuleNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveRuleNetworkFirewallPolicyRequest): google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified RemoveRuleNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveRuleNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveRuleNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveRuleNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a RemoveRuleNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveRuleNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a RemoveRuleNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveRuleNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveRuleNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveRuleNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveRuleNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveRuleNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveRuleNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveRuleNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveRuleRegionNetworkFirewallPolicyRequest. */
                interface IRemoveRuleRegionNetworkFirewallPolicyRequest {

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest firewallPolicy */
                    firewallPolicy?: (string|null);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest priority */
                    priority?: (number|null);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a RemoveRuleRegionNetworkFirewallPolicyRequest. */
                class RemoveRuleRegionNetworkFirewallPolicyRequest implements IRemoveRuleRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new RemoveRuleRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveRuleRegionNetworkFirewallPolicyRequest);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest firewallPolicy. */
                    public firewallPolicy: string;

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest priority. */
                    public priority?: (number|null);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest requestId. */
                    public requestId?: (string|null);

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest _priority. */
                    public _priority?: "priority";

                    /** RemoveRuleRegionNetworkFirewallPolicyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new RemoveRuleRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveRuleRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveRuleRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified RemoveRuleRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveRuleRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveRuleRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a RemoveRuleRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveRuleRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a RemoveRuleRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveRuleRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveRuleRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveRuleRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveRuleRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveRuleRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveRuleRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveRuleRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RemoveRuleSecurityPolicyRequest. */
                interface IRemoveRuleSecurityPolicyRequest {

                    /** RemoveRuleSecurityPolicyRequest priority */
                    priority?: (number|null);

                    /** RemoveRuleSecurityPolicyRequest project */
                    project?: (string|null);

                    /** RemoveRuleSecurityPolicyRequest securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a RemoveRuleSecurityPolicyRequest. */
                class RemoveRuleSecurityPolicyRequest implements IRemoveRuleSecurityPolicyRequest {

                    /**
                     * Constructs a new RemoveRuleSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRemoveRuleSecurityPolicyRequest);

                    /** RemoveRuleSecurityPolicyRequest priority. */
                    public priority?: (number|null);

                    /** RemoveRuleSecurityPolicyRequest project. */
                    public project: string;

                    /** RemoveRuleSecurityPolicyRequest securityPolicy. */
                    public securityPolicy: string;

                    /** RemoveRuleSecurityPolicyRequest _priority. */
                    public _priority?: "priority";

                    /**
                     * Creates a new RemoveRuleSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RemoveRuleSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRemoveRuleSecurityPolicyRequest): google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest;

                    /**
                     * Encodes the specified RemoveRuleSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRemoveRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RemoveRuleSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest.verify|verify} messages.
                     * @param message RemoveRuleSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRemoveRuleSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RemoveRuleSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RemoveRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest;

                    /**
                     * Decodes a RemoveRuleSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RemoveRuleSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest;

                    /**
                     * Verifies a RemoveRuleSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RemoveRuleSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RemoveRuleSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a RemoveRuleSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message RemoveRuleSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RemoveRuleSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RemoveRuleSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RemoveRuleSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RequestMirrorPolicy. */
                interface IRequestMirrorPolicy {

                    /** RequestMirrorPolicy backendService */
                    backendService?: (string|null);
                }

                /** Represents a RequestMirrorPolicy. */
                class RequestMirrorPolicy implements IRequestMirrorPolicy {

                    /**
                     * Constructs a new RequestMirrorPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRequestMirrorPolicy);

                    /** RequestMirrorPolicy backendService. */
                    public backendService?: (string|null);

                    /** RequestMirrorPolicy _backendService. */
                    public _backendService?: "backendService";

                    /**
                     * Creates a new RequestMirrorPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RequestMirrorPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRequestMirrorPolicy): google.cloud.compute.v1.RequestMirrorPolicy;

                    /**
                     * Encodes the specified RequestMirrorPolicy message. Does not implicitly {@link google.cloud.compute.v1.RequestMirrorPolicy.verify|verify} messages.
                     * @param message RequestMirrorPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRequestMirrorPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RequestMirrorPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RequestMirrorPolicy.verify|verify} messages.
                     * @param message RequestMirrorPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRequestMirrorPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RequestMirrorPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RequestMirrorPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RequestMirrorPolicy;

                    /**
                     * Decodes a RequestMirrorPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RequestMirrorPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RequestMirrorPolicy;

                    /**
                     * Verifies a RequestMirrorPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RequestMirrorPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RequestMirrorPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RequestMirrorPolicy;

                    /**
                     * Creates a plain object from a RequestMirrorPolicy message. Also converts values to other types if specified.
                     * @param message RequestMirrorPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RequestMirrorPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RequestMirrorPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RequestMirrorPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Reservation. */
                interface IReservation {

                    /** Reservation commitment */
                    commitment?: (string|null);

                    /** Reservation creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Reservation description */
                    description?: (string|null);

                    /** Reservation id */
                    id?: (number|Long|string|null);

                    /** Reservation kind */
                    kind?: (string|null);

                    /** Reservation name */
                    name?: (string|null);

                    /** Reservation satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Reservation selfLink */
                    selfLink?: (string|null);

                    /** Reservation shareSettings */
                    shareSettings?: (google.cloud.compute.v1.IShareSettings|null);

                    /** Reservation specificReservation */
                    specificReservation?: (google.cloud.compute.v1.IAllocationSpecificSKUReservation|null);

                    /** Reservation specificReservationRequired */
                    specificReservationRequired?: (boolean|null);

                    /** Reservation status */
                    status?: (string|null);

                    /** Reservation zone */
                    zone?: (string|null);
                }

                /** Represents a Reservation. */
                class Reservation implements IReservation {

                    /**
                     * Constructs a new Reservation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReservation);

                    /** Reservation commitment. */
                    public commitment?: (string|null);

                    /** Reservation creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Reservation description. */
                    public description?: (string|null);

                    /** Reservation id. */
                    public id?: (number|Long|string|null);

                    /** Reservation kind. */
                    public kind?: (string|null);

                    /** Reservation name. */
                    public name?: (string|null);

                    /** Reservation satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** Reservation selfLink. */
                    public selfLink?: (string|null);

                    /** Reservation shareSettings. */
                    public shareSettings?: (google.cloud.compute.v1.IShareSettings|null);

                    /** Reservation specificReservation. */
                    public specificReservation?: (google.cloud.compute.v1.IAllocationSpecificSKUReservation|null);

                    /** Reservation specificReservationRequired. */
                    public specificReservationRequired?: (boolean|null);

                    /** Reservation status. */
                    public status?: (string|null);

                    /** Reservation zone. */
                    public zone?: (string|null);

                    /** Reservation _commitment. */
                    public _commitment?: "commitment";

                    /** Reservation _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Reservation _description. */
                    public _description?: "description";

                    /** Reservation _id. */
                    public _id?: "id";

                    /** Reservation _kind. */
                    public _kind?: "kind";

                    /** Reservation _name. */
                    public _name?: "name";

                    /** Reservation _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** Reservation _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Reservation _shareSettings. */
                    public _shareSettings?: "shareSettings";

                    /** Reservation _specificReservation. */
                    public _specificReservation?: "specificReservation";

                    /** Reservation _specificReservationRequired. */
                    public _specificReservationRequired?: "specificReservationRequired";

                    /** Reservation _status. */
                    public _status?: "status";

                    /** Reservation _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new Reservation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Reservation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReservation): google.cloud.compute.v1.Reservation;

                    /**
                     * Encodes the specified Reservation message. Does not implicitly {@link google.cloud.compute.v1.Reservation.verify|verify} messages.
                     * @param message Reservation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReservation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Reservation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Reservation.verify|verify} messages.
                     * @param message Reservation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReservation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Reservation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Reservation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Reservation;

                    /**
                     * Decodes a Reservation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Reservation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Reservation;

                    /**
                     * Verifies a Reservation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Reservation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Reservation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Reservation;

                    /**
                     * Creates a plain object from a Reservation message. Also converts values to other types if specified.
                     * @param message Reservation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Reservation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Reservation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Reservation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Reservation {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        INVALID = 530283991,
                        READY = 77848963,
                        UPDATING = 494614342
                    }
                }

                /** Properties of a ReservationAffinity. */
                interface IReservationAffinity {

                    /** ReservationAffinity consumeReservationType */
                    consumeReservationType?: (string|null);

                    /** ReservationAffinity key */
                    key?: (string|null);

                    /** ReservationAffinity values */
                    values?: (string[]|null);
                }

                /** Represents a ReservationAffinity. */
                class ReservationAffinity implements IReservationAffinity {

                    /**
                     * Constructs a new ReservationAffinity.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReservationAffinity);

                    /** ReservationAffinity consumeReservationType. */
                    public consumeReservationType?: (string|null);

                    /** ReservationAffinity key. */
                    public key?: (string|null);

                    /** ReservationAffinity values. */
                    public values: string[];

                    /** ReservationAffinity _consumeReservationType. */
                    public _consumeReservationType?: "consumeReservationType";

                    /** ReservationAffinity _key. */
                    public _key?: "key";

                    /**
                     * Creates a new ReservationAffinity instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReservationAffinity instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReservationAffinity): google.cloud.compute.v1.ReservationAffinity;

                    /**
                     * Encodes the specified ReservationAffinity message. Does not implicitly {@link google.cloud.compute.v1.ReservationAffinity.verify|verify} messages.
                     * @param message ReservationAffinity message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReservationAffinity, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReservationAffinity message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ReservationAffinity.verify|verify} messages.
                     * @param message ReservationAffinity message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReservationAffinity, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReservationAffinity message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReservationAffinity
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ReservationAffinity;

                    /**
                     * Decodes a ReservationAffinity message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReservationAffinity
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ReservationAffinity;

                    /**
                     * Verifies a ReservationAffinity message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReservationAffinity message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReservationAffinity
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ReservationAffinity;

                    /**
                     * Creates a plain object from a ReservationAffinity message. Also converts values to other types if specified.
                     * @param message ReservationAffinity
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ReservationAffinity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReservationAffinity to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReservationAffinity
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ReservationAffinity {

                    /** ConsumeReservationType enum. */
                    enum ConsumeReservationType {
                        UNDEFINED_CONSUME_RESERVATION_TYPE = 0,
                        ANY_RESERVATION = 200008121,
                        NO_RESERVATION = 169322030,
                        SPECIFIC_RESERVATION = 229889055,
                        UNSPECIFIED = 526786327
                    }
                }

                /** Properties of a ReservationAggregatedList. */
                interface IReservationAggregatedList {

                    /** ReservationAggregatedList id */
                    id?: (string|null);

                    /** ReservationAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IReservationsScopedList }|null);

                    /** ReservationAggregatedList kind */
                    kind?: (string|null);

                    /** ReservationAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ReservationAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** ReservationAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** ReservationAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ReservationAggregatedList. */
                class ReservationAggregatedList implements IReservationAggregatedList {

                    /**
                     * Constructs a new ReservationAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReservationAggregatedList);

                    /** ReservationAggregatedList id. */
                    public id?: (string|null);

                    /** ReservationAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IReservationsScopedList };

                    /** ReservationAggregatedList kind. */
                    public kind?: (string|null);

                    /** ReservationAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ReservationAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** ReservationAggregatedList unreachables. */
                    public unreachables: string[];

                    /** ReservationAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ReservationAggregatedList _id. */
                    public _id?: "id";

                    /** ReservationAggregatedList _kind. */
                    public _kind?: "kind";

                    /** ReservationAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ReservationAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ReservationAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ReservationAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReservationAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReservationAggregatedList): google.cloud.compute.v1.ReservationAggregatedList;

                    /**
                     * Encodes the specified ReservationAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.ReservationAggregatedList.verify|verify} messages.
                     * @param message ReservationAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReservationAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReservationAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ReservationAggregatedList.verify|verify} messages.
                     * @param message ReservationAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReservationAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReservationAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReservationAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ReservationAggregatedList;

                    /**
                     * Decodes a ReservationAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReservationAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ReservationAggregatedList;

                    /**
                     * Verifies a ReservationAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReservationAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReservationAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ReservationAggregatedList;

                    /**
                     * Creates a plain object from a ReservationAggregatedList message. Also converts values to other types if specified.
                     * @param message ReservationAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ReservationAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReservationAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReservationAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ReservationList. */
                interface IReservationList {

                    /** ReservationList id */
                    id?: (string|null);

                    /** ReservationList items */
                    items?: (google.cloud.compute.v1.IReservation[]|null);

                    /** ReservationList kind */
                    kind?: (string|null);

                    /** ReservationList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ReservationList selfLink */
                    selfLink?: (string|null);

                    /** ReservationList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ReservationList. */
                class ReservationList implements IReservationList {

                    /**
                     * Constructs a new ReservationList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReservationList);

                    /** ReservationList id. */
                    public id?: (string|null);

                    /** ReservationList items. */
                    public items: google.cloud.compute.v1.IReservation[];

                    /** ReservationList kind. */
                    public kind?: (string|null);

                    /** ReservationList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ReservationList selfLink. */
                    public selfLink?: (string|null);

                    /** ReservationList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ReservationList _id. */
                    public _id?: "id";

                    /** ReservationList _kind. */
                    public _kind?: "kind";

                    /** ReservationList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ReservationList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ReservationList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ReservationList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReservationList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReservationList): google.cloud.compute.v1.ReservationList;

                    /**
                     * Encodes the specified ReservationList message. Does not implicitly {@link google.cloud.compute.v1.ReservationList.verify|verify} messages.
                     * @param message ReservationList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReservationList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReservationList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ReservationList.verify|verify} messages.
                     * @param message ReservationList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReservationList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReservationList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReservationList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ReservationList;

                    /**
                     * Decodes a ReservationList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReservationList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ReservationList;

                    /**
                     * Verifies a ReservationList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReservationList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReservationList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ReservationList;

                    /**
                     * Creates a plain object from a ReservationList message. Also converts values to other types if specified.
                     * @param message ReservationList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ReservationList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReservationList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReservationList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ReservationsResizeRequest. */
                interface IReservationsResizeRequest {

                    /** ReservationsResizeRequest specificSkuCount */
                    specificSkuCount?: (number|Long|string|null);
                }

                /** Represents a ReservationsResizeRequest. */
                class ReservationsResizeRequest implements IReservationsResizeRequest {

                    /**
                     * Constructs a new ReservationsResizeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReservationsResizeRequest);

                    /** ReservationsResizeRequest specificSkuCount. */
                    public specificSkuCount?: (number|Long|string|null);

                    /** ReservationsResizeRequest _specificSkuCount. */
                    public _specificSkuCount?: "specificSkuCount";

                    /**
                     * Creates a new ReservationsResizeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReservationsResizeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReservationsResizeRequest): google.cloud.compute.v1.ReservationsResizeRequest;

                    /**
                     * Encodes the specified ReservationsResizeRequest message. Does not implicitly {@link google.cloud.compute.v1.ReservationsResizeRequest.verify|verify} messages.
                     * @param message ReservationsResizeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReservationsResizeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReservationsResizeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ReservationsResizeRequest.verify|verify} messages.
                     * @param message ReservationsResizeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReservationsResizeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReservationsResizeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReservationsResizeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ReservationsResizeRequest;

                    /**
                     * Decodes a ReservationsResizeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReservationsResizeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ReservationsResizeRequest;

                    /**
                     * Verifies a ReservationsResizeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReservationsResizeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReservationsResizeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ReservationsResizeRequest;

                    /**
                     * Creates a plain object from a ReservationsResizeRequest message. Also converts values to other types if specified.
                     * @param message ReservationsResizeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ReservationsResizeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReservationsResizeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReservationsResizeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ReservationsScopedList. */
                interface IReservationsScopedList {

                    /** ReservationsScopedList reservations */
                    reservations?: (google.cloud.compute.v1.IReservation[]|null);

                    /** ReservationsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ReservationsScopedList. */
                class ReservationsScopedList implements IReservationsScopedList {

                    /**
                     * Constructs a new ReservationsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IReservationsScopedList);

                    /** ReservationsScopedList reservations. */
                    public reservations: google.cloud.compute.v1.IReservation[];

                    /** ReservationsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ReservationsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ReservationsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReservationsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IReservationsScopedList): google.cloud.compute.v1.ReservationsScopedList;

                    /**
                     * Encodes the specified ReservationsScopedList message. Does not implicitly {@link google.cloud.compute.v1.ReservationsScopedList.verify|verify} messages.
                     * @param message ReservationsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IReservationsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReservationsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ReservationsScopedList.verify|verify} messages.
                     * @param message ReservationsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IReservationsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReservationsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReservationsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ReservationsScopedList;

                    /**
                     * Decodes a ReservationsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReservationsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ReservationsScopedList;

                    /**
                     * Verifies a ReservationsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReservationsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReservationsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ReservationsScopedList;

                    /**
                     * Creates a plain object from a ReservationsScopedList message. Also converts values to other types if specified.
                     * @param message ReservationsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ReservationsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReservationsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReservationsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResetInstanceRequest. */
                interface IResetInstanceRequest {

                    /** ResetInstanceRequest instance */
                    instance?: (string|null);

                    /** ResetInstanceRequest project */
                    project?: (string|null);

                    /** ResetInstanceRequest requestId */
                    requestId?: (string|null);

                    /** ResetInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ResetInstanceRequest. */
                class ResetInstanceRequest implements IResetInstanceRequest {

                    /**
                     * Constructs a new ResetInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResetInstanceRequest);

                    /** ResetInstanceRequest instance. */
                    public instance: string;

                    /** ResetInstanceRequest project. */
                    public project: string;

                    /** ResetInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** ResetInstanceRequest zone. */
                    public zone: string;

                    /** ResetInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResetInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResetInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResetInstanceRequest): google.cloud.compute.v1.ResetInstanceRequest;

                    /**
                     * Encodes the specified ResetInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.ResetInstanceRequest.verify|verify} messages.
                     * @param message ResetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResetInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResetInstanceRequest.verify|verify} messages.
                     * @param message ResetInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResetInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResetInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResetInstanceRequest;

                    /**
                     * Decodes a ResetInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResetInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResetInstanceRequest;

                    /**
                     * Verifies a ResetInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResetInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResetInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResetInstanceRequest;

                    /**
                     * Creates a plain object from a ResetInstanceRequest message. Also converts values to other types if specified.
                     * @param message ResetInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResetInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResetInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResetInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResizeDiskRequest. */
                interface IResizeDiskRequest {

                    /** ResizeDiskRequest disk */
                    disk?: (string|null);

                    /** ResizeDiskRequest disksResizeRequestResource */
                    disksResizeRequestResource?: (google.cloud.compute.v1.IDisksResizeRequest|null);

                    /** ResizeDiskRequest project */
                    project?: (string|null);

                    /** ResizeDiskRequest requestId */
                    requestId?: (string|null);

                    /** ResizeDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ResizeDiskRequest. */
                class ResizeDiskRequest implements IResizeDiskRequest {

                    /**
                     * Constructs a new ResizeDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResizeDiskRequest);

                    /** ResizeDiskRequest disk. */
                    public disk: string;

                    /** ResizeDiskRequest disksResizeRequestResource. */
                    public disksResizeRequestResource?: (google.cloud.compute.v1.IDisksResizeRequest|null);

                    /** ResizeDiskRequest project. */
                    public project: string;

                    /** ResizeDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** ResizeDiskRequest zone. */
                    public zone: string;

                    /** ResizeDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResizeDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResizeDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResizeDiskRequest): google.cloud.compute.v1.ResizeDiskRequest;

                    /**
                     * Encodes the specified ResizeDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.ResizeDiskRequest.verify|verify} messages.
                     * @param message ResizeDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResizeDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResizeDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResizeDiskRequest.verify|verify} messages.
                     * @param message ResizeDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResizeDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResizeDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResizeDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResizeDiskRequest;

                    /**
                     * Decodes a ResizeDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResizeDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResizeDiskRequest;

                    /**
                     * Verifies a ResizeDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResizeDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResizeDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResizeDiskRequest;

                    /**
                     * Creates a plain object from a ResizeDiskRequest message. Also converts values to other types if specified.
                     * @param message ResizeDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResizeDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResizeDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResizeDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResizeInstanceGroupManagerRequest. */
                interface IResizeInstanceGroupManagerRequest {

                    /** ResizeInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ResizeInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** ResizeInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** ResizeInstanceGroupManagerRequest size */
                    size?: (number|null);

                    /** ResizeInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ResizeInstanceGroupManagerRequest. */
                class ResizeInstanceGroupManagerRequest implements IResizeInstanceGroupManagerRequest {

                    /**
                     * Constructs a new ResizeInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResizeInstanceGroupManagerRequest);

                    /** ResizeInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ResizeInstanceGroupManagerRequest project. */
                    public project: string;

                    /** ResizeInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** ResizeInstanceGroupManagerRequest size. */
                    public size: number;

                    /** ResizeInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** ResizeInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResizeInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResizeInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResizeInstanceGroupManagerRequest): google.cloud.compute.v1.ResizeInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified ResizeInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.ResizeInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ResizeInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResizeInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResizeInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResizeInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ResizeInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResizeInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResizeInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResizeInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResizeInstanceGroupManagerRequest;

                    /**
                     * Decodes a ResizeInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResizeInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResizeInstanceGroupManagerRequest;

                    /**
                     * Verifies a ResizeInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResizeInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResizeInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResizeInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a ResizeInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message ResizeInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResizeInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResizeInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResizeInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResizeRegionDiskRequest. */
                interface IResizeRegionDiskRequest {

                    /** ResizeRegionDiskRequest disk */
                    disk?: (string|null);

                    /** ResizeRegionDiskRequest project */
                    project?: (string|null);

                    /** ResizeRegionDiskRequest region */
                    region?: (string|null);

                    /** ResizeRegionDiskRequest regionDisksResizeRequestResource */
                    regionDisksResizeRequestResource?: (google.cloud.compute.v1.IRegionDisksResizeRequest|null);

                    /** ResizeRegionDiskRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a ResizeRegionDiskRequest. */
                class ResizeRegionDiskRequest implements IResizeRegionDiskRequest {

                    /**
                     * Constructs a new ResizeRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResizeRegionDiskRequest);

                    /** ResizeRegionDiskRequest disk. */
                    public disk: string;

                    /** ResizeRegionDiskRequest project. */
                    public project: string;

                    /** ResizeRegionDiskRequest region. */
                    public region: string;

                    /** ResizeRegionDiskRequest regionDisksResizeRequestResource. */
                    public regionDisksResizeRequestResource?: (google.cloud.compute.v1.IRegionDisksResizeRequest|null);

                    /** ResizeRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** ResizeRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResizeRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResizeRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResizeRegionDiskRequest): google.cloud.compute.v1.ResizeRegionDiskRequest;

                    /**
                     * Encodes the specified ResizeRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.ResizeRegionDiskRequest.verify|verify} messages.
                     * @param message ResizeRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResizeRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResizeRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResizeRegionDiskRequest.verify|verify} messages.
                     * @param message ResizeRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResizeRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResizeRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResizeRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResizeRegionDiskRequest;

                    /**
                     * Decodes a ResizeRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResizeRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResizeRegionDiskRequest;

                    /**
                     * Verifies a ResizeRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResizeRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResizeRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResizeRegionDiskRequest;

                    /**
                     * Creates a plain object from a ResizeRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message ResizeRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResizeRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResizeRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResizeRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResizeRegionInstanceGroupManagerRequest. */
                interface IResizeRegionInstanceGroupManagerRequest {

                    /** ResizeRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** ResizeRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** ResizeRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** ResizeRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** ResizeRegionInstanceGroupManagerRequest size */
                    size?: (number|null);
                }

                /** Represents a ResizeRegionInstanceGroupManagerRequest. */
                class ResizeRegionInstanceGroupManagerRequest implements IResizeRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new ResizeRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest);

                    /** ResizeRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** ResizeRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** ResizeRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** ResizeRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** ResizeRegionInstanceGroupManagerRequest size. */
                    public size: number;

                    /** ResizeRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResizeRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResizeRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest): google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified ResizeRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ResizeRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResizeRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message ResizeRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResizeRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResizeRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a ResizeRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResizeRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a ResizeRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResizeRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResizeRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a ResizeRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message ResizeRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResizeRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResizeRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResizeRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResizeReservationRequest. */
                interface IResizeReservationRequest {

                    /** ResizeReservationRequest project */
                    project?: (string|null);

                    /** ResizeReservationRequest requestId */
                    requestId?: (string|null);

                    /** ResizeReservationRequest reservation */
                    reservation?: (string|null);

                    /** ResizeReservationRequest reservationsResizeRequestResource */
                    reservationsResizeRequestResource?: (google.cloud.compute.v1.IReservationsResizeRequest|null);

                    /** ResizeReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ResizeReservationRequest. */
                class ResizeReservationRequest implements IResizeReservationRequest {

                    /**
                     * Constructs a new ResizeReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResizeReservationRequest);

                    /** ResizeReservationRequest project. */
                    public project: string;

                    /** ResizeReservationRequest requestId. */
                    public requestId?: (string|null);

                    /** ResizeReservationRequest reservation. */
                    public reservation: string;

                    /** ResizeReservationRequest reservationsResizeRequestResource. */
                    public reservationsResizeRequestResource?: (google.cloud.compute.v1.IReservationsResizeRequest|null);

                    /** ResizeReservationRequest zone. */
                    public zone: string;

                    /** ResizeReservationRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResizeReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResizeReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResizeReservationRequest): google.cloud.compute.v1.ResizeReservationRequest;

                    /**
                     * Encodes the specified ResizeReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.ResizeReservationRequest.verify|verify} messages.
                     * @param message ResizeReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResizeReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResizeReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResizeReservationRequest.verify|verify} messages.
                     * @param message ResizeReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResizeReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResizeReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResizeReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResizeReservationRequest;

                    /**
                     * Decodes a ResizeReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResizeReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResizeReservationRequest;

                    /**
                     * Verifies a ResizeReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResizeReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResizeReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResizeReservationRequest;

                    /**
                     * Creates a plain object from a ResizeReservationRequest message. Also converts values to other types if specified.
                     * @param message ResizeReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResizeReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResizeReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResizeReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourceCommitment. */
                interface IResourceCommitment {

                    /** ResourceCommitment acceleratorType */
                    acceleratorType?: (string|null);

                    /** ResourceCommitment amount */
                    amount?: (number|Long|string|null);

                    /** ResourceCommitment type */
                    type?: (string|null);
                }

                /** Represents a ResourceCommitment. */
                class ResourceCommitment implements IResourceCommitment {

                    /**
                     * Constructs a new ResourceCommitment.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourceCommitment);

                    /** ResourceCommitment acceleratorType. */
                    public acceleratorType?: (string|null);

                    /** ResourceCommitment amount. */
                    public amount?: (number|Long|string|null);

                    /** ResourceCommitment type. */
                    public type?: (string|null);

                    /** ResourceCommitment _acceleratorType. */
                    public _acceleratorType?: "acceleratorType";

                    /** ResourceCommitment _amount. */
                    public _amount?: "amount";

                    /** ResourceCommitment _type. */
                    public _type?: "type";

                    /**
                     * Creates a new ResourceCommitment instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourceCommitment instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourceCommitment): google.cloud.compute.v1.ResourceCommitment;

                    /**
                     * Encodes the specified ResourceCommitment message. Does not implicitly {@link google.cloud.compute.v1.ResourceCommitment.verify|verify} messages.
                     * @param message ResourceCommitment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourceCommitment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourceCommitment message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourceCommitment.verify|verify} messages.
                     * @param message ResourceCommitment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourceCommitment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourceCommitment message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourceCommitment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourceCommitment;

                    /**
                     * Decodes a ResourceCommitment message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourceCommitment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourceCommitment;

                    /**
                     * Verifies a ResourceCommitment message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourceCommitment message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourceCommitment
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourceCommitment;

                    /**
                     * Creates a plain object from a ResourceCommitment message. Also converts values to other types if specified.
                     * @param message ResourceCommitment
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourceCommitment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourceCommitment to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourceCommitment
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ResourceCommitment {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        ACCELERATOR = 429815371,
                        LOCAL_SSD = 508934896,
                        MEMORY = 123056385,
                        UNSPECIFIED = 526786327,
                        VCPU = 2628978
                    }
                }

                /** Properties of a ResourceGroupReference. */
                interface IResourceGroupReference {

                    /** ResourceGroupReference group */
                    group?: (string|null);
                }

                /** Represents a ResourceGroupReference. */
                class ResourceGroupReference implements IResourceGroupReference {

                    /**
                     * Constructs a new ResourceGroupReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourceGroupReference);

                    /** ResourceGroupReference group. */
                    public group?: (string|null);

                    /** ResourceGroupReference _group. */
                    public _group?: "group";

                    /**
                     * Creates a new ResourceGroupReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourceGroupReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourceGroupReference): google.cloud.compute.v1.ResourceGroupReference;

                    /**
                     * Encodes the specified ResourceGroupReference message. Does not implicitly {@link google.cloud.compute.v1.ResourceGroupReference.verify|verify} messages.
                     * @param message ResourceGroupReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourceGroupReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourceGroupReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourceGroupReference.verify|verify} messages.
                     * @param message ResourceGroupReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourceGroupReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourceGroupReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourceGroupReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourceGroupReference;

                    /**
                     * Decodes a ResourceGroupReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourceGroupReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourceGroupReference;

                    /**
                     * Verifies a ResourceGroupReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourceGroupReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourceGroupReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourceGroupReference;

                    /**
                     * Creates a plain object from a ResourceGroupReference message. Also converts values to other types if specified.
                     * @param message ResourceGroupReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourceGroupReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourceGroupReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourceGroupReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePoliciesScopedList. */
                interface IResourcePoliciesScopedList {

                    /** ResourcePoliciesScopedList resourcePolicies */
                    resourcePolicies?: (google.cloud.compute.v1.IResourcePolicy[]|null);

                    /** ResourcePoliciesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ResourcePoliciesScopedList. */
                class ResourcePoliciesScopedList implements IResourcePoliciesScopedList {

                    /**
                     * Constructs a new ResourcePoliciesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePoliciesScopedList);

                    /** ResourcePoliciesScopedList resourcePolicies. */
                    public resourcePolicies: google.cloud.compute.v1.IResourcePolicy[];

                    /** ResourcePoliciesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ResourcePoliciesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ResourcePoliciesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePoliciesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePoliciesScopedList): google.cloud.compute.v1.ResourcePoliciesScopedList;

                    /**
                     * Encodes the specified ResourcePoliciesScopedList message. Does not implicitly {@link google.cloud.compute.v1.ResourcePoliciesScopedList.verify|verify} messages.
                     * @param message ResourcePoliciesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePoliciesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePoliciesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePoliciesScopedList.verify|verify} messages.
                     * @param message ResourcePoliciesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePoliciesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePoliciesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePoliciesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePoliciesScopedList;

                    /**
                     * Decodes a ResourcePoliciesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePoliciesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePoliciesScopedList;

                    /**
                     * Verifies a ResourcePoliciesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePoliciesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePoliciesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePoliciesScopedList;

                    /**
                     * Creates a plain object from a ResourcePoliciesScopedList message. Also converts values to other types if specified.
                     * @param message ResourcePoliciesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePoliciesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePoliciesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePoliciesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicy. */
                interface IResourcePolicy {

                    /** ResourcePolicy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** ResourcePolicy description */
                    description?: (string|null);

                    /** ResourcePolicy groupPlacementPolicy */
                    groupPlacementPolicy?: (google.cloud.compute.v1.IResourcePolicyGroupPlacementPolicy|null);

                    /** ResourcePolicy id */
                    id?: (number|Long|string|null);

                    /** ResourcePolicy instanceSchedulePolicy */
                    instanceSchedulePolicy?: (google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicy|null);

                    /** ResourcePolicy kind */
                    kind?: (string|null);

                    /** ResourcePolicy name */
                    name?: (string|null);

                    /** ResourcePolicy region */
                    region?: (string|null);

                    /** ResourcePolicy resourceStatus */
                    resourceStatus?: (google.cloud.compute.v1.IResourcePolicyResourceStatus|null);

                    /** ResourcePolicy selfLink */
                    selfLink?: (string|null);

                    /** ResourcePolicy snapshotSchedulePolicy */
                    snapshotSchedulePolicy?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicy|null);

                    /** ResourcePolicy status */
                    status?: (string|null);
                }

                /** Represents a ResourcePolicy. */
                class ResourcePolicy implements IResourcePolicy {

                    /**
                     * Constructs a new ResourcePolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicy);

                    /** ResourcePolicy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** ResourcePolicy description. */
                    public description?: (string|null);

                    /** ResourcePolicy groupPlacementPolicy. */
                    public groupPlacementPolicy?: (google.cloud.compute.v1.IResourcePolicyGroupPlacementPolicy|null);

                    /** ResourcePolicy id. */
                    public id?: (number|Long|string|null);

                    /** ResourcePolicy instanceSchedulePolicy. */
                    public instanceSchedulePolicy?: (google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicy|null);

                    /** ResourcePolicy kind. */
                    public kind?: (string|null);

                    /** ResourcePolicy name. */
                    public name?: (string|null);

                    /** ResourcePolicy region. */
                    public region?: (string|null);

                    /** ResourcePolicy resourceStatus. */
                    public resourceStatus?: (google.cloud.compute.v1.IResourcePolicyResourceStatus|null);

                    /** ResourcePolicy selfLink. */
                    public selfLink?: (string|null);

                    /** ResourcePolicy snapshotSchedulePolicy. */
                    public snapshotSchedulePolicy?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicy|null);

                    /** ResourcePolicy status. */
                    public status?: (string|null);

                    /** ResourcePolicy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** ResourcePolicy _description. */
                    public _description?: "description";

                    /** ResourcePolicy _groupPlacementPolicy. */
                    public _groupPlacementPolicy?: "groupPlacementPolicy";

                    /** ResourcePolicy _id. */
                    public _id?: "id";

                    /** ResourcePolicy _instanceSchedulePolicy. */
                    public _instanceSchedulePolicy?: "instanceSchedulePolicy";

                    /** ResourcePolicy _kind. */
                    public _kind?: "kind";

                    /** ResourcePolicy _name. */
                    public _name?: "name";

                    /** ResourcePolicy _region. */
                    public _region?: "region";

                    /** ResourcePolicy _resourceStatus. */
                    public _resourceStatus?: "resourceStatus";

                    /** ResourcePolicy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ResourcePolicy _snapshotSchedulePolicy. */
                    public _snapshotSchedulePolicy?: "snapshotSchedulePolicy";

                    /** ResourcePolicy _status. */
                    public _status?: "status";

                    /**
                     * Creates a new ResourcePolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicy): google.cloud.compute.v1.ResourcePolicy;

                    /**
                     * Encodes the specified ResourcePolicy message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicy.verify|verify} messages.
                     * @param message ResourcePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicy.verify|verify} messages.
                     * @param message ResourcePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicy;

                    /**
                     * Decodes a ResourcePolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicy;

                    /**
                     * Verifies a ResourcePolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicy;

                    /**
                     * Creates a plain object from a ResourcePolicy message. Also converts values to other types if specified.
                     * @param message ResourcePolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ResourcePolicy {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        EXPIRED = 482489093,
                        INVALID = 530283991,
                        READY = 77848963
                    }
                }

                /** Properties of a ResourcePolicyAggregatedList. */
                interface IResourcePolicyAggregatedList {

                    /** ResourcePolicyAggregatedList etag */
                    etag?: (string|null);

                    /** ResourcePolicyAggregatedList id */
                    id?: (string|null);

                    /** ResourcePolicyAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IResourcePoliciesScopedList }|null);

                    /** ResourcePolicyAggregatedList kind */
                    kind?: (string|null);

                    /** ResourcePolicyAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ResourcePolicyAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** ResourcePolicyAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** ResourcePolicyAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ResourcePolicyAggregatedList. */
                class ResourcePolicyAggregatedList implements IResourcePolicyAggregatedList {

                    /**
                     * Constructs a new ResourcePolicyAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyAggregatedList);

                    /** ResourcePolicyAggregatedList etag. */
                    public etag?: (string|null);

                    /** ResourcePolicyAggregatedList id. */
                    public id?: (string|null);

                    /** ResourcePolicyAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IResourcePoliciesScopedList };

                    /** ResourcePolicyAggregatedList kind. */
                    public kind?: (string|null);

                    /** ResourcePolicyAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ResourcePolicyAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** ResourcePolicyAggregatedList unreachables. */
                    public unreachables: string[];

                    /** ResourcePolicyAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ResourcePolicyAggregatedList _etag. */
                    public _etag?: "etag";

                    /** ResourcePolicyAggregatedList _id. */
                    public _id?: "id";

                    /** ResourcePolicyAggregatedList _kind. */
                    public _kind?: "kind";

                    /** ResourcePolicyAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ResourcePolicyAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ResourcePolicyAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ResourcePolicyAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyAggregatedList): google.cloud.compute.v1.ResourcePolicyAggregatedList;

                    /**
                     * Encodes the specified ResourcePolicyAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyAggregatedList.verify|verify} messages.
                     * @param message ResourcePolicyAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyAggregatedList.verify|verify} messages.
                     * @param message ResourcePolicyAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyAggregatedList;

                    /**
                     * Decodes a ResourcePolicyAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyAggregatedList;

                    /**
                     * Verifies a ResourcePolicyAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyAggregatedList;

                    /**
                     * Creates a plain object from a ResourcePolicyAggregatedList message. Also converts values to other types if specified.
                     * @param message ResourcePolicyAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyDailyCycle. */
                interface IResourcePolicyDailyCycle {

                    /** ResourcePolicyDailyCycle daysInCycle */
                    daysInCycle?: (number|null);

                    /** ResourcePolicyDailyCycle duration */
                    duration?: (string|null);

                    /** ResourcePolicyDailyCycle startTime */
                    startTime?: (string|null);
                }

                /** Represents a ResourcePolicyDailyCycle. */
                class ResourcePolicyDailyCycle implements IResourcePolicyDailyCycle {

                    /**
                     * Constructs a new ResourcePolicyDailyCycle.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyDailyCycle);

                    /** ResourcePolicyDailyCycle daysInCycle. */
                    public daysInCycle?: (number|null);

                    /** ResourcePolicyDailyCycle duration. */
                    public duration?: (string|null);

                    /** ResourcePolicyDailyCycle startTime. */
                    public startTime?: (string|null);

                    /** ResourcePolicyDailyCycle _daysInCycle. */
                    public _daysInCycle?: "daysInCycle";

                    /** ResourcePolicyDailyCycle _duration. */
                    public _duration?: "duration";

                    /** ResourcePolicyDailyCycle _startTime. */
                    public _startTime?: "startTime";

                    /**
                     * Creates a new ResourcePolicyDailyCycle instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyDailyCycle instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyDailyCycle): google.cloud.compute.v1.ResourcePolicyDailyCycle;

                    /**
                     * Encodes the specified ResourcePolicyDailyCycle message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyDailyCycle.verify|verify} messages.
                     * @param message ResourcePolicyDailyCycle message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyDailyCycle, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyDailyCycle message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyDailyCycle.verify|verify} messages.
                     * @param message ResourcePolicyDailyCycle message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyDailyCycle, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyDailyCycle message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyDailyCycle
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyDailyCycle;

                    /**
                     * Decodes a ResourcePolicyDailyCycle message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyDailyCycle
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyDailyCycle;

                    /**
                     * Verifies a ResourcePolicyDailyCycle message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyDailyCycle message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyDailyCycle
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyDailyCycle;

                    /**
                     * Creates a plain object from a ResourcePolicyDailyCycle message. Also converts values to other types if specified.
                     * @param message ResourcePolicyDailyCycle
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyDailyCycle, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyDailyCycle to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyDailyCycle
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyGroupPlacementPolicy. */
                interface IResourcePolicyGroupPlacementPolicy {

                    /** ResourcePolicyGroupPlacementPolicy availabilityDomainCount */
                    availabilityDomainCount?: (number|null);

                    /** ResourcePolicyGroupPlacementPolicy collocation */
                    collocation?: (string|null);

                    /** ResourcePolicyGroupPlacementPolicy vmCount */
                    vmCount?: (number|null);
                }

                /** Represents a ResourcePolicyGroupPlacementPolicy. */
                class ResourcePolicyGroupPlacementPolicy implements IResourcePolicyGroupPlacementPolicy {

                    /**
                     * Constructs a new ResourcePolicyGroupPlacementPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyGroupPlacementPolicy);

                    /** ResourcePolicyGroupPlacementPolicy availabilityDomainCount. */
                    public availabilityDomainCount?: (number|null);

                    /** ResourcePolicyGroupPlacementPolicy collocation. */
                    public collocation?: (string|null);

                    /** ResourcePolicyGroupPlacementPolicy vmCount. */
                    public vmCount?: (number|null);

                    /** ResourcePolicyGroupPlacementPolicy _availabilityDomainCount. */
                    public _availabilityDomainCount?: "availabilityDomainCount";

                    /** ResourcePolicyGroupPlacementPolicy _collocation. */
                    public _collocation?: "collocation";

                    /** ResourcePolicyGroupPlacementPolicy _vmCount. */
                    public _vmCount?: "vmCount";

                    /**
                     * Creates a new ResourcePolicyGroupPlacementPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyGroupPlacementPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyGroupPlacementPolicy): google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy;

                    /**
                     * Encodes the specified ResourcePolicyGroupPlacementPolicy message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy.verify|verify} messages.
                     * @param message ResourcePolicyGroupPlacementPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyGroupPlacementPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyGroupPlacementPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy.verify|verify} messages.
                     * @param message ResourcePolicyGroupPlacementPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyGroupPlacementPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyGroupPlacementPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyGroupPlacementPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy;

                    /**
                     * Decodes a ResourcePolicyGroupPlacementPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyGroupPlacementPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy;

                    /**
                     * Verifies a ResourcePolicyGroupPlacementPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyGroupPlacementPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyGroupPlacementPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy;

                    /**
                     * Creates a plain object from a ResourcePolicyGroupPlacementPolicy message. Also converts values to other types if specified.
                     * @param message ResourcePolicyGroupPlacementPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyGroupPlacementPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyGroupPlacementPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyGroupPlacementPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ResourcePolicyGroupPlacementPolicy {

                    /** Collocation enum. */
                    enum Collocation {
                        UNDEFINED_COLLOCATION = 0,
                        COLLOCATED = 103257554,
                        UNSPECIFIED_COLLOCATION = 464308205
                    }
                }

                /** Properties of a ResourcePolicyHourlyCycle. */
                interface IResourcePolicyHourlyCycle {

                    /** ResourcePolicyHourlyCycle duration */
                    duration?: (string|null);

                    /** ResourcePolicyHourlyCycle hoursInCycle */
                    hoursInCycle?: (number|null);

                    /** ResourcePolicyHourlyCycle startTime */
                    startTime?: (string|null);
                }

                /** Represents a ResourcePolicyHourlyCycle. */
                class ResourcePolicyHourlyCycle implements IResourcePolicyHourlyCycle {

                    /**
                     * Constructs a new ResourcePolicyHourlyCycle.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyHourlyCycle);

                    /** ResourcePolicyHourlyCycle duration. */
                    public duration?: (string|null);

                    /** ResourcePolicyHourlyCycle hoursInCycle. */
                    public hoursInCycle?: (number|null);

                    /** ResourcePolicyHourlyCycle startTime. */
                    public startTime?: (string|null);

                    /** ResourcePolicyHourlyCycle _duration. */
                    public _duration?: "duration";

                    /** ResourcePolicyHourlyCycle _hoursInCycle. */
                    public _hoursInCycle?: "hoursInCycle";

                    /** ResourcePolicyHourlyCycle _startTime. */
                    public _startTime?: "startTime";

                    /**
                     * Creates a new ResourcePolicyHourlyCycle instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyHourlyCycle instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyHourlyCycle): google.cloud.compute.v1.ResourcePolicyHourlyCycle;

                    /**
                     * Encodes the specified ResourcePolicyHourlyCycle message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyHourlyCycle.verify|verify} messages.
                     * @param message ResourcePolicyHourlyCycle message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyHourlyCycle, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyHourlyCycle message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyHourlyCycle.verify|verify} messages.
                     * @param message ResourcePolicyHourlyCycle message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyHourlyCycle, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyHourlyCycle message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyHourlyCycle
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyHourlyCycle;

                    /**
                     * Decodes a ResourcePolicyHourlyCycle message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyHourlyCycle
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyHourlyCycle;

                    /**
                     * Verifies a ResourcePolicyHourlyCycle message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyHourlyCycle message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyHourlyCycle
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyHourlyCycle;

                    /**
                     * Creates a plain object from a ResourcePolicyHourlyCycle message. Also converts values to other types if specified.
                     * @param message ResourcePolicyHourlyCycle
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyHourlyCycle, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyHourlyCycle to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyHourlyCycle
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyInstanceSchedulePolicy. */
                interface IResourcePolicyInstanceSchedulePolicy {

                    /** ResourcePolicyInstanceSchedulePolicy expirationTime */
                    expirationTime?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicy startTime */
                    startTime?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicy timeZone */
                    timeZone?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicy vmStartSchedule */
                    vmStartSchedule?: (google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule|null);

                    /** ResourcePolicyInstanceSchedulePolicy vmStopSchedule */
                    vmStopSchedule?: (google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule|null);
                }

                /** Represents a ResourcePolicyInstanceSchedulePolicy. */
                class ResourcePolicyInstanceSchedulePolicy implements IResourcePolicyInstanceSchedulePolicy {

                    /**
                     * Constructs a new ResourcePolicyInstanceSchedulePolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicy);

                    /** ResourcePolicyInstanceSchedulePolicy expirationTime. */
                    public expirationTime?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicy startTime. */
                    public startTime?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicy timeZone. */
                    public timeZone?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicy vmStartSchedule. */
                    public vmStartSchedule?: (google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule|null);

                    /** ResourcePolicyInstanceSchedulePolicy vmStopSchedule. */
                    public vmStopSchedule?: (google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule|null);

                    /** ResourcePolicyInstanceSchedulePolicy _expirationTime. */
                    public _expirationTime?: "expirationTime";

                    /** ResourcePolicyInstanceSchedulePolicy _startTime. */
                    public _startTime?: "startTime";

                    /** ResourcePolicyInstanceSchedulePolicy _timeZone. */
                    public _timeZone?: "timeZone";

                    /** ResourcePolicyInstanceSchedulePolicy _vmStartSchedule. */
                    public _vmStartSchedule?: "vmStartSchedule";

                    /** ResourcePolicyInstanceSchedulePolicy _vmStopSchedule. */
                    public _vmStopSchedule?: "vmStopSchedule";

                    /**
                     * Creates a new ResourcePolicyInstanceSchedulePolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyInstanceSchedulePolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicy): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy;

                    /**
                     * Encodes the specified ResourcePolicyInstanceSchedulePolicy message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy.verify|verify} messages.
                     * @param message ResourcePolicyInstanceSchedulePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyInstanceSchedulePolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy.verify|verify} messages.
                     * @param message ResourcePolicyInstanceSchedulePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyInstanceSchedulePolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyInstanceSchedulePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy;

                    /**
                     * Decodes a ResourcePolicyInstanceSchedulePolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyInstanceSchedulePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy;

                    /**
                     * Verifies a ResourcePolicyInstanceSchedulePolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyInstanceSchedulePolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyInstanceSchedulePolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy;

                    /**
                     * Creates a plain object from a ResourcePolicyInstanceSchedulePolicy message. Also converts values to other types if specified.
                     * @param message ResourcePolicyInstanceSchedulePolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyInstanceSchedulePolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyInstanceSchedulePolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyInstanceSchedulePolicySchedule. */
                interface IResourcePolicyInstanceSchedulePolicySchedule {

                    /** ResourcePolicyInstanceSchedulePolicySchedule schedule */
                    schedule?: (string|null);
                }

                /** Represents a ResourcePolicyInstanceSchedulePolicySchedule. */
                class ResourcePolicyInstanceSchedulePolicySchedule implements IResourcePolicyInstanceSchedulePolicySchedule {

                    /**
                     * Constructs a new ResourcePolicyInstanceSchedulePolicySchedule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule);

                    /** ResourcePolicyInstanceSchedulePolicySchedule schedule. */
                    public schedule?: (string|null);

                    /** ResourcePolicyInstanceSchedulePolicySchedule _schedule. */
                    public _schedule?: "schedule";

                    /**
                     * Creates a new ResourcePolicyInstanceSchedulePolicySchedule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyInstanceSchedulePolicySchedule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule;

                    /**
                     * Encodes the specified ResourcePolicyInstanceSchedulePolicySchedule message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule.verify|verify} messages.
                     * @param message ResourcePolicyInstanceSchedulePolicySchedule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyInstanceSchedulePolicySchedule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule.verify|verify} messages.
                     * @param message ResourcePolicyInstanceSchedulePolicySchedule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyInstanceSchedulePolicySchedule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyInstanceSchedulePolicySchedule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyInstanceSchedulePolicySchedule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule;

                    /**
                     * Decodes a ResourcePolicyInstanceSchedulePolicySchedule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyInstanceSchedulePolicySchedule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule;

                    /**
                     * Verifies a ResourcePolicyInstanceSchedulePolicySchedule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyInstanceSchedulePolicySchedule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyInstanceSchedulePolicySchedule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule;

                    /**
                     * Creates a plain object from a ResourcePolicyInstanceSchedulePolicySchedule message. Also converts values to other types if specified.
                     * @param message ResourcePolicyInstanceSchedulePolicySchedule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyInstanceSchedulePolicySchedule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyInstanceSchedulePolicySchedule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyInstanceSchedulePolicySchedule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyList. */
                interface IResourcePolicyList {

                    /** ResourcePolicyList etag */
                    etag?: (string|null);

                    /** ResourcePolicyList id */
                    id?: (string|null);

                    /** ResourcePolicyList items */
                    items?: (google.cloud.compute.v1.IResourcePolicy[]|null);

                    /** ResourcePolicyList kind */
                    kind?: (string|null);

                    /** ResourcePolicyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ResourcePolicyList selfLink */
                    selfLink?: (string|null);

                    /** ResourcePolicyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ResourcePolicyList. */
                class ResourcePolicyList implements IResourcePolicyList {

                    /**
                     * Constructs a new ResourcePolicyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyList);

                    /** ResourcePolicyList etag. */
                    public etag?: (string|null);

                    /** ResourcePolicyList id. */
                    public id?: (string|null);

                    /** ResourcePolicyList items. */
                    public items: google.cloud.compute.v1.IResourcePolicy[];

                    /** ResourcePolicyList kind. */
                    public kind?: (string|null);

                    /** ResourcePolicyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ResourcePolicyList selfLink. */
                    public selfLink?: (string|null);

                    /** ResourcePolicyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ResourcePolicyList _etag. */
                    public _etag?: "etag";

                    /** ResourcePolicyList _id. */
                    public _id?: "id";

                    /** ResourcePolicyList _kind. */
                    public _kind?: "kind";

                    /** ResourcePolicyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ResourcePolicyList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ResourcePolicyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ResourcePolicyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyList): google.cloud.compute.v1.ResourcePolicyList;

                    /**
                     * Encodes the specified ResourcePolicyList message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyList.verify|verify} messages.
                     * @param message ResourcePolicyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyList.verify|verify} messages.
                     * @param message ResourcePolicyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyList;

                    /**
                     * Decodes a ResourcePolicyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyList;

                    /**
                     * Verifies a ResourcePolicyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyList;

                    /**
                     * Creates a plain object from a ResourcePolicyList message. Also converts values to other types if specified.
                     * @param message ResourcePolicyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyResourceStatus. */
                interface IResourcePolicyResourceStatus {

                    /** ResourcePolicyResourceStatus instanceSchedulePolicy */
                    instanceSchedulePolicy?: (google.cloud.compute.v1.IResourcePolicyResourceStatusInstanceSchedulePolicyStatus|null);
                }

                /** Represents a ResourcePolicyResourceStatus. */
                class ResourcePolicyResourceStatus implements IResourcePolicyResourceStatus {

                    /**
                     * Constructs a new ResourcePolicyResourceStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyResourceStatus);

                    /** ResourcePolicyResourceStatus instanceSchedulePolicy. */
                    public instanceSchedulePolicy?: (google.cloud.compute.v1.IResourcePolicyResourceStatusInstanceSchedulePolicyStatus|null);

                    /** ResourcePolicyResourceStatus _instanceSchedulePolicy. */
                    public _instanceSchedulePolicy?: "instanceSchedulePolicy";

                    /**
                     * Creates a new ResourcePolicyResourceStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyResourceStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyResourceStatus): google.cloud.compute.v1.ResourcePolicyResourceStatus;

                    /**
                     * Encodes the specified ResourcePolicyResourceStatus message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyResourceStatus.verify|verify} messages.
                     * @param message ResourcePolicyResourceStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyResourceStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyResourceStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyResourceStatus.verify|verify} messages.
                     * @param message ResourcePolicyResourceStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyResourceStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyResourceStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyResourceStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyResourceStatus;

                    /**
                     * Decodes a ResourcePolicyResourceStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyResourceStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyResourceStatus;

                    /**
                     * Verifies a ResourcePolicyResourceStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyResourceStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyResourceStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyResourceStatus;

                    /**
                     * Creates a plain object from a ResourcePolicyResourceStatus message. Also converts values to other types if specified.
                     * @param message ResourcePolicyResourceStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyResourceStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyResourceStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyResourceStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus. */
                interface IResourcePolicyResourceStatusInstanceSchedulePolicyStatus {

                    /** ResourcePolicyResourceStatusInstanceSchedulePolicyStatus lastRunStartTime */
                    lastRunStartTime?: (string|null);

                    /** ResourcePolicyResourceStatusInstanceSchedulePolicyStatus nextRunStartTime */
                    nextRunStartTime?: (string|null);
                }

                /** Represents a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus. */
                class ResourcePolicyResourceStatusInstanceSchedulePolicyStatus implements IResourcePolicyResourceStatusInstanceSchedulePolicyStatus {

                    /**
                     * Constructs a new ResourcePolicyResourceStatusInstanceSchedulePolicyStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyResourceStatusInstanceSchedulePolicyStatus);

                    /** ResourcePolicyResourceStatusInstanceSchedulePolicyStatus lastRunStartTime. */
                    public lastRunStartTime?: (string|null);

                    /** ResourcePolicyResourceStatusInstanceSchedulePolicyStatus nextRunStartTime. */
                    public nextRunStartTime?: (string|null);

                    /** ResourcePolicyResourceStatusInstanceSchedulePolicyStatus _lastRunStartTime. */
                    public _lastRunStartTime?: "lastRunStartTime";

                    /** ResourcePolicyResourceStatusInstanceSchedulePolicyStatus _nextRunStartTime. */
                    public _nextRunStartTime?: "nextRunStartTime";

                    /**
                     * Creates a new ResourcePolicyResourceStatusInstanceSchedulePolicyStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyResourceStatusInstanceSchedulePolicyStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyResourceStatusInstanceSchedulePolicyStatus): google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus;

                    /**
                     * Encodes the specified ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus.verify|verify} messages.
                     * @param message ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyResourceStatusInstanceSchedulePolicyStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus.verify|verify} messages.
                     * @param message ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyResourceStatusInstanceSchedulePolicyStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyResourceStatusInstanceSchedulePolicyStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus;

                    /**
                     * Decodes a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyResourceStatusInstanceSchedulePolicyStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus;

                    /**
                     * Verifies a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyResourceStatusInstanceSchedulePolicyStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus;

                    /**
                     * Creates a plain object from a ResourcePolicyResourceStatusInstanceSchedulePolicyStatus message. Also converts values to other types if specified.
                     * @param message ResourcePolicyResourceStatusInstanceSchedulePolicyStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyResourceStatusInstanceSchedulePolicyStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyResourceStatusInstanceSchedulePolicyStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicySnapshotSchedulePolicy. */
                interface IResourcePolicySnapshotSchedulePolicy {

                    /** ResourcePolicySnapshotSchedulePolicy retentionPolicy */
                    retentionPolicy?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicyRetentionPolicy|null);

                    /** ResourcePolicySnapshotSchedulePolicy schedule */
                    schedule?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySchedule|null);

                    /** ResourcePolicySnapshotSchedulePolicy snapshotProperties */
                    snapshotProperties?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySnapshotProperties|null);
                }

                /** Represents a ResourcePolicySnapshotSchedulePolicy. */
                class ResourcePolicySnapshotSchedulePolicy implements IResourcePolicySnapshotSchedulePolicy {

                    /**
                     * Constructs a new ResourcePolicySnapshotSchedulePolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicy);

                    /** ResourcePolicySnapshotSchedulePolicy retentionPolicy. */
                    public retentionPolicy?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicyRetentionPolicy|null);

                    /** ResourcePolicySnapshotSchedulePolicy schedule. */
                    public schedule?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySchedule|null);

                    /** ResourcePolicySnapshotSchedulePolicy snapshotProperties. */
                    public snapshotProperties?: (google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySnapshotProperties|null);

                    /** ResourcePolicySnapshotSchedulePolicy _retentionPolicy. */
                    public _retentionPolicy?: "retentionPolicy";

                    /** ResourcePolicySnapshotSchedulePolicy _schedule. */
                    public _schedule?: "schedule";

                    /** ResourcePolicySnapshotSchedulePolicy _snapshotProperties. */
                    public _snapshotProperties?: "snapshotProperties";

                    /**
                     * Creates a new ResourcePolicySnapshotSchedulePolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicySnapshotSchedulePolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicy): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicy message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicySnapshotSchedulePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicySnapshotSchedulePolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy;

                    /**
                     * Verifies a ResourcePolicySnapshotSchedulePolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicySnapshotSchedulePolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicySnapshotSchedulePolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy;

                    /**
                     * Creates a plain object from a ResourcePolicySnapshotSchedulePolicy message. Also converts values to other types if specified.
                     * @param message ResourcePolicySnapshotSchedulePolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicySnapshotSchedulePolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicySnapshotSchedulePolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicySnapshotSchedulePolicyRetentionPolicy. */
                interface IResourcePolicySnapshotSchedulePolicyRetentionPolicy {

                    /** ResourcePolicySnapshotSchedulePolicyRetentionPolicy maxRetentionDays */
                    maxRetentionDays?: (number|null);

                    /** ResourcePolicySnapshotSchedulePolicyRetentionPolicy onSourceDiskDelete */
                    onSourceDiskDelete?: (string|null);
                }

                /** Represents a ResourcePolicySnapshotSchedulePolicyRetentionPolicy. */
                class ResourcePolicySnapshotSchedulePolicyRetentionPolicy implements IResourcePolicySnapshotSchedulePolicyRetentionPolicy {

                    /**
                     * Constructs a new ResourcePolicySnapshotSchedulePolicyRetentionPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicyRetentionPolicy);

                    /** ResourcePolicySnapshotSchedulePolicyRetentionPolicy maxRetentionDays. */
                    public maxRetentionDays?: (number|null);

                    /** ResourcePolicySnapshotSchedulePolicyRetentionPolicy onSourceDiskDelete. */
                    public onSourceDiskDelete?: (string|null);

                    /** ResourcePolicySnapshotSchedulePolicyRetentionPolicy _maxRetentionDays. */
                    public _maxRetentionDays?: "maxRetentionDays";

                    /** ResourcePolicySnapshotSchedulePolicyRetentionPolicy _onSourceDiskDelete. */
                    public _onSourceDiskDelete?: "onSourceDiskDelete";

                    /**
                     * Creates a new ResourcePolicySnapshotSchedulePolicyRetentionPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicySnapshotSchedulePolicyRetentionPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicyRetentionPolicy): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicyRetentionPolicy message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicyRetentionPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicyRetentionPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicyRetentionPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicyRetentionPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicyRetentionPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicyRetentionPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicySnapshotSchedulePolicyRetentionPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicyRetentionPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicySnapshotSchedulePolicyRetentionPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy;

                    /**
                     * Verifies a ResourcePolicySnapshotSchedulePolicyRetentionPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicySnapshotSchedulePolicyRetentionPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicySnapshotSchedulePolicyRetentionPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy;

                    /**
                     * Creates a plain object from a ResourcePolicySnapshotSchedulePolicyRetentionPolicy message. Also converts values to other types if specified.
                     * @param message ResourcePolicySnapshotSchedulePolicyRetentionPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicyRetentionPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicySnapshotSchedulePolicyRetentionPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicySnapshotSchedulePolicyRetentionPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ResourcePolicySnapshotSchedulePolicyRetentionPolicy {

                    /** OnSourceDiskDelete enum. */
                    enum OnSourceDiskDelete {
                        UNDEFINED_ON_SOURCE_DISK_DELETE = 0,
                        APPLY_RETENTION_POLICY = 535071332,
                        KEEP_AUTO_SNAPSHOTS = 258925689,
                        UNSPECIFIED_ON_SOURCE_DISK_DELETE = 239140769
                    }
                }

                /** Properties of a ResourcePolicySnapshotSchedulePolicySchedule. */
                interface IResourcePolicySnapshotSchedulePolicySchedule {

                    /** ResourcePolicySnapshotSchedulePolicySchedule dailySchedule */
                    dailySchedule?: (google.cloud.compute.v1.IResourcePolicyDailyCycle|null);

                    /** ResourcePolicySnapshotSchedulePolicySchedule hourlySchedule */
                    hourlySchedule?: (google.cloud.compute.v1.IResourcePolicyHourlyCycle|null);

                    /** ResourcePolicySnapshotSchedulePolicySchedule weeklySchedule */
                    weeklySchedule?: (google.cloud.compute.v1.IResourcePolicyWeeklyCycle|null);
                }

                /** Represents a ResourcePolicySnapshotSchedulePolicySchedule. */
                class ResourcePolicySnapshotSchedulePolicySchedule implements IResourcePolicySnapshotSchedulePolicySchedule {

                    /**
                     * Constructs a new ResourcePolicySnapshotSchedulePolicySchedule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySchedule);

                    /** ResourcePolicySnapshotSchedulePolicySchedule dailySchedule. */
                    public dailySchedule?: (google.cloud.compute.v1.IResourcePolicyDailyCycle|null);

                    /** ResourcePolicySnapshotSchedulePolicySchedule hourlySchedule. */
                    public hourlySchedule?: (google.cloud.compute.v1.IResourcePolicyHourlyCycle|null);

                    /** ResourcePolicySnapshotSchedulePolicySchedule weeklySchedule. */
                    public weeklySchedule?: (google.cloud.compute.v1.IResourcePolicyWeeklyCycle|null);

                    /** ResourcePolicySnapshotSchedulePolicySchedule _dailySchedule. */
                    public _dailySchedule?: "dailySchedule";

                    /** ResourcePolicySnapshotSchedulePolicySchedule _hourlySchedule. */
                    public _hourlySchedule?: "hourlySchedule";

                    /** ResourcePolicySnapshotSchedulePolicySchedule _weeklySchedule. */
                    public _weeklySchedule?: "weeklySchedule";

                    /**
                     * Creates a new ResourcePolicySnapshotSchedulePolicySchedule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicySnapshotSchedulePolicySchedule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySchedule): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicySchedule message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicySchedule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySchedule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicySchedule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicySchedule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySchedule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicySchedule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicySnapshotSchedulePolicySchedule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicySchedule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicySnapshotSchedulePolicySchedule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule;

                    /**
                     * Verifies a ResourcePolicySnapshotSchedulePolicySchedule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicySnapshotSchedulePolicySchedule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicySnapshotSchedulePolicySchedule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule;

                    /**
                     * Creates a plain object from a ResourcePolicySnapshotSchedulePolicySchedule message. Also converts values to other types if specified.
                     * @param message ResourcePolicySnapshotSchedulePolicySchedule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySchedule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicySnapshotSchedulePolicySchedule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicySnapshotSchedulePolicySchedule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicySnapshotSchedulePolicySnapshotProperties. */
                interface IResourcePolicySnapshotSchedulePolicySnapshotProperties {

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties chainName */
                    chainName?: (string|null);

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties guestFlush */
                    guestFlush?: (boolean|null);

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties labels */
                    labels?: ({ [k: string]: string }|null);

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties storageLocations */
                    storageLocations?: (string[]|null);
                }

                /** Represents a ResourcePolicySnapshotSchedulePolicySnapshotProperties. */
                class ResourcePolicySnapshotSchedulePolicySnapshotProperties implements IResourcePolicySnapshotSchedulePolicySnapshotProperties {

                    /**
                     * Constructs a new ResourcePolicySnapshotSchedulePolicySnapshotProperties.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySnapshotProperties);

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties chainName. */
                    public chainName?: (string|null);

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties guestFlush. */
                    public guestFlush?: (boolean|null);

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties labels. */
                    public labels: { [k: string]: string };

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties storageLocations. */
                    public storageLocations: string[];

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties _chainName. */
                    public _chainName?: "chainName";

                    /** ResourcePolicySnapshotSchedulePolicySnapshotProperties _guestFlush. */
                    public _guestFlush?: "guestFlush";

                    /**
                     * Creates a new ResourcePolicySnapshotSchedulePolicySnapshotProperties instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicySnapshotSchedulePolicySnapshotProperties instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySnapshotProperties): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicySnapshotProperties message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicySnapshotProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySnapshotProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicySnapshotSchedulePolicySnapshotProperties message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties.verify|verify} messages.
                     * @param message ResourcePolicySnapshotSchedulePolicySnapshotProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicySnapshotSchedulePolicySnapshotProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicySnapshotProperties message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicySnapshotSchedulePolicySnapshotProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties;

                    /**
                     * Decodes a ResourcePolicySnapshotSchedulePolicySnapshotProperties message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicySnapshotSchedulePolicySnapshotProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties;

                    /**
                     * Verifies a ResourcePolicySnapshotSchedulePolicySnapshotProperties message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicySnapshotSchedulePolicySnapshotProperties message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicySnapshotSchedulePolicySnapshotProperties
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties;

                    /**
                     * Creates a plain object from a ResourcePolicySnapshotSchedulePolicySnapshotProperties message. Also converts values to other types if specified.
                     * @param message ResourcePolicySnapshotSchedulePolicySnapshotProperties
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicySnapshotSchedulePolicySnapshotProperties, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicySnapshotSchedulePolicySnapshotProperties to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicySnapshotSchedulePolicySnapshotProperties
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyWeeklyCycle. */
                interface IResourcePolicyWeeklyCycle {

                    /** ResourcePolicyWeeklyCycle dayOfWeeks */
                    dayOfWeeks?: (google.cloud.compute.v1.IResourcePolicyWeeklyCycleDayOfWeek[]|null);
                }

                /** Represents a ResourcePolicyWeeklyCycle. */
                class ResourcePolicyWeeklyCycle implements IResourcePolicyWeeklyCycle {

                    /**
                     * Constructs a new ResourcePolicyWeeklyCycle.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyWeeklyCycle);

                    /** ResourcePolicyWeeklyCycle dayOfWeeks. */
                    public dayOfWeeks: google.cloud.compute.v1.IResourcePolicyWeeklyCycleDayOfWeek[];

                    /**
                     * Creates a new ResourcePolicyWeeklyCycle instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyWeeklyCycle instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyWeeklyCycle): google.cloud.compute.v1.ResourcePolicyWeeklyCycle;

                    /**
                     * Encodes the specified ResourcePolicyWeeklyCycle message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyWeeklyCycle.verify|verify} messages.
                     * @param message ResourcePolicyWeeklyCycle message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyWeeklyCycle, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyWeeklyCycle message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyWeeklyCycle.verify|verify} messages.
                     * @param message ResourcePolicyWeeklyCycle message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyWeeklyCycle, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyWeeklyCycle message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyWeeklyCycle
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyWeeklyCycle;

                    /**
                     * Decodes a ResourcePolicyWeeklyCycle message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyWeeklyCycle
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyWeeklyCycle;

                    /**
                     * Verifies a ResourcePolicyWeeklyCycle message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyWeeklyCycle message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyWeeklyCycle
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyWeeklyCycle;

                    /**
                     * Creates a plain object from a ResourcePolicyWeeklyCycle message. Also converts values to other types if specified.
                     * @param message ResourcePolicyWeeklyCycle
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyWeeklyCycle, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyWeeklyCycle to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyWeeklyCycle
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResourcePolicyWeeklyCycleDayOfWeek. */
                interface IResourcePolicyWeeklyCycleDayOfWeek {

                    /** ResourcePolicyWeeklyCycleDayOfWeek day */
                    day?: (string|null);

                    /** ResourcePolicyWeeklyCycleDayOfWeek duration */
                    duration?: (string|null);

                    /** ResourcePolicyWeeklyCycleDayOfWeek startTime */
                    startTime?: (string|null);
                }

                /** Represents a ResourcePolicyWeeklyCycleDayOfWeek. */
                class ResourcePolicyWeeklyCycleDayOfWeek implements IResourcePolicyWeeklyCycleDayOfWeek {

                    /**
                     * Constructs a new ResourcePolicyWeeklyCycleDayOfWeek.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourcePolicyWeeklyCycleDayOfWeek);

                    /** ResourcePolicyWeeklyCycleDayOfWeek day. */
                    public day?: (string|null);

                    /** ResourcePolicyWeeklyCycleDayOfWeek duration. */
                    public duration?: (string|null);

                    /** ResourcePolicyWeeklyCycleDayOfWeek startTime. */
                    public startTime?: (string|null);

                    /** ResourcePolicyWeeklyCycleDayOfWeek _day. */
                    public _day?: "day";

                    /** ResourcePolicyWeeklyCycleDayOfWeek _duration. */
                    public _duration?: "duration";

                    /** ResourcePolicyWeeklyCycleDayOfWeek _startTime. */
                    public _startTime?: "startTime";

                    /**
                     * Creates a new ResourcePolicyWeeklyCycleDayOfWeek instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourcePolicyWeeklyCycleDayOfWeek instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourcePolicyWeeklyCycleDayOfWeek): google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek;

                    /**
                     * Encodes the specified ResourcePolicyWeeklyCycleDayOfWeek message. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek.verify|verify} messages.
                     * @param message ResourcePolicyWeeklyCycleDayOfWeek message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourcePolicyWeeklyCycleDayOfWeek, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourcePolicyWeeklyCycleDayOfWeek message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek.verify|verify} messages.
                     * @param message ResourcePolicyWeeklyCycleDayOfWeek message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourcePolicyWeeklyCycleDayOfWeek, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourcePolicyWeeklyCycleDayOfWeek message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourcePolicyWeeklyCycleDayOfWeek
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek;

                    /**
                     * Decodes a ResourcePolicyWeeklyCycleDayOfWeek message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourcePolicyWeeklyCycleDayOfWeek
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek;

                    /**
                     * Verifies a ResourcePolicyWeeklyCycleDayOfWeek message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourcePolicyWeeklyCycleDayOfWeek message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourcePolicyWeeklyCycleDayOfWeek
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek;

                    /**
                     * Creates a plain object from a ResourcePolicyWeeklyCycleDayOfWeek message. Also converts values to other types if specified.
                     * @param message ResourcePolicyWeeklyCycleDayOfWeek
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourcePolicyWeeklyCycleDayOfWeek, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourcePolicyWeeklyCycleDayOfWeek to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourcePolicyWeeklyCycleDayOfWeek
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ResourcePolicyWeeklyCycleDayOfWeek {

                    /** Day enum. */
                    enum Day {
                        UNDEFINED_DAY = 0,
                        FRIDAY = 471398751,
                        INVALID = 530283991,
                        MONDAY = 132310288,
                        SATURDAY = 279037881,
                        SUNDAY = 309626320,
                        THURSDAY = 207198682,
                        TUESDAY = 277509677,
                        WEDNESDAY = 422029110
                    }
                }

                /** Properties of a ResourceStatus. */
                interface IResourceStatus {

                    /** ResourceStatus physicalHost */
                    physicalHost?: (string|null);
                }

                /** Represents a ResourceStatus. */
                class ResourceStatus implements IResourceStatus {

                    /**
                     * Constructs a new ResourceStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResourceStatus);

                    /** ResourceStatus physicalHost. */
                    public physicalHost?: (string|null);

                    /** ResourceStatus _physicalHost. */
                    public _physicalHost?: "physicalHost";

                    /**
                     * Creates a new ResourceStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResourceStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResourceStatus): google.cloud.compute.v1.ResourceStatus;

                    /**
                     * Encodes the specified ResourceStatus message. Does not implicitly {@link google.cloud.compute.v1.ResourceStatus.verify|verify} messages.
                     * @param message ResourceStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResourceStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResourceStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResourceStatus.verify|verify} messages.
                     * @param message ResourceStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResourceStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResourceStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResourceStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResourceStatus;

                    /**
                     * Decodes a ResourceStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResourceStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResourceStatus;

                    /**
                     * Verifies a ResourceStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResourceStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResourceStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResourceStatus;

                    /**
                     * Creates a plain object from a ResourceStatus message. Also converts values to other types if specified.
                     * @param message ResourceStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResourceStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResourceStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResourceStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ResumeInstanceRequest. */
                interface IResumeInstanceRequest {

                    /** ResumeInstanceRequest instance */
                    instance?: (string|null);

                    /** ResumeInstanceRequest project */
                    project?: (string|null);

                    /** ResumeInstanceRequest requestId */
                    requestId?: (string|null);

                    /** ResumeInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a ResumeInstanceRequest. */
                class ResumeInstanceRequest implements IResumeInstanceRequest {

                    /**
                     * Constructs a new ResumeInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IResumeInstanceRequest);

                    /** ResumeInstanceRequest instance. */
                    public instance: string;

                    /** ResumeInstanceRequest project. */
                    public project: string;

                    /** ResumeInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** ResumeInstanceRequest zone. */
                    public zone: string;

                    /** ResumeInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new ResumeInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ResumeInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IResumeInstanceRequest): google.cloud.compute.v1.ResumeInstanceRequest;

                    /**
                     * Encodes the specified ResumeInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.ResumeInstanceRequest.verify|verify} messages.
                     * @param message ResumeInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IResumeInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ResumeInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ResumeInstanceRequest.verify|verify} messages.
                     * @param message ResumeInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IResumeInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ResumeInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ResumeInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ResumeInstanceRequest;

                    /**
                     * Decodes a ResumeInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ResumeInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ResumeInstanceRequest;

                    /**
                     * Verifies a ResumeInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ResumeInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ResumeInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ResumeInstanceRequest;

                    /**
                     * Creates a plain object from a ResumeInstanceRequest message. Also converts values to other types if specified.
                     * @param message ResumeInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ResumeInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ResumeInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ResumeInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Route. */
                interface IRoute {

                    /** Route asPaths */
                    asPaths?: (google.cloud.compute.v1.IRouteAsPath[]|null);

                    /** Route creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Route description */
                    description?: (string|null);

                    /** Route destRange */
                    destRange?: (string|null);

                    /** Route id */
                    id?: (number|Long|string|null);

                    /** Route kind */
                    kind?: (string|null);

                    /** Route name */
                    name?: (string|null);

                    /** Route network */
                    network?: (string|null);

                    /** Route nextHopGateway */
                    nextHopGateway?: (string|null);

                    /** Route nextHopIlb */
                    nextHopIlb?: (string|null);

                    /** Route nextHopInstance */
                    nextHopInstance?: (string|null);

                    /** Route nextHopIp */
                    nextHopIp?: (string|null);

                    /** Route nextHopNetwork */
                    nextHopNetwork?: (string|null);

                    /** Route nextHopPeering */
                    nextHopPeering?: (string|null);

                    /** Route nextHopVpnTunnel */
                    nextHopVpnTunnel?: (string|null);

                    /** Route priority */
                    priority?: (number|null);

                    /** Route routeStatus */
                    routeStatus?: (string|null);

                    /** Route routeType */
                    routeType?: (string|null);

                    /** Route selfLink */
                    selfLink?: (string|null);

                    /** Route tags */
                    tags?: (string[]|null);

                    /** Route warnings */
                    warnings?: (google.cloud.compute.v1.IWarnings[]|null);
                }

                /** Represents a Route. */
                class Route implements IRoute {

                    /**
                     * Constructs a new Route.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRoute);

                    /** Route asPaths. */
                    public asPaths: google.cloud.compute.v1.IRouteAsPath[];

                    /** Route creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Route description. */
                    public description?: (string|null);

                    /** Route destRange. */
                    public destRange?: (string|null);

                    /** Route id. */
                    public id?: (number|Long|string|null);

                    /** Route kind. */
                    public kind?: (string|null);

                    /** Route name. */
                    public name?: (string|null);

                    /** Route network. */
                    public network?: (string|null);

                    /** Route nextHopGateway. */
                    public nextHopGateway?: (string|null);

                    /** Route nextHopIlb. */
                    public nextHopIlb?: (string|null);

                    /** Route nextHopInstance. */
                    public nextHopInstance?: (string|null);

                    /** Route nextHopIp. */
                    public nextHopIp?: (string|null);

                    /** Route nextHopNetwork. */
                    public nextHopNetwork?: (string|null);

                    /** Route nextHopPeering. */
                    public nextHopPeering?: (string|null);

                    /** Route nextHopVpnTunnel. */
                    public nextHopVpnTunnel?: (string|null);

                    /** Route priority. */
                    public priority?: (number|null);

                    /** Route routeStatus. */
                    public routeStatus?: (string|null);

                    /** Route routeType. */
                    public routeType?: (string|null);

                    /** Route selfLink. */
                    public selfLink?: (string|null);

                    /** Route tags. */
                    public tags: string[];

                    /** Route warnings. */
                    public warnings: google.cloud.compute.v1.IWarnings[];

                    /** Route _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Route _description. */
                    public _description?: "description";

                    /** Route _destRange. */
                    public _destRange?: "destRange";

                    /** Route _id. */
                    public _id?: "id";

                    /** Route _kind. */
                    public _kind?: "kind";

                    /** Route _name. */
                    public _name?: "name";

                    /** Route _network. */
                    public _network?: "network";

                    /** Route _nextHopGateway. */
                    public _nextHopGateway?: "nextHopGateway";

                    /** Route _nextHopIlb. */
                    public _nextHopIlb?: "nextHopIlb";

                    /** Route _nextHopInstance. */
                    public _nextHopInstance?: "nextHopInstance";

                    /** Route _nextHopIp. */
                    public _nextHopIp?: "nextHopIp";

                    /** Route _nextHopNetwork. */
                    public _nextHopNetwork?: "nextHopNetwork";

                    /** Route _nextHopPeering. */
                    public _nextHopPeering?: "nextHopPeering";

                    /** Route _nextHopVpnTunnel. */
                    public _nextHopVpnTunnel?: "nextHopVpnTunnel";

                    /** Route _priority. */
                    public _priority?: "priority";

                    /** Route _routeStatus. */
                    public _routeStatus?: "routeStatus";

                    /** Route _routeType. */
                    public _routeType?: "routeType";

                    /** Route _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new Route instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Route instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRoute): google.cloud.compute.v1.Route;

                    /**
                     * Encodes the specified Route message. Does not implicitly {@link google.cloud.compute.v1.Route.verify|verify} messages.
                     * @param message Route message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRoute, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Route message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Route.verify|verify} messages.
                     * @param message Route message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRoute, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Route message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Route
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Route;

                    /**
                     * Decodes a Route message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Route
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Route;

                    /**
                     * Verifies a Route message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Route message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Route
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Route;

                    /**
                     * Creates a plain object from a Route message. Also converts values to other types if specified.
                     * @param message Route
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Route, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Route to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Route
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Route {

                    /** RouteStatus enum. */
                    enum RouteStatus {
                        UNDEFINED_ROUTE_STATUS = 0,
                        ACTIVE = 314733318,
                        DROPPED = 496235424,
                        INACTIVE = 270421099,
                        PENDING = 35394935
                    }

                    /** RouteType enum. */
                    enum RouteType {
                        UNDEFINED_ROUTE_TYPE = 0,
                        BGP = 65707,
                        STATIC = 308331118,
                        SUBNET = 309278557,
                        TRANSIT = 187793843
                    }
                }

                /** Properties of a RouteAsPath. */
                interface IRouteAsPath {

                    /** RouteAsPath asLists */
                    asLists?: (number[]|null);

                    /** RouteAsPath pathSegmentType */
                    pathSegmentType?: (string|null);
                }

                /** Represents a RouteAsPath. */
                class RouteAsPath implements IRouteAsPath {

                    /**
                     * Constructs a new RouteAsPath.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouteAsPath);

                    /** RouteAsPath asLists. */
                    public asLists: number[];

                    /** RouteAsPath pathSegmentType. */
                    public pathSegmentType?: (string|null);

                    /** RouteAsPath _pathSegmentType. */
                    public _pathSegmentType?: "pathSegmentType";

                    /**
                     * Creates a new RouteAsPath instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouteAsPath instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouteAsPath): google.cloud.compute.v1.RouteAsPath;

                    /**
                     * Encodes the specified RouteAsPath message. Does not implicitly {@link google.cloud.compute.v1.RouteAsPath.verify|verify} messages.
                     * @param message RouteAsPath message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouteAsPath, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouteAsPath message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouteAsPath.verify|verify} messages.
                     * @param message RouteAsPath message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouteAsPath, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouteAsPath message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouteAsPath
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouteAsPath;

                    /**
                     * Decodes a RouteAsPath message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouteAsPath
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouteAsPath;

                    /**
                     * Verifies a RouteAsPath message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouteAsPath message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouteAsPath
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouteAsPath;

                    /**
                     * Creates a plain object from a RouteAsPath message. Also converts values to other types if specified.
                     * @param message RouteAsPath
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouteAsPath, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouteAsPath to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouteAsPath
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouteAsPath {

                    /** PathSegmentType enum. */
                    enum PathSegmentType {
                        UNDEFINED_PATH_SEGMENT_TYPE = 0,
                        AS_CONFED_SEQUENCE = 222152624,
                        AS_CONFED_SET = 374040307,
                        AS_SEQUENCE = 106735918,
                        AS_SET = 329846453
                    }
                }

                /** Properties of a RouteList. */
                interface IRouteList {

                    /** RouteList id */
                    id?: (string|null);

                    /** RouteList items */
                    items?: (google.cloud.compute.v1.IRoute[]|null);

                    /** RouteList kind */
                    kind?: (string|null);

                    /** RouteList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RouteList selfLink */
                    selfLink?: (string|null);

                    /** RouteList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RouteList. */
                class RouteList implements IRouteList {

                    /**
                     * Constructs a new RouteList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouteList);

                    /** RouteList id. */
                    public id?: (string|null);

                    /** RouteList items. */
                    public items: google.cloud.compute.v1.IRoute[];

                    /** RouteList kind. */
                    public kind?: (string|null);

                    /** RouteList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RouteList selfLink. */
                    public selfLink?: (string|null);

                    /** RouteList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RouteList _id. */
                    public _id?: "id";

                    /** RouteList _kind. */
                    public _kind?: "kind";

                    /** RouteList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RouteList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RouteList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RouteList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouteList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouteList): google.cloud.compute.v1.RouteList;

                    /**
                     * Encodes the specified RouteList message. Does not implicitly {@link google.cloud.compute.v1.RouteList.verify|verify} messages.
                     * @param message RouteList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouteList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouteList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouteList.verify|verify} messages.
                     * @param message RouteList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouteList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouteList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouteList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouteList;

                    /**
                     * Decodes a RouteList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouteList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouteList;

                    /**
                     * Verifies a RouteList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouteList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouteList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouteList;

                    /**
                     * Creates a plain object from a RouteList message. Also converts values to other types if specified.
                     * @param message RouteList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouteList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouteList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouteList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Router. */
                interface IRouter {

                    /** Router bgp */
                    bgp?: (google.cloud.compute.v1.IRouterBgp|null);

                    /** Router bgpPeers */
                    bgpPeers?: (google.cloud.compute.v1.IRouterBgpPeer[]|null);

                    /** Router creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Router description */
                    description?: (string|null);

                    /** Router encryptedInterconnectRouter */
                    encryptedInterconnectRouter?: (boolean|null);

                    /** Router id */
                    id?: (number|Long|string|null);

                    /** Router interfaces */
                    interfaces?: (google.cloud.compute.v1.IRouterInterface[]|null);

                    /** Router kind */
                    kind?: (string|null);

                    /** Router md5AuthenticationKeys */
                    md5AuthenticationKeys?: (google.cloud.compute.v1.IRouterMd5AuthenticationKey[]|null);

                    /** Router name */
                    name?: (string|null);

                    /** Router nats */
                    nats?: (google.cloud.compute.v1.IRouterNat[]|null);

                    /** Router network */
                    network?: (string|null);

                    /** Router region */
                    region?: (string|null);

                    /** Router selfLink */
                    selfLink?: (string|null);
                }

                /** Represents a Router. */
                class Router implements IRouter {

                    /**
                     * Constructs a new Router.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouter);

                    /** Router bgp. */
                    public bgp?: (google.cloud.compute.v1.IRouterBgp|null);

                    /** Router bgpPeers. */
                    public bgpPeers: google.cloud.compute.v1.IRouterBgpPeer[];

                    /** Router creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Router description. */
                    public description?: (string|null);

                    /** Router encryptedInterconnectRouter. */
                    public encryptedInterconnectRouter?: (boolean|null);

                    /** Router id. */
                    public id?: (number|Long|string|null);

                    /** Router interfaces. */
                    public interfaces: google.cloud.compute.v1.IRouterInterface[];

                    /** Router kind. */
                    public kind?: (string|null);

                    /** Router md5AuthenticationKeys. */
                    public md5AuthenticationKeys: google.cloud.compute.v1.IRouterMd5AuthenticationKey[];

                    /** Router name. */
                    public name?: (string|null);

                    /** Router nats. */
                    public nats: google.cloud.compute.v1.IRouterNat[];

                    /** Router network. */
                    public network?: (string|null);

                    /** Router region. */
                    public region?: (string|null);

                    /** Router selfLink. */
                    public selfLink?: (string|null);

                    /** Router _bgp. */
                    public _bgp?: "bgp";

                    /** Router _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Router _description. */
                    public _description?: "description";

                    /** Router _encryptedInterconnectRouter. */
                    public _encryptedInterconnectRouter?: "encryptedInterconnectRouter";

                    /** Router _id. */
                    public _id?: "id";

                    /** Router _kind. */
                    public _kind?: "kind";

                    /** Router _name. */
                    public _name?: "name";

                    /** Router _network. */
                    public _network?: "network";

                    /** Router _region. */
                    public _region?: "region";

                    /** Router _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new Router instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Router instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouter): google.cloud.compute.v1.Router;

                    /**
                     * Encodes the specified Router message. Does not implicitly {@link google.cloud.compute.v1.Router.verify|verify} messages.
                     * @param message Router message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouter, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Router message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Router.verify|verify} messages.
                     * @param message Router message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouter, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Router message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Router
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Router;

                    /**
                     * Decodes a Router message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Router
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Router;

                    /**
                     * Verifies a Router message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Router message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Router
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Router;

                    /**
                     * Creates a plain object from a Router message. Also converts values to other types if specified.
                     * @param message Router
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Router, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Router to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Router
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterAdvertisedIpRange. */
                interface IRouterAdvertisedIpRange {

                    /** RouterAdvertisedIpRange description */
                    description?: (string|null);

                    /** RouterAdvertisedIpRange range */
                    range?: (string|null);
                }

                /** Represents a RouterAdvertisedIpRange. */
                class RouterAdvertisedIpRange implements IRouterAdvertisedIpRange {

                    /**
                     * Constructs a new RouterAdvertisedIpRange.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterAdvertisedIpRange);

                    /** RouterAdvertisedIpRange description. */
                    public description?: (string|null);

                    /** RouterAdvertisedIpRange range. */
                    public range?: (string|null);

                    /** RouterAdvertisedIpRange _description. */
                    public _description?: "description";

                    /** RouterAdvertisedIpRange _range. */
                    public _range?: "range";

                    /**
                     * Creates a new RouterAdvertisedIpRange instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterAdvertisedIpRange instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterAdvertisedIpRange): google.cloud.compute.v1.RouterAdvertisedIpRange;

                    /**
                     * Encodes the specified RouterAdvertisedIpRange message. Does not implicitly {@link google.cloud.compute.v1.RouterAdvertisedIpRange.verify|verify} messages.
                     * @param message RouterAdvertisedIpRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterAdvertisedIpRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterAdvertisedIpRange message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterAdvertisedIpRange.verify|verify} messages.
                     * @param message RouterAdvertisedIpRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterAdvertisedIpRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterAdvertisedIpRange message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterAdvertisedIpRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterAdvertisedIpRange;

                    /**
                     * Decodes a RouterAdvertisedIpRange message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterAdvertisedIpRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterAdvertisedIpRange;

                    /**
                     * Verifies a RouterAdvertisedIpRange message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterAdvertisedIpRange message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterAdvertisedIpRange
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterAdvertisedIpRange;

                    /**
                     * Creates a plain object from a RouterAdvertisedIpRange message. Also converts values to other types if specified.
                     * @param message RouterAdvertisedIpRange
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterAdvertisedIpRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterAdvertisedIpRange to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterAdvertisedIpRange
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterAggregatedList. */
                interface IRouterAggregatedList {

                    /** RouterAggregatedList id */
                    id?: (string|null);

                    /** RouterAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IRoutersScopedList }|null);

                    /** RouterAggregatedList kind */
                    kind?: (string|null);

                    /** RouterAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RouterAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** RouterAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** RouterAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RouterAggregatedList. */
                class RouterAggregatedList implements IRouterAggregatedList {

                    /**
                     * Constructs a new RouterAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterAggregatedList);

                    /** RouterAggregatedList id. */
                    public id?: (string|null);

                    /** RouterAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IRoutersScopedList };

                    /** RouterAggregatedList kind. */
                    public kind?: (string|null);

                    /** RouterAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RouterAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** RouterAggregatedList unreachables. */
                    public unreachables: string[];

                    /** RouterAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RouterAggregatedList _id. */
                    public _id?: "id";

                    /** RouterAggregatedList _kind. */
                    public _kind?: "kind";

                    /** RouterAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RouterAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RouterAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RouterAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterAggregatedList): google.cloud.compute.v1.RouterAggregatedList;

                    /**
                     * Encodes the specified RouterAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.RouterAggregatedList.verify|verify} messages.
                     * @param message RouterAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterAggregatedList.verify|verify} messages.
                     * @param message RouterAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterAggregatedList;

                    /**
                     * Decodes a RouterAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterAggregatedList;

                    /**
                     * Verifies a RouterAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterAggregatedList;

                    /**
                     * Creates a plain object from a RouterAggregatedList message. Also converts values to other types if specified.
                     * @param message RouterAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterBgp. */
                interface IRouterBgp {

                    /** RouterBgp advertiseMode */
                    advertiseMode?: (string|null);

                    /** RouterBgp advertisedGroups */
                    advertisedGroups?: (string[]|null);

                    /** RouterBgp advertisedIpRanges */
                    advertisedIpRanges?: (google.cloud.compute.v1.IRouterAdvertisedIpRange[]|null);

                    /** RouterBgp asn */
                    asn?: (number|null);

                    /** RouterBgp keepaliveInterval */
                    keepaliveInterval?: (number|null);
                }

                /** Represents a RouterBgp. */
                class RouterBgp implements IRouterBgp {

                    /**
                     * Constructs a new RouterBgp.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterBgp);

                    /** RouterBgp advertiseMode. */
                    public advertiseMode?: (string|null);

                    /** RouterBgp advertisedGroups. */
                    public advertisedGroups: string[];

                    /** RouterBgp advertisedIpRanges. */
                    public advertisedIpRanges: google.cloud.compute.v1.IRouterAdvertisedIpRange[];

                    /** RouterBgp asn. */
                    public asn?: (number|null);

                    /** RouterBgp keepaliveInterval. */
                    public keepaliveInterval?: (number|null);

                    /** RouterBgp _advertiseMode. */
                    public _advertiseMode?: "advertiseMode";

                    /** RouterBgp _asn. */
                    public _asn?: "asn";

                    /** RouterBgp _keepaliveInterval. */
                    public _keepaliveInterval?: "keepaliveInterval";

                    /**
                     * Creates a new RouterBgp instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterBgp instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterBgp): google.cloud.compute.v1.RouterBgp;

                    /**
                     * Encodes the specified RouterBgp message. Does not implicitly {@link google.cloud.compute.v1.RouterBgp.verify|verify} messages.
                     * @param message RouterBgp message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterBgp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterBgp message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterBgp.verify|verify} messages.
                     * @param message RouterBgp message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterBgp, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterBgp message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterBgp
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterBgp;

                    /**
                     * Decodes a RouterBgp message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterBgp
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterBgp;

                    /**
                     * Verifies a RouterBgp message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterBgp message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterBgp
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterBgp;

                    /**
                     * Creates a plain object from a RouterBgp message. Also converts values to other types if specified.
                     * @param message RouterBgp
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterBgp, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterBgp to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterBgp
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterBgp {

                    /** AdvertiseMode enum. */
                    enum AdvertiseMode {
                        UNDEFINED_ADVERTISE_MODE = 0,
                        CUSTOM = 388595569,
                        DEFAULT = 115302945
                    }

                    /** AdvertisedGroups enum. */
                    enum AdvertisedGroups {
                        UNDEFINED_ADVERTISED_GROUPS = 0,
                        ALL_SUBNETS = 3622872
                    }
                }

                /** Properties of a RouterBgpPeer. */
                interface IRouterBgpPeer {

                    /** RouterBgpPeer advertiseMode */
                    advertiseMode?: (string|null);

                    /** RouterBgpPeer advertisedGroups */
                    advertisedGroups?: (string[]|null);

                    /** RouterBgpPeer advertisedIpRanges */
                    advertisedIpRanges?: (google.cloud.compute.v1.IRouterAdvertisedIpRange[]|null);

                    /** RouterBgpPeer advertisedRoutePriority */
                    advertisedRoutePriority?: (number|null);

                    /** RouterBgpPeer bfd */
                    bfd?: (google.cloud.compute.v1.IRouterBgpPeerBfd|null);

                    /** RouterBgpPeer enable */
                    enable?: (string|null);

                    /** RouterBgpPeer enableIpv6 */
                    enableIpv6?: (boolean|null);

                    /** RouterBgpPeer interfaceName */
                    interfaceName?: (string|null);

                    /** RouterBgpPeer ipAddress */
                    ipAddress?: (string|null);

                    /** RouterBgpPeer ipv6NexthopAddress */
                    ipv6NexthopAddress?: (string|null);

                    /** RouterBgpPeer managementType */
                    managementType?: (string|null);

                    /** RouterBgpPeer md5AuthenticationKeyName */
                    md5AuthenticationKeyName?: (string|null);

                    /** RouterBgpPeer name */
                    name?: (string|null);

                    /** RouterBgpPeer peerAsn */
                    peerAsn?: (number|null);

                    /** RouterBgpPeer peerIpAddress */
                    peerIpAddress?: (string|null);

                    /** RouterBgpPeer peerIpv6NexthopAddress */
                    peerIpv6NexthopAddress?: (string|null);

                    /** RouterBgpPeer routerApplianceInstance */
                    routerApplianceInstance?: (string|null);
                }

                /** Represents a RouterBgpPeer. */
                class RouterBgpPeer implements IRouterBgpPeer {

                    /**
                     * Constructs a new RouterBgpPeer.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterBgpPeer);

                    /** RouterBgpPeer advertiseMode. */
                    public advertiseMode?: (string|null);

                    /** RouterBgpPeer advertisedGroups. */
                    public advertisedGroups: string[];

                    /** RouterBgpPeer advertisedIpRanges. */
                    public advertisedIpRanges: google.cloud.compute.v1.IRouterAdvertisedIpRange[];

                    /** RouterBgpPeer advertisedRoutePriority. */
                    public advertisedRoutePriority?: (number|null);

                    /** RouterBgpPeer bfd. */
                    public bfd?: (google.cloud.compute.v1.IRouterBgpPeerBfd|null);

                    /** RouterBgpPeer enable. */
                    public enable?: (string|null);

                    /** RouterBgpPeer enableIpv6. */
                    public enableIpv6?: (boolean|null);

                    /** RouterBgpPeer interfaceName. */
                    public interfaceName?: (string|null);

                    /** RouterBgpPeer ipAddress. */
                    public ipAddress?: (string|null);

                    /** RouterBgpPeer ipv6NexthopAddress. */
                    public ipv6NexthopAddress?: (string|null);

                    /** RouterBgpPeer managementType. */
                    public managementType?: (string|null);

                    /** RouterBgpPeer md5AuthenticationKeyName. */
                    public md5AuthenticationKeyName?: (string|null);

                    /** RouterBgpPeer name. */
                    public name?: (string|null);

                    /** RouterBgpPeer peerAsn. */
                    public peerAsn?: (number|null);

                    /** RouterBgpPeer peerIpAddress. */
                    public peerIpAddress?: (string|null);

                    /** RouterBgpPeer peerIpv6NexthopAddress. */
                    public peerIpv6NexthopAddress?: (string|null);

                    /** RouterBgpPeer routerApplianceInstance. */
                    public routerApplianceInstance?: (string|null);

                    /** RouterBgpPeer _advertiseMode. */
                    public _advertiseMode?: "advertiseMode";

                    /** RouterBgpPeer _advertisedRoutePriority. */
                    public _advertisedRoutePriority?: "advertisedRoutePriority";

                    /** RouterBgpPeer _bfd. */
                    public _bfd?: "bfd";

                    /** RouterBgpPeer _enable. */
                    public _enable?: "enable";

                    /** RouterBgpPeer _enableIpv6. */
                    public _enableIpv6?: "enableIpv6";

                    /** RouterBgpPeer _interfaceName. */
                    public _interfaceName?: "interfaceName";

                    /** RouterBgpPeer _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /** RouterBgpPeer _ipv6NexthopAddress. */
                    public _ipv6NexthopAddress?: "ipv6NexthopAddress";

                    /** RouterBgpPeer _managementType. */
                    public _managementType?: "managementType";

                    /** RouterBgpPeer _md5AuthenticationKeyName. */
                    public _md5AuthenticationKeyName?: "md5AuthenticationKeyName";

                    /** RouterBgpPeer _name. */
                    public _name?: "name";

                    /** RouterBgpPeer _peerAsn. */
                    public _peerAsn?: "peerAsn";

                    /** RouterBgpPeer _peerIpAddress. */
                    public _peerIpAddress?: "peerIpAddress";

                    /** RouterBgpPeer _peerIpv6NexthopAddress. */
                    public _peerIpv6NexthopAddress?: "peerIpv6NexthopAddress";

                    /** RouterBgpPeer _routerApplianceInstance. */
                    public _routerApplianceInstance?: "routerApplianceInstance";

                    /**
                     * Creates a new RouterBgpPeer instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterBgpPeer instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterBgpPeer): google.cloud.compute.v1.RouterBgpPeer;

                    /**
                     * Encodes the specified RouterBgpPeer message. Does not implicitly {@link google.cloud.compute.v1.RouterBgpPeer.verify|verify} messages.
                     * @param message RouterBgpPeer message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterBgpPeer, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterBgpPeer message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterBgpPeer.verify|verify} messages.
                     * @param message RouterBgpPeer message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterBgpPeer, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterBgpPeer message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterBgpPeer
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterBgpPeer;

                    /**
                     * Decodes a RouterBgpPeer message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterBgpPeer
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterBgpPeer;

                    /**
                     * Verifies a RouterBgpPeer message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterBgpPeer message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterBgpPeer
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterBgpPeer;

                    /**
                     * Creates a plain object from a RouterBgpPeer message. Also converts values to other types if specified.
                     * @param message RouterBgpPeer
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterBgpPeer, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterBgpPeer to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterBgpPeer
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterBgpPeer {

                    /** AdvertiseMode enum. */
                    enum AdvertiseMode {
                        UNDEFINED_ADVERTISE_MODE = 0,
                        CUSTOM = 388595569,
                        DEFAULT = 115302945
                    }

                    /** AdvertisedGroups enum. */
                    enum AdvertisedGroups {
                        UNDEFINED_ADVERTISED_GROUPS = 0,
                        ALL_SUBNETS = 3622872
                    }

                    /** Enable enum. */
                    enum Enable {
                        UNDEFINED_ENABLE = 0,
                        FALSE = 66658563,
                        TRUE = 2583950
                    }

                    /** ManagementType enum. */
                    enum ManagementType {
                        UNDEFINED_MANAGEMENT_TYPE = 0,
                        MANAGED_BY_ATTACHMENT = 458926411,
                        MANAGED_BY_USER = 317294067
                    }
                }

                /** Properties of a RouterBgpPeerBfd. */
                interface IRouterBgpPeerBfd {

                    /** RouterBgpPeerBfd minReceiveInterval */
                    minReceiveInterval?: (number|null);

                    /** RouterBgpPeerBfd minTransmitInterval */
                    minTransmitInterval?: (number|null);

                    /** RouterBgpPeerBfd multiplier */
                    multiplier?: (number|null);

                    /** RouterBgpPeerBfd sessionInitializationMode */
                    sessionInitializationMode?: (string|null);
                }

                /** Represents a RouterBgpPeerBfd. */
                class RouterBgpPeerBfd implements IRouterBgpPeerBfd {

                    /**
                     * Constructs a new RouterBgpPeerBfd.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterBgpPeerBfd);

                    /** RouterBgpPeerBfd minReceiveInterval. */
                    public minReceiveInterval?: (number|null);

                    /** RouterBgpPeerBfd minTransmitInterval. */
                    public minTransmitInterval?: (number|null);

                    /** RouterBgpPeerBfd multiplier. */
                    public multiplier?: (number|null);

                    /** RouterBgpPeerBfd sessionInitializationMode. */
                    public sessionInitializationMode?: (string|null);

                    /** RouterBgpPeerBfd _minReceiveInterval. */
                    public _minReceiveInterval?: "minReceiveInterval";

                    /** RouterBgpPeerBfd _minTransmitInterval. */
                    public _minTransmitInterval?: "minTransmitInterval";

                    /** RouterBgpPeerBfd _multiplier. */
                    public _multiplier?: "multiplier";

                    /** RouterBgpPeerBfd _sessionInitializationMode. */
                    public _sessionInitializationMode?: "sessionInitializationMode";

                    /**
                     * Creates a new RouterBgpPeerBfd instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterBgpPeerBfd instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterBgpPeerBfd): google.cloud.compute.v1.RouterBgpPeerBfd;

                    /**
                     * Encodes the specified RouterBgpPeerBfd message. Does not implicitly {@link google.cloud.compute.v1.RouterBgpPeerBfd.verify|verify} messages.
                     * @param message RouterBgpPeerBfd message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterBgpPeerBfd, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterBgpPeerBfd message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterBgpPeerBfd.verify|verify} messages.
                     * @param message RouterBgpPeerBfd message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterBgpPeerBfd, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterBgpPeerBfd message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterBgpPeerBfd
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterBgpPeerBfd;

                    /**
                     * Decodes a RouterBgpPeerBfd message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterBgpPeerBfd
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterBgpPeerBfd;

                    /**
                     * Verifies a RouterBgpPeerBfd message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterBgpPeerBfd message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterBgpPeerBfd
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterBgpPeerBfd;

                    /**
                     * Creates a plain object from a RouterBgpPeerBfd message. Also converts values to other types if specified.
                     * @param message RouterBgpPeerBfd
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterBgpPeerBfd, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterBgpPeerBfd to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterBgpPeerBfd
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterBgpPeerBfd {

                    /** SessionInitializationMode enum. */
                    enum SessionInitializationMode {
                        UNDEFINED_SESSION_INITIALIZATION_MODE = 0,
                        ACTIVE = 314733318,
                        DISABLED = 516696700,
                        PASSIVE = 462813959
                    }
                }

                /** Properties of a RouterInterface. */
                interface IRouterInterface {

                    /** RouterInterface ipRange */
                    ipRange?: (string|null);

                    /** RouterInterface linkedInterconnectAttachment */
                    linkedInterconnectAttachment?: (string|null);

                    /** RouterInterface linkedVpnTunnel */
                    linkedVpnTunnel?: (string|null);

                    /** RouterInterface managementType */
                    managementType?: (string|null);

                    /** RouterInterface name */
                    name?: (string|null);

                    /** RouterInterface privateIpAddress */
                    privateIpAddress?: (string|null);

                    /** RouterInterface redundantInterface */
                    redundantInterface?: (string|null);

                    /** RouterInterface subnetwork */
                    subnetwork?: (string|null);
                }

                /** Represents a RouterInterface. */
                class RouterInterface implements IRouterInterface {

                    /**
                     * Constructs a new RouterInterface.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterInterface);

                    /** RouterInterface ipRange. */
                    public ipRange?: (string|null);

                    /** RouterInterface linkedInterconnectAttachment. */
                    public linkedInterconnectAttachment?: (string|null);

                    /** RouterInterface linkedVpnTunnel. */
                    public linkedVpnTunnel?: (string|null);

                    /** RouterInterface managementType. */
                    public managementType?: (string|null);

                    /** RouterInterface name. */
                    public name?: (string|null);

                    /** RouterInterface privateIpAddress. */
                    public privateIpAddress?: (string|null);

                    /** RouterInterface redundantInterface. */
                    public redundantInterface?: (string|null);

                    /** RouterInterface subnetwork. */
                    public subnetwork?: (string|null);

                    /** RouterInterface _ipRange. */
                    public _ipRange?: "ipRange";

                    /** RouterInterface _linkedInterconnectAttachment. */
                    public _linkedInterconnectAttachment?: "linkedInterconnectAttachment";

                    /** RouterInterface _linkedVpnTunnel. */
                    public _linkedVpnTunnel?: "linkedVpnTunnel";

                    /** RouterInterface _managementType. */
                    public _managementType?: "managementType";

                    /** RouterInterface _name. */
                    public _name?: "name";

                    /** RouterInterface _privateIpAddress. */
                    public _privateIpAddress?: "privateIpAddress";

                    /** RouterInterface _redundantInterface. */
                    public _redundantInterface?: "redundantInterface";

                    /** RouterInterface _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /**
                     * Creates a new RouterInterface instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterInterface instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterInterface): google.cloud.compute.v1.RouterInterface;

                    /**
                     * Encodes the specified RouterInterface message. Does not implicitly {@link google.cloud.compute.v1.RouterInterface.verify|verify} messages.
                     * @param message RouterInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterInterface message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterInterface.verify|verify} messages.
                     * @param message RouterInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterInterface message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterInterface;

                    /**
                     * Decodes a RouterInterface message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterInterface;

                    /**
                     * Verifies a RouterInterface message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterInterface message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterInterface
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterInterface;

                    /**
                     * Creates a plain object from a RouterInterface message. Also converts values to other types if specified.
                     * @param message RouterInterface
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterInterface, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterInterface to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterInterface
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterInterface {

                    /** ManagementType enum. */
                    enum ManagementType {
                        UNDEFINED_MANAGEMENT_TYPE = 0,
                        MANAGED_BY_ATTACHMENT = 458926411,
                        MANAGED_BY_USER = 317294067
                    }
                }

                /** Properties of a RouterList. */
                interface IRouterList {

                    /** RouterList id */
                    id?: (string|null);

                    /** RouterList items */
                    items?: (google.cloud.compute.v1.IRouter[]|null);

                    /** RouterList kind */
                    kind?: (string|null);

                    /** RouterList nextPageToken */
                    nextPageToken?: (string|null);

                    /** RouterList selfLink */
                    selfLink?: (string|null);

                    /** RouterList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RouterList. */
                class RouterList implements IRouterList {

                    /**
                     * Constructs a new RouterList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterList);

                    /** RouterList id. */
                    public id?: (string|null);

                    /** RouterList items. */
                    public items: google.cloud.compute.v1.IRouter[];

                    /** RouterList kind. */
                    public kind?: (string|null);

                    /** RouterList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** RouterList selfLink. */
                    public selfLink?: (string|null);

                    /** RouterList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RouterList _id. */
                    public _id?: "id";

                    /** RouterList _kind. */
                    public _kind?: "kind";

                    /** RouterList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** RouterList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** RouterList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RouterList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterList): google.cloud.compute.v1.RouterList;

                    /**
                     * Encodes the specified RouterList message. Does not implicitly {@link google.cloud.compute.v1.RouterList.verify|verify} messages.
                     * @param message RouterList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterList.verify|verify} messages.
                     * @param message RouterList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterList;

                    /**
                     * Decodes a RouterList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterList;

                    /**
                     * Verifies a RouterList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterList;

                    /**
                     * Creates a plain object from a RouterList message. Also converts values to other types if specified.
                     * @param message RouterList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterMd5AuthenticationKey. */
                interface IRouterMd5AuthenticationKey {

                    /** RouterMd5AuthenticationKey key */
                    key?: (string|null);

                    /** RouterMd5AuthenticationKey name */
                    name?: (string|null);
                }

                /** Represents a RouterMd5AuthenticationKey. */
                class RouterMd5AuthenticationKey implements IRouterMd5AuthenticationKey {

                    /**
                     * Constructs a new RouterMd5AuthenticationKey.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterMd5AuthenticationKey);

                    /** RouterMd5AuthenticationKey key. */
                    public key?: (string|null);

                    /** RouterMd5AuthenticationKey name. */
                    public name?: (string|null);

                    /** RouterMd5AuthenticationKey _key. */
                    public _key?: "key";

                    /** RouterMd5AuthenticationKey _name. */
                    public _name?: "name";

                    /**
                     * Creates a new RouterMd5AuthenticationKey instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterMd5AuthenticationKey instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterMd5AuthenticationKey): google.cloud.compute.v1.RouterMd5AuthenticationKey;

                    /**
                     * Encodes the specified RouterMd5AuthenticationKey message. Does not implicitly {@link google.cloud.compute.v1.RouterMd5AuthenticationKey.verify|verify} messages.
                     * @param message RouterMd5AuthenticationKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterMd5AuthenticationKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterMd5AuthenticationKey message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterMd5AuthenticationKey.verify|verify} messages.
                     * @param message RouterMd5AuthenticationKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterMd5AuthenticationKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterMd5AuthenticationKey message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterMd5AuthenticationKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterMd5AuthenticationKey;

                    /**
                     * Decodes a RouterMd5AuthenticationKey message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterMd5AuthenticationKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterMd5AuthenticationKey;

                    /**
                     * Verifies a RouterMd5AuthenticationKey message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterMd5AuthenticationKey message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterMd5AuthenticationKey
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterMd5AuthenticationKey;

                    /**
                     * Creates a plain object from a RouterMd5AuthenticationKey message. Also converts values to other types if specified.
                     * @param message RouterMd5AuthenticationKey
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterMd5AuthenticationKey, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterMd5AuthenticationKey to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterMd5AuthenticationKey
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterNat. */
                interface IRouterNat {

                    /** RouterNat drainNatIps */
                    drainNatIps?: (string[]|null);

                    /** RouterNat enableDynamicPortAllocation */
                    enableDynamicPortAllocation?: (boolean|null);

                    /** RouterNat enableEndpointIndependentMapping */
                    enableEndpointIndependentMapping?: (boolean|null);

                    /** RouterNat endpointTypes */
                    endpointTypes?: (string[]|null);

                    /** RouterNat icmpIdleTimeoutSec */
                    icmpIdleTimeoutSec?: (number|null);

                    /** RouterNat logConfig */
                    logConfig?: (google.cloud.compute.v1.IRouterNatLogConfig|null);

                    /** RouterNat maxPortsPerVm */
                    maxPortsPerVm?: (number|null);

                    /** RouterNat minPortsPerVm */
                    minPortsPerVm?: (number|null);

                    /** RouterNat name */
                    name?: (string|null);

                    /** RouterNat natIpAllocateOption */
                    natIpAllocateOption?: (string|null);

                    /** RouterNat natIps */
                    natIps?: (string[]|null);

                    /** RouterNat rules */
                    rules?: (google.cloud.compute.v1.IRouterNatRule[]|null);

                    /** RouterNat sourceSubnetworkIpRangesToNat */
                    sourceSubnetworkIpRangesToNat?: (string|null);

                    /** RouterNat subnetworks */
                    subnetworks?: (google.cloud.compute.v1.IRouterNatSubnetworkToNat[]|null);

                    /** RouterNat tcpEstablishedIdleTimeoutSec */
                    tcpEstablishedIdleTimeoutSec?: (number|null);

                    /** RouterNat tcpTimeWaitTimeoutSec */
                    tcpTimeWaitTimeoutSec?: (number|null);

                    /** RouterNat tcpTransitoryIdleTimeoutSec */
                    tcpTransitoryIdleTimeoutSec?: (number|null);

                    /** RouterNat udpIdleTimeoutSec */
                    udpIdleTimeoutSec?: (number|null);
                }

                /** Represents a RouterNat. */
                class RouterNat implements IRouterNat {

                    /**
                     * Constructs a new RouterNat.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterNat);

                    /** RouterNat drainNatIps. */
                    public drainNatIps: string[];

                    /** RouterNat enableDynamicPortAllocation. */
                    public enableDynamicPortAllocation?: (boolean|null);

                    /** RouterNat enableEndpointIndependentMapping. */
                    public enableEndpointIndependentMapping?: (boolean|null);

                    /** RouterNat endpointTypes. */
                    public endpointTypes: string[];

                    /** RouterNat icmpIdleTimeoutSec. */
                    public icmpIdleTimeoutSec?: (number|null);

                    /** RouterNat logConfig. */
                    public logConfig?: (google.cloud.compute.v1.IRouterNatLogConfig|null);

                    /** RouterNat maxPortsPerVm. */
                    public maxPortsPerVm?: (number|null);

                    /** RouterNat minPortsPerVm. */
                    public minPortsPerVm?: (number|null);

                    /** RouterNat name. */
                    public name?: (string|null);

                    /** RouterNat natIpAllocateOption. */
                    public natIpAllocateOption?: (string|null);

                    /** RouterNat natIps. */
                    public natIps: string[];

                    /** RouterNat rules. */
                    public rules: google.cloud.compute.v1.IRouterNatRule[];

                    /** RouterNat sourceSubnetworkIpRangesToNat. */
                    public sourceSubnetworkIpRangesToNat?: (string|null);

                    /** RouterNat subnetworks. */
                    public subnetworks: google.cloud.compute.v1.IRouterNatSubnetworkToNat[];

                    /** RouterNat tcpEstablishedIdleTimeoutSec. */
                    public tcpEstablishedIdleTimeoutSec?: (number|null);

                    /** RouterNat tcpTimeWaitTimeoutSec. */
                    public tcpTimeWaitTimeoutSec?: (number|null);

                    /** RouterNat tcpTransitoryIdleTimeoutSec. */
                    public tcpTransitoryIdleTimeoutSec?: (number|null);

                    /** RouterNat udpIdleTimeoutSec. */
                    public udpIdleTimeoutSec?: (number|null);

                    /** RouterNat _enableDynamicPortAllocation. */
                    public _enableDynamicPortAllocation?: "enableDynamicPortAllocation";

                    /** RouterNat _enableEndpointIndependentMapping. */
                    public _enableEndpointIndependentMapping?: "enableEndpointIndependentMapping";

                    /** RouterNat _icmpIdleTimeoutSec. */
                    public _icmpIdleTimeoutSec?: "icmpIdleTimeoutSec";

                    /** RouterNat _logConfig. */
                    public _logConfig?: "logConfig";

                    /** RouterNat _maxPortsPerVm. */
                    public _maxPortsPerVm?: "maxPortsPerVm";

                    /** RouterNat _minPortsPerVm. */
                    public _minPortsPerVm?: "minPortsPerVm";

                    /** RouterNat _name. */
                    public _name?: "name";

                    /** RouterNat _natIpAllocateOption. */
                    public _natIpAllocateOption?: "natIpAllocateOption";

                    /** RouterNat _sourceSubnetworkIpRangesToNat. */
                    public _sourceSubnetworkIpRangesToNat?: "sourceSubnetworkIpRangesToNat";

                    /** RouterNat _tcpEstablishedIdleTimeoutSec. */
                    public _tcpEstablishedIdleTimeoutSec?: "tcpEstablishedIdleTimeoutSec";

                    /** RouterNat _tcpTimeWaitTimeoutSec. */
                    public _tcpTimeWaitTimeoutSec?: "tcpTimeWaitTimeoutSec";

                    /** RouterNat _tcpTransitoryIdleTimeoutSec. */
                    public _tcpTransitoryIdleTimeoutSec?: "tcpTransitoryIdleTimeoutSec";

                    /** RouterNat _udpIdleTimeoutSec. */
                    public _udpIdleTimeoutSec?: "udpIdleTimeoutSec";

                    /**
                     * Creates a new RouterNat instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterNat instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterNat): google.cloud.compute.v1.RouterNat;

                    /**
                     * Encodes the specified RouterNat message. Does not implicitly {@link google.cloud.compute.v1.RouterNat.verify|verify} messages.
                     * @param message RouterNat message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterNat, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterNat message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterNat.verify|verify} messages.
                     * @param message RouterNat message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterNat, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterNat message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterNat
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterNat;

                    /**
                     * Decodes a RouterNat message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterNat
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterNat;

                    /**
                     * Verifies a RouterNat message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterNat message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterNat
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterNat;

                    /**
                     * Creates a plain object from a RouterNat message. Also converts values to other types if specified.
                     * @param message RouterNat
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterNat, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterNat to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterNat
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterNat {

                    /** EndpointTypes enum. */
                    enum EndpointTypes {
                        UNDEFINED_ENDPOINT_TYPES = 0,
                        ENDPOINT_TYPE_SWG = 159344456,
                        ENDPOINT_TYPE_VM = 57095474
                    }

                    /** NatIpAllocateOption enum. */
                    enum NatIpAllocateOption {
                        UNDEFINED_NAT_IP_ALLOCATE_OPTION = 0,
                        AUTO_ONLY = 182333500,
                        MANUAL_ONLY = 261251205
                    }

                    /** SourceSubnetworkIpRangesToNat enum. */
                    enum SourceSubnetworkIpRangesToNat {
                        UNDEFINED_SOURCE_SUBNETWORK_IP_RANGES_TO_NAT = 0,
                        ALL_SUBNETWORKS_ALL_IP_RANGES = 179964376,
                        ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES = 185573819,
                        LIST_OF_SUBNETWORKS = 517542270
                    }
                }

                /** Properties of a RouterNatLogConfig. */
                interface IRouterNatLogConfig {

                    /** RouterNatLogConfig enable */
                    enable?: (boolean|null);

                    /** RouterNatLogConfig filter */
                    filter?: (string|null);
                }

                /** Represents a RouterNatLogConfig. */
                class RouterNatLogConfig implements IRouterNatLogConfig {

                    /**
                     * Constructs a new RouterNatLogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterNatLogConfig);

                    /** RouterNatLogConfig enable. */
                    public enable?: (boolean|null);

                    /** RouterNatLogConfig filter. */
                    public filter?: (string|null);

                    /** RouterNatLogConfig _enable. */
                    public _enable?: "enable";

                    /** RouterNatLogConfig _filter. */
                    public _filter?: "filter";

                    /**
                     * Creates a new RouterNatLogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterNatLogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterNatLogConfig): google.cloud.compute.v1.RouterNatLogConfig;

                    /**
                     * Encodes the specified RouterNatLogConfig message. Does not implicitly {@link google.cloud.compute.v1.RouterNatLogConfig.verify|verify} messages.
                     * @param message RouterNatLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterNatLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterNatLogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterNatLogConfig.verify|verify} messages.
                     * @param message RouterNatLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterNatLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterNatLogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterNatLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterNatLogConfig;

                    /**
                     * Decodes a RouterNatLogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterNatLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterNatLogConfig;

                    /**
                     * Verifies a RouterNatLogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterNatLogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterNatLogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterNatLogConfig;

                    /**
                     * Creates a plain object from a RouterNatLogConfig message. Also converts values to other types if specified.
                     * @param message RouterNatLogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterNatLogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterNatLogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterNatLogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterNatLogConfig {

                    /** Filter enum. */
                    enum Filter {
                        UNDEFINED_FILTER = 0,
                        ALL = 64897,
                        ERRORS_ONLY = 307484672,
                        TRANSLATIONS_ONLY = 357212649
                    }
                }

                /** Properties of a RouterNatRule. */
                interface IRouterNatRule {

                    /** RouterNatRule action */
                    action?: (google.cloud.compute.v1.IRouterNatRuleAction|null);

                    /** RouterNatRule description */
                    description?: (string|null);

                    /** RouterNatRule match */
                    match?: (string|null);

                    /** RouterNatRule ruleNumber */
                    ruleNumber?: (number|null);
                }

                /** Represents a RouterNatRule. */
                class RouterNatRule implements IRouterNatRule {

                    /**
                     * Constructs a new RouterNatRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterNatRule);

                    /** RouterNatRule action. */
                    public action?: (google.cloud.compute.v1.IRouterNatRuleAction|null);

                    /** RouterNatRule description. */
                    public description?: (string|null);

                    /** RouterNatRule match. */
                    public match?: (string|null);

                    /** RouterNatRule ruleNumber. */
                    public ruleNumber?: (number|null);

                    /** RouterNatRule _action. */
                    public _action?: "action";

                    /** RouterNatRule _description. */
                    public _description?: "description";

                    /** RouterNatRule _match. */
                    public _match?: "match";

                    /** RouterNatRule _ruleNumber. */
                    public _ruleNumber?: "ruleNumber";

                    /**
                     * Creates a new RouterNatRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterNatRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterNatRule): google.cloud.compute.v1.RouterNatRule;

                    /**
                     * Encodes the specified RouterNatRule message. Does not implicitly {@link google.cloud.compute.v1.RouterNatRule.verify|verify} messages.
                     * @param message RouterNatRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterNatRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterNatRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterNatRule.verify|verify} messages.
                     * @param message RouterNatRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterNatRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterNatRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterNatRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterNatRule;

                    /**
                     * Decodes a RouterNatRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterNatRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterNatRule;

                    /**
                     * Verifies a RouterNatRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterNatRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterNatRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterNatRule;

                    /**
                     * Creates a plain object from a RouterNatRule message. Also converts values to other types if specified.
                     * @param message RouterNatRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterNatRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterNatRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterNatRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterNatRuleAction. */
                interface IRouterNatRuleAction {

                    /** RouterNatRuleAction sourceNatActiveIps */
                    sourceNatActiveIps?: (string[]|null);

                    /** RouterNatRuleAction sourceNatDrainIps */
                    sourceNatDrainIps?: (string[]|null);
                }

                /** Represents a RouterNatRuleAction. */
                class RouterNatRuleAction implements IRouterNatRuleAction {

                    /**
                     * Constructs a new RouterNatRuleAction.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterNatRuleAction);

                    /** RouterNatRuleAction sourceNatActiveIps. */
                    public sourceNatActiveIps: string[];

                    /** RouterNatRuleAction sourceNatDrainIps. */
                    public sourceNatDrainIps: string[];

                    /**
                     * Creates a new RouterNatRuleAction instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterNatRuleAction instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterNatRuleAction): google.cloud.compute.v1.RouterNatRuleAction;

                    /**
                     * Encodes the specified RouterNatRuleAction message. Does not implicitly {@link google.cloud.compute.v1.RouterNatRuleAction.verify|verify} messages.
                     * @param message RouterNatRuleAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterNatRuleAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterNatRuleAction message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterNatRuleAction.verify|verify} messages.
                     * @param message RouterNatRuleAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterNatRuleAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterNatRuleAction message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterNatRuleAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterNatRuleAction;

                    /**
                     * Decodes a RouterNatRuleAction message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterNatRuleAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterNatRuleAction;

                    /**
                     * Verifies a RouterNatRuleAction message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterNatRuleAction message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterNatRuleAction
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterNatRuleAction;

                    /**
                     * Creates a plain object from a RouterNatRuleAction message. Also converts values to other types if specified.
                     * @param message RouterNatRuleAction
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterNatRuleAction, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterNatRuleAction to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterNatRuleAction
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterNatSubnetworkToNat. */
                interface IRouterNatSubnetworkToNat {

                    /** RouterNatSubnetworkToNat name */
                    name?: (string|null);

                    /** RouterNatSubnetworkToNat secondaryIpRangeNames */
                    secondaryIpRangeNames?: (string[]|null);

                    /** RouterNatSubnetworkToNat sourceIpRangesToNat */
                    sourceIpRangesToNat?: (string[]|null);
                }

                /** Represents a RouterNatSubnetworkToNat. */
                class RouterNatSubnetworkToNat implements IRouterNatSubnetworkToNat {

                    /**
                     * Constructs a new RouterNatSubnetworkToNat.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterNatSubnetworkToNat);

                    /** RouterNatSubnetworkToNat name. */
                    public name?: (string|null);

                    /** RouterNatSubnetworkToNat secondaryIpRangeNames. */
                    public secondaryIpRangeNames: string[];

                    /** RouterNatSubnetworkToNat sourceIpRangesToNat. */
                    public sourceIpRangesToNat: string[];

                    /** RouterNatSubnetworkToNat _name. */
                    public _name?: "name";

                    /**
                     * Creates a new RouterNatSubnetworkToNat instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterNatSubnetworkToNat instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterNatSubnetworkToNat): google.cloud.compute.v1.RouterNatSubnetworkToNat;

                    /**
                     * Encodes the specified RouterNatSubnetworkToNat message. Does not implicitly {@link google.cloud.compute.v1.RouterNatSubnetworkToNat.verify|verify} messages.
                     * @param message RouterNatSubnetworkToNat message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterNatSubnetworkToNat, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterNatSubnetworkToNat message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterNatSubnetworkToNat.verify|verify} messages.
                     * @param message RouterNatSubnetworkToNat message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterNatSubnetworkToNat, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterNatSubnetworkToNat message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterNatSubnetworkToNat
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterNatSubnetworkToNat;

                    /**
                     * Decodes a RouterNatSubnetworkToNat message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterNatSubnetworkToNat
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterNatSubnetworkToNat;

                    /**
                     * Verifies a RouterNatSubnetworkToNat message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterNatSubnetworkToNat message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterNatSubnetworkToNat
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterNatSubnetworkToNat;

                    /**
                     * Creates a plain object from a RouterNatSubnetworkToNat message. Also converts values to other types if specified.
                     * @param message RouterNatSubnetworkToNat
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterNatSubnetworkToNat, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterNatSubnetworkToNat to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterNatSubnetworkToNat
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterNatSubnetworkToNat {

                    /** SourceIpRangesToNat enum. */
                    enum SourceIpRangesToNat {
                        UNDEFINED_SOURCE_IP_RANGES_TO_NAT = 0,
                        ALL_IP_RANGES = 35608496,
                        LIST_OF_SECONDARY_IP_RANGES = 192289308,
                        PRIMARY_IP_RANGE = 297109954
                    }
                }

                /** Properties of a RouterStatus. */
                interface IRouterStatus {

                    /** RouterStatus bestRoutes */
                    bestRoutes?: (google.cloud.compute.v1.IRoute[]|null);

                    /** RouterStatus bestRoutesForRouter */
                    bestRoutesForRouter?: (google.cloud.compute.v1.IRoute[]|null);

                    /** RouterStatus bgpPeerStatus */
                    bgpPeerStatus?: (google.cloud.compute.v1.IRouterStatusBgpPeerStatus[]|null);

                    /** RouterStatus natStatus */
                    natStatus?: (google.cloud.compute.v1.IRouterStatusNatStatus[]|null);

                    /** RouterStatus network */
                    network?: (string|null);
                }

                /** Represents a RouterStatus. */
                class RouterStatus implements IRouterStatus {

                    /**
                     * Constructs a new RouterStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterStatus);

                    /** RouterStatus bestRoutes. */
                    public bestRoutes: google.cloud.compute.v1.IRoute[];

                    /** RouterStatus bestRoutesForRouter. */
                    public bestRoutesForRouter: google.cloud.compute.v1.IRoute[];

                    /** RouterStatus bgpPeerStatus. */
                    public bgpPeerStatus: google.cloud.compute.v1.IRouterStatusBgpPeerStatus[];

                    /** RouterStatus natStatus. */
                    public natStatus: google.cloud.compute.v1.IRouterStatusNatStatus[];

                    /** RouterStatus network. */
                    public network?: (string|null);

                    /** RouterStatus _network. */
                    public _network?: "network";

                    /**
                     * Creates a new RouterStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterStatus): google.cloud.compute.v1.RouterStatus;

                    /**
                     * Encodes the specified RouterStatus message. Does not implicitly {@link google.cloud.compute.v1.RouterStatus.verify|verify} messages.
                     * @param message RouterStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterStatus.verify|verify} messages.
                     * @param message RouterStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterStatus;

                    /**
                     * Decodes a RouterStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterStatus;

                    /**
                     * Verifies a RouterStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterStatus;

                    /**
                     * Creates a plain object from a RouterStatus message. Also converts values to other types if specified.
                     * @param message RouterStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterStatusBgpPeerStatus. */
                interface IRouterStatusBgpPeerStatus {

                    /** RouterStatusBgpPeerStatus advertisedRoutes */
                    advertisedRoutes?: (google.cloud.compute.v1.IRoute[]|null);

                    /** RouterStatusBgpPeerStatus bfdStatus */
                    bfdStatus?: (google.cloud.compute.v1.IBfdStatus|null);

                    /** RouterStatusBgpPeerStatus enableIpv6 */
                    enableIpv6?: (boolean|null);

                    /** RouterStatusBgpPeerStatus ipAddress */
                    ipAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus ipv6NexthopAddress */
                    ipv6NexthopAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus linkedVpnTunnel */
                    linkedVpnTunnel?: (string|null);

                    /** RouterStatusBgpPeerStatus md5AuthEnabled */
                    md5AuthEnabled?: (boolean|null);

                    /** RouterStatusBgpPeerStatus name */
                    name?: (string|null);

                    /** RouterStatusBgpPeerStatus numLearnedRoutes */
                    numLearnedRoutes?: (number|null);

                    /** RouterStatusBgpPeerStatus peerIpAddress */
                    peerIpAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus peerIpv6NexthopAddress */
                    peerIpv6NexthopAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus routerApplianceInstance */
                    routerApplianceInstance?: (string|null);

                    /** RouterStatusBgpPeerStatus state */
                    state?: (string|null);

                    /** RouterStatusBgpPeerStatus status */
                    status?: (string|null);

                    /** RouterStatusBgpPeerStatus statusReason */
                    statusReason?: (string|null);

                    /** RouterStatusBgpPeerStatus uptime */
                    uptime?: (string|null);

                    /** RouterStatusBgpPeerStatus uptimeSeconds */
                    uptimeSeconds?: (string|null);
                }

                /** Represents a RouterStatusBgpPeerStatus. */
                class RouterStatusBgpPeerStatus implements IRouterStatusBgpPeerStatus {

                    /**
                     * Constructs a new RouterStatusBgpPeerStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterStatusBgpPeerStatus);

                    /** RouterStatusBgpPeerStatus advertisedRoutes. */
                    public advertisedRoutes: google.cloud.compute.v1.IRoute[];

                    /** RouterStatusBgpPeerStatus bfdStatus. */
                    public bfdStatus?: (google.cloud.compute.v1.IBfdStatus|null);

                    /** RouterStatusBgpPeerStatus enableIpv6. */
                    public enableIpv6?: (boolean|null);

                    /** RouterStatusBgpPeerStatus ipAddress. */
                    public ipAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus ipv6NexthopAddress. */
                    public ipv6NexthopAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus linkedVpnTunnel. */
                    public linkedVpnTunnel?: (string|null);

                    /** RouterStatusBgpPeerStatus md5AuthEnabled. */
                    public md5AuthEnabled?: (boolean|null);

                    /** RouterStatusBgpPeerStatus name. */
                    public name?: (string|null);

                    /** RouterStatusBgpPeerStatus numLearnedRoutes. */
                    public numLearnedRoutes?: (number|null);

                    /** RouterStatusBgpPeerStatus peerIpAddress. */
                    public peerIpAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus peerIpv6NexthopAddress. */
                    public peerIpv6NexthopAddress?: (string|null);

                    /** RouterStatusBgpPeerStatus routerApplianceInstance. */
                    public routerApplianceInstance?: (string|null);

                    /** RouterStatusBgpPeerStatus state. */
                    public state?: (string|null);

                    /** RouterStatusBgpPeerStatus status. */
                    public status?: (string|null);

                    /** RouterStatusBgpPeerStatus statusReason. */
                    public statusReason?: (string|null);

                    /** RouterStatusBgpPeerStatus uptime. */
                    public uptime?: (string|null);

                    /** RouterStatusBgpPeerStatus uptimeSeconds. */
                    public uptimeSeconds?: (string|null);

                    /** RouterStatusBgpPeerStatus _bfdStatus. */
                    public _bfdStatus?: "bfdStatus";

                    /** RouterStatusBgpPeerStatus _enableIpv6. */
                    public _enableIpv6?: "enableIpv6";

                    /** RouterStatusBgpPeerStatus _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /** RouterStatusBgpPeerStatus _ipv6NexthopAddress. */
                    public _ipv6NexthopAddress?: "ipv6NexthopAddress";

                    /** RouterStatusBgpPeerStatus _linkedVpnTunnel. */
                    public _linkedVpnTunnel?: "linkedVpnTunnel";

                    /** RouterStatusBgpPeerStatus _md5AuthEnabled. */
                    public _md5AuthEnabled?: "md5AuthEnabled";

                    /** RouterStatusBgpPeerStatus _name. */
                    public _name?: "name";

                    /** RouterStatusBgpPeerStatus _numLearnedRoutes. */
                    public _numLearnedRoutes?: "numLearnedRoutes";

                    /** RouterStatusBgpPeerStatus _peerIpAddress. */
                    public _peerIpAddress?: "peerIpAddress";

                    /** RouterStatusBgpPeerStatus _peerIpv6NexthopAddress. */
                    public _peerIpv6NexthopAddress?: "peerIpv6NexthopAddress";

                    /** RouterStatusBgpPeerStatus _routerApplianceInstance. */
                    public _routerApplianceInstance?: "routerApplianceInstance";

                    /** RouterStatusBgpPeerStatus _state. */
                    public _state?: "state";

                    /** RouterStatusBgpPeerStatus _status. */
                    public _status?: "status";

                    /** RouterStatusBgpPeerStatus _statusReason. */
                    public _statusReason?: "statusReason";

                    /** RouterStatusBgpPeerStatus _uptime. */
                    public _uptime?: "uptime";

                    /** RouterStatusBgpPeerStatus _uptimeSeconds. */
                    public _uptimeSeconds?: "uptimeSeconds";

                    /**
                     * Creates a new RouterStatusBgpPeerStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterStatusBgpPeerStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterStatusBgpPeerStatus): google.cloud.compute.v1.RouterStatusBgpPeerStatus;

                    /**
                     * Encodes the specified RouterStatusBgpPeerStatus message. Does not implicitly {@link google.cloud.compute.v1.RouterStatusBgpPeerStatus.verify|verify} messages.
                     * @param message RouterStatusBgpPeerStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterStatusBgpPeerStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterStatusBgpPeerStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterStatusBgpPeerStatus.verify|verify} messages.
                     * @param message RouterStatusBgpPeerStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterStatusBgpPeerStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterStatusBgpPeerStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterStatusBgpPeerStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterStatusBgpPeerStatus;

                    /**
                     * Decodes a RouterStatusBgpPeerStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterStatusBgpPeerStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterStatusBgpPeerStatus;

                    /**
                     * Verifies a RouterStatusBgpPeerStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterStatusBgpPeerStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterStatusBgpPeerStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterStatusBgpPeerStatus;

                    /**
                     * Creates a plain object from a RouterStatusBgpPeerStatus message. Also converts values to other types if specified.
                     * @param message RouterStatusBgpPeerStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterStatusBgpPeerStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterStatusBgpPeerStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterStatusBgpPeerStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RouterStatusBgpPeerStatus {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DOWN = 2104482,
                        UNKNOWN = 433141802,
                        UP = 2715
                    }

                    /** StatusReason enum. */
                    enum StatusReason {
                        UNDEFINED_STATUS_REASON = 0,
                        MD5_AUTH_INTERNAL_PROBLEM = 140462259,
                        STATUS_REASON_UNSPECIFIED = 394331913
                    }
                }

                /** Properties of a RouterStatusNatStatus. */
                interface IRouterStatusNatStatus {

                    /** RouterStatusNatStatus autoAllocatedNatIps */
                    autoAllocatedNatIps?: (string[]|null);

                    /** RouterStatusNatStatus drainAutoAllocatedNatIps */
                    drainAutoAllocatedNatIps?: (string[]|null);

                    /** RouterStatusNatStatus drainUserAllocatedNatIps */
                    drainUserAllocatedNatIps?: (string[]|null);

                    /** RouterStatusNatStatus minExtraNatIpsNeeded */
                    minExtraNatIpsNeeded?: (number|null);

                    /** RouterStatusNatStatus name */
                    name?: (string|null);

                    /** RouterStatusNatStatus numVmEndpointsWithNatMappings */
                    numVmEndpointsWithNatMappings?: (number|null);

                    /** RouterStatusNatStatus ruleStatus */
                    ruleStatus?: (google.cloud.compute.v1.IRouterStatusNatStatusNatRuleStatus[]|null);

                    /** RouterStatusNatStatus userAllocatedNatIpResources */
                    userAllocatedNatIpResources?: (string[]|null);

                    /** RouterStatusNatStatus userAllocatedNatIps */
                    userAllocatedNatIps?: (string[]|null);
                }

                /** Represents a RouterStatusNatStatus. */
                class RouterStatusNatStatus implements IRouterStatusNatStatus {

                    /**
                     * Constructs a new RouterStatusNatStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterStatusNatStatus);

                    /** RouterStatusNatStatus autoAllocatedNatIps. */
                    public autoAllocatedNatIps: string[];

                    /** RouterStatusNatStatus drainAutoAllocatedNatIps. */
                    public drainAutoAllocatedNatIps: string[];

                    /** RouterStatusNatStatus drainUserAllocatedNatIps. */
                    public drainUserAllocatedNatIps: string[];

                    /** RouterStatusNatStatus minExtraNatIpsNeeded. */
                    public minExtraNatIpsNeeded?: (number|null);

                    /** RouterStatusNatStatus name. */
                    public name?: (string|null);

                    /** RouterStatusNatStatus numVmEndpointsWithNatMappings. */
                    public numVmEndpointsWithNatMappings?: (number|null);

                    /** RouterStatusNatStatus ruleStatus. */
                    public ruleStatus: google.cloud.compute.v1.IRouterStatusNatStatusNatRuleStatus[];

                    /** RouterStatusNatStatus userAllocatedNatIpResources. */
                    public userAllocatedNatIpResources: string[];

                    /** RouterStatusNatStatus userAllocatedNatIps. */
                    public userAllocatedNatIps: string[];

                    /** RouterStatusNatStatus _minExtraNatIpsNeeded. */
                    public _minExtraNatIpsNeeded?: "minExtraNatIpsNeeded";

                    /** RouterStatusNatStatus _name. */
                    public _name?: "name";

                    /** RouterStatusNatStatus _numVmEndpointsWithNatMappings. */
                    public _numVmEndpointsWithNatMappings?: "numVmEndpointsWithNatMappings";

                    /**
                     * Creates a new RouterStatusNatStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterStatusNatStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterStatusNatStatus): google.cloud.compute.v1.RouterStatusNatStatus;

                    /**
                     * Encodes the specified RouterStatusNatStatus message. Does not implicitly {@link google.cloud.compute.v1.RouterStatusNatStatus.verify|verify} messages.
                     * @param message RouterStatusNatStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterStatusNatStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterStatusNatStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterStatusNatStatus.verify|verify} messages.
                     * @param message RouterStatusNatStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterStatusNatStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterStatusNatStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterStatusNatStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterStatusNatStatus;

                    /**
                     * Decodes a RouterStatusNatStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterStatusNatStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterStatusNatStatus;

                    /**
                     * Verifies a RouterStatusNatStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterStatusNatStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterStatusNatStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterStatusNatStatus;

                    /**
                     * Creates a plain object from a RouterStatusNatStatus message. Also converts values to other types if specified.
                     * @param message RouterStatusNatStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterStatusNatStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterStatusNatStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterStatusNatStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterStatusNatStatusNatRuleStatus. */
                interface IRouterStatusNatStatusNatRuleStatus {

                    /** RouterStatusNatStatusNatRuleStatus activeNatIps */
                    activeNatIps?: (string[]|null);

                    /** RouterStatusNatStatusNatRuleStatus drainNatIps */
                    drainNatIps?: (string[]|null);

                    /** RouterStatusNatStatusNatRuleStatus minExtraIpsNeeded */
                    minExtraIpsNeeded?: (number|null);

                    /** RouterStatusNatStatusNatRuleStatus numVmEndpointsWithNatMappings */
                    numVmEndpointsWithNatMappings?: (number|null);

                    /** RouterStatusNatStatusNatRuleStatus ruleNumber */
                    ruleNumber?: (number|null);
                }

                /** Represents a RouterStatusNatStatusNatRuleStatus. */
                class RouterStatusNatStatusNatRuleStatus implements IRouterStatusNatStatusNatRuleStatus {

                    /**
                     * Constructs a new RouterStatusNatStatusNatRuleStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterStatusNatStatusNatRuleStatus);

                    /** RouterStatusNatStatusNatRuleStatus activeNatIps. */
                    public activeNatIps: string[];

                    /** RouterStatusNatStatusNatRuleStatus drainNatIps. */
                    public drainNatIps: string[];

                    /** RouterStatusNatStatusNatRuleStatus minExtraIpsNeeded. */
                    public minExtraIpsNeeded?: (number|null);

                    /** RouterStatusNatStatusNatRuleStatus numVmEndpointsWithNatMappings. */
                    public numVmEndpointsWithNatMappings?: (number|null);

                    /** RouterStatusNatStatusNatRuleStatus ruleNumber. */
                    public ruleNumber?: (number|null);

                    /** RouterStatusNatStatusNatRuleStatus _minExtraIpsNeeded. */
                    public _minExtraIpsNeeded?: "minExtraIpsNeeded";

                    /** RouterStatusNatStatusNatRuleStatus _numVmEndpointsWithNatMappings. */
                    public _numVmEndpointsWithNatMappings?: "numVmEndpointsWithNatMappings";

                    /** RouterStatusNatStatusNatRuleStatus _ruleNumber. */
                    public _ruleNumber?: "ruleNumber";

                    /**
                     * Creates a new RouterStatusNatStatusNatRuleStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterStatusNatStatusNatRuleStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterStatusNatStatusNatRuleStatus): google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus;

                    /**
                     * Encodes the specified RouterStatusNatStatusNatRuleStatus message. Does not implicitly {@link google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus.verify|verify} messages.
                     * @param message RouterStatusNatStatusNatRuleStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterStatusNatStatusNatRuleStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterStatusNatStatusNatRuleStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus.verify|verify} messages.
                     * @param message RouterStatusNatStatusNatRuleStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterStatusNatStatusNatRuleStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterStatusNatStatusNatRuleStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterStatusNatStatusNatRuleStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus;

                    /**
                     * Decodes a RouterStatusNatStatusNatRuleStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterStatusNatStatusNatRuleStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus;

                    /**
                     * Verifies a RouterStatusNatStatusNatRuleStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterStatusNatStatusNatRuleStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterStatusNatStatusNatRuleStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus;

                    /**
                     * Creates a plain object from a RouterStatusNatStatusNatRuleStatus message. Also converts values to other types if specified.
                     * @param message RouterStatusNatStatusNatRuleStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterStatusNatStatusNatRuleStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterStatusNatStatusNatRuleStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterStatusNatStatusNatRuleStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RouterStatusResponse. */
                interface IRouterStatusResponse {

                    /** RouterStatusResponse kind */
                    kind?: (string|null);

                    /** RouterStatusResponse result */
                    result?: (google.cloud.compute.v1.IRouterStatus|null);
                }

                /** Represents a RouterStatusResponse. */
                class RouterStatusResponse implements IRouterStatusResponse {

                    /**
                     * Constructs a new RouterStatusResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRouterStatusResponse);

                    /** RouterStatusResponse kind. */
                    public kind?: (string|null);

                    /** RouterStatusResponse result. */
                    public result?: (google.cloud.compute.v1.IRouterStatus|null);

                    /** RouterStatusResponse _kind. */
                    public _kind?: "kind";

                    /** RouterStatusResponse _result. */
                    public _result?: "result";

                    /**
                     * Creates a new RouterStatusResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RouterStatusResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRouterStatusResponse): google.cloud.compute.v1.RouterStatusResponse;

                    /**
                     * Encodes the specified RouterStatusResponse message. Does not implicitly {@link google.cloud.compute.v1.RouterStatusResponse.verify|verify} messages.
                     * @param message RouterStatusResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRouterStatusResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RouterStatusResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RouterStatusResponse.verify|verify} messages.
                     * @param message RouterStatusResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRouterStatusResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RouterStatusResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RouterStatusResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RouterStatusResponse;

                    /**
                     * Decodes a RouterStatusResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RouterStatusResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RouterStatusResponse;

                    /**
                     * Verifies a RouterStatusResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RouterStatusResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RouterStatusResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RouterStatusResponse;

                    /**
                     * Creates a plain object from a RouterStatusResponse message. Also converts values to other types if specified.
                     * @param message RouterStatusResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RouterStatusResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RouterStatusResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RouterStatusResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RoutersPreviewResponse. */
                interface IRoutersPreviewResponse {

                    /** RoutersPreviewResponse resource */
                    resource?: (google.cloud.compute.v1.IRouter|null);
                }

                /** Represents a RoutersPreviewResponse. */
                class RoutersPreviewResponse implements IRoutersPreviewResponse {

                    /**
                     * Constructs a new RoutersPreviewResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRoutersPreviewResponse);

                    /** RoutersPreviewResponse resource. */
                    public resource?: (google.cloud.compute.v1.IRouter|null);

                    /** RoutersPreviewResponse _resource. */
                    public _resource?: "resource";

                    /**
                     * Creates a new RoutersPreviewResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RoutersPreviewResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRoutersPreviewResponse): google.cloud.compute.v1.RoutersPreviewResponse;

                    /**
                     * Encodes the specified RoutersPreviewResponse message. Does not implicitly {@link google.cloud.compute.v1.RoutersPreviewResponse.verify|verify} messages.
                     * @param message RoutersPreviewResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRoutersPreviewResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RoutersPreviewResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RoutersPreviewResponse.verify|verify} messages.
                     * @param message RoutersPreviewResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRoutersPreviewResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RoutersPreviewResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RoutersPreviewResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RoutersPreviewResponse;

                    /**
                     * Decodes a RoutersPreviewResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RoutersPreviewResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RoutersPreviewResponse;

                    /**
                     * Verifies a RoutersPreviewResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RoutersPreviewResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RoutersPreviewResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RoutersPreviewResponse;

                    /**
                     * Creates a plain object from a RoutersPreviewResponse message. Also converts values to other types if specified.
                     * @param message RoutersPreviewResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RoutersPreviewResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RoutersPreviewResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RoutersPreviewResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RoutersScopedList. */
                interface IRoutersScopedList {

                    /** RoutersScopedList routers */
                    routers?: (google.cloud.compute.v1.IRouter[]|null);

                    /** RoutersScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a RoutersScopedList. */
                class RoutersScopedList implements IRoutersScopedList {

                    /**
                     * Constructs a new RoutersScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRoutersScopedList);

                    /** RoutersScopedList routers. */
                    public routers: google.cloud.compute.v1.IRouter[];

                    /** RoutersScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** RoutersScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new RoutersScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RoutersScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRoutersScopedList): google.cloud.compute.v1.RoutersScopedList;

                    /**
                     * Encodes the specified RoutersScopedList message. Does not implicitly {@link google.cloud.compute.v1.RoutersScopedList.verify|verify} messages.
                     * @param message RoutersScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRoutersScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RoutersScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.RoutersScopedList.verify|verify} messages.
                     * @param message RoutersScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRoutersScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RoutersScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RoutersScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.RoutersScopedList;

                    /**
                     * Decodes a RoutersScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RoutersScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.RoutersScopedList;

                    /**
                     * Verifies a RoutersScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RoutersScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RoutersScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.RoutersScopedList;

                    /**
                     * Creates a plain object from a RoutersScopedList message. Also converts values to other types if specified.
                     * @param message RoutersScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.RoutersScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RoutersScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RoutersScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Rule. */
                interface IRule {

                    /** Rule action */
                    action?: (string|null);

                    /** Rule conditions */
                    conditions?: (google.cloud.compute.v1.ICondition[]|null);

                    /** Rule description */
                    description?: (string|null);

                    /** Rule ins */
                    ins?: (string[]|null);

                    /** Rule logConfigs */
                    logConfigs?: (google.cloud.compute.v1.ILogConfig[]|null);

                    /** Rule notIns */
                    notIns?: (string[]|null);

                    /** Rule permissions */
                    permissions?: (string[]|null);
                }

                /** Represents a Rule. */
                class Rule implements IRule {

                    /**
                     * Constructs a new Rule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IRule);

                    /** Rule action. */
                    public action?: (string|null);

                    /** Rule conditions. */
                    public conditions: google.cloud.compute.v1.ICondition[];

                    /** Rule description. */
                    public description?: (string|null);

                    /** Rule ins. */
                    public ins: string[];

                    /** Rule logConfigs. */
                    public logConfigs: google.cloud.compute.v1.ILogConfig[];

                    /** Rule notIns. */
                    public notIns: string[];

                    /** Rule permissions. */
                    public permissions: string[];

                    /** Rule _action. */
                    public _action?: "action";

                    /** Rule _description. */
                    public _description?: "description";

                    /**
                     * Creates a new Rule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Rule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IRule): google.cloud.compute.v1.Rule;

                    /**
                     * Encodes the specified Rule message. Does not implicitly {@link google.cloud.compute.v1.Rule.verify|verify} messages.
                     * @param message Rule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Rule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Rule.verify|verify} messages.
                     * @param message Rule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Rule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Rule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Rule;

                    /**
                     * Decodes a Rule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Rule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Rule;

                    /**
                     * Verifies a Rule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Rule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Rule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Rule;

                    /**
                     * Creates a plain object from a Rule message. Also converts values to other types if specified.
                     * @param message Rule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Rule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Rule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Rule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Rule {

                    /** Action enum. */
                    enum Action {
                        UNDEFINED_ACTION = 0,
                        ALLOW = 62368553,
                        ALLOW_WITH_LOG = 76034177,
                        DENY = 2094604,
                        DENY_WITH_LOG = 351433982,
                        LOG = 75556,
                        NO_ACTION = 260643444
                    }
                }

                /** Properties of a SSLHealthCheck. */
                interface ISSLHealthCheck {

                    /** SSLHealthCheck port */
                    port?: (number|null);

                    /** SSLHealthCheck portName */
                    portName?: (string|null);

                    /** SSLHealthCheck portSpecification */
                    portSpecification?: (string|null);

                    /** SSLHealthCheck proxyHeader */
                    proxyHeader?: (string|null);

                    /** SSLHealthCheck request */
                    request?: (string|null);

                    /** SSLHealthCheck response */
                    response?: (string|null);
                }

                /** Represents a SSLHealthCheck. */
                class SSLHealthCheck implements ISSLHealthCheck {

                    /**
                     * Constructs a new SSLHealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISSLHealthCheck);

                    /** SSLHealthCheck port. */
                    public port?: (number|null);

                    /** SSLHealthCheck portName. */
                    public portName?: (string|null);

                    /** SSLHealthCheck portSpecification. */
                    public portSpecification?: (string|null);

                    /** SSLHealthCheck proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** SSLHealthCheck request. */
                    public request?: (string|null);

                    /** SSLHealthCheck response. */
                    public response?: (string|null);

                    /** SSLHealthCheck _port. */
                    public _port?: "port";

                    /** SSLHealthCheck _portName. */
                    public _portName?: "portName";

                    /** SSLHealthCheck _portSpecification. */
                    public _portSpecification?: "portSpecification";

                    /** SSLHealthCheck _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** SSLHealthCheck _request. */
                    public _request?: "request";

                    /** SSLHealthCheck _response. */
                    public _response?: "response";

                    /**
                     * Creates a new SSLHealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SSLHealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISSLHealthCheck): google.cloud.compute.v1.SSLHealthCheck;

                    /**
                     * Encodes the specified SSLHealthCheck message. Does not implicitly {@link google.cloud.compute.v1.SSLHealthCheck.verify|verify} messages.
                     * @param message SSLHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISSLHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SSLHealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SSLHealthCheck.verify|verify} messages.
                     * @param message SSLHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISSLHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SSLHealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SSLHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SSLHealthCheck;

                    /**
                     * Decodes a SSLHealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SSLHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SSLHealthCheck;

                    /**
                     * Verifies a SSLHealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SSLHealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SSLHealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SSLHealthCheck;

                    /**
                     * Creates a plain object from a SSLHealthCheck message. Also converts values to other types if specified.
                     * @param message SSLHealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SSLHealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SSLHealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SSLHealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SSLHealthCheck {

                    /** PortSpecification enum. */
                    enum PortSpecification {
                        UNDEFINED_PORT_SPECIFICATION = 0,
                        USE_FIXED_PORT = 190235748,
                        USE_NAMED_PORT = 349300671,
                        USE_SERVING_PORT = 362637516
                    }

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a SavedAttachedDisk. */
                interface ISavedAttachedDisk {

                    /** SavedAttachedDisk autoDelete */
                    autoDelete?: (boolean|null);

                    /** SavedAttachedDisk boot */
                    boot?: (boolean|null);

                    /** SavedAttachedDisk deviceName */
                    deviceName?: (string|null);

                    /** SavedAttachedDisk diskEncryptionKey */
                    diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** SavedAttachedDisk diskSizeGb */
                    diskSizeGb?: (number|Long|string|null);

                    /** SavedAttachedDisk diskType */
                    diskType?: (string|null);

                    /** SavedAttachedDisk guestOsFeatures */
                    guestOsFeatures?: (google.cloud.compute.v1.IGuestOsFeature[]|null);

                    /** SavedAttachedDisk index */
                    index?: (number|null);

                    /** SavedAttachedDisk interface */
                    "interface"?: (string|null);

                    /** SavedAttachedDisk kind */
                    kind?: (string|null);

                    /** SavedAttachedDisk licenses */
                    licenses?: (string[]|null);

                    /** SavedAttachedDisk mode */
                    mode?: (string|null);

                    /** SavedAttachedDisk source */
                    source?: (string|null);

                    /** SavedAttachedDisk storageBytes */
                    storageBytes?: (number|Long|string|null);

                    /** SavedAttachedDisk storageBytesStatus */
                    storageBytesStatus?: (string|null);

                    /** SavedAttachedDisk type */
                    type?: (string|null);
                }

                /** Represents a SavedAttachedDisk. */
                class SavedAttachedDisk implements ISavedAttachedDisk {

                    /**
                     * Constructs a new SavedAttachedDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISavedAttachedDisk);

                    /** SavedAttachedDisk autoDelete. */
                    public autoDelete?: (boolean|null);

                    /** SavedAttachedDisk boot. */
                    public boot?: (boolean|null);

                    /** SavedAttachedDisk deviceName. */
                    public deviceName?: (string|null);

                    /** SavedAttachedDisk diskEncryptionKey. */
                    public diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** SavedAttachedDisk diskSizeGb. */
                    public diskSizeGb?: (number|Long|string|null);

                    /** SavedAttachedDisk diskType. */
                    public diskType?: (string|null);

                    /** SavedAttachedDisk guestOsFeatures. */
                    public guestOsFeatures: google.cloud.compute.v1.IGuestOsFeature[];

                    /** SavedAttachedDisk index. */
                    public index?: (number|null);

                    /** SavedAttachedDisk interface. */
                    public interface?: (string|null);

                    /** SavedAttachedDisk kind. */
                    public kind?: (string|null);

                    /** SavedAttachedDisk licenses. */
                    public licenses: string[];

                    /** SavedAttachedDisk mode. */
                    public mode?: (string|null);

                    /** SavedAttachedDisk source. */
                    public source?: (string|null);

                    /** SavedAttachedDisk storageBytes. */
                    public storageBytes?: (number|Long|string|null);

                    /** SavedAttachedDisk storageBytesStatus. */
                    public storageBytesStatus?: (string|null);

                    /** SavedAttachedDisk type. */
                    public type?: (string|null);

                    /** SavedAttachedDisk _autoDelete. */
                    public _autoDelete?: "autoDelete";

                    /** SavedAttachedDisk _boot. */
                    public _boot?: "boot";

                    /** SavedAttachedDisk _deviceName. */
                    public _deviceName?: "deviceName";

                    /** SavedAttachedDisk _diskEncryptionKey. */
                    public _diskEncryptionKey?: "diskEncryptionKey";

                    /** SavedAttachedDisk _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** SavedAttachedDisk _diskType. */
                    public _diskType?: "diskType";

                    /** SavedAttachedDisk _index. */
                    public _index?: "index";

                    /** SavedAttachedDisk _interface. */
                    public _interface?: "interface";

                    /** SavedAttachedDisk _kind. */
                    public _kind?: "kind";

                    /** SavedAttachedDisk _mode. */
                    public _mode?: "mode";

                    /** SavedAttachedDisk _source. */
                    public _source?: "source";

                    /** SavedAttachedDisk _storageBytes. */
                    public _storageBytes?: "storageBytes";

                    /** SavedAttachedDisk _storageBytesStatus. */
                    public _storageBytesStatus?: "storageBytesStatus";

                    /** SavedAttachedDisk _type. */
                    public _type?: "type";

                    /**
                     * Creates a new SavedAttachedDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SavedAttachedDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISavedAttachedDisk): google.cloud.compute.v1.SavedAttachedDisk;

                    /**
                     * Encodes the specified SavedAttachedDisk message. Does not implicitly {@link google.cloud.compute.v1.SavedAttachedDisk.verify|verify} messages.
                     * @param message SavedAttachedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISavedAttachedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SavedAttachedDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SavedAttachedDisk.verify|verify} messages.
                     * @param message SavedAttachedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISavedAttachedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SavedAttachedDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SavedAttachedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SavedAttachedDisk;

                    /**
                     * Decodes a SavedAttachedDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SavedAttachedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SavedAttachedDisk;

                    /**
                     * Verifies a SavedAttachedDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SavedAttachedDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SavedAttachedDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SavedAttachedDisk;

                    /**
                     * Creates a plain object from a SavedAttachedDisk message. Also converts values to other types if specified.
                     * @param message SavedAttachedDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SavedAttachedDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SavedAttachedDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SavedAttachedDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SavedAttachedDisk {

                    /** Interface enum. */
                    enum Interface {
                        UNDEFINED_INTERFACE = 0,
                        NVME = 2408800,
                        SCSI = 2539686
                    }

                    /** Mode enum. */
                    enum Mode {
                        UNDEFINED_MODE = 0,
                        READ_ONLY = 91950261,
                        READ_WRITE = 173607894
                    }

                    /** StorageBytesStatus enum. */
                    enum StorageBytesStatus {
                        UNDEFINED_STORAGE_BYTES_STATUS = 0,
                        UPDATING = 494614342,
                        UP_TO_DATE = 101306702
                    }

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        PERSISTENT = 460683927,
                        SCRATCH = 496778970
                    }
                }

                /** Properties of a SavedDisk. */
                interface ISavedDisk {

                    /** SavedDisk architecture */
                    architecture?: (string|null);

                    /** SavedDisk kind */
                    kind?: (string|null);

                    /** SavedDisk sourceDisk */
                    sourceDisk?: (string|null);

                    /** SavedDisk storageBytes */
                    storageBytes?: (number|Long|string|null);

                    /** SavedDisk storageBytesStatus */
                    storageBytesStatus?: (string|null);
                }

                /** Represents a SavedDisk. */
                class SavedDisk implements ISavedDisk {

                    /**
                     * Constructs a new SavedDisk.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISavedDisk);

                    /** SavedDisk architecture. */
                    public architecture?: (string|null);

                    /** SavedDisk kind. */
                    public kind?: (string|null);

                    /** SavedDisk sourceDisk. */
                    public sourceDisk?: (string|null);

                    /** SavedDisk storageBytes. */
                    public storageBytes?: (number|Long|string|null);

                    /** SavedDisk storageBytesStatus. */
                    public storageBytesStatus?: (string|null);

                    /** SavedDisk _architecture. */
                    public _architecture?: "architecture";

                    /** SavedDisk _kind. */
                    public _kind?: "kind";

                    /** SavedDisk _sourceDisk. */
                    public _sourceDisk?: "sourceDisk";

                    /** SavedDisk _storageBytes. */
                    public _storageBytes?: "storageBytes";

                    /** SavedDisk _storageBytesStatus. */
                    public _storageBytesStatus?: "storageBytesStatus";

                    /**
                     * Creates a new SavedDisk instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SavedDisk instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISavedDisk): google.cloud.compute.v1.SavedDisk;

                    /**
                     * Encodes the specified SavedDisk message. Does not implicitly {@link google.cloud.compute.v1.SavedDisk.verify|verify} messages.
                     * @param message SavedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISavedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SavedDisk message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SavedDisk.verify|verify} messages.
                     * @param message SavedDisk message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISavedDisk, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SavedDisk message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SavedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SavedDisk;

                    /**
                     * Decodes a SavedDisk message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SavedDisk
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SavedDisk;

                    /**
                     * Verifies a SavedDisk message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SavedDisk message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SavedDisk
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SavedDisk;

                    /**
                     * Creates a plain object from a SavedDisk message. Also converts values to other types if specified.
                     * @param message SavedDisk
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SavedDisk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SavedDisk to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SavedDisk
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SavedDisk {

                    /** Architecture enum. */
                    enum Architecture {
                        UNDEFINED_ARCHITECTURE = 0,
                        ARCHITECTURE_UNSPECIFIED = 394750507,
                        ARM64 = 62547450,
                        X86_64 = 425300551
                    }

                    /** StorageBytesStatus enum. */
                    enum StorageBytesStatus {
                        UNDEFINED_STORAGE_BYTES_STATUS = 0,
                        UPDATING = 494614342,
                        UP_TO_DATE = 101306702
                    }
                }

                /** Properties of a ScalingScheduleStatus. */
                interface IScalingScheduleStatus {

                    /** ScalingScheduleStatus lastStartTime */
                    lastStartTime?: (string|null);

                    /** ScalingScheduleStatus nextStartTime */
                    nextStartTime?: (string|null);

                    /** ScalingScheduleStatus state */
                    state?: (string|null);
                }

                /** Represents a ScalingScheduleStatus. */
                class ScalingScheduleStatus implements IScalingScheduleStatus {

                    /**
                     * Constructs a new ScalingScheduleStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IScalingScheduleStatus);

                    /** ScalingScheduleStatus lastStartTime. */
                    public lastStartTime?: (string|null);

                    /** ScalingScheduleStatus nextStartTime. */
                    public nextStartTime?: (string|null);

                    /** ScalingScheduleStatus state. */
                    public state?: (string|null);

                    /** ScalingScheduleStatus _lastStartTime. */
                    public _lastStartTime?: "lastStartTime";

                    /** ScalingScheduleStatus _nextStartTime. */
                    public _nextStartTime?: "nextStartTime";

                    /** ScalingScheduleStatus _state. */
                    public _state?: "state";

                    /**
                     * Creates a new ScalingScheduleStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ScalingScheduleStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IScalingScheduleStatus): google.cloud.compute.v1.ScalingScheduleStatus;

                    /**
                     * Encodes the specified ScalingScheduleStatus message. Does not implicitly {@link google.cloud.compute.v1.ScalingScheduleStatus.verify|verify} messages.
                     * @param message ScalingScheduleStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IScalingScheduleStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ScalingScheduleStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ScalingScheduleStatus.verify|verify} messages.
                     * @param message ScalingScheduleStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IScalingScheduleStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ScalingScheduleStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ScalingScheduleStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ScalingScheduleStatus;

                    /**
                     * Decodes a ScalingScheduleStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ScalingScheduleStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ScalingScheduleStatus;

                    /**
                     * Verifies a ScalingScheduleStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ScalingScheduleStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ScalingScheduleStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ScalingScheduleStatus;

                    /**
                     * Creates a plain object from a ScalingScheduleStatus message. Also converts values to other types if specified.
                     * @param message ScalingScheduleStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ScalingScheduleStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ScalingScheduleStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ScalingScheduleStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ScalingScheduleStatus {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        ACTIVE = 314733318,
                        DISABLED = 516696700,
                        OBSOLETE = 66532761,
                        READY = 77848963
                    }
                }

                /** Properties of a Scheduling. */
                interface IScheduling {

                    /** Scheduling automaticRestart */
                    automaticRestart?: (boolean|null);

                    /** Scheduling instanceTerminationAction */
                    instanceTerminationAction?: (string|null);

                    /** Scheduling locationHint */
                    locationHint?: (string|null);

                    /** Scheduling minNodeCpus */
                    minNodeCpus?: (number|null);

                    /** Scheduling nodeAffinities */
                    nodeAffinities?: (google.cloud.compute.v1.ISchedulingNodeAffinity[]|null);

                    /** Scheduling onHostMaintenance */
                    onHostMaintenance?: (string|null);

                    /** Scheduling preemptible */
                    preemptible?: (boolean|null);

                    /** Scheduling provisioningModel */
                    provisioningModel?: (string|null);
                }

                /** Represents a Scheduling. */
                class Scheduling implements IScheduling {

                    /**
                     * Constructs a new Scheduling.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IScheduling);

                    /** Scheduling automaticRestart. */
                    public automaticRestart?: (boolean|null);

                    /** Scheduling instanceTerminationAction. */
                    public instanceTerminationAction?: (string|null);

                    /** Scheduling locationHint. */
                    public locationHint?: (string|null);

                    /** Scheduling minNodeCpus. */
                    public minNodeCpus?: (number|null);

                    /** Scheduling nodeAffinities. */
                    public nodeAffinities: google.cloud.compute.v1.ISchedulingNodeAffinity[];

                    /** Scheduling onHostMaintenance. */
                    public onHostMaintenance?: (string|null);

                    /** Scheduling preemptible. */
                    public preemptible?: (boolean|null);

                    /** Scheduling provisioningModel. */
                    public provisioningModel?: (string|null);

                    /** Scheduling _automaticRestart. */
                    public _automaticRestart?: "automaticRestart";

                    /** Scheduling _instanceTerminationAction. */
                    public _instanceTerminationAction?: "instanceTerminationAction";

                    /** Scheduling _locationHint. */
                    public _locationHint?: "locationHint";

                    /** Scheduling _minNodeCpus. */
                    public _minNodeCpus?: "minNodeCpus";

                    /** Scheduling _onHostMaintenance. */
                    public _onHostMaintenance?: "onHostMaintenance";

                    /** Scheduling _preemptible. */
                    public _preemptible?: "preemptible";

                    /** Scheduling _provisioningModel. */
                    public _provisioningModel?: "provisioningModel";

                    /**
                     * Creates a new Scheduling instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Scheduling instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IScheduling): google.cloud.compute.v1.Scheduling;

                    /**
                     * Encodes the specified Scheduling message. Does not implicitly {@link google.cloud.compute.v1.Scheduling.verify|verify} messages.
                     * @param message Scheduling message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IScheduling, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Scheduling message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Scheduling.verify|verify} messages.
                     * @param message Scheduling message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IScheduling, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Scheduling message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Scheduling
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Scheduling;

                    /**
                     * Decodes a Scheduling message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Scheduling
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Scheduling;

                    /**
                     * Verifies a Scheduling message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Scheduling message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Scheduling
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Scheduling;

                    /**
                     * Creates a plain object from a Scheduling message. Also converts values to other types if specified.
                     * @param message Scheduling
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Scheduling, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Scheduling to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Scheduling
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Scheduling {

                    /** InstanceTerminationAction enum. */
                    enum InstanceTerminationAction {
                        UNDEFINED_INSTANCE_TERMINATION_ACTION = 0,
                        DELETE = 402225579,
                        INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92954803,
                        STOP = 2555906
                    }

                    /** OnHostMaintenance enum. */
                    enum OnHostMaintenance {
                        UNDEFINED_ON_HOST_MAINTENANCE = 0,
                        MIGRATE = 165699979,
                        TERMINATE = 527617601
                    }

                    /** ProvisioningModel enum. */
                    enum ProvisioningModel {
                        UNDEFINED_PROVISIONING_MODEL = 0,
                        SPOT = 2552066,
                        STANDARD = 484642493
                    }
                }

                /** Properties of a SchedulingNodeAffinity. */
                interface ISchedulingNodeAffinity {

                    /** SchedulingNodeAffinity key */
                    key?: (string|null);

                    /** SchedulingNodeAffinity operator */
                    operator?: (string|null);

                    /** SchedulingNodeAffinity values */
                    values?: (string[]|null);
                }

                /** Represents a SchedulingNodeAffinity. */
                class SchedulingNodeAffinity implements ISchedulingNodeAffinity {

                    /**
                     * Constructs a new SchedulingNodeAffinity.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISchedulingNodeAffinity);

                    /** SchedulingNodeAffinity key. */
                    public key?: (string|null);

                    /** SchedulingNodeAffinity operator. */
                    public operator?: (string|null);

                    /** SchedulingNodeAffinity values. */
                    public values: string[];

                    /** SchedulingNodeAffinity _key. */
                    public _key?: "key";

                    /** SchedulingNodeAffinity _operator. */
                    public _operator?: "operator";

                    /**
                     * Creates a new SchedulingNodeAffinity instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SchedulingNodeAffinity instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISchedulingNodeAffinity): google.cloud.compute.v1.SchedulingNodeAffinity;

                    /**
                     * Encodes the specified SchedulingNodeAffinity message. Does not implicitly {@link google.cloud.compute.v1.SchedulingNodeAffinity.verify|verify} messages.
                     * @param message SchedulingNodeAffinity message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISchedulingNodeAffinity, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SchedulingNodeAffinity message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SchedulingNodeAffinity.verify|verify} messages.
                     * @param message SchedulingNodeAffinity message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISchedulingNodeAffinity, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SchedulingNodeAffinity message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SchedulingNodeAffinity
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SchedulingNodeAffinity;

                    /**
                     * Decodes a SchedulingNodeAffinity message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SchedulingNodeAffinity
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SchedulingNodeAffinity;

                    /**
                     * Verifies a SchedulingNodeAffinity message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SchedulingNodeAffinity message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SchedulingNodeAffinity
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SchedulingNodeAffinity;

                    /**
                     * Creates a plain object from a SchedulingNodeAffinity message. Also converts values to other types if specified.
                     * @param message SchedulingNodeAffinity
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SchedulingNodeAffinity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SchedulingNodeAffinity to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SchedulingNodeAffinity
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SchedulingNodeAffinity {

                    /** Operator enum. */
                    enum Operator {
                        UNDEFINED_OPERATOR = 0,
                        IN = 2341,
                        NOT_IN = 161144369,
                        OPERATOR_UNSPECIFIED = 128892924
                    }
                }

                /** Properties of a ScratchDisks. */
                interface IScratchDisks {

                    /** ScratchDisks diskGb */
                    diskGb?: (number|null);
                }

                /** Represents a ScratchDisks. */
                class ScratchDisks implements IScratchDisks {

                    /**
                     * Constructs a new ScratchDisks.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IScratchDisks);

                    /** ScratchDisks diskGb. */
                    public diskGb?: (number|null);

                    /** ScratchDisks _diskGb. */
                    public _diskGb?: "diskGb";

                    /**
                     * Creates a new ScratchDisks instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ScratchDisks instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IScratchDisks): google.cloud.compute.v1.ScratchDisks;

                    /**
                     * Encodes the specified ScratchDisks message. Does not implicitly {@link google.cloud.compute.v1.ScratchDisks.verify|verify} messages.
                     * @param message ScratchDisks message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IScratchDisks, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ScratchDisks message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ScratchDisks.verify|verify} messages.
                     * @param message ScratchDisks message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IScratchDisks, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ScratchDisks message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ScratchDisks
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ScratchDisks;

                    /**
                     * Decodes a ScratchDisks message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ScratchDisks
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ScratchDisks;

                    /**
                     * Verifies a ScratchDisks message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ScratchDisks message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ScratchDisks
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ScratchDisks;

                    /**
                     * Creates a plain object from a ScratchDisks message. Also converts values to other types if specified.
                     * @param message ScratchDisks
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ScratchDisks, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ScratchDisks to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ScratchDisks
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Screenshot. */
                interface IScreenshot {

                    /** Screenshot contents */
                    contents?: (string|null);

                    /** Screenshot kind */
                    kind?: (string|null);
                }

                /** Represents a Screenshot. */
                class Screenshot implements IScreenshot {

                    /**
                     * Constructs a new Screenshot.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IScreenshot);

                    /** Screenshot contents. */
                    public contents?: (string|null);

                    /** Screenshot kind. */
                    public kind?: (string|null);

                    /** Screenshot _contents. */
                    public _contents?: "contents";

                    /** Screenshot _kind. */
                    public _kind?: "kind";

                    /**
                     * Creates a new Screenshot instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Screenshot instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IScreenshot): google.cloud.compute.v1.Screenshot;

                    /**
                     * Encodes the specified Screenshot message. Does not implicitly {@link google.cloud.compute.v1.Screenshot.verify|verify} messages.
                     * @param message Screenshot message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IScreenshot, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Screenshot message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Screenshot.verify|verify} messages.
                     * @param message Screenshot message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IScreenshot, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Screenshot message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Screenshot
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Screenshot;

                    /**
                     * Decodes a Screenshot message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Screenshot
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Screenshot;

                    /**
                     * Verifies a Screenshot message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Screenshot message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Screenshot
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Screenshot;

                    /**
                     * Creates a plain object from a Screenshot message. Also converts values to other types if specified.
                     * @param message Screenshot
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Screenshot, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Screenshot to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Screenshot
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPoliciesAggregatedList. */
                interface ISecurityPoliciesAggregatedList {

                    /** SecurityPoliciesAggregatedList etag */
                    etag?: (string|null);

                    /** SecurityPoliciesAggregatedList id */
                    id?: (string|null);

                    /** SecurityPoliciesAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ISecurityPoliciesScopedList }|null);

                    /** SecurityPoliciesAggregatedList kind */
                    kind?: (string|null);

                    /** SecurityPoliciesAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SecurityPoliciesAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** SecurityPoliciesAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** SecurityPoliciesAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SecurityPoliciesAggregatedList. */
                class SecurityPoliciesAggregatedList implements ISecurityPoliciesAggregatedList {

                    /**
                     * Constructs a new SecurityPoliciesAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPoliciesAggregatedList);

                    /** SecurityPoliciesAggregatedList etag. */
                    public etag?: (string|null);

                    /** SecurityPoliciesAggregatedList id. */
                    public id?: (string|null);

                    /** SecurityPoliciesAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ISecurityPoliciesScopedList };

                    /** SecurityPoliciesAggregatedList kind. */
                    public kind?: (string|null);

                    /** SecurityPoliciesAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SecurityPoliciesAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** SecurityPoliciesAggregatedList unreachables. */
                    public unreachables: string[];

                    /** SecurityPoliciesAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SecurityPoliciesAggregatedList _etag. */
                    public _etag?: "etag";

                    /** SecurityPoliciesAggregatedList _id. */
                    public _id?: "id";

                    /** SecurityPoliciesAggregatedList _kind. */
                    public _kind?: "kind";

                    /** SecurityPoliciesAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SecurityPoliciesAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SecurityPoliciesAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SecurityPoliciesAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPoliciesAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPoliciesAggregatedList): google.cloud.compute.v1.SecurityPoliciesAggregatedList;

                    /**
                     * Encodes the specified SecurityPoliciesAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesAggregatedList.verify|verify} messages.
                     * @param message SecurityPoliciesAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPoliciesAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPoliciesAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesAggregatedList.verify|verify} messages.
                     * @param message SecurityPoliciesAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPoliciesAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPoliciesAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPoliciesAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPoliciesAggregatedList;

                    /**
                     * Decodes a SecurityPoliciesAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPoliciesAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPoliciesAggregatedList;

                    /**
                     * Verifies a SecurityPoliciesAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPoliciesAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPoliciesAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPoliciesAggregatedList;

                    /**
                     * Creates a plain object from a SecurityPoliciesAggregatedList message. Also converts values to other types if specified.
                     * @param message SecurityPoliciesAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPoliciesAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPoliciesAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPoliciesAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPoliciesListPreconfiguredExpressionSetsResponse. */
                interface ISecurityPoliciesListPreconfiguredExpressionSetsResponse {

                    /** SecurityPoliciesListPreconfiguredExpressionSetsResponse preconfiguredExpressionSets */
                    preconfiguredExpressionSets?: (google.cloud.compute.v1.ISecurityPoliciesWafConfig|null);
                }

                /** Represents a SecurityPoliciesListPreconfiguredExpressionSetsResponse. */
                class SecurityPoliciesListPreconfiguredExpressionSetsResponse implements ISecurityPoliciesListPreconfiguredExpressionSetsResponse {

                    /**
                     * Constructs a new SecurityPoliciesListPreconfiguredExpressionSetsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPoliciesListPreconfiguredExpressionSetsResponse);

                    /** SecurityPoliciesListPreconfiguredExpressionSetsResponse preconfiguredExpressionSets. */
                    public preconfiguredExpressionSets?: (google.cloud.compute.v1.ISecurityPoliciesWafConfig|null);

                    /** SecurityPoliciesListPreconfiguredExpressionSetsResponse _preconfiguredExpressionSets. */
                    public _preconfiguredExpressionSets?: "preconfiguredExpressionSets";

                    /**
                     * Creates a new SecurityPoliciesListPreconfiguredExpressionSetsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPoliciesListPreconfiguredExpressionSetsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPoliciesListPreconfiguredExpressionSetsResponse): google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse;

                    /**
                     * Encodes the specified SecurityPoliciesListPreconfiguredExpressionSetsResponse message. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse.verify|verify} messages.
                     * @param message SecurityPoliciesListPreconfiguredExpressionSetsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPoliciesListPreconfiguredExpressionSetsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPoliciesListPreconfiguredExpressionSetsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse.verify|verify} messages.
                     * @param message SecurityPoliciesListPreconfiguredExpressionSetsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPoliciesListPreconfiguredExpressionSetsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPoliciesListPreconfiguredExpressionSetsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse;

                    /**
                     * Decodes a SecurityPoliciesListPreconfiguredExpressionSetsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse;

                    /**
                     * Verifies a SecurityPoliciesListPreconfiguredExpressionSetsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPoliciesListPreconfiguredExpressionSetsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse;

                    /**
                     * Creates a plain object from a SecurityPoliciesListPreconfiguredExpressionSetsResponse message. Also converts values to other types if specified.
                     * @param message SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPoliciesListPreconfiguredExpressionSetsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPoliciesScopedList. */
                interface ISecurityPoliciesScopedList {

                    /** SecurityPoliciesScopedList securityPolicies */
                    securityPolicies?: (google.cloud.compute.v1.ISecurityPolicy[]|null);

                    /** SecurityPoliciesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SecurityPoliciesScopedList. */
                class SecurityPoliciesScopedList implements ISecurityPoliciesScopedList {

                    /**
                     * Constructs a new SecurityPoliciesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPoliciesScopedList);

                    /** SecurityPoliciesScopedList securityPolicies. */
                    public securityPolicies: google.cloud.compute.v1.ISecurityPolicy[];

                    /** SecurityPoliciesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SecurityPoliciesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SecurityPoliciesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPoliciesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPoliciesScopedList): google.cloud.compute.v1.SecurityPoliciesScopedList;

                    /**
                     * Encodes the specified SecurityPoliciesScopedList message. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesScopedList.verify|verify} messages.
                     * @param message SecurityPoliciesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPoliciesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPoliciesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesScopedList.verify|verify} messages.
                     * @param message SecurityPoliciesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPoliciesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPoliciesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPoliciesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPoliciesScopedList;

                    /**
                     * Decodes a SecurityPoliciesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPoliciesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPoliciesScopedList;

                    /**
                     * Verifies a SecurityPoliciesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPoliciesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPoliciesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPoliciesScopedList;

                    /**
                     * Creates a plain object from a SecurityPoliciesScopedList message. Also converts values to other types if specified.
                     * @param message SecurityPoliciesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPoliciesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPoliciesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPoliciesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPoliciesWafConfig. */
                interface ISecurityPoliciesWafConfig {

                    /** SecurityPoliciesWafConfig wafRules */
                    wafRules?: (google.cloud.compute.v1.IPreconfiguredWafSet|null);
                }

                /** Represents a SecurityPoliciesWafConfig. */
                class SecurityPoliciesWafConfig implements ISecurityPoliciesWafConfig {

                    /**
                     * Constructs a new SecurityPoliciesWafConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPoliciesWafConfig);

                    /** SecurityPoliciesWafConfig wafRules. */
                    public wafRules?: (google.cloud.compute.v1.IPreconfiguredWafSet|null);

                    /** SecurityPoliciesWafConfig _wafRules. */
                    public _wafRules?: "wafRules";

                    /**
                     * Creates a new SecurityPoliciesWafConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPoliciesWafConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPoliciesWafConfig): google.cloud.compute.v1.SecurityPoliciesWafConfig;

                    /**
                     * Encodes the specified SecurityPoliciesWafConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesWafConfig.verify|verify} messages.
                     * @param message SecurityPoliciesWafConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPoliciesWafConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPoliciesWafConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPoliciesWafConfig.verify|verify} messages.
                     * @param message SecurityPoliciesWafConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPoliciesWafConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPoliciesWafConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPoliciesWafConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPoliciesWafConfig;

                    /**
                     * Decodes a SecurityPoliciesWafConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPoliciesWafConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPoliciesWafConfig;

                    /**
                     * Verifies a SecurityPoliciesWafConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPoliciesWafConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPoliciesWafConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPoliciesWafConfig;

                    /**
                     * Creates a plain object from a SecurityPoliciesWafConfig message. Also converts values to other types if specified.
                     * @param message SecurityPoliciesWafConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPoliciesWafConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPoliciesWafConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPoliciesWafConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicy. */
                interface ISecurityPolicy {

                    /** SecurityPolicy adaptiveProtectionConfig */
                    adaptiveProtectionConfig?: (google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfig|null);

                    /** SecurityPolicy advancedOptionsConfig */
                    advancedOptionsConfig?: (google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfig|null);

                    /** SecurityPolicy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** SecurityPolicy ddosProtectionConfig */
                    ddosProtectionConfig?: (google.cloud.compute.v1.ISecurityPolicyDdosProtectionConfig|null);

                    /** SecurityPolicy description */
                    description?: (string|null);

                    /** SecurityPolicy fingerprint */
                    fingerprint?: (string|null);

                    /** SecurityPolicy id */
                    id?: (number|Long|string|null);

                    /** SecurityPolicy kind */
                    kind?: (string|null);

                    /** SecurityPolicy name */
                    name?: (string|null);

                    /** SecurityPolicy recaptchaOptionsConfig */
                    recaptchaOptionsConfig?: (google.cloud.compute.v1.ISecurityPolicyRecaptchaOptionsConfig|null);

                    /** SecurityPolicy region */
                    region?: (string|null);

                    /** SecurityPolicy rules */
                    rules?: (google.cloud.compute.v1.ISecurityPolicyRule[]|null);

                    /** SecurityPolicy selfLink */
                    selfLink?: (string|null);

                    /** SecurityPolicy type */
                    type?: (string|null);
                }

                /** Represents a SecurityPolicy. */
                class SecurityPolicy implements ISecurityPolicy {

                    /**
                     * Constructs a new SecurityPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicy);

                    /** SecurityPolicy adaptiveProtectionConfig. */
                    public adaptiveProtectionConfig?: (google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfig|null);

                    /** SecurityPolicy advancedOptionsConfig. */
                    public advancedOptionsConfig?: (google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfig|null);

                    /** SecurityPolicy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** SecurityPolicy ddosProtectionConfig. */
                    public ddosProtectionConfig?: (google.cloud.compute.v1.ISecurityPolicyDdosProtectionConfig|null);

                    /** SecurityPolicy description. */
                    public description?: (string|null);

                    /** SecurityPolicy fingerprint. */
                    public fingerprint?: (string|null);

                    /** SecurityPolicy id. */
                    public id?: (number|Long|string|null);

                    /** SecurityPolicy kind. */
                    public kind?: (string|null);

                    /** SecurityPolicy name. */
                    public name?: (string|null);

                    /** SecurityPolicy recaptchaOptionsConfig. */
                    public recaptchaOptionsConfig?: (google.cloud.compute.v1.ISecurityPolicyRecaptchaOptionsConfig|null);

                    /** SecurityPolicy region. */
                    public region?: (string|null);

                    /** SecurityPolicy rules. */
                    public rules: google.cloud.compute.v1.ISecurityPolicyRule[];

                    /** SecurityPolicy selfLink. */
                    public selfLink?: (string|null);

                    /** SecurityPolicy type. */
                    public type?: (string|null);

                    /** SecurityPolicy _adaptiveProtectionConfig. */
                    public _adaptiveProtectionConfig?: "adaptiveProtectionConfig";

                    /** SecurityPolicy _advancedOptionsConfig. */
                    public _advancedOptionsConfig?: "advancedOptionsConfig";

                    /** SecurityPolicy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** SecurityPolicy _ddosProtectionConfig. */
                    public _ddosProtectionConfig?: "ddosProtectionConfig";

                    /** SecurityPolicy _description. */
                    public _description?: "description";

                    /** SecurityPolicy _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** SecurityPolicy _id. */
                    public _id?: "id";

                    /** SecurityPolicy _kind. */
                    public _kind?: "kind";

                    /** SecurityPolicy _name. */
                    public _name?: "name";

                    /** SecurityPolicy _recaptchaOptionsConfig. */
                    public _recaptchaOptionsConfig?: "recaptchaOptionsConfig";

                    /** SecurityPolicy _region. */
                    public _region?: "region";

                    /** SecurityPolicy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SecurityPolicy _type. */
                    public _type?: "type";

                    /**
                     * Creates a new SecurityPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicy): google.cloud.compute.v1.SecurityPolicy;

                    /**
                     * Encodes the specified SecurityPolicy message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicy.verify|verify} messages.
                     * @param message SecurityPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicy.verify|verify} messages.
                     * @param message SecurityPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicy;

                    /**
                     * Decodes a SecurityPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicy;

                    /**
                     * Verifies a SecurityPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicy;

                    /**
                     * Creates a plain object from a SecurityPolicy message. Also converts values to other types if specified.
                     * @param message SecurityPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicy {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        CLOUD_ARMOR = 260640373,
                        CLOUD_ARMOR_EDGE = 250728775,
                        CLOUD_ARMOR_NETWORK = 488527428
                    }
                }

                /** Properties of a SecurityPolicyAdaptiveProtectionConfig. */
                interface ISecurityPolicyAdaptiveProtectionConfig {

                    /** SecurityPolicyAdaptiveProtectionConfig layer7DdosDefenseConfig */
                    layer7DdosDefenseConfig?: (google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig|null);
                }

                /** Represents a SecurityPolicyAdaptiveProtectionConfig. */
                class SecurityPolicyAdaptiveProtectionConfig implements ISecurityPolicyAdaptiveProtectionConfig {

                    /**
                     * Constructs a new SecurityPolicyAdaptiveProtectionConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfig);

                    /** SecurityPolicyAdaptiveProtectionConfig layer7DdosDefenseConfig. */
                    public layer7DdosDefenseConfig?: (google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig|null);

                    /** SecurityPolicyAdaptiveProtectionConfig _layer7DdosDefenseConfig. */
                    public _layer7DdosDefenseConfig?: "layer7DdosDefenseConfig";

                    /**
                     * Creates a new SecurityPolicyAdaptiveProtectionConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyAdaptiveProtectionConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfig): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig;

                    /**
                     * Encodes the specified SecurityPolicyAdaptiveProtectionConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdaptiveProtectionConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyAdaptiveProtectionConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdaptiveProtectionConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyAdaptiveProtectionConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyAdaptiveProtectionConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig;

                    /**
                     * Decodes a SecurityPolicyAdaptiveProtectionConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyAdaptiveProtectionConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig;

                    /**
                     * Verifies a SecurityPolicyAdaptiveProtectionConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyAdaptiveProtectionConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyAdaptiveProtectionConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyAdaptiveProtectionConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyAdaptiveProtectionConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyAdaptiveProtectionConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyAdaptiveProtectionConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig. */
                interface ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig {

                    /** SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig enable */
                    enable?: (boolean|null);

                    /** SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig ruleVisibility */
                    ruleVisibility?: (string|null);
                }

                /** Represents a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig. */
                class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig implements ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig {

                    /**
                     * Constructs a new SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig);

                    /** SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig enable. */
                    public enable?: (boolean|null);

                    /** SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig ruleVisibility. */
                    public ruleVisibility?: (string|null);

                    /** SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig _enable. */
                    public _enable?: "enable";

                    /** SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig _ruleVisibility. */
                    public _ruleVisibility?: "ruleVisibility";

                    /**
                     * Creates a new SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig;

                    /**
                     * Encodes the specified SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig;

                    /**
                     * Decodes a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig;

                    /**
                     * Verifies a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig {

                    /** RuleVisibility enum. */
                    enum RuleVisibility {
                        UNDEFINED_RULE_VISIBILITY = 0,
                        PREMIUM = 399530551,
                        STANDARD = 484642493
                    }
                }

                /** Properties of a SecurityPolicyAdvancedOptionsConfig. */
                interface ISecurityPolicyAdvancedOptionsConfig {

                    /** SecurityPolicyAdvancedOptionsConfig jsonCustomConfig */
                    jsonCustomConfig?: (google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig|null);

                    /** SecurityPolicyAdvancedOptionsConfig jsonParsing */
                    jsonParsing?: (string|null);

                    /** SecurityPolicyAdvancedOptionsConfig logLevel */
                    logLevel?: (string|null);
                }

                /** Represents a SecurityPolicyAdvancedOptionsConfig. */
                class SecurityPolicyAdvancedOptionsConfig implements ISecurityPolicyAdvancedOptionsConfig {

                    /**
                     * Constructs a new SecurityPolicyAdvancedOptionsConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfig);

                    /** SecurityPolicyAdvancedOptionsConfig jsonCustomConfig. */
                    public jsonCustomConfig?: (google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig|null);

                    /** SecurityPolicyAdvancedOptionsConfig jsonParsing. */
                    public jsonParsing?: (string|null);

                    /** SecurityPolicyAdvancedOptionsConfig logLevel. */
                    public logLevel?: (string|null);

                    /** SecurityPolicyAdvancedOptionsConfig _jsonCustomConfig. */
                    public _jsonCustomConfig?: "jsonCustomConfig";

                    /** SecurityPolicyAdvancedOptionsConfig _jsonParsing. */
                    public _jsonParsing?: "jsonParsing";

                    /** SecurityPolicyAdvancedOptionsConfig _logLevel. */
                    public _logLevel?: "logLevel";

                    /**
                     * Creates a new SecurityPolicyAdvancedOptionsConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyAdvancedOptionsConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfig): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig;

                    /**
                     * Encodes the specified SecurityPolicyAdvancedOptionsConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdvancedOptionsConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyAdvancedOptionsConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdvancedOptionsConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyAdvancedOptionsConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyAdvancedOptionsConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig;

                    /**
                     * Decodes a SecurityPolicyAdvancedOptionsConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyAdvancedOptionsConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig;

                    /**
                     * Verifies a SecurityPolicyAdvancedOptionsConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyAdvancedOptionsConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyAdvancedOptionsConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyAdvancedOptionsConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyAdvancedOptionsConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyAdvancedOptionsConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyAdvancedOptionsConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicyAdvancedOptionsConfig {

                    /** JsonParsing enum. */
                    enum JsonParsing {
                        UNDEFINED_JSON_PARSING = 0,
                        DISABLED = 516696700,
                        STANDARD = 484642493
                    }

                    /** LogLevel enum. */
                    enum LogLevel {
                        UNDEFINED_LOG_LEVEL = 0,
                        NORMAL = 161067239,
                        VERBOSE = 532219234
                    }
                }

                /** Properties of a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig. */
                interface ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig {

                    /** SecurityPolicyAdvancedOptionsConfigJsonCustomConfig contentTypes */
                    contentTypes?: (string[]|null);
                }

                /** Represents a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig. */
                class SecurityPolicyAdvancedOptionsConfigJsonCustomConfig implements ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig {

                    /**
                     * Constructs a new SecurityPolicyAdvancedOptionsConfigJsonCustomConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig);

                    /** SecurityPolicyAdvancedOptionsConfigJsonCustomConfig contentTypes. */
                    public contentTypes: string[];

                    /**
                     * Creates a new SecurityPolicyAdvancedOptionsConfigJsonCustomConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyAdvancedOptionsConfigJsonCustomConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig;

                    /**
                     * Encodes the specified SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig.verify|verify} messages.
                     * @param message SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyAdvancedOptionsConfigJsonCustomConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig;

                    /**
                     * Decodes a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig;

                    /**
                     * Verifies a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyAdvancedOptionsConfigJsonCustomConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyAdvancedOptionsConfigJsonCustomConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyDdosProtectionConfig. */
                interface ISecurityPolicyDdosProtectionConfig {

                    /** SecurityPolicyDdosProtectionConfig ddosProtection */
                    ddosProtection?: (string|null);
                }

                /** Represents a SecurityPolicyDdosProtectionConfig. */
                class SecurityPolicyDdosProtectionConfig implements ISecurityPolicyDdosProtectionConfig {

                    /**
                     * Constructs a new SecurityPolicyDdosProtectionConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyDdosProtectionConfig);

                    /** SecurityPolicyDdosProtectionConfig ddosProtection. */
                    public ddosProtection?: (string|null);

                    /** SecurityPolicyDdosProtectionConfig _ddosProtection. */
                    public _ddosProtection?: "ddosProtection";

                    /**
                     * Creates a new SecurityPolicyDdosProtectionConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyDdosProtectionConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyDdosProtectionConfig): google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig;

                    /**
                     * Encodes the specified SecurityPolicyDdosProtectionConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig.verify|verify} messages.
                     * @param message SecurityPolicyDdosProtectionConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyDdosProtectionConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyDdosProtectionConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig.verify|verify} messages.
                     * @param message SecurityPolicyDdosProtectionConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyDdosProtectionConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyDdosProtectionConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyDdosProtectionConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig;

                    /**
                     * Decodes a SecurityPolicyDdosProtectionConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyDdosProtectionConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig;

                    /**
                     * Verifies a SecurityPolicyDdosProtectionConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyDdosProtectionConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyDdosProtectionConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyDdosProtectionConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyDdosProtectionConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyDdosProtectionConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyDdosProtectionConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyDdosProtectionConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicyDdosProtectionConfig {

                    /** DdosProtection enum. */
                    enum DdosProtection {
                        UNDEFINED_DDOS_PROTECTION = 0,
                        ADVANCED = 63789090,
                        STANDARD = 484642493
                    }
                }

                /** Properties of a SecurityPolicyList. */
                interface ISecurityPolicyList {

                    /** SecurityPolicyList id */
                    id?: (string|null);

                    /** SecurityPolicyList items */
                    items?: (google.cloud.compute.v1.ISecurityPolicy[]|null);

                    /** SecurityPolicyList kind */
                    kind?: (string|null);

                    /** SecurityPolicyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SecurityPolicyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SecurityPolicyList. */
                class SecurityPolicyList implements ISecurityPolicyList {

                    /**
                     * Constructs a new SecurityPolicyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyList);

                    /** SecurityPolicyList id. */
                    public id?: (string|null);

                    /** SecurityPolicyList items. */
                    public items: google.cloud.compute.v1.ISecurityPolicy[];

                    /** SecurityPolicyList kind. */
                    public kind?: (string|null);

                    /** SecurityPolicyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SecurityPolicyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SecurityPolicyList _id. */
                    public _id?: "id";

                    /** SecurityPolicyList _kind. */
                    public _kind?: "kind";

                    /** SecurityPolicyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SecurityPolicyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SecurityPolicyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyList): google.cloud.compute.v1.SecurityPolicyList;

                    /**
                     * Encodes the specified SecurityPolicyList message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyList.verify|verify} messages.
                     * @param message SecurityPolicyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyList.verify|verify} messages.
                     * @param message SecurityPolicyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyList;

                    /**
                     * Decodes a SecurityPolicyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyList;

                    /**
                     * Verifies a SecurityPolicyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyList;

                    /**
                     * Creates a plain object from a SecurityPolicyList message. Also converts values to other types if specified.
                     * @param message SecurityPolicyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRecaptchaOptionsConfig. */
                interface ISecurityPolicyRecaptchaOptionsConfig {

                    /** SecurityPolicyRecaptchaOptionsConfig redirectSiteKey */
                    redirectSiteKey?: (string|null);
                }

                /** Represents a SecurityPolicyRecaptchaOptionsConfig. */
                class SecurityPolicyRecaptchaOptionsConfig implements ISecurityPolicyRecaptchaOptionsConfig {

                    /**
                     * Constructs a new SecurityPolicyRecaptchaOptionsConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRecaptchaOptionsConfig);

                    /** SecurityPolicyRecaptchaOptionsConfig redirectSiteKey. */
                    public redirectSiteKey?: (string|null);

                    /** SecurityPolicyRecaptchaOptionsConfig _redirectSiteKey. */
                    public _redirectSiteKey?: "redirectSiteKey";

                    /**
                     * Creates a new SecurityPolicyRecaptchaOptionsConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRecaptchaOptionsConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRecaptchaOptionsConfig): google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig;

                    /**
                     * Encodes the specified SecurityPolicyRecaptchaOptionsConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig.verify|verify} messages.
                     * @param message SecurityPolicyRecaptchaOptionsConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRecaptchaOptionsConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRecaptchaOptionsConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig.verify|verify} messages.
                     * @param message SecurityPolicyRecaptchaOptionsConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRecaptchaOptionsConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRecaptchaOptionsConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRecaptchaOptionsConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig;

                    /**
                     * Decodes a SecurityPolicyRecaptchaOptionsConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRecaptchaOptionsConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig;

                    /**
                     * Verifies a SecurityPolicyRecaptchaOptionsConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRecaptchaOptionsConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRecaptchaOptionsConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyRecaptchaOptionsConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRecaptchaOptionsConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRecaptchaOptionsConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRecaptchaOptionsConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRecaptchaOptionsConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyReference. */
                interface ISecurityPolicyReference {

                    /** SecurityPolicyReference securityPolicy */
                    securityPolicy?: (string|null);
                }

                /** Represents a SecurityPolicyReference. */
                class SecurityPolicyReference implements ISecurityPolicyReference {

                    /**
                     * Constructs a new SecurityPolicyReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyReference);

                    /** SecurityPolicyReference securityPolicy. */
                    public securityPolicy?: (string|null);

                    /** SecurityPolicyReference _securityPolicy. */
                    public _securityPolicy?: "securityPolicy";

                    /**
                     * Creates a new SecurityPolicyReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyReference): google.cloud.compute.v1.SecurityPolicyReference;

                    /**
                     * Encodes the specified SecurityPolicyReference message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyReference.verify|verify} messages.
                     * @param message SecurityPolicyReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyReference.verify|verify} messages.
                     * @param message SecurityPolicyReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyReference;

                    /**
                     * Decodes a SecurityPolicyReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyReference;

                    /**
                     * Verifies a SecurityPolicyReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyReference;

                    /**
                     * Creates a plain object from a SecurityPolicyReference message. Also converts values to other types if specified.
                     * @param message SecurityPolicyReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRule. */
                interface ISecurityPolicyRule {

                    /** SecurityPolicyRule action */
                    action?: (string|null);

                    /** SecurityPolicyRule description */
                    description?: (string|null);

                    /** SecurityPolicyRule headerAction */
                    headerAction?: (google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderAction|null);

                    /** SecurityPolicyRule kind */
                    kind?: (string|null);

                    /** SecurityPolicyRule match */
                    match?: (google.cloud.compute.v1.ISecurityPolicyRuleMatcher|null);

                    /** SecurityPolicyRule preview */
                    preview?: (boolean|null);

                    /** SecurityPolicyRule priority */
                    priority?: (number|null);

                    /** SecurityPolicyRule rateLimitOptions */
                    rateLimitOptions?: (google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptions|null);

                    /** SecurityPolicyRule redirectOptions */
                    redirectOptions?: (google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions|null);
                }

                /** Represents a SecurityPolicyRule. */
                class SecurityPolicyRule implements ISecurityPolicyRule {

                    /**
                     * Constructs a new SecurityPolicyRule.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRule);

                    /** SecurityPolicyRule action. */
                    public action?: (string|null);

                    /** SecurityPolicyRule description. */
                    public description?: (string|null);

                    /** SecurityPolicyRule headerAction. */
                    public headerAction?: (google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderAction|null);

                    /** SecurityPolicyRule kind. */
                    public kind?: (string|null);

                    /** SecurityPolicyRule match. */
                    public match?: (google.cloud.compute.v1.ISecurityPolicyRuleMatcher|null);

                    /** SecurityPolicyRule preview. */
                    public preview?: (boolean|null);

                    /** SecurityPolicyRule priority. */
                    public priority?: (number|null);

                    /** SecurityPolicyRule rateLimitOptions. */
                    public rateLimitOptions?: (google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptions|null);

                    /** SecurityPolicyRule redirectOptions. */
                    public redirectOptions?: (google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions|null);

                    /** SecurityPolicyRule _action. */
                    public _action?: "action";

                    /** SecurityPolicyRule _description. */
                    public _description?: "description";

                    /** SecurityPolicyRule _headerAction. */
                    public _headerAction?: "headerAction";

                    /** SecurityPolicyRule _kind. */
                    public _kind?: "kind";

                    /** SecurityPolicyRule _match. */
                    public _match?: "match";

                    /** SecurityPolicyRule _preview. */
                    public _preview?: "preview";

                    /** SecurityPolicyRule _priority. */
                    public _priority?: "priority";

                    /** SecurityPolicyRule _rateLimitOptions. */
                    public _rateLimitOptions?: "rateLimitOptions";

                    /** SecurityPolicyRule _redirectOptions. */
                    public _redirectOptions?: "redirectOptions";

                    /**
                     * Creates a new SecurityPolicyRule instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRule instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRule): google.cloud.compute.v1.SecurityPolicyRule;

                    /**
                     * Encodes the specified SecurityPolicyRule message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRule.verify|verify} messages.
                     * @param message SecurityPolicyRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRule message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRule.verify|verify} messages.
                     * @param message SecurityPolicyRule message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRule, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRule message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRule;

                    /**
                     * Decodes a SecurityPolicyRule message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRule
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRule;

                    /**
                     * Verifies a SecurityPolicyRule message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRule message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRule
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRule;

                    /**
                     * Creates a plain object from a SecurityPolicyRule message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRule
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRule to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRule
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRuleHttpHeaderAction. */
                interface ISecurityPolicyRuleHttpHeaderAction {

                    /** SecurityPolicyRuleHttpHeaderAction requestHeadersToAdds */
                    requestHeadersToAdds?: (google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption[]|null);
                }

                /** Represents a SecurityPolicyRuleHttpHeaderAction. */
                class SecurityPolicyRuleHttpHeaderAction implements ISecurityPolicyRuleHttpHeaderAction {

                    /**
                     * Constructs a new SecurityPolicyRuleHttpHeaderAction.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderAction);

                    /** SecurityPolicyRuleHttpHeaderAction requestHeadersToAdds. */
                    public requestHeadersToAdds: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption[];

                    /**
                     * Creates a new SecurityPolicyRuleHttpHeaderAction instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleHttpHeaderAction instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderAction): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction;

                    /**
                     * Encodes the specified SecurityPolicyRuleHttpHeaderAction message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction.verify|verify} messages.
                     * @param message SecurityPolicyRuleHttpHeaderAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleHttpHeaderAction message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction.verify|verify} messages.
                     * @param message SecurityPolicyRuleHttpHeaderAction message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderAction, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleHttpHeaderAction message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleHttpHeaderAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction;

                    /**
                     * Decodes a SecurityPolicyRuleHttpHeaderAction message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleHttpHeaderAction
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction;

                    /**
                     * Verifies a SecurityPolicyRuleHttpHeaderAction message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleHttpHeaderAction message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleHttpHeaderAction
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleHttpHeaderAction message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleHttpHeaderAction
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderAction, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleHttpHeaderAction to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleHttpHeaderAction
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption. */
                interface ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption {

                    /** SecurityPolicyRuleHttpHeaderActionHttpHeaderOption headerName */
                    headerName?: (string|null);

                    /** SecurityPolicyRuleHttpHeaderActionHttpHeaderOption headerValue */
                    headerValue?: (string|null);
                }

                /** Represents a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption. */
                class SecurityPolicyRuleHttpHeaderActionHttpHeaderOption implements ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption {

                    /**
                     * Constructs a new SecurityPolicyRuleHttpHeaderActionHttpHeaderOption.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption);

                    /** SecurityPolicyRuleHttpHeaderActionHttpHeaderOption headerName. */
                    public headerName?: (string|null);

                    /** SecurityPolicyRuleHttpHeaderActionHttpHeaderOption headerValue. */
                    public headerValue?: (string|null);

                    /** SecurityPolicyRuleHttpHeaderActionHttpHeaderOption _headerName. */
                    public _headerName?: "headerName";

                    /** SecurityPolicyRuleHttpHeaderActionHttpHeaderOption _headerValue. */
                    public _headerValue?: "headerValue";

                    /**
                     * Creates a new SecurityPolicyRuleHttpHeaderActionHttpHeaderOption instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleHttpHeaderActionHttpHeaderOption instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption;

                    /**
                     * Encodes the specified SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption.verify|verify} messages.
                     * @param message SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption.verify|verify} messages.
                     * @param message SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleHttpHeaderActionHttpHeaderOption, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleHttpHeaderActionHttpHeaderOption
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption;

                    /**
                     * Decodes a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleHttpHeaderActionHttpHeaderOption
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption;

                    /**
                     * Verifies a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleHttpHeaderActionHttpHeaderOption
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleHttpHeaderActionHttpHeaderOption message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleHttpHeaderActionHttpHeaderOption
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleHttpHeaderActionHttpHeaderOption to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleHttpHeaderActionHttpHeaderOption
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRuleMatcher. */
                interface ISecurityPolicyRuleMatcher {

                    /** SecurityPolicyRuleMatcher config */
                    config?: (google.cloud.compute.v1.ISecurityPolicyRuleMatcherConfig|null);

                    /** SecurityPolicyRuleMatcher expr */
                    expr?: (google.cloud.compute.v1.IExpr|null);

                    /** SecurityPolicyRuleMatcher versionedExpr */
                    versionedExpr?: (string|null);
                }

                /** Represents a SecurityPolicyRuleMatcher. */
                class SecurityPolicyRuleMatcher implements ISecurityPolicyRuleMatcher {

                    /**
                     * Constructs a new SecurityPolicyRuleMatcher.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleMatcher);

                    /** SecurityPolicyRuleMatcher config. */
                    public config?: (google.cloud.compute.v1.ISecurityPolicyRuleMatcherConfig|null);

                    /** SecurityPolicyRuleMatcher expr. */
                    public expr?: (google.cloud.compute.v1.IExpr|null);

                    /** SecurityPolicyRuleMatcher versionedExpr. */
                    public versionedExpr?: (string|null);

                    /** SecurityPolicyRuleMatcher _config. */
                    public _config?: "config";

                    /** SecurityPolicyRuleMatcher _expr. */
                    public _expr?: "expr";

                    /** SecurityPolicyRuleMatcher _versionedExpr. */
                    public _versionedExpr?: "versionedExpr";

                    /**
                     * Creates a new SecurityPolicyRuleMatcher instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleMatcher instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleMatcher): google.cloud.compute.v1.SecurityPolicyRuleMatcher;

                    /**
                     * Encodes the specified SecurityPolicyRuleMatcher message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleMatcher.verify|verify} messages.
                     * @param message SecurityPolicyRuleMatcher message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleMatcher, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleMatcher message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleMatcher.verify|verify} messages.
                     * @param message SecurityPolicyRuleMatcher message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleMatcher, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleMatcher message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleMatcher
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleMatcher;

                    /**
                     * Decodes a SecurityPolicyRuleMatcher message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleMatcher
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleMatcher;

                    /**
                     * Verifies a SecurityPolicyRuleMatcher message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleMatcher message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleMatcher
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleMatcher;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleMatcher message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleMatcher
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleMatcher, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleMatcher to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleMatcher
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicyRuleMatcher {

                    /** VersionedExpr enum. */
                    enum VersionedExpr {
                        UNDEFINED_VERSIONED_EXPR = 0,
                        SRC_IPS_V1 = 70925961
                    }
                }

                /** Properties of a SecurityPolicyRuleMatcherConfig. */
                interface ISecurityPolicyRuleMatcherConfig {

                    /** SecurityPolicyRuleMatcherConfig srcIpRanges */
                    srcIpRanges?: (string[]|null);
                }

                /** Represents a SecurityPolicyRuleMatcherConfig. */
                class SecurityPolicyRuleMatcherConfig implements ISecurityPolicyRuleMatcherConfig {

                    /**
                     * Constructs a new SecurityPolicyRuleMatcherConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleMatcherConfig);

                    /** SecurityPolicyRuleMatcherConfig srcIpRanges. */
                    public srcIpRanges: string[];

                    /**
                     * Creates a new SecurityPolicyRuleMatcherConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleMatcherConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleMatcherConfig): google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig;

                    /**
                     * Encodes the specified SecurityPolicyRuleMatcherConfig message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig.verify|verify} messages.
                     * @param message SecurityPolicyRuleMatcherConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleMatcherConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleMatcherConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig.verify|verify} messages.
                     * @param message SecurityPolicyRuleMatcherConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleMatcherConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleMatcherConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleMatcherConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig;

                    /**
                     * Decodes a SecurityPolicyRuleMatcherConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleMatcherConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig;

                    /**
                     * Verifies a SecurityPolicyRuleMatcherConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleMatcherConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleMatcherConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleMatcherConfig message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleMatcherConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleMatcherConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleMatcherConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleMatcherConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRuleRateLimitOptions. */
                interface ISecurityPolicyRuleRateLimitOptions {

                    /** SecurityPolicyRuleRateLimitOptions banDurationSec */
                    banDurationSec?: (number|null);

                    /** SecurityPolicyRuleRateLimitOptions banThreshold */
                    banThreshold?: (google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold|null);

                    /** SecurityPolicyRuleRateLimitOptions conformAction */
                    conformAction?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions enforceOnKey */
                    enforceOnKey?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions enforceOnKeyName */
                    enforceOnKeyName?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions exceedAction */
                    exceedAction?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions exceedRedirectOptions */
                    exceedRedirectOptions?: (google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions|null);

                    /** SecurityPolicyRuleRateLimitOptions rateLimitThreshold */
                    rateLimitThreshold?: (google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold|null);
                }

                /** Represents a SecurityPolicyRuleRateLimitOptions. */
                class SecurityPolicyRuleRateLimitOptions implements ISecurityPolicyRuleRateLimitOptions {

                    /**
                     * Constructs a new SecurityPolicyRuleRateLimitOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptions);

                    /** SecurityPolicyRuleRateLimitOptions banDurationSec. */
                    public banDurationSec?: (number|null);

                    /** SecurityPolicyRuleRateLimitOptions banThreshold. */
                    public banThreshold?: (google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold|null);

                    /** SecurityPolicyRuleRateLimitOptions conformAction. */
                    public conformAction?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions enforceOnKey. */
                    public enforceOnKey?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions enforceOnKeyName. */
                    public enforceOnKeyName?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions exceedAction. */
                    public exceedAction?: (string|null);

                    /** SecurityPolicyRuleRateLimitOptions exceedRedirectOptions. */
                    public exceedRedirectOptions?: (google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions|null);

                    /** SecurityPolicyRuleRateLimitOptions rateLimitThreshold. */
                    public rateLimitThreshold?: (google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold|null);

                    /** SecurityPolicyRuleRateLimitOptions _banDurationSec. */
                    public _banDurationSec?: "banDurationSec";

                    /** SecurityPolicyRuleRateLimitOptions _banThreshold. */
                    public _banThreshold?: "banThreshold";

                    /** SecurityPolicyRuleRateLimitOptions _conformAction. */
                    public _conformAction?: "conformAction";

                    /** SecurityPolicyRuleRateLimitOptions _enforceOnKey. */
                    public _enforceOnKey?: "enforceOnKey";

                    /** SecurityPolicyRuleRateLimitOptions _enforceOnKeyName. */
                    public _enforceOnKeyName?: "enforceOnKeyName";

                    /** SecurityPolicyRuleRateLimitOptions _exceedAction. */
                    public _exceedAction?: "exceedAction";

                    /** SecurityPolicyRuleRateLimitOptions _exceedRedirectOptions. */
                    public _exceedRedirectOptions?: "exceedRedirectOptions";

                    /** SecurityPolicyRuleRateLimitOptions _rateLimitThreshold. */
                    public _rateLimitThreshold?: "rateLimitThreshold";

                    /**
                     * Creates a new SecurityPolicyRuleRateLimitOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleRateLimitOptions instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptions): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions;

                    /**
                     * Encodes the specified SecurityPolicyRuleRateLimitOptions message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions.verify|verify} messages.
                     * @param message SecurityPolicyRuleRateLimitOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleRateLimitOptions message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions.verify|verify} messages.
                     * @param message SecurityPolicyRuleRateLimitOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleRateLimitOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleRateLimitOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions;

                    /**
                     * Decodes a SecurityPolicyRuleRateLimitOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleRateLimitOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions;

                    /**
                     * Verifies a SecurityPolicyRuleRateLimitOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleRateLimitOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleRateLimitOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleRateLimitOptions message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleRateLimitOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleRateLimitOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleRateLimitOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicyRuleRateLimitOptions {

                    /** EnforceOnKey enum. */
                    enum EnforceOnKey {
                        UNDEFINED_ENFORCE_ON_KEY = 0,
                        ALL = 64897,
                        HTTP_COOKIE = 494981627,
                        HTTP_HEADER = 91597348,
                        HTTP_PATH = 311503228,
                        IP = 2343,
                        REGION_CODE = 79559768,
                        SNI = 82254,
                        XFF_IP = 438707118
                    }
                }

                /** Properties of a SecurityPolicyRuleRateLimitOptionsThreshold. */
                interface ISecurityPolicyRuleRateLimitOptionsThreshold {

                    /** SecurityPolicyRuleRateLimitOptionsThreshold count */
                    count?: (number|null);

                    /** SecurityPolicyRuleRateLimitOptionsThreshold intervalSec */
                    intervalSec?: (number|null);
                }

                /** Represents a SecurityPolicyRuleRateLimitOptionsThreshold. */
                class SecurityPolicyRuleRateLimitOptionsThreshold implements ISecurityPolicyRuleRateLimitOptionsThreshold {

                    /**
                     * Constructs a new SecurityPolicyRuleRateLimitOptionsThreshold.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold);

                    /** SecurityPolicyRuleRateLimitOptionsThreshold count. */
                    public count?: (number|null);

                    /** SecurityPolicyRuleRateLimitOptionsThreshold intervalSec. */
                    public intervalSec?: (number|null);

                    /** SecurityPolicyRuleRateLimitOptionsThreshold _count. */
                    public _count?: "count";

                    /** SecurityPolicyRuleRateLimitOptionsThreshold _intervalSec. */
                    public _intervalSec?: "intervalSec";

                    /**
                     * Creates a new SecurityPolicyRuleRateLimitOptionsThreshold instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleRateLimitOptionsThreshold instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold;

                    /**
                     * Encodes the specified SecurityPolicyRuleRateLimitOptionsThreshold message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold.verify|verify} messages.
                     * @param message SecurityPolicyRuleRateLimitOptionsThreshold message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleRateLimitOptionsThreshold message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold.verify|verify} messages.
                     * @param message SecurityPolicyRuleRateLimitOptionsThreshold message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleRateLimitOptionsThreshold, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleRateLimitOptionsThreshold message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleRateLimitOptionsThreshold
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold;

                    /**
                     * Decodes a SecurityPolicyRuleRateLimitOptionsThreshold message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleRateLimitOptionsThreshold
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold;

                    /**
                     * Verifies a SecurityPolicyRuleRateLimitOptionsThreshold message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleRateLimitOptionsThreshold message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleRateLimitOptionsThreshold
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleRateLimitOptionsThreshold message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleRateLimitOptionsThreshold
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleRateLimitOptionsThreshold, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleRateLimitOptionsThreshold to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleRateLimitOptionsThreshold
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SecurityPolicyRuleRedirectOptions. */
                interface ISecurityPolicyRuleRedirectOptions {

                    /** SecurityPolicyRuleRedirectOptions target */
                    target?: (string|null);

                    /** SecurityPolicyRuleRedirectOptions type */
                    type?: (string|null);
                }

                /** Represents a SecurityPolicyRuleRedirectOptions. */
                class SecurityPolicyRuleRedirectOptions implements ISecurityPolicyRuleRedirectOptions {

                    /**
                     * Constructs a new SecurityPolicyRuleRedirectOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions);

                    /** SecurityPolicyRuleRedirectOptions target. */
                    public target?: (string|null);

                    /** SecurityPolicyRuleRedirectOptions type. */
                    public type?: (string|null);

                    /** SecurityPolicyRuleRedirectOptions _target. */
                    public _target?: "target";

                    /** SecurityPolicyRuleRedirectOptions _type. */
                    public _type?: "type";

                    /**
                     * Creates a new SecurityPolicyRuleRedirectOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecurityPolicyRuleRedirectOptions instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions): google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions;

                    /**
                     * Encodes the specified SecurityPolicyRuleRedirectOptions message. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions.verify|verify} messages.
                     * @param message SecurityPolicyRuleRedirectOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecurityPolicyRuleRedirectOptions message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions.verify|verify} messages.
                     * @param message SecurityPolicyRuleRedirectOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecurityPolicyRuleRedirectOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecurityPolicyRuleRedirectOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecurityPolicyRuleRedirectOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions;

                    /**
                     * Decodes a SecurityPolicyRuleRedirectOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecurityPolicyRuleRedirectOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions;

                    /**
                     * Verifies a SecurityPolicyRuleRedirectOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecurityPolicyRuleRedirectOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecurityPolicyRuleRedirectOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions;

                    /**
                     * Creates a plain object from a SecurityPolicyRuleRedirectOptions message. Also converts values to other types if specified.
                     * @param message SecurityPolicyRuleRedirectOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecurityPolicyRuleRedirectOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecurityPolicyRuleRedirectOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecurityPolicyRuleRedirectOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SecurityPolicyRuleRedirectOptions {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        EXTERNAL_302 = 395733761,
                        GOOGLE_RECAPTCHA = 518803009
                    }
                }

                /** Properties of a SecuritySettings. */
                interface ISecuritySettings {

                    /** SecuritySettings clientTlsPolicy */
                    clientTlsPolicy?: (string|null);

                    /** SecuritySettings subjectAltNames */
                    subjectAltNames?: (string[]|null);
                }

                /** Represents a SecuritySettings. */
                class SecuritySettings implements ISecuritySettings {

                    /**
                     * Constructs a new SecuritySettings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISecuritySettings);

                    /** SecuritySettings clientTlsPolicy. */
                    public clientTlsPolicy?: (string|null);

                    /** SecuritySettings subjectAltNames. */
                    public subjectAltNames: string[];

                    /** SecuritySettings _clientTlsPolicy. */
                    public _clientTlsPolicy?: "clientTlsPolicy";

                    /**
                     * Creates a new SecuritySettings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SecuritySettings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISecuritySettings): google.cloud.compute.v1.SecuritySettings;

                    /**
                     * Encodes the specified SecuritySettings message. Does not implicitly {@link google.cloud.compute.v1.SecuritySettings.verify|verify} messages.
                     * @param message SecuritySettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISecuritySettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SecuritySettings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SecuritySettings.verify|verify} messages.
                     * @param message SecuritySettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISecuritySettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SecuritySettings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SecuritySettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SecuritySettings;

                    /**
                     * Decodes a SecuritySettings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SecuritySettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SecuritySettings;

                    /**
                     * Verifies a SecuritySettings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SecuritySettings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SecuritySettings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SecuritySettings;

                    /**
                     * Creates a plain object from a SecuritySettings message. Also converts values to other types if specified.
                     * @param message SecuritySettings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SecuritySettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SecuritySettings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SecuritySettings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SendDiagnosticInterruptInstanceRequest. */
                interface ISendDiagnosticInterruptInstanceRequest {

                    /** SendDiagnosticInterruptInstanceRequest instance */
                    instance?: (string|null);

                    /** SendDiagnosticInterruptInstanceRequest project */
                    project?: (string|null);

                    /** SendDiagnosticInterruptInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SendDiagnosticInterruptInstanceRequest. */
                class SendDiagnosticInterruptInstanceRequest implements ISendDiagnosticInterruptInstanceRequest {

                    /**
                     * Constructs a new SendDiagnosticInterruptInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceRequest);

                    /** SendDiagnosticInterruptInstanceRequest instance. */
                    public instance: string;

                    /** SendDiagnosticInterruptInstanceRequest project. */
                    public project: string;

                    /** SendDiagnosticInterruptInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new SendDiagnosticInterruptInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SendDiagnosticInterruptInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceRequest): google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest;

                    /**
                     * Encodes the specified SendDiagnosticInterruptInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest.verify|verify} messages.
                     * @param message SendDiagnosticInterruptInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SendDiagnosticInterruptInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest.verify|verify} messages.
                     * @param message SendDiagnosticInterruptInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SendDiagnosticInterruptInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SendDiagnosticInterruptInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest;

                    /**
                     * Decodes a SendDiagnosticInterruptInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SendDiagnosticInterruptInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest;

                    /**
                     * Verifies a SendDiagnosticInterruptInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SendDiagnosticInterruptInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SendDiagnosticInterruptInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest;

                    /**
                     * Creates a plain object from a SendDiagnosticInterruptInstanceRequest message. Also converts values to other types if specified.
                     * @param message SendDiagnosticInterruptInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SendDiagnosticInterruptInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SendDiagnosticInterruptInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SendDiagnosticInterruptInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SendDiagnosticInterruptInstanceResponse. */
                interface ISendDiagnosticInterruptInstanceResponse {
                }

                /** Represents a SendDiagnosticInterruptInstanceResponse. */
                class SendDiagnosticInterruptInstanceResponse implements ISendDiagnosticInterruptInstanceResponse {

                    /**
                     * Constructs a new SendDiagnosticInterruptInstanceResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceResponse);

                    /**
                     * Creates a new SendDiagnosticInterruptInstanceResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SendDiagnosticInterruptInstanceResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceResponse): google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse;

                    /**
                     * Encodes the specified SendDiagnosticInterruptInstanceResponse message. Does not implicitly {@link google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse.verify|verify} messages.
                     * @param message SendDiagnosticInterruptInstanceResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SendDiagnosticInterruptInstanceResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse.verify|verify} messages.
                     * @param message SendDiagnosticInterruptInstanceResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SendDiagnosticInterruptInstanceResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SendDiagnosticInterruptInstanceResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse;

                    /**
                     * Decodes a SendDiagnosticInterruptInstanceResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SendDiagnosticInterruptInstanceResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse;

                    /**
                     * Verifies a SendDiagnosticInterruptInstanceResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SendDiagnosticInterruptInstanceResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SendDiagnosticInterruptInstanceResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse;

                    /**
                     * Creates a plain object from a SendDiagnosticInterruptInstanceResponse message. Also converts values to other types if specified.
                     * @param message SendDiagnosticInterruptInstanceResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SendDiagnosticInterruptInstanceResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SendDiagnosticInterruptInstanceResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SerialPortOutput. */
                interface ISerialPortOutput {

                    /** SerialPortOutput contents */
                    contents?: (string|null);

                    /** SerialPortOutput kind */
                    kind?: (string|null);

                    /** SerialPortOutput next */
                    next?: (number|Long|string|null);

                    /** SerialPortOutput selfLink */
                    selfLink?: (string|null);

                    /** SerialPortOutput start */
                    start?: (number|Long|string|null);
                }

                /** Represents a SerialPortOutput. */
                class SerialPortOutput implements ISerialPortOutput {

                    /**
                     * Constructs a new SerialPortOutput.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISerialPortOutput);

                    /** SerialPortOutput contents. */
                    public contents?: (string|null);

                    /** SerialPortOutput kind. */
                    public kind?: (string|null);

                    /** SerialPortOutput next. */
                    public next?: (number|Long|string|null);

                    /** SerialPortOutput selfLink. */
                    public selfLink?: (string|null);

                    /** SerialPortOutput start. */
                    public start?: (number|Long|string|null);

                    /** SerialPortOutput _contents. */
                    public _contents?: "contents";

                    /** SerialPortOutput _kind. */
                    public _kind?: "kind";

                    /** SerialPortOutput _next. */
                    public _next?: "next";

                    /** SerialPortOutput _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SerialPortOutput _start. */
                    public _start?: "start";

                    /**
                     * Creates a new SerialPortOutput instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SerialPortOutput instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISerialPortOutput): google.cloud.compute.v1.SerialPortOutput;

                    /**
                     * Encodes the specified SerialPortOutput message. Does not implicitly {@link google.cloud.compute.v1.SerialPortOutput.verify|verify} messages.
                     * @param message SerialPortOutput message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISerialPortOutput, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SerialPortOutput message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SerialPortOutput.verify|verify} messages.
                     * @param message SerialPortOutput message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISerialPortOutput, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SerialPortOutput message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SerialPortOutput
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SerialPortOutput;

                    /**
                     * Decodes a SerialPortOutput message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SerialPortOutput
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SerialPortOutput;

                    /**
                     * Verifies a SerialPortOutput message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SerialPortOutput message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SerialPortOutput
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SerialPortOutput;

                    /**
                     * Creates a plain object from a SerialPortOutput message. Also converts values to other types if specified.
                     * @param message SerialPortOutput
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SerialPortOutput, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SerialPortOutput to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SerialPortOutput
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ServerBinding. */
                interface IServerBinding {

                    /** ServerBinding type */
                    type?: (string|null);
                }

                /** Represents a ServerBinding. */
                class ServerBinding implements IServerBinding {

                    /**
                     * Constructs a new ServerBinding.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServerBinding);

                    /** ServerBinding type. */
                    public type?: (string|null);

                    /** ServerBinding _type. */
                    public _type?: "type";

                    /**
                     * Creates a new ServerBinding instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServerBinding instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServerBinding): google.cloud.compute.v1.ServerBinding;

                    /**
                     * Encodes the specified ServerBinding message. Does not implicitly {@link google.cloud.compute.v1.ServerBinding.verify|verify} messages.
                     * @param message ServerBinding message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServerBinding, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServerBinding message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServerBinding.verify|verify} messages.
                     * @param message ServerBinding message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServerBinding, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServerBinding message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServerBinding
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServerBinding;

                    /**
                     * Decodes a ServerBinding message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServerBinding
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServerBinding;

                    /**
                     * Verifies a ServerBinding message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServerBinding message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServerBinding
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServerBinding;

                    /**
                     * Creates a plain object from a ServerBinding message. Also converts values to other types if specified.
                     * @param message ServerBinding
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServerBinding, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServerBinding to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServerBinding
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ServerBinding {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        RESTART_NODE_ON_ANY_SERVER = 502950985,
                        RESTART_NODE_ON_MINIMAL_SERVERS = 204166495,
                        SERVER_BINDING_TYPE_UNSPECIFIED = 180825512
                    }
                }

                /** Properties of a ServiceAccount. */
                interface IServiceAccount {

                    /** ServiceAccount email */
                    email?: (string|null);

                    /** ServiceAccount scopes */
                    scopes?: (string[]|null);
                }

                /** Represents a ServiceAccount. */
                class ServiceAccount implements IServiceAccount {

                    /**
                     * Constructs a new ServiceAccount.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAccount);

                    /** ServiceAccount email. */
                    public email?: (string|null);

                    /** ServiceAccount scopes. */
                    public scopes: string[];

                    /** ServiceAccount _email. */
                    public _email?: "email";

                    /**
                     * Creates a new ServiceAccount instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAccount instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAccount): google.cloud.compute.v1.ServiceAccount;

                    /**
                     * Encodes the specified ServiceAccount message. Does not implicitly {@link google.cloud.compute.v1.ServiceAccount.verify|verify} messages.
                     * @param message ServiceAccount message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAccount, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAccount message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAccount.verify|verify} messages.
                     * @param message ServiceAccount message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAccount, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAccount message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAccount
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAccount;

                    /**
                     * Decodes a ServiceAccount message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAccount
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAccount;

                    /**
                     * Verifies a ServiceAccount message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAccount message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAccount
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAccount;

                    /**
                     * Creates a plain object from a ServiceAccount message. Also converts values to other types if specified.
                     * @param message ServiceAccount
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAccount, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAccount to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAccount
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ServiceAttachment. */
                interface IServiceAttachment {

                    /** ServiceAttachment connectedEndpoints */
                    connectedEndpoints?: (google.cloud.compute.v1.IServiceAttachmentConnectedEndpoint[]|null);

                    /** ServiceAttachment connectionPreference */
                    connectionPreference?: (string|null);

                    /** ServiceAttachment consumerAcceptLists */
                    consumerAcceptLists?: (google.cloud.compute.v1.IServiceAttachmentConsumerProjectLimit[]|null);

                    /** ServiceAttachment consumerRejectLists */
                    consumerRejectLists?: (string[]|null);

                    /** ServiceAttachment creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** ServiceAttachment description */
                    description?: (string|null);

                    /** ServiceAttachment domainNames */
                    domainNames?: (string[]|null);

                    /** ServiceAttachment enableProxyProtocol */
                    enableProxyProtocol?: (boolean|null);

                    /** ServiceAttachment fingerprint */
                    fingerprint?: (string|null);

                    /** ServiceAttachment id */
                    id?: (number|Long|string|null);

                    /** ServiceAttachment kind */
                    kind?: (string|null);

                    /** ServiceAttachment name */
                    name?: (string|null);

                    /** ServiceAttachment natSubnets */
                    natSubnets?: (string[]|null);

                    /** ServiceAttachment producerForwardingRule */
                    producerForwardingRule?: (string|null);

                    /** ServiceAttachment pscServiceAttachmentId */
                    pscServiceAttachmentId?: (google.cloud.compute.v1.IUint128|null);

                    /** ServiceAttachment region */
                    region?: (string|null);

                    /** ServiceAttachment selfLink */
                    selfLink?: (string|null);

                    /** ServiceAttachment targetService */
                    targetService?: (string|null);
                }

                /** Represents a ServiceAttachment. */
                class ServiceAttachment implements IServiceAttachment {

                    /**
                     * Constructs a new ServiceAttachment.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAttachment);

                    /** ServiceAttachment connectedEndpoints. */
                    public connectedEndpoints: google.cloud.compute.v1.IServiceAttachmentConnectedEndpoint[];

                    /** ServiceAttachment connectionPreference. */
                    public connectionPreference?: (string|null);

                    /** ServiceAttachment consumerAcceptLists. */
                    public consumerAcceptLists: google.cloud.compute.v1.IServiceAttachmentConsumerProjectLimit[];

                    /** ServiceAttachment consumerRejectLists. */
                    public consumerRejectLists: string[];

                    /** ServiceAttachment creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** ServiceAttachment description. */
                    public description?: (string|null);

                    /** ServiceAttachment domainNames. */
                    public domainNames: string[];

                    /** ServiceAttachment enableProxyProtocol. */
                    public enableProxyProtocol?: (boolean|null);

                    /** ServiceAttachment fingerprint. */
                    public fingerprint?: (string|null);

                    /** ServiceAttachment id. */
                    public id?: (number|Long|string|null);

                    /** ServiceAttachment kind. */
                    public kind?: (string|null);

                    /** ServiceAttachment name. */
                    public name?: (string|null);

                    /** ServiceAttachment natSubnets. */
                    public natSubnets: string[];

                    /** ServiceAttachment producerForwardingRule. */
                    public producerForwardingRule?: (string|null);

                    /** ServiceAttachment pscServiceAttachmentId. */
                    public pscServiceAttachmentId?: (google.cloud.compute.v1.IUint128|null);

                    /** ServiceAttachment region. */
                    public region?: (string|null);

                    /** ServiceAttachment selfLink. */
                    public selfLink?: (string|null);

                    /** ServiceAttachment targetService. */
                    public targetService?: (string|null);

                    /** ServiceAttachment _connectionPreference. */
                    public _connectionPreference?: "connectionPreference";

                    /** ServiceAttachment _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** ServiceAttachment _description. */
                    public _description?: "description";

                    /** ServiceAttachment _enableProxyProtocol. */
                    public _enableProxyProtocol?: "enableProxyProtocol";

                    /** ServiceAttachment _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** ServiceAttachment _id. */
                    public _id?: "id";

                    /** ServiceAttachment _kind. */
                    public _kind?: "kind";

                    /** ServiceAttachment _name. */
                    public _name?: "name";

                    /** ServiceAttachment _producerForwardingRule. */
                    public _producerForwardingRule?: "producerForwardingRule";

                    /** ServiceAttachment _pscServiceAttachmentId. */
                    public _pscServiceAttachmentId?: "pscServiceAttachmentId";

                    /** ServiceAttachment _region. */
                    public _region?: "region";

                    /** ServiceAttachment _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ServiceAttachment _targetService. */
                    public _targetService?: "targetService";

                    /**
                     * Creates a new ServiceAttachment instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAttachment instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAttachment): google.cloud.compute.v1.ServiceAttachment;

                    /**
                     * Encodes the specified ServiceAttachment message. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachment.verify|verify} messages.
                     * @param message ServiceAttachment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAttachment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAttachment message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachment.verify|verify} messages.
                     * @param message ServiceAttachment message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAttachment, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAttachment message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAttachment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAttachment;

                    /**
                     * Decodes a ServiceAttachment message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAttachment
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAttachment;

                    /**
                     * Verifies a ServiceAttachment message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAttachment message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAttachment
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAttachment;

                    /**
                     * Creates a plain object from a ServiceAttachment message. Also converts values to other types if specified.
                     * @param message ServiceAttachment
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAttachment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAttachment to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAttachment
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ServiceAttachment {

                    /** ConnectionPreference enum. */
                    enum ConnectionPreference {
                        UNDEFINED_CONNECTION_PREFERENCE = 0,
                        ACCEPT_AUTOMATIC = 75250580,
                        ACCEPT_MANUAL = 373061341,
                        CONNECTION_PREFERENCE_UNSPECIFIED = 34590772
                    }
                }

                /** Properties of a ServiceAttachmentAggregatedList. */
                interface IServiceAttachmentAggregatedList {

                    /** ServiceAttachmentAggregatedList id */
                    id?: (string|null);

                    /** ServiceAttachmentAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IServiceAttachmentsScopedList }|null);

                    /** ServiceAttachmentAggregatedList kind */
                    kind?: (string|null);

                    /** ServiceAttachmentAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ServiceAttachmentAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** ServiceAttachmentAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** ServiceAttachmentAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ServiceAttachmentAggregatedList. */
                class ServiceAttachmentAggregatedList implements IServiceAttachmentAggregatedList {

                    /**
                     * Constructs a new ServiceAttachmentAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAttachmentAggregatedList);

                    /** ServiceAttachmentAggregatedList id. */
                    public id?: (string|null);

                    /** ServiceAttachmentAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IServiceAttachmentsScopedList };

                    /** ServiceAttachmentAggregatedList kind. */
                    public kind?: (string|null);

                    /** ServiceAttachmentAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ServiceAttachmentAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** ServiceAttachmentAggregatedList unreachables. */
                    public unreachables: string[];

                    /** ServiceAttachmentAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ServiceAttachmentAggregatedList _id. */
                    public _id?: "id";

                    /** ServiceAttachmentAggregatedList _kind. */
                    public _kind?: "kind";

                    /** ServiceAttachmentAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ServiceAttachmentAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ServiceAttachmentAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ServiceAttachmentAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAttachmentAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAttachmentAggregatedList): google.cloud.compute.v1.ServiceAttachmentAggregatedList;

                    /**
                     * Encodes the specified ServiceAttachmentAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentAggregatedList.verify|verify} messages.
                     * @param message ServiceAttachmentAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAttachmentAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAttachmentAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentAggregatedList.verify|verify} messages.
                     * @param message ServiceAttachmentAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAttachmentAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAttachmentAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAttachmentAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAttachmentAggregatedList;

                    /**
                     * Decodes a ServiceAttachmentAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAttachmentAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAttachmentAggregatedList;

                    /**
                     * Verifies a ServiceAttachmentAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAttachmentAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAttachmentAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAttachmentAggregatedList;

                    /**
                     * Creates a plain object from a ServiceAttachmentAggregatedList message. Also converts values to other types if specified.
                     * @param message ServiceAttachmentAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAttachmentAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAttachmentAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAttachmentAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ServiceAttachmentConnectedEndpoint. */
                interface IServiceAttachmentConnectedEndpoint {

                    /** ServiceAttachmentConnectedEndpoint endpoint */
                    endpoint?: (string|null);

                    /** ServiceAttachmentConnectedEndpoint pscConnectionId */
                    pscConnectionId?: (number|Long|string|null);

                    /** ServiceAttachmentConnectedEndpoint status */
                    status?: (string|null);
                }

                /** Represents a ServiceAttachmentConnectedEndpoint. */
                class ServiceAttachmentConnectedEndpoint implements IServiceAttachmentConnectedEndpoint {

                    /**
                     * Constructs a new ServiceAttachmentConnectedEndpoint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAttachmentConnectedEndpoint);

                    /** ServiceAttachmentConnectedEndpoint endpoint. */
                    public endpoint?: (string|null);

                    /** ServiceAttachmentConnectedEndpoint pscConnectionId. */
                    public pscConnectionId?: (number|Long|string|null);

                    /** ServiceAttachmentConnectedEndpoint status. */
                    public status?: (string|null);

                    /** ServiceAttachmentConnectedEndpoint _endpoint. */
                    public _endpoint?: "endpoint";

                    /** ServiceAttachmentConnectedEndpoint _pscConnectionId. */
                    public _pscConnectionId?: "pscConnectionId";

                    /** ServiceAttachmentConnectedEndpoint _status. */
                    public _status?: "status";

                    /**
                     * Creates a new ServiceAttachmentConnectedEndpoint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAttachmentConnectedEndpoint instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAttachmentConnectedEndpoint): google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint;

                    /**
                     * Encodes the specified ServiceAttachmentConnectedEndpoint message. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint.verify|verify} messages.
                     * @param message ServiceAttachmentConnectedEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAttachmentConnectedEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAttachmentConnectedEndpoint message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint.verify|verify} messages.
                     * @param message ServiceAttachmentConnectedEndpoint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAttachmentConnectedEndpoint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAttachmentConnectedEndpoint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAttachmentConnectedEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint;

                    /**
                     * Decodes a ServiceAttachmentConnectedEndpoint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAttachmentConnectedEndpoint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint;

                    /**
                     * Verifies a ServiceAttachmentConnectedEndpoint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAttachmentConnectedEndpoint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAttachmentConnectedEndpoint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint;

                    /**
                     * Creates a plain object from a ServiceAttachmentConnectedEndpoint message. Also converts values to other types if specified.
                     * @param message ServiceAttachmentConnectedEndpoint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAttachmentConnectedEndpoint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAttachmentConnectedEndpoint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAttachmentConnectedEndpoint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ServiceAttachmentConnectedEndpoint {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ACCEPTED = 246714279,
                        CLOSED = 380163436,
                        NEEDS_ATTENTION = 344491452,
                        PENDING = 35394935,
                        REJECTED = 174130302,
                        STATUS_UNSPECIFIED = 42133066
                    }
                }

                /** Properties of a ServiceAttachmentConsumerProjectLimit. */
                interface IServiceAttachmentConsumerProjectLimit {

                    /** ServiceAttachmentConsumerProjectLimit connectionLimit */
                    connectionLimit?: (number|null);

                    /** ServiceAttachmentConsumerProjectLimit projectIdOrNum */
                    projectIdOrNum?: (string|null);
                }

                /** Represents a ServiceAttachmentConsumerProjectLimit. */
                class ServiceAttachmentConsumerProjectLimit implements IServiceAttachmentConsumerProjectLimit {

                    /**
                     * Constructs a new ServiceAttachmentConsumerProjectLimit.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAttachmentConsumerProjectLimit);

                    /** ServiceAttachmentConsumerProjectLimit connectionLimit. */
                    public connectionLimit?: (number|null);

                    /** ServiceAttachmentConsumerProjectLimit projectIdOrNum. */
                    public projectIdOrNum?: (string|null);

                    /** ServiceAttachmentConsumerProjectLimit _connectionLimit. */
                    public _connectionLimit?: "connectionLimit";

                    /** ServiceAttachmentConsumerProjectLimit _projectIdOrNum. */
                    public _projectIdOrNum?: "projectIdOrNum";

                    /**
                     * Creates a new ServiceAttachmentConsumerProjectLimit instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAttachmentConsumerProjectLimit instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAttachmentConsumerProjectLimit): google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit;

                    /**
                     * Encodes the specified ServiceAttachmentConsumerProjectLimit message. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit.verify|verify} messages.
                     * @param message ServiceAttachmentConsumerProjectLimit message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAttachmentConsumerProjectLimit, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAttachmentConsumerProjectLimit message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit.verify|verify} messages.
                     * @param message ServiceAttachmentConsumerProjectLimit message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAttachmentConsumerProjectLimit, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAttachmentConsumerProjectLimit message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAttachmentConsumerProjectLimit
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit;

                    /**
                     * Decodes a ServiceAttachmentConsumerProjectLimit message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAttachmentConsumerProjectLimit
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit;

                    /**
                     * Verifies a ServiceAttachmentConsumerProjectLimit message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAttachmentConsumerProjectLimit message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAttachmentConsumerProjectLimit
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit;

                    /**
                     * Creates a plain object from a ServiceAttachmentConsumerProjectLimit message. Also converts values to other types if specified.
                     * @param message ServiceAttachmentConsumerProjectLimit
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAttachmentConsumerProjectLimit, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAttachmentConsumerProjectLimit to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAttachmentConsumerProjectLimit
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ServiceAttachmentList. */
                interface IServiceAttachmentList {

                    /** ServiceAttachmentList id */
                    id?: (string|null);

                    /** ServiceAttachmentList items */
                    items?: (google.cloud.compute.v1.IServiceAttachment[]|null);

                    /** ServiceAttachmentList kind */
                    kind?: (string|null);

                    /** ServiceAttachmentList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ServiceAttachmentList selfLink */
                    selfLink?: (string|null);

                    /** ServiceAttachmentList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ServiceAttachmentList. */
                class ServiceAttachmentList implements IServiceAttachmentList {

                    /**
                     * Constructs a new ServiceAttachmentList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAttachmentList);

                    /** ServiceAttachmentList id. */
                    public id?: (string|null);

                    /** ServiceAttachmentList items. */
                    public items: google.cloud.compute.v1.IServiceAttachment[];

                    /** ServiceAttachmentList kind. */
                    public kind?: (string|null);

                    /** ServiceAttachmentList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ServiceAttachmentList selfLink. */
                    public selfLink?: (string|null);

                    /** ServiceAttachmentList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ServiceAttachmentList _id. */
                    public _id?: "id";

                    /** ServiceAttachmentList _kind. */
                    public _kind?: "kind";

                    /** ServiceAttachmentList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ServiceAttachmentList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ServiceAttachmentList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ServiceAttachmentList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAttachmentList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAttachmentList): google.cloud.compute.v1.ServiceAttachmentList;

                    /**
                     * Encodes the specified ServiceAttachmentList message. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentList.verify|verify} messages.
                     * @param message ServiceAttachmentList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAttachmentList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAttachmentList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentList.verify|verify} messages.
                     * @param message ServiceAttachmentList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAttachmentList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAttachmentList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAttachmentList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAttachmentList;

                    /**
                     * Decodes a ServiceAttachmentList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAttachmentList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAttachmentList;

                    /**
                     * Verifies a ServiceAttachmentList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAttachmentList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAttachmentList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAttachmentList;

                    /**
                     * Creates a plain object from a ServiceAttachmentList message. Also converts values to other types if specified.
                     * @param message ServiceAttachmentList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAttachmentList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAttachmentList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAttachmentList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ServiceAttachmentsScopedList. */
                interface IServiceAttachmentsScopedList {

                    /** ServiceAttachmentsScopedList serviceAttachments */
                    serviceAttachments?: (google.cloud.compute.v1.IServiceAttachment[]|null);

                    /** ServiceAttachmentsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ServiceAttachmentsScopedList. */
                class ServiceAttachmentsScopedList implements IServiceAttachmentsScopedList {

                    /**
                     * Constructs a new ServiceAttachmentsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IServiceAttachmentsScopedList);

                    /** ServiceAttachmentsScopedList serviceAttachments. */
                    public serviceAttachments: google.cloud.compute.v1.IServiceAttachment[];

                    /** ServiceAttachmentsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ServiceAttachmentsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ServiceAttachmentsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ServiceAttachmentsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IServiceAttachmentsScopedList): google.cloud.compute.v1.ServiceAttachmentsScopedList;

                    /**
                     * Encodes the specified ServiceAttachmentsScopedList message. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentsScopedList.verify|verify} messages.
                     * @param message ServiceAttachmentsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IServiceAttachmentsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ServiceAttachmentsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ServiceAttachmentsScopedList.verify|verify} messages.
                     * @param message ServiceAttachmentsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IServiceAttachmentsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ServiceAttachmentsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ServiceAttachmentsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ServiceAttachmentsScopedList;

                    /**
                     * Decodes a ServiceAttachmentsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ServiceAttachmentsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ServiceAttachmentsScopedList;

                    /**
                     * Verifies a ServiceAttachmentsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ServiceAttachmentsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ServiceAttachmentsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ServiceAttachmentsScopedList;

                    /**
                     * Creates a plain object from a ServiceAttachmentsScopedList message. Also converts values to other types if specified.
                     * @param message ServiceAttachmentsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ServiceAttachmentsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ServiceAttachmentsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ServiceAttachmentsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetBackendServiceTargetSslProxyRequest. */
                interface ISetBackendServiceTargetSslProxyRequest {

                    /** SetBackendServiceTargetSslProxyRequest project */
                    project?: (string|null);

                    /** SetBackendServiceTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetBackendServiceTargetSslProxyRequest targetSslProxiesSetBackendServiceRequestResource */
                    targetSslProxiesSetBackendServiceRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetBackendServiceRequest|null);

                    /** SetBackendServiceTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a SetBackendServiceTargetSslProxyRequest. */
                class SetBackendServiceTargetSslProxyRequest implements ISetBackendServiceTargetSslProxyRequest {

                    /**
                     * Constructs a new SetBackendServiceTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetBackendServiceTargetSslProxyRequest);

                    /** SetBackendServiceTargetSslProxyRequest project. */
                    public project: string;

                    /** SetBackendServiceTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetBackendServiceTargetSslProxyRequest targetSslProxiesSetBackendServiceRequestResource. */
                    public targetSslProxiesSetBackendServiceRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetBackendServiceRequest|null);

                    /** SetBackendServiceTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /** SetBackendServiceTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetBackendServiceTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetBackendServiceTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetBackendServiceTargetSslProxyRequest): google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest;

                    /**
                     * Encodes the specified SetBackendServiceTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetBackendServiceTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetBackendServiceTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetBackendServiceTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetBackendServiceTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetBackendServiceTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetBackendServiceTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetBackendServiceTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest;

                    /**
                     * Decodes a SetBackendServiceTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetBackendServiceTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest;

                    /**
                     * Verifies a SetBackendServiceTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetBackendServiceTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetBackendServiceTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a SetBackendServiceTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message SetBackendServiceTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetBackendServiceTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetBackendServiceTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetBackendServiceTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetBackendServiceTargetTcpProxyRequest. */
                interface ISetBackendServiceTargetTcpProxyRequest {

                    /** SetBackendServiceTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** SetBackendServiceTargetTcpProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetBackendServiceTargetTcpProxyRequest targetTcpProxiesSetBackendServiceRequestResource */
                    targetTcpProxiesSetBackendServiceRequestResource?: (google.cloud.compute.v1.ITargetTcpProxiesSetBackendServiceRequest|null);

                    /** SetBackendServiceTargetTcpProxyRequest targetTcpProxy */
                    targetTcpProxy?: (string|null);
                }

                /** Represents a SetBackendServiceTargetTcpProxyRequest. */
                class SetBackendServiceTargetTcpProxyRequest implements ISetBackendServiceTargetTcpProxyRequest {

                    /**
                     * Constructs a new SetBackendServiceTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetBackendServiceTargetTcpProxyRequest);

                    /** SetBackendServiceTargetTcpProxyRequest project. */
                    public project: string;

                    /** SetBackendServiceTargetTcpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetBackendServiceTargetTcpProxyRequest targetTcpProxiesSetBackendServiceRequestResource. */
                    public targetTcpProxiesSetBackendServiceRequestResource?: (google.cloud.compute.v1.ITargetTcpProxiesSetBackendServiceRequest|null);

                    /** SetBackendServiceTargetTcpProxyRequest targetTcpProxy. */
                    public targetTcpProxy: string;

                    /** SetBackendServiceTargetTcpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetBackendServiceTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetBackendServiceTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetBackendServiceTargetTcpProxyRequest): google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest;

                    /**
                     * Encodes the specified SetBackendServiceTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest.verify|verify} messages.
                     * @param message SetBackendServiceTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetBackendServiceTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetBackendServiceTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest.verify|verify} messages.
                     * @param message SetBackendServiceTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetBackendServiceTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetBackendServiceTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetBackendServiceTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest;

                    /**
                     * Decodes a SetBackendServiceTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetBackendServiceTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest;

                    /**
                     * Verifies a SetBackendServiceTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetBackendServiceTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetBackendServiceTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from a SetBackendServiceTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message SetBackendServiceTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetBackendServiceTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetBackendServiceTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetBackendServiceTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetBackupTargetPoolRequest. */
                interface ISetBackupTargetPoolRequest {

                    /** SetBackupTargetPoolRequest failoverRatio */
                    failoverRatio?: (number|null);

                    /** SetBackupTargetPoolRequest project */
                    project?: (string|null);

                    /** SetBackupTargetPoolRequest region */
                    region?: (string|null);

                    /** SetBackupTargetPoolRequest requestId */
                    requestId?: (string|null);

                    /** SetBackupTargetPoolRequest targetPool */
                    targetPool?: (string|null);

                    /** SetBackupTargetPoolRequest targetReferenceResource */
                    targetReferenceResource?: (google.cloud.compute.v1.ITargetReference|null);
                }

                /** Represents a SetBackupTargetPoolRequest. */
                class SetBackupTargetPoolRequest implements ISetBackupTargetPoolRequest {

                    /**
                     * Constructs a new SetBackupTargetPoolRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetBackupTargetPoolRequest);

                    /** SetBackupTargetPoolRequest failoverRatio. */
                    public failoverRatio?: (number|null);

                    /** SetBackupTargetPoolRequest project. */
                    public project: string;

                    /** SetBackupTargetPoolRequest region. */
                    public region: string;

                    /** SetBackupTargetPoolRequest requestId. */
                    public requestId?: (string|null);

                    /** SetBackupTargetPoolRequest targetPool. */
                    public targetPool: string;

                    /** SetBackupTargetPoolRequest targetReferenceResource. */
                    public targetReferenceResource?: (google.cloud.compute.v1.ITargetReference|null);

                    /** SetBackupTargetPoolRequest _failoverRatio. */
                    public _failoverRatio?: "failoverRatio";

                    /** SetBackupTargetPoolRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetBackupTargetPoolRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetBackupTargetPoolRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetBackupTargetPoolRequest): google.cloud.compute.v1.SetBackupTargetPoolRequest;

                    /**
                     * Encodes the specified SetBackupTargetPoolRequest message. Does not implicitly {@link google.cloud.compute.v1.SetBackupTargetPoolRequest.verify|verify} messages.
                     * @param message SetBackupTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetBackupTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetBackupTargetPoolRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetBackupTargetPoolRequest.verify|verify} messages.
                     * @param message SetBackupTargetPoolRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetBackupTargetPoolRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetBackupTargetPoolRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetBackupTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetBackupTargetPoolRequest;

                    /**
                     * Decodes a SetBackupTargetPoolRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetBackupTargetPoolRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetBackupTargetPoolRequest;

                    /**
                     * Verifies a SetBackupTargetPoolRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetBackupTargetPoolRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetBackupTargetPoolRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetBackupTargetPoolRequest;

                    /**
                     * Creates a plain object from a SetBackupTargetPoolRequest message. Also converts values to other types if specified.
                     * @param message SetBackupTargetPoolRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetBackupTargetPoolRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetBackupTargetPoolRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetBackupTargetPoolRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetCertificateMapTargetHttpsProxyRequest. */
                interface ISetCertificateMapTargetHttpsProxyRequest {

                    /** SetCertificateMapTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetCertificateMapTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetCertificateMapTargetHttpsProxyRequest targetHttpsProxiesSetCertificateMapRequestResource */
                    targetHttpsProxiesSetCertificateMapRequestResource?: (google.cloud.compute.v1.ITargetHttpsProxiesSetCertificateMapRequest|null);

                    /** SetCertificateMapTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a SetCertificateMapTargetHttpsProxyRequest. */
                class SetCertificateMapTargetHttpsProxyRequest implements ISetCertificateMapTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetCertificateMapTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetCertificateMapTargetHttpsProxyRequest);

                    /** SetCertificateMapTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetCertificateMapTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetCertificateMapTargetHttpsProxyRequest targetHttpsProxiesSetCertificateMapRequestResource. */
                    public targetHttpsProxiesSetCertificateMapRequestResource?: (google.cloud.compute.v1.ITargetHttpsProxiesSetCertificateMapRequest|null);

                    /** SetCertificateMapTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetCertificateMapTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetCertificateMapTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetCertificateMapTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetCertificateMapTargetHttpsProxyRequest): google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetCertificateMapTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetCertificateMapTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetCertificateMapTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetCertificateMapTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetCertificateMapTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetCertificateMapTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetCertificateMapTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetCertificateMapTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetCertificateMapTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetCertificateMapTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetCertificateMapTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetCertificateMapTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetCertificateMapTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetCertificateMapTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetCertificateMapTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetCertificateMapTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetCertificateMapTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetCertificateMapTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetCertificateMapTargetSslProxyRequest. */
                interface ISetCertificateMapTargetSslProxyRequest {

                    /** SetCertificateMapTargetSslProxyRequest project */
                    project?: (string|null);

                    /** SetCertificateMapTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetCertificateMapTargetSslProxyRequest targetSslProxiesSetCertificateMapRequestResource */
                    targetSslProxiesSetCertificateMapRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetCertificateMapRequest|null);

                    /** SetCertificateMapTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a SetCertificateMapTargetSslProxyRequest. */
                class SetCertificateMapTargetSslProxyRequest implements ISetCertificateMapTargetSslProxyRequest {

                    /**
                     * Constructs a new SetCertificateMapTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetCertificateMapTargetSslProxyRequest);

                    /** SetCertificateMapTargetSslProxyRequest project. */
                    public project: string;

                    /** SetCertificateMapTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetCertificateMapTargetSslProxyRequest targetSslProxiesSetCertificateMapRequestResource. */
                    public targetSslProxiesSetCertificateMapRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetCertificateMapRequest|null);

                    /** SetCertificateMapTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /** SetCertificateMapTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetCertificateMapTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetCertificateMapTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetCertificateMapTargetSslProxyRequest): google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest;

                    /**
                     * Encodes the specified SetCertificateMapTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetCertificateMapTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetCertificateMapTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetCertificateMapTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetCertificateMapTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetCertificateMapTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetCertificateMapTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetCertificateMapTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest;

                    /**
                     * Decodes a SetCertificateMapTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetCertificateMapTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest;

                    /**
                     * Verifies a SetCertificateMapTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetCertificateMapTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetCertificateMapTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a SetCertificateMapTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message SetCertificateMapTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetCertificateMapTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetCertificateMapTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetCertificateMapTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetCommonInstanceMetadataProjectRequest. */
                interface ISetCommonInstanceMetadataProjectRequest {

                    /** SetCommonInstanceMetadataProjectRequest metadataResource */
                    metadataResource?: (google.cloud.compute.v1.IMetadata|null);

                    /** SetCommonInstanceMetadataProjectRequest project */
                    project?: (string|null);

                    /** SetCommonInstanceMetadataProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a SetCommonInstanceMetadataProjectRequest. */
                class SetCommonInstanceMetadataProjectRequest implements ISetCommonInstanceMetadataProjectRequest {

                    /**
                     * Constructs a new SetCommonInstanceMetadataProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest);

                    /** SetCommonInstanceMetadataProjectRequest metadataResource. */
                    public metadataResource?: (google.cloud.compute.v1.IMetadata|null);

                    /** SetCommonInstanceMetadataProjectRequest project. */
                    public project: string;

                    /** SetCommonInstanceMetadataProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** SetCommonInstanceMetadataProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetCommonInstanceMetadataProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetCommonInstanceMetadataProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest): google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest;

                    /**
                     * Encodes the specified SetCommonInstanceMetadataProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest.verify|verify} messages.
                     * @param message SetCommonInstanceMetadataProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetCommonInstanceMetadataProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest.verify|verify} messages.
                     * @param message SetCommonInstanceMetadataProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetCommonInstanceMetadataProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetCommonInstanceMetadataProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest;

                    /**
                     * Decodes a SetCommonInstanceMetadataProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetCommonInstanceMetadataProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest;

                    /**
                     * Verifies a SetCommonInstanceMetadataProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetCommonInstanceMetadataProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetCommonInstanceMetadataProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest;

                    /**
                     * Creates a plain object from a SetCommonInstanceMetadataProjectRequest message. Also converts values to other types if specified.
                     * @param message SetCommonInstanceMetadataProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetCommonInstanceMetadataProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetCommonInstanceMetadataProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetCommonInstanceMetadataProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultNetworkTierProjectRequest. */
                interface ISetDefaultNetworkTierProjectRequest {

                    /** SetDefaultNetworkTierProjectRequest project */
                    project?: (string|null);

                    /** SetDefaultNetworkTierProjectRequest projectsSetDefaultNetworkTierRequestResource */
                    projectsSetDefaultNetworkTierRequestResource?: (google.cloud.compute.v1.IProjectsSetDefaultNetworkTierRequest|null);

                    /** SetDefaultNetworkTierProjectRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a SetDefaultNetworkTierProjectRequest. */
                class SetDefaultNetworkTierProjectRequest implements ISetDefaultNetworkTierProjectRequest {

                    /**
                     * Constructs a new SetDefaultNetworkTierProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest);

                    /** SetDefaultNetworkTierProjectRequest project. */
                    public project: string;

                    /** SetDefaultNetworkTierProjectRequest projectsSetDefaultNetworkTierRequestResource. */
                    public projectsSetDefaultNetworkTierRequestResource?: (google.cloud.compute.v1.IProjectsSetDefaultNetworkTierRequest|null);

                    /** SetDefaultNetworkTierProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** SetDefaultNetworkTierProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetDefaultNetworkTierProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultNetworkTierProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest): google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest;

                    /**
                     * Encodes the specified SetDefaultNetworkTierProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest.verify|verify} messages.
                     * @param message SetDefaultNetworkTierProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultNetworkTierProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest.verify|verify} messages.
                     * @param message SetDefaultNetworkTierProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultNetworkTierProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultNetworkTierProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest;

                    /**
                     * Decodes a SetDefaultNetworkTierProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultNetworkTierProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest;

                    /**
                     * Verifies a SetDefaultNetworkTierProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultNetworkTierProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultNetworkTierProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest;

                    /**
                     * Creates a plain object from a SetDefaultNetworkTierProjectRequest message. Also converts values to other types if specified.
                     * @param message SetDefaultNetworkTierProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetDefaultNetworkTierProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultNetworkTierProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultNetworkTierProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDeletionProtectionInstanceRequest. */
                interface ISetDeletionProtectionInstanceRequest {

                    /** SetDeletionProtectionInstanceRequest deletionProtection */
                    deletionProtection?: (boolean|null);

                    /** SetDeletionProtectionInstanceRequest project */
                    project?: (string|null);

                    /** SetDeletionProtectionInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetDeletionProtectionInstanceRequest resource */
                    resource?: (string|null);

                    /** SetDeletionProtectionInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetDeletionProtectionInstanceRequest. */
                class SetDeletionProtectionInstanceRequest implements ISetDeletionProtectionInstanceRequest {

                    /**
                     * Constructs a new SetDeletionProtectionInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetDeletionProtectionInstanceRequest);

                    /** SetDeletionProtectionInstanceRequest deletionProtection. */
                    public deletionProtection?: (boolean|null);

                    /** SetDeletionProtectionInstanceRequest project. */
                    public project: string;

                    /** SetDeletionProtectionInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetDeletionProtectionInstanceRequest resource. */
                    public resource: string;

                    /** SetDeletionProtectionInstanceRequest zone. */
                    public zone: string;

                    /** SetDeletionProtectionInstanceRequest _deletionProtection. */
                    public _deletionProtection?: "deletionProtection";

                    /** SetDeletionProtectionInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetDeletionProtectionInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDeletionProtectionInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetDeletionProtectionInstanceRequest): google.cloud.compute.v1.SetDeletionProtectionInstanceRequest;

                    /**
                     * Encodes the specified SetDeletionProtectionInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetDeletionProtectionInstanceRequest.verify|verify} messages.
                     * @param message SetDeletionProtectionInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetDeletionProtectionInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDeletionProtectionInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetDeletionProtectionInstanceRequest.verify|verify} messages.
                     * @param message SetDeletionProtectionInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetDeletionProtectionInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDeletionProtectionInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDeletionProtectionInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetDeletionProtectionInstanceRequest;

                    /**
                     * Decodes a SetDeletionProtectionInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDeletionProtectionInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetDeletionProtectionInstanceRequest;

                    /**
                     * Verifies a SetDeletionProtectionInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDeletionProtectionInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDeletionProtectionInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetDeletionProtectionInstanceRequest;

                    /**
                     * Creates a plain object from a SetDeletionProtectionInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetDeletionProtectionInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetDeletionProtectionInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDeletionProtectionInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDeletionProtectionInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDiskAutoDeleteInstanceRequest. */
                interface ISetDiskAutoDeleteInstanceRequest {

                    /** SetDiskAutoDeleteInstanceRequest autoDelete */
                    autoDelete?: (boolean|null);

                    /** SetDiskAutoDeleteInstanceRequest deviceName */
                    deviceName?: (string|null);

                    /** SetDiskAutoDeleteInstanceRequest instance */
                    instance?: (string|null);

                    /** SetDiskAutoDeleteInstanceRequest project */
                    project?: (string|null);

                    /** SetDiskAutoDeleteInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetDiskAutoDeleteInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetDiskAutoDeleteInstanceRequest. */
                class SetDiskAutoDeleteInstanceRequest implements ISetDiskAutoDeleteInstanceRequest {

                    /**
                     * Constructs a new SetDiskAutoDeleteInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetDiskAutoDeleteInstanceRequest);

                    /** SetDiskAutoDeleteInstanceRequest autoDelete. */
                    public autoDelete: boolean;

                    /** SetDiskAutoDeleteInstanceRequest deviceName. */
                    public deviceName: string;

                    /** SetDiskAutoDeleteInstanceRequest instance. */
                    public instance: string;

                    /** SetDiskAutoDeleteInstanceRequest project. */
                    public project: string;

                    /** SetDiskAutoDeleteInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetDiskAutoDeleteInstanceRequest zone. */
                    public zone: string;

                    /** SetDiskAutoDeleteInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetDiskAutoDeleteInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDiskAutoDeleteInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetDiskAutoDeleteInstanceRequest): google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest;

                    /**
                     * Encodes the specified SetDiskAutoDeleteInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest.verify|verify} messages.
                     * @param message SetDiskAutoDeleteInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetDiskAutoDeleteInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDiskAutoDeleteInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest.verify|verify} messages.
                     * @param message SetDiskAutoDeleteInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetDiskAutoDeleteInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDiskAutoDeleteInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDiskAutoDeleteInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest;

                    /**
                     * Decodes a SetDiskAutoDeleteInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDiskAutoDeleteInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest;

                    /**
                     * Verifies a SetDiskAutoDeleteInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDiskAutoDeleteInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDiskAutoDeleteInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest;

                    /**
                     * Creates a plain object from a SetDiskAutoDeleteInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetDiskAutoDeleteInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetDiskAutoDeleteInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDiskAutoDeleteInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDiskAutoDeleteInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetEdgeSecurityPolicyBackendBucketRequest. */
                interface ISetEdgeSecurityPolicyBackendBucketRequest {

                    /** SetEdgeSecurityPolicyBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** SetEdgeSecurityPolicyBackendBucketRequest project */
                    project?: (string|null);

                    /** SetEdgeSecurityPolicyBackendBucketRequest requestId */
                    requestId?: (string|null);

                    /** SetEdgeSecurityPolicyBackendBucketRequest securityPolicyReferenceResource */
                    securityPolicyReferenceResource?: (google.cloud.compute.v1.ISecurityPolicyReference|null);
                }

                /** Represents a SetEdgeSecurityPolicyBackendBucketRequest. */
                class SetEdgeSecurityPolicyBackendBucketRequest implements ISetEdgeSecurityPolicyBackendBucketRequest {

                    /**
                     * Constructs a new SetEdgeSecurityPolicyBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendBucketRequest);

                    /** SetEdgeSecurityPolicyBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** SetEdgeSecurityPolicyBackendBucketRequest project. */
                    public project: string;

                    /** SetEdgeSecurityPolicyBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** SetEdgeSecurityPolicyBackendBucketRequest securityPolicyReferenceResource. */
                    public securityPolicyReferenceResource?: (google.cloud.compute.v1.ISecurityPolicyReference|null);

                    /** SetEdgeSecurityPolicyBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetEdgeSecurityPolicyBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetEdgeSecurityPolicyBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendBucketRequest): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest;

                    /**
                     * Encodes the specified SetEdgeSecurityPolicyBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest.verify|verify} messages.
                     * @param message SetEdgeSecurityPolicyBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetEdgeSecurityPolicyBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest.verify|verify} messages.
                     * @param message SetEdgeSecurityPolicyBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetEdgeSecurityPolicyBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetEdgeSecurityPolicyBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest;

                    /**
                     * Decodes a SetEdgeSecurityPolicyBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetEdgeSecurityPolicyBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest;

                    /**
                     * Verifies a SetEdgeSecurityPolicyBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetEdgeSecurityPolicyBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetEdgeSecurityPolicyBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest;

                    /**
                     * Creates a plain object from a SetEdgeSecurityPolicyBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message SetEdgeSecurityPolicyBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetEdgeSecurityPolicyBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetEdgeSecurityPolicyBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetEdgeSecurityPolicyBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetEdgeSecurityPolicyBackendServiceRequest. */
                interface ISetEdgeSecurityPolicyBackendServiceRequest {

                    /** SetEdgeSecurityPolicyBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** SetEdgeSecurityPolicyBackendServiceRequest project */
                    project?: (string|null);

                    /** SetEdgeSecurityPolicyBackendServiceRequest requestId */
                    requestId?: (string|null);

                    /** SetEdgeSecurityPolicyBackendServiceRequest securityPolicyReferenceResource */
                    securityPolicyReferenceResource?: (google.cloud.compute.v1.ISecurityPolicyReference|null);
                }

                /** Represents a SetEdgeSecurityPolicyBackendServiceRequest. */
                class SetEdgeSecurityPolicyBackendServiceRequest implements ISetEdgeSecurityPolicyBackendServiceRequest {

                    /**
                     * Constructs a new SetEdgeSecurityPolicyBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendServiceRequest);

                    /** SetEdgeSecurityPolicyBackendServiceRequest backendService. */
                    public backendService: string;

                    /** SetEdgeSecurityPolicyBackendServiceRequest project. */
                    public project: string;

                    /** SetEdgeSecurityPolicyBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetEdgeSecurityPolicyBackendServiceRequest securityPolicyReferenceResource. */
                    public securityPolicyReferenceResource?: (google.cloud.compute.v1.ISecurityPolicyReference|null);

                    /** SetEdgeSecurityPolicyBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetEdgeSecurityPolicyBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetEdgeSecurityPolicyBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendServiceRequest): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest;

                    /**
                     * Encodes the specified SetEdgeSecurityPolicyBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message SetEdgeSecurityPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetEdgeSecurityPolicyBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message SetEdgeSecurityPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetEdgeSecurityPolicyBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetEdgeSecurityPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest;

                    /**
                     * Decodes a SetEdgeSecurityPolicyBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetEdgeSecurityPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest;

                    /**
                     * Verifies a SetEdgeSecurityPolicyBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetEdgeSecurityPolicyBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetEdgeSecurityPolicyBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest;

                    /**
                     * Creates a plain object from a SetEdgeSecurityPolicyBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message SetEdgeSecurityPolicyBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetEdgeSecurityPolicyBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetEdgeSecurityPolicyBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetEdgeSecurityPolicyBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyBackendServiceRequest. */
                interface ISetIamPolicyBackendServiceRequest {

                    /** SetIamPolicyBackendServiceRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyBackendServiceRequest project */
                    project?: (string|null);

                    /** SetIamPolicyBackendServiceRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyBackendServiceRequest. */
                class SetIamPolicyBackendServiceRequest implements ISetIamPolicyBackendServiceRequest {

                    /**
                     * Constructs a new SetIamPolicyBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyBackendServiceRequest);

                    /** SetIamPolicyBackendServiceRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyBackendServiceRequest project. */
                    public project: string;

                    /** SetIamPolicyBackendServiceRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyBackendServiceRequest): google.cloud.compute.v1.SetIamPolicyBackendServiceRequest;

                    /**
                     * Encodes the specified SetIamPolicyBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message SetIamPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message SetIamPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyBackendServiceRequest;

                    /**
                     * Decodes a SetIamPolicyBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyBackendServiceRequest;

                    /**
                     * Verifies a SetIamPolicyBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyBackendServiceRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyDiskRequest. */
                interface ISetIamPolicyDiskRequest {

                    /** SetIamPolicyDiskRequest project */
                    project?: (string|null);

                    /** SetIamPolicyDiskRequest resource */
                    resource?: (string|null);

                    /** SetIamPolicyDiskRequest zone */
                    zone?: (string|null);

                    /** SetIamPolicyDiskRequest zoneSetPolicyRequestResource */
                    zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);
                }

                /** Represents a SetIamPolicyDiskRequest. */
                class SetIamPolicyDiskRequest implements ISetIamPolicyDiskRequest {

                    /**
                     * Constructs a new SetIamPolicyDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyDiskRequest);

                    /** SetIamPolicyDiskRequest project. */
                    public project: string;

                    /** SetIamPolicyDiskRequest resource. */
                    public resource: string;

                    /** SetIamPolicyDiskRequest zone. */
                    public zone: string;

                    /** SetIamPolicyDiskRequest zoneSetPolicyRequestResource. */
                    public zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);

                    /**
                     * Creates a new SetIamPolicyDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyDiskRequest): google.cloud.compute.v1.SetIamPolicyDiskRequest;

                    /**
                     * Encodes the specified SetIamPolicyDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyDiskRequest.verify|verify} messages.
                     * @param message SetIamPolicyDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyDiskRequest.verify|verify} messages.
                     * @param message SetIamPolicyDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyDiskRequest;

                    /**
                     * Decodes a SetIamPolicyDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyDiskRequest;

                    /**
                     * Verifies a SetIamPolicyDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyDiskRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyDiskRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyFirewallPolicyRequest. */
                interface ISetIamPolicyFirewallPolicyRequest {

                    /** SetIamPolicyFirewallPolicyRequest globalOrganizationSetPolicyRequestResource */
                    globalOrganizationSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalOrganizationSetPolicyRequest|null);

                    /** SetIamPolicyFirewallPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyFirewallPolicyRequest. */
                class SetIamPolicyFirewallPolicyRequest implements ISetIamPolicyFirewallPolicyRequest {

                    /**
                     * Constructs a new SetIamPolicyFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyFirewallPolicyRequest);

                    /** SetIamPolicyFirewallPolicyRequest globalOrganizationSetPolicyRequestResource. */
                    public globalOrganizationSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalOrganizationSetPolicyRequest|null);

                    /** SetIamPolicyFirewallPolicyRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyFirewallPolicyRequest): google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest;

                    /**
                     * Encodes the specified SetIamPolicyFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest;

                    /**
                     * Decodes a SetIamPolicyFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest;

                    /**
                     * Verifies a SetIamPolicyFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyImageRequest. */
                interface ISetIamPolicyImageRequest {

                    /** SetIamPolicyImageRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyImageRequest project */
                    project?: (string|null);

                    /** SetIamPolicyImageRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyImageRequest. */
                class SetIamPolicyImageRequest implements ISetIamPolicyImageRequest {

                    /**
                     * Constructs a new SetIamPolicyImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyImageRequest);

                    /** SetIamPolicyImageRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyImageRequest project. */
                    public project: string;

                    /** SetIamPolicyImageRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyImageRequest): google.cloud.compute.v1.SetIamPolicyImageRequest;

                    /**
                     * Encodes the specified SetIamPolicyImageRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyImageRequest.verify|verify} messages.
                     * @param message SetIamPolicyImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyImageRequest.verify|verify} messages.
                     * @param message SetIamPolicyImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyImageRequest;

                    /**
                     * Decodes a SetIamPolicyImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyImageRequest;

                    /**
                     * Verifies a SetIamPolicyImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyImageRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyImageRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyInstanceRequest. */
                interface ISetIamPolicyInstanceRequest {

                    /** SetIamPolicyInstanceRequest project */
                    project?: (string|null);

                    /** SetIamPolicyInstanceRequest resource */
                    resource?: (string|null);

                    /** SetIamPolicyInstanceRequest zone */
                    zone?: (string|null);

                    /** SetIamPolicyInstanceRequest zoneSetPolicyRequestResource */
                    zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);
                }

                /** Represents a SetIamPolicyInstanceRequest. */
                class SetIamPolicyInstanceRequest implements ISetIamPolicyInstanceRequest {

                    /**
                     * Constructs a new SetIamPolicyInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyInstanceRequest);

                    /** SetIamPolicyInstanceRequest project. */
                    public project: string;

                    /** SetIamPolicyInstanceRequest resource. */
                    public resource: string;

                    /** SetIamPolicyInstanceRequest zone. */
                    public zone: string;

                    /** SetIamPolicyInstanceRequest zoneSetPolicyRequestResource. */
                    public zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);

                    /**
                     * Creates a new SetIamPolicyInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyInstanceRequest): google.cloud.compute.v1.SetIamPolicyInstanceRequest;

                    /**
                     * Encodes the specified SetIamPolicyInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyInstanceRequest.verify|verify} messages.
                     * @param message SetIamPolicyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyInstanceRequest.verify|verify} messages.
                     * @param message SetIamPolicyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyInstanceRequest;

                    /**
                     * Decodes a SetIamPolicyInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyInstanceRequest;

                    /**
                     * Verifies a SetIamPolicyInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyInstanceRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyInstanceTemplateRequest. */
                interface ISetIamPolicyInstanceTemplateRequest {

                    /** SetIamPolicyInstanceTemplateRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyInstanceTemplateRequest project */
                    project?: (string|null);

                    /** SetIamPolicyInstanceTemplateRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyInstanceTemplateRequest. */
                class SetIamPolicyInstanceTemplateRequest implements ISetIamPolicyInstanceTemplateRequest {

                    /**
                     * Constructs a new SetIamPolicyInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyInstanceTemplateRequest);

                    /** SetIamPolicyInstanceTemplateRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyInstanceTemplateRequest project. */
                    public project: string;

                    /** SetIamPolicyInstanceTemplateRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyInstanceTemplateRequest): google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest;

                    /**
                     * Encodes the specified SetIamPolicyInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest.verify|verify} messages.
                     * @param message SetIamPolicyInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest.verify|verify} messages.
                     * @param message SetIamPolicyInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest;

                    /**
                     * Decodes a SetIamPolicyInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest;

                    /**
                     * Verifies a SetIamPolicyInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyLicenseRequest. */
                interface ISetIamPolicyLicenseRequest {

                    /** SetIamPolicyLicenseRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyLicenseRequest project */
                    project?: (string|null);

                    /** SetIamPolicyLicenseRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyLicenseRequest. */
                class SetIamPolicyLicenseRequest implements ISetIamPolicyLicenseRequest {

                    /**
                     * Constructs a new SetIamPolicyLicenseRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyLicenseRequest);

                    /** SetIamPolicyLicenseRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyLicenseRequest project. */
                    public project: string;

                    /** SetIamPolicyLicenseRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyLicenseRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyLicenseRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyLicenseRequest): google.cloud.compute.v1.SetIamPolicyLicenseRequest;

                    /**
                     * Encodes the specified SetIamPolicyLicenseRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyLicenseRequest.verify|verify} messages.
                     * @param message SetIamPolicyLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyLicenseRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyLicenseRequest.verify|verify} messages.
                     * @param message SetIamPolicyLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyLicenseRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyLicenseRequest;

                    /**
                     * Decodes a SetIamPolicyLicenseRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyLicenseRequest;

                    /**
                     * Verifies a SetIamPolicyLicenseRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyLicenseRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyLicenseRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyLicenseRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyLicenseRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyLicenseRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyLicenseRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyLicenseRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyLicenseRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyMachineImageRequest. */
                interface ISetIamPolicyMachineImageRequest {

                    /** SetIamPolicyMachineImageRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyMachineImageRequest project */
                    project?: (string|null);

                    /** SetIamPolicyMachineImageRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyMachineImageRequest. */
                class SetIamPolicyMachineImageRequest implements ISetIamPolicyMachineImageRequest {

                    /**
                     * Constructs a new SetIamPolicyMachineImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyMachineImageRequest);

                    /** SetIamPolicyMachineImageRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyMachineImageRequest project. */
                    public project: string;

                    /** SetIamPolicyMachineImageRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyMachineImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyMachineImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyMachineImageRequest): google.cloud.compute.v1.SetIamPolicyMachineImageRequest;

                    /**
                     * Encodes the specified SetIamPolicyMachineImageRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyMachineImageRequest.verify|verify} messages.
                     * @param message SetIamPolicyMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyMachineImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyMachineImageRequest.verify|verify} messages.
                     * @param message SetIamPolicyMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyMachineImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyMachineImageRequest;

                    /**
                     * Decodes a SetIamPolicyMachineImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyMachineImageRequest;

                    /**
                     * Verifies a SetIamPolicyMachineImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyMachineImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyMachineImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyMachineImageRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyMachineImageRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyMachineImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyMachineImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyMachineImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyMachineImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyNetworkFirewallPolicyRequest. */
                interface ISetIamPolicyNetworkFirewallPolicyRequest {

                    /** SetIamPolicyNetworkFirewallPolicyRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** SetIamPolicyNetworkFirewallPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyNetworkFirewallPolicyRequest. */
                class SetIamPolicyNetworkFirewallPolicyRequest implements ISetIamPolicyNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new SetIamPolicyNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyNetworkFirewallPolicyRequest);

                    /** SetIamPolicyNetworkFirewallPolicyRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicyNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** SetIamPolicyNetworkFirewallPolicyRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyNetworkFirewallPolicyRequest): google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified SetIamPolicyNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a SetIamPolicyNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a SetIamPolicyNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyNodeGroupRequest. */
                interface ISetIamPolicyNodeGroupRequest {

                    /** SetIamPolicyNodeGroupRequest project */
                    project?: (string|null);

                    /** SetIamPolicyNodeGroupRequest resource */
                    resource?: (string|null);

                    /** SetIamPolicyNodeGroupRequest zone */
                    zone?: (string|null);

                    /** SetIamPolicyNodeGroupRequest zoneSetPolicyRequestResource */
                    zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);
                }

                /** Represents a SetIamPolicyNodeGroupRequest. */
                class SetIamPolicyNodeGroupRequest implements ISetIamPolicyNodeGroupRequest {

                    /**
                     * Constructs a new SetIamPolicyNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest);

                    /** SetIamPolicyNodeGroupRequest project. */
                    public project: string;

                    /** SetIamPolicyNodeGroupRequest resource. */
                    public resource: string;

                    /** SetIamPolicyNodeGroupRequest zone. */
                    public zone: string;

                    /** SetIamPolicyNodeGroupRequest zoneSetPolicyRequestResource. */
                    public zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);

                    /**
                     * Creates a new SetIamPolicyNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest): google.cloud.compute.v1.SetIamPolicyNodeGroupRequest;

                    /**
                     * Encodes the specified SetIamPolicyNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyNodeGroupRequest.verify|verify} messages.
                     * @param message SetIamPolicyNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyNodeGroupRequest.verify|verify} messages.
                     * @param message SetIamPolicyNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyNodeGroupRequest;

                    /**
                     * Decodes a SetIamPolicyNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyNodeGroupRequest;

                    /**
                     * Verifies a SetIamPolicyNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyNodeGroupRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyNodeTemplateRequest. */
                interface ISetIamPolicyNodeTemplateRequest {

                    /** SetIamPolicyNodeTemplateRequest project */
                    project?: (string|null);

                    /** SetIamPolicyNodeTemplateRequest region */
                    region?: (string|null);

                    /** SetIamPolicyNodeTemplateRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyNodeTemplateRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyNodeTemplateRequest. */
                class SetIamPolicyNodeTemplateRequest implements ISetIamPolicyNodeTemplateRequest {

                    /**
                     * Constructs a new SetIamPolicyNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyNodeTemplateRequest);

                    /** SetIamPolicyNodeTemplateRequest project. */
                    public project: string;

                    /** SetIamPolicyNodeTemplateRequest region. */
                    public region: string;

                    /** SetIamPolicyNodeTemplateRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyNodeTemplateRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyNodeTemplateRequest): google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest;

                    /**
                     * Encodes the specified SetIamPolicyNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest.verify|verify} messages.
                     * @param message SetIamPolicyNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest.verify|verify} messages.
                     * @param message SetIamPolicyNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest;

                    /**
                     * Decodes a SetIamPolicyNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest;

                    /**
                     * Verifies a SetIamPolicyNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyRegionBackendServiceRequest. */
                interface ISetIamPolicyRegionBackendServiceRequest {

                    /** SetIamPolicyRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** SetIamPolicyRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** SetIamPolicyRegionBackendServiceRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyRegionBackendServiceRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyRegionBackendServiceRequest. */
                class SetIamPolicyRegionBackendServiceRequest implements ISetIamPolicyRegionBackendServiceRequest {

                    /**
                     * Constructs a new SetIamPolicyRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyRegionBackendServiceRequest);

                    /** SetIamPolicyRegionBackendServiceRequest project. */
                    public project: string;

                    /** SetIamPolicyRegionBackendServiceRequest region. */
                    public region: string;

                    /** SetIamPolicyRegionBackendServiceRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyRegionBackendServiceRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyRegionBackendServiceRequest): google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Encodes the specified SetIamPolicyRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest.verify|verify} messages.
                     * @param message SetIamPolicyRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest.verify|verify} messages.
                     * @param message SetIamPolicyRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Decodes a SetIamPolicyRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Verifies a SetIamPolicyRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyRegionDiskRequest. */
                interface ISetIamPolicyRegionDiskRequest {

                    /** SetIamPolicyRegionDiskRequest project */
                    project?: (string|null);

                    /** SetIamPolicyRegionDiskRequest region */
                    region?: (string|null);

                    /** SetIamPolicyRegionDiskRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyRegionDiskRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyRegionDiskRequest. */
                class SetIamPolicyRegionDiskRequest implements ISetIamPolicyRegionDiskRequest {

                    /**
                     * Constructs a new SetIamPolicyRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyRegionDiskRequest);

                    /** SetIamPolicyRegionDiskRequest project. */
                    public project: string;

                    /** SetIamPolicyRegionDiskRequest region. */
                    public region: string;

                    /** SetIamPolicyRegionDiskRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyRegionDiskRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyRegionDiskRequest): google.cloud.compute.v1.SetIamPolicyRegionDiskRequest;

                    /**
                     * Encodes the specified SetIamPolicyRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyRegionDiskRequest.verify|verify} messages.
                     * @param message SetIamPolicyRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyRegionDiskRequest.verify|verify} messages.
                     * @param message SetIamPolicyRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyRegionDiskRequest;

                    /**
                     * Decodes a SetIamPolicyRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyRegionDiskRequest;

                    /**
                     * Verifies a SetIamPolicyRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyRegionDiskRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyRegionNetworkFirewallPolicyRequest. */
                interface ISetIamPolicyRegionNetworkFirewallPolicyRequest {

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyRegionNetworkFirewallPolicyRequest. */
                class SetIamPolicyRegionNetworkFirewallPolicyRequest implements ISetIamPolicyRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new SetIamPolicyRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyRegionNetworkFirewallPolicyRequest);

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyRegionNetworkFirewallPolicyRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified SetIamPolicyRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a SetIamPolicyRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a SetIamPolicyRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyReservationRequest. */
                interface ISetIamPolicyReservationRequest {

                    /** SetIamPolicyReservationRequest project */
                    project?: (string|null);

                    /** SetIamPolicyReservationRequest resource */
                    resource?: (string|null);

                    /** SetIamPolicyReservationRequest zone */
                    zone?: (string|null);

                    /** SetIamPolicyReservationRequest zoneSetPolicyRequestResource */
                    zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);
                }

                /** Represents a SetIamPolicyReservationRequest. */
                class SetIamPolicyReservationRequest implements ISetIamPolicyReservationRequest {

                    /**
                     * Constructs a new SetIamPolicyReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyReservationRequest);

                    /** SetIamPolicyReservationRequest project. */
                    public project: string;

                    /** SetIamPolicyReservationRequest resource. */
                    public resource: string;

                    /** SetIamPolicyReservationRequest zone. */
                    public zone: string;

                    /** SetIamPolicyReservationRequest zoneSetPolicyRequestResource. */
                    public zoneSetPolicyRequestResource?: (google.cloud.compute.v1.IZoneSetPolicyRequest|null);

                    /**
                     * Creates a new SetIamPolicyReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyReservationRequest): google.cloud.compute.v1.SetIamPolicyReservationRequest;

                    /**
                     * Encodes the specified SetIamPolicyReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyReservationRequest.verify|verify} messages.
                     * @param message SetIamPolicyReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyReservationRequest.verify|verify} messages.
                     * @param message SetIamPolicyReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyReservationRequest;

                    /**
                     * Decodes a SetIamPolicyReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyReservationRequest;

                    /**
                     * Verifies a SetIamPolicyReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyReservationRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyReservationRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyResourcePolicyRequest. */
                interface ISetIamPolicyResourcePolicyRequest {

                    /** SetIamPolicyResourcePolicyRequest project */
                    project?: (string|null);

                    /** SetIamPolicyResourcePolicyRequest region */
                    region?: (string|null);

                    /** SetIamPolicyResourcePolicyRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyResourcePolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyResourcePolicyRequest. */
                class SetIamPolicyResourcePolicyRequest implements ISetIamPolicyResourcePolicyRequest {

                    /**
                     * Constructs a new SetIamPolicyResourcePolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyResourcePolicyRequest);

                    /** SetIamPolicyResourcePolicyRequest project. */
                    public project: string;

                    /** SetIamPolicyResourcePolicyRequest region. */
                    public region: string;

                    /** SetIamPolicyResourcePolicyRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyResourcePolicyRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyResourcePolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyResourcePolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyResourcePolicyRequest): google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest;

                    /**
                     * Encodes the specified SetIamPolicyResourcePolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyResourcePolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest.verify|verify} messages.
                     * @param message SetIamPolicyResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyResourcePolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest;

                    /**
                     * Decodes a SetIamPolicyResourcePolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest;

                    /**
                     * Verifies a SetIamPolicyResourcePolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyResourcePolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyResourcePolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyResourcePolicyRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyResourcePolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyResourcePolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyResourcePolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyResourcePolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicyServiceAttachmentRequest. */
                interface ISetIamPolicyServiceAttachmentRequest {

                    /** SetIamPolicyServiceAttachmentRequest project */
                    project?: (string|null);

                    /** SetIamPolicyServiceAttachmentRequest region */
                    region?: (string|null);

                    /** SetIamPolicyServiceAttachmentRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyServiceAttachmentRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicyServiceAttachmentRequest. */
                class SetIamPolicyServiceAttachmentRequest implements ISetIamPolicyServiceAttachmentRequest {

                    /**
                     * Constructs a new SetIamPolicyServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicyServiceAttachmentRequest);

                    /** SetIamPolicyServiceAttachmentRequest project. */
                    public project: string;

                    /** SetIamPolicyServiceAttachmentRequest region. */
                    public region: string;

                    /** SetIamPolicyServiceAttachmentRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicyServiceAttachmentRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicyServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicyServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicyServiceAttachmentRequest): google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest;

                    /**
                     * Encodes the specified SetIamPolicyServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest.verify|verify} messages.
                     * @param message SetIamPolicyServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicyServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicyServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest.verify|verify} messages.
                     * @param message SetIamPolicyServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicyServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicyServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicyServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest;

                    /**
                     * Decodes a SetIamPolicyServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicyServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest;

                    /**
                     * Verifies a SetIamPolicyServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicyServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicyServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest;

                    /**
                     * Creates a plain object from a SetIamPolicyServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicyServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicyServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicyServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicyServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicySnapshotRequest. */
                interface ISetIamPolicySnapshotRequest {

                    /** SetIamPolicySnapshotRequest globalSetPolicyRequestResource */
                    globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicySnapshotRequest project */
                    project?: (string|null);

                    /** SetIamPolicySnapshotRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicySnapshotRequest. */
                class SetIamPolicySnapshotRequest implements ISetIamPolicySnapshotRequest {

                    /**
                     * Constructs a new SetIamPolicySnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicySnapshotRequest);

                    /** SetIamPolicySnapshotRequest globalSetPolicyRequestResource. */
                    public globalSetPolicyRequestResource?: (google.cloud.compute.v1.IGlobalSetPolicyRequest|null);

                    /** SetIamPolicySnapshotRequest project. */
                    public project: string;

                    /** SetIamPolicySnapshotRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicySnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicySnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicySnapshotRequest): google.cloud.compute.v1.SetIamPolicySnapshotRequest;

                    /**
                     * Encodes the specified SetIamPolicySnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicySnapshotRequest.verify|verify} messages.
                     * @param message SetIamPolicySnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicySnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicySnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicySnapshotRequest.verify|verify} messages.
                     * @param message SetIamPolicySnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicySnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicySnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicySnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicySnapshotRequest;

                    /**
                     * Decodes a SetIamPolicySnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicySnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicySnapshotRequest;

                    /**
                     * Verifies a SetIamPolicySnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicySnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicySnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicySnapshotRequest;

                    /**
                     * Creates a plain object from a SetIamPolicySnapshotRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicySnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicySnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicySnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicySnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetIamPolicySubnetworkRequest. */
                interface ISetIamPolicySubnetworkRequest {

                    /** SetIamPolicySubnetworkRequest project */
                    project?: (string|null);

                    /** SetIamPolicySubnetworkRequest region */
                    region?: (string|null);

                    /** SetIamPolicySubnetworkRequest regionSetPolicyRequestResource */
                    regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicySubnetworkRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetIamPolicySubnetworkRequest. */
                class SetIamPolicySubnetworkRequest implements ISetIamPolicySubnetworkRequest {

                    /**
                     * Constructs a new SetIamPolicySubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetIamPolicySubnetworkRequest);

                    /** SetIamPolicySubnetworkRequest project. */
                    public project: string;

                    /** SetIamPolicySubnetworkRequest region. */
                    public region: string;

                    /** SetIamPolicySubnetworkRequest regionSetPolicyRequestResource. */
                    public regionSetPolicyRequestResource?: (google.cloud.compute.v1.IRegionSetPolicyRequest|null);

                    /** SetIamPolicySubnetworkRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetIamPolicySubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetIamPolicySubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetIamPolicySubnetworkRequest): google.cloud.compute.v1.SetIamPolicySubnetworkRequest;

                    /**
                     * Encodes the specified SetIamPolicySubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicySubnetworkRequest.verify|verify} messages.
                     * @param message SetIamPolicySubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetIamPolicySubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetIamPolicySubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetIamPolicySubnetworkRequest.verify|verify} messages.
                     * @param message SetIamPolicySubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetIamPolicySubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetIamPolicySubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetIamPolicySubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetIamPolicySubnetworkRequest;

                    /**
                     * Decodes a SetIamPolicySubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetIamPolicySubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetIamPolicySubnetworkRequest;

                    /**
                     * Verifies a SetIamPolicySubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetIamPolicySubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetIamPolicySubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetIamPolicySubnetworkRequest;

                    /**
                     * Creates a plain object from a SetIamPolicySubnetworkRequest message. Also converts values to other types if specified.
                     * @param message SetIamPolicySubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetIamPolicySubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetIamPolicySubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetIamPolicySubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetInstanceTemplateInstanceGroupManagerRequest. */
                interface ISetInstanceTemplateInstanceGroupManagerRequest {

                    /** SetInstanceTemplateInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** SetInstanceTemplateInstanceGroupManagerRequest instanceGroupManagersSetInstanceTemplateRequestResource */
                    instanceGroupManagersSetInstanceTemplateRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersSetInstanceTemplateRequest|null);

                    /** SetInstanceTemplateInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** SetInstanceTemplateInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** SetInstanceTemplateInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetInstanceTemplateInstanceGroupManagerRequest. */
                class SetInstanceTemplateInstanceGroupManagerRequest implements ISetInstanceTemplateInstanceGroupManagerRequest {

                    /**
                     * Constructs a new SetInstanceTemplateInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest);

                    /** SetInstanceTemplateInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** SetInstanceTemplateInstanceGroupManagerRequest instanceGroupManagersSetInstanceTemplateRequestResource. */
                    public instanceGroupManagersSetInstanceTemplateRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersSetInstanceTemplateRequest|null);

                    /** SetInstanceTemplateInstanceGroupManagerRequest project. */
                    public project: string;

                    /** SetInstanceTemplateInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** SetInstanceTemplateInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** SetInstanceTemplateInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetInstanceTemplateInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetInstanceTemplateInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest): google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified SetInstanceTemplateInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetInstanceTemplateInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetInstanceTemplateInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetInstanceTemplateInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetInstanceTemplateInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetInstanceTemplateInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest;

                    /**
                     * Decodes a SetInstanceTemplateInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetInstanceTemplateInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest;

                    /**
                     * Verifies a SetInstanceTemplateInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetInstanceTemplateInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetInstanceTemplateInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a SetInstanceTemplateInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message SetInstanceTemplateInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetInstanceTemplateInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetInstanceTemplateInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetInstanceTemplateInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetInstanceTemplateRegionInstanceGroupManagerRequest. */
                interface ISetInstanceTemplateRegionInstanceGroupManagerRequest {

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest regionInstanceGroupManagersSetTemplateRequestResource */
                    regionInstanceGroupManagersSetTemplateRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersSetTemplateRequest|null);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a SetInstanceTemplateRegionInstanceGroupManagerRequest. */
                class SetInstanceTemplateRegionInstanceGroupManagerRequest implements ISetInstanceTemplateRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new SetInstanceTemplateRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest regionInstanceGroupManagersSetTemplateRequestResource. */
                    public regionInstanceGroupManagersSetTemplateRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersSetTemplateRequest|null);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** SetInstanceTemplateRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetInstanceTemplateRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetInstanceTemplateRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest): google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified SetInstanceTemplateRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetInstanceTemplateRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetInstanceTemplateRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetInstanceTemplateRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetInstanceTemplateRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetInstanceTemplateRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a SetInstanceTemplateRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetInstanceTemplateRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a SetInstanceTemplateRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetInstanceTemplateRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetInstanceTemplateRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a SetInstanceTemplateRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message SetInstanceTemplateRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetInstanceTemplateRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetInstanceTemplateRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetInstanceTemplateRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsAddressRequest. */
                interface ISetLabelsAddressRequest {

                    /** SetLabelsAddressRequest project */
                    project?: (string|null);

                    /** SetLabelsAddressRequest region */
                    region?: (string|null);

                    /** SetLabelsAddressRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsAddressRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsAddressRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsAddressRequest. */
                class SetLabelsAddressRequest implements ISetLabelsAddressRequest {

                    /**
                     * Constructs a new SetLabelsAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsAddressRequest);

                    /** SetLabelsAddressRequest project. */
                    public project: string;

                    /** SetLabelsAddressRequest region. */
                    public region: string;

                    /** SetLabelsAddressRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsAddressRequest resource. */
                    public resource: string;

                    /** SetLabelsAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsAddressRequest): google.cloud.compute.v1.SetLabelsAddressRequest;

                    /**
                     * Encodes the specified SetLabelsAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsAddressRequest.verify|verify} messages.
                     * @param message SetLabelsAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsAddressRequest.verify|verify} messages.
                     * @param message SetLabelsAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsAddressRequest;

                    /**
                     * Decodes a SetLabelsAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsAddressRequest;

                    /**
                     * Verifies a SetLabelsAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsAddressRequest;

                    /**
                     * Creates a plain object from a SetLabelsAddressRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsDiskRequest. */
                interface ISetLabelsDiskRequest {

                    /** SetLabelsDiskRequest project */
                    project?: (string|null);

                    /** SetLabelsDiskRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsDiskRequest resource */
                    resource?: (string|null);

                    /** SetLabelsDiskRequest zone */
                    zone?: (string|null);

                    /** SetLabelsDiskRequest zoneSetLabelsRequestResource */
                    zoneSetLabelsRequestResource?: (google.cloud.compute.v1.IZoneSetLabelsRequest|null);
                }

                /** Represents a SetLabelsDiskRequest. */
                class SetLabelsDiskRequest implements ISetLabelsDiskRequest {

                    /**
                     * Constructs a new SetLabelsDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsDiskRequest);

                    /** SetLabelsDiskRequest project. */
                    public project: string;

                    /** SetLabelsDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsDiskRequest resource. */
                    public resource: string;

                    /** SetLabelsDiskRequest zone. */
                    public zone: string;

                    /** SetLabelsDiskRequest zoneSetLabelsRequestResource. */
                    public zoneSetLabelsRequestResource?: (google.cloud.compute.v1.IZoneSetLabelsRequest|null);

                    /** SetLabelsDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsDiskRequest): google.cloud.compute.v1.SetLabelsDiskRequest;

                    /**
                     * Encodes the specified SetLabelsDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsDiskRequest.verify|verify} messages.
                     * @param message SetLabelsDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsDiskRequest.verify|verify} messages.
                     * @param message SetLabelsDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsDiskRequest;

                    /**
                     * Decodes a SetLabelsDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsDiskRequest;

                    /**
                     * Verifies a SetLabelsDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsDiskRequest;

                    /**
                     * Creates a plain object from a SetLabelsDiskRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsExternalVpnGatewayRequest. */
                interface ISetLabelsExternalVpnGatewayRequest {

                    /** SetLabelsExternalVpnGatewayRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsExternalVpnGatewayRequest project */
                    project?: (string|null);

                    /** SetLabelsExternalVpnGatewayRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsExternalVpnGatewayRequest. */
                class SetLabelsExternalVpnGatewayRequest implements ISetLabelsExternalVpnGatewayRequest {

                    /**
                     * Constructs a new SetLabelsExternalVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsExternalVpnGatewayRequest);

                    /** SetLabelsExternalVpnGatewayRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsExternalVpnGatewayRequest project. */
                    public project: string;

                    /** SetLabelsExternalVpnGatewayRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsExternalVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsExternalVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsExternalVpnGatewayRequest): google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest;

                    /**
                     * Encodes the specified SetLabelsExternalVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message SetLabelsExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsExternalVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message SetLabelsExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsExternalVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest;

                    /**
                     * Decodes a SetLabelsExternalVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest;

                    /**
                     * Verifies a SetLabelsExternalVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsExternalVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsExternalVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest;

                    /**
                     * Creates a plain object from a SetLabelsExternalVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsExternalVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsExternalVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsExternalVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsExternalVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsForwardingRuleRequest. */
                interface ISetLabelsForwardingRuleRequest {

                    /** SetLabelsForwardingRuleRequest project */
                    project?: (string|null);

                    /** SetLabelsForwardingRuleRequest region */
                    region?: (string|null);

                    /** SetLabelsForwardingRuleRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsForwardingRuleRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsForwardingRuleRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsForwardingRuleRequest. */
                class SetLabelsForwardingRuleRequest implements ISetLabelsForwardingRuleRequest {

                    /**
                     * Constructs a new SetLabelsForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsForwardingRuleRequest);

                    /** SetLabelsForwardingRuleRequest project. */
                    public project: string;

                    /** SetLabelsForwardingRuleRequest region. */
                    public region: string;

                    /** SetLabelsForwardingRuleRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsForwardingRuleRequest resource. */
                    public resource: string;

                    /** SetLabelsForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsForwardingRuleRequest): google.cloud.compute.v1.SetLabelsForwardingRuleRequest;

                    /**
                     * Encodes the specified SetLabelsForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsForwardingRuleRequest.verify|verify} messages.
                     * @param message SetLabelsForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsForwardingRuleRequest.verify|verify} messages.
                     * @param message SetLabelsForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsForwardingRuleRequest;

                    /**
                     * Decodes a SetLabelsForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsForwardingRuleRequest;

                    /**
                     * Verifies a SetLabelsForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsForwardingRuleRequest;

                    /**
                     * Creates a plain object from a SetLabelsForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsGlobalAddressRequest. */
                interface ISetLabelsGlobalAddressRequest {

                    /** SetLabelsGlobalAddressRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsGlobalAddressRequest project */
                    project?: (string|null);

                    /** SetLabelsGlobalAddressRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsGlobalAddressRequest. */
                class SetLabelsGlobalAddressRequest implements ISetLabelsGlobalAddressRequest {

                    /**
                     * Constructs a new SetLabelsGlobalAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsGlobalAddressRequest);

                    /** SetLabelsGlobalAddressRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsGlobalAddressRequest project. */
                    public project: string;

                    /** SetLabelsGlobalAddressRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsGlobalAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsGlobalAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsGlobalAddressRequest): google.cloud.compute.v1.SetLabelsGlobalAddressRequest;

                    /**
                     * Encodes the specified SetLabelsGlobalAddressRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsGlobalAddressRequest.verify|verify} messages.
                     * @param message SetLabelsGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsGlobalAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsGlobalAddressRequest.verify|verify} messages.
                     * @param message SetLabelsGlobalAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsGlobalAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsGlobalAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsGlobalAddressRequest;

                    /**
                     * Decodes a SetLabelsGlobalAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsGlobalAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsGlobalAddressRequest;

                    /**
                     * Verifies a SetLabelsGlobalAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsGlobalAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsGlobalAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsGlobalAddressRequest;

                    /**
                     * Creates a plain object from a SetLabelsGlobalAddressRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsGlobalAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsGlobalAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsGlobalAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsGlobalAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsGlobalForwardingRuleRequest. */
                interface ISetLabelsGlobalForwardingRuleRequest {

                    /** SetLabelsGlobalForwardingRuleRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsGlobalForwardingRuleRequest project */
                    project?: (string|null);

                    /** SetLabelsGlobalForwardingRuleRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsGlobalForwardingRuleRequest. */
                class SetLabelsGlobalForwardingRuleRequest implements ISetLabelsGlobalForwardingRuleRequest {

                    /**
                     * Constructs a new SetLabelsGlobalForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsGlobalForwardingRuleRequest);

                    /** SetLabelsGlobalForwardingRuleRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsGlobalForwardingRuleRequest project. */
                    public project: string;

                    /** SetLabelsGlobalForwardingRuleRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsGlobalForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsGlobalForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsGlobalForwardingRuleRequest): google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest;

                    /**
                     * Encodes the specified SetLabelsGlobalForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message SetLabelsGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsGlobalForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message SetLabelsGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsGlobalForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest;

                    /**
                     * Decodes a SetLabelsGlobalForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest;

                    /**
                     * Verifies a SetLabelsGlobalForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsGlobalForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsGlobalForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest;

                    /**
                     * Creates a plain object from a SetLabelsGlobalForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsGlobalForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsGlobalForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsGlobalForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsGlobalForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsImageRequest. */
                interface ISetLabelsImageRequest {

                    /** SetLabelsImageRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsImageRequest project */
                    project?: (string|null);

                    /** SetLabelsImageRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsImageRequest. */
                class SetLabelsImageRequest implements ISetLabelsImageRequest {

                    /**
                     * Constructs a new SetLabelsImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsImageRequest);

                    /** SetLabelsImageRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsImageRequest project. */
                    public project: string;

                    /** SetLabelsImageRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsImageRequest): google.cloud.compute.v1.SetLabelsImageRequest;

                    /**
                     * Encodes the specified SetLabelsImageRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsImageRequest.verify|verify} messages.
                     * @param message SetLabelsImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsImageRequest.verify|verify} messages.
                     * @param message SetLabelsImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsImageRequest;

                    /**
                     * Decodes a SetLabelsImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsImageRequest;

                    /**
                     * Verifies a SetLabelsImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsImageRequest;

                    /**
                     * Creates a plain object from a SetLabelsImageRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsInstanceRequest. */
                interface ISetLabelsInstanceRequest {

                    /** SetLabelsInstanceRequest instance */
                    instance?: (string|null);

                    /** SetLabelsInstanceRequest instancesSetLabelsRequestResource */
                    instancesSetLabelsRequestResource?: (google.cloud.compute.v1.IInstancesSetLabelsRequest|null);

                    /** SetLabelsInstanceRequest project */
                    project?: (string|null);

                    /** SetLabelsInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetLabelsInstanceRequest. */
                class SetLabelsInstanceRequest implements ISetLabelsInstanceRequest {

                    /**
                     * Constructs a new SetLabelsInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsInstanceRequest);

                    /** SetLabelsInstanceRequest instance. */
                    public instance: string;

                    /** SetLabelsInstanceRequest instancesSetLabelsRequestResource. */
                    public instancesSetLabelsRequestResource?: (google.cloud.compute.v1.IInstancesSetLabelsRequest|null);

                    /** SetLabelsInstanceRequest project. */
                    public project: string;

                    /** SetLabelsInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsInstanceRequest zone. */
                    public zone: string;

                    /** SetLabelsInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsInstanceRequest): google.cloud.compute.v1.SetLabelsInstanceRequest;

                    /**
                     * Encodes the specified SetLabelsInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsInstanceRequest.verify|verify} messages.
                     * @param message SetLabelsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsInstanceRequest.verify|verify} messages.
                     * @param message SetLabelsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsInstanceRequest;

                    /**
                     * Decodes a SetLabelsInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsInstanceRequest;

                    /**
                     * Verifies a SetLabelsInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsInstanceRequest;

                    /**
                     * Creates a plain object from a SetLabelsInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsInterconnectAttachmentRequest. */
                interface ISetLabelsInterconnectAttachmentRequest {

                    /** SetLabelsInterconnectAttachmentRequest project */
                    project?: (string|null);

                    /** SetLabelsInterconnectAttachmentRequest region */
                    region?: (string|null);

                    /** SetLabelsInterconnectAttachmentRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsInterconnectAttachmentRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsInterconnectAttachmentRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsInterconnectAttachmentRequest. */
                class SetLabelsInterconnectAttachmentRequest implements ISetLabelsInterconnectAttachmentRequest {

                    /**
                     * Constructs a new SetLabelsInterconnectAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsInterconnectAttachmentRequest);

                    /** SetLabelsInterconnectAttachmentRequest project. */
                    public project: string;

                    /** SetLabelsInterconnectAttachmentRequest region. */
                    public region: string;

                    /** SetLabelsInterconnectAttachmentRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsInterconnectAttachmentRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsInterconnectAttachmentRequest resource. */
                    public resource: string;

                    /** SetLabelsInterconnectAttachmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsInterconnectAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsInterconnectAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsInterconnectAttachmentRequest): google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest;

                    /**
                     * Encodes the specified SetLabelsInterconnectAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message SetLabelsInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsInterconnectAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest.verify|verify} messages.
                     * @param message SetLabelsInterconnectAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsInterconnectAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsInterconnectAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest;

                    /**
                     * Decodes a SetLabelsInterconnectAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsInterconnectAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest;

                    /**
                     * Verifies a SetLabelsInterconnectAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsInterconnectAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsInterconnectAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest;

                    /**
                     * Creates a plain object from a SetLabelsInterconnectAttachmentRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsInterconnectAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsInterconnectAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsInterconnectAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsInterconnectAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsInterconnectRequest. */
                interface ISetLabelsInterconnectRequest {

                    /** SetLabelsInterconnectRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsInterconnectRequest project */
                    project?: (string|null);

                    /** SetLabelsInterconnectRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsInterconnectRequest. */
                class SetLabelsInterconnectRequest implements ISetLabelsInterconnectRequest {

                    /**
                     * Constructs a new SetLabelsInterconnectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsInterconnectRequest);

                    /** SetLabelsInterconnectRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsInterconnectRequest project. */
                    public project: string;

                    /** SetLabelsInterconnectRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsInterconnectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsInterconnectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsInterconnectRequest): google.cloud.compute.v1.SetLabelsInterconnectRequest;

                    /**
                     * Encodes the specified SetLabelsInterconnectRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsInterconnectRequest.verify|verify} messages.
                     * @param message SetLabelsInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsInterconnectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsInterconnectRequest.verify|verify} messages.
                     * @param message SetLabelsInterconnectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsInterconnectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsInterconnectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsInterconnectRequest;

                    /**
                     * Decodes a SetLabelsInterconnectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsInterconnectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsInterconnectRequest;

                    /**
                     * Verifies a SetLabelsInterconnectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsInterconnectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsInterconnectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsInterconnectRequest;

                    /**
                     * Creates a plain object from a SetLabelsInterconnectRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsInterconnectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsInterconnectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsInterconnectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsInterconnectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsRegionDiskRequest. */
                interface ISetLabelsRegionDiskRequest {

                    /** SetLabelsRegionDiskRequest project */
                    project?: (string|null);

                    /** SetLabelsRegionDiskRequest region */
                    region?: (string|null);

                    /** SetLabelsRegionDiskRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsRegionDiskRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsRegionDiskRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsRegionDiskRequest. */
                class SetLabelsRegionDiskRequest implements ISetLabelsRegionDiskRequest {

                    /**
                     * Constructs a new SetLabelsRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsRegionDiskRequest);

                    /** SetLabelsRegionDiskRequest project. */
                    public project: string;

                    /** SetLabelsRegionDiskRequest region. */
                    public region: string;

                    /** SetLabelsRegionDiskRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsRegionDiskRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsRegionDiskRequest resource. */
                    public resource: string;

                    /** SetLabelsRegionDiskRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsRegionDiskRequest): google.cloud.compute.v1.SetLabelsRegionDiskRequest;

                    /**
                     * Encodes the specified SetLabelsRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsRegionDiskRequest.verify|verify} messages.
                     * @param message SetLabelsRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsRegionDiskRequest.verify|verify} messages.
                     * @param message SetLabelsRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsRegionDiskRequest;

                    /**
                     * Decodes a SetLabelsRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsRegionDiskRequest;

                    /**
                     * Verifies a SetLabelsRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsRegionDiskRequest;

                    /**
                     * Creates a plain object from a SetLabelsRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsSecurityPolicyRequest. */
                interface ISetLabelsSecurityPolicyRequest {

                    /** SetLabelsSecurityPolicyRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsSecurityPolicyRequest project */
                    project?: (string|null);

                    /** SetLabelsSecurityPolicyRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsSecurityPolicyRequest. */
                class SetLabelsSecurityPolicyRequest implements ISetLabelsSecurityPolicyRequest {

                    /**
                     * Constructs a new SetLabelsSecurityPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsSecurityPolicyRequest);

                    /** SetLabelsSecurityPolicyRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsSecurityPolicyRequest project. */
                    public project: string;

                    /** SetLabelsSecurityPolicyRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsSecurityPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsSecurityPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsSecurityPolicyRequest): google.cloud.compute.v1.SetLabelsSecurityPolicyRequest;

                    /**
                     * Encodes the specified SetLabelsSecurityPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsSecurityPolicyRequest.verify|verify} messages.
                     * @param message SetLabelsSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsSecurityPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsSecurityPolicyRequest.verify|verify} messages.
                     * @param message SetLabelsSecurityPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsSecurityPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsSecurityPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsSecurityPolicyRequest;

                    /**
                     * Decodes a SetLabelsSecurityPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsSecurityPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsSecurityPolicyRequest;

                    /**
                     * Verifies a SetLabelsSecurityPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsSecurityPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsSecurityPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsSecurityPolicyRequest;

                    /**
                     * Creates a plain object from a SetLabelsSecurityPolicyRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsSecurityPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsSecurityPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsSecurityPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsSecurityPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsSnapshotRequest. */
                interface ISetLabelsSnapshotRequest {

                    /** SetLabelsSnapshotRequest globalSetLabelsRequestResource */
                    globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsSnapshotRequest project */
                    project?: (string|null);

                    /** SetLabelsSnapshotRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsSnapshotRequest. */
                class SetLabelsSnapshotRequest implements ISetLabelsSnapshotRequest {

                    /**
                     * Constructs a new SetLabelsSnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsSnapshotRequest);

                    /** SetLabelsSnapshotRequest globalSetLabelsRequestResource. */
                    public globalSetLabelsRequestResource?: (google.cloud.compute.v1.IGlobalSetLabelsRequest|null);

                    /** SetLabelsSnapshotRequest project. */
                    public project: string;

                    /** SetLabelsSnapshotRequest resource. */
                    public resource: string;

                    /**
                     * Creates a new SetLabelsSnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsSnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsSnapshotRequest): google.cloud.compute.v1.SetLabelsSnapshotRequest;

                    /**
                     * Encodes the specified SetLabelsSnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsSnapshotRequest.verify|verify} messages.
                     * @param message SetLabelsSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsSnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsSnapshotRequest.verify|verify} messages.
                     * @param message SetLabelsSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsSnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsSnapshotRequest;

                    /**
                     * Decodes a SetLabelsSnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsSnapshotRequest;

                    /**
                     * Verifies a SetLabelsSnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsSnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsSnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsSnapshotRequest;

                    /**
                     * Creates a plain object from a SetLabelsSnapshotRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsSnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsSnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsSnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsSnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsTargetVpnGatewayRequest. */
                interface ISetLabelsTargetVpnGatewayRequest {

                    /** SetLabelsTargetVpnGatewayRequest project */
                    project?: (string|null);

                    /** SetLabelsTargetVpnGatewayRequest region */
                    region?: (string|null);

                    /** SetLabelsTargetVpnGatewayRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsTargetVpnGatewayRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsTargetVpnGatewayRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsTargetVpnGatewayRequest. */
                class SetLabelsTargetVpnGatewayRequest implements ISetLabelsTargetVpnGatewayRequest {

                    /**
                     * Constructs a new SetLabelsTargetVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsTargetVpnGatewayRequest);

                    /** SetLabelsTargetVpnGatewayRequest project. */
                    public project: string;

                    /** SetLabelsTargetVpnGatewayRequest region. */
                    public region: string;

                    /** SetLabelsTargetVpnGatewayRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsTargetVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsTargetVpnGatewayRequest resource. */
                    public resource: string;

                    /** SetLabelsTargetVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsTargetVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsTargetVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsTargetVpnGatewayRequest): google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest;

                    /**
                     * Encodes the specified SetLabelsTargetVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message SetLabelsTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsTargetVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest.verify|verify} messages.
                     * @param message SetLabelsTargetVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsTargetVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsTargetVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest;

                    /**
                     * Decodes a SetLabelsTargetVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsTargetVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest;

                    /**
                     * Verifies a SetLabelsTargetVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsTargetVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsTargetVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest;

                    /**
                     * Creates a plain object from a SetLabelsTargetVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsTargetVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsTargetVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsTargetVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsTargetVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsVpnGatewayRequest. */
                interface ISetLabelsVpnGatewayRequest {

                    /** SetLabelsVpnGatewayRequest project */
                    project?: (string|null);

                    /** SetLabelsVpnGatewayRequest region */
                    region?: (string|null);

                    /** SetLabelsVpnGatewayRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsVpnGatewayRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsVpnGatewayRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsVpnGatewayRequest. */
                class SetLabelsVpnGatewayRequest implements ISetLabelsVpnGatewayRequest {

                    /**
                     * Constructs a new SetLabelsVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsVpnGatewayRequest);

                    /** SetLabelsVpnGatewayRequest project. */
                    public project: string;

                    /** SetLabelsVpnGatewayRequest region. */
                    public region: string;

                    /** SetLabelsVpnGatewayRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsVpnGatewayRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsVpnGatewayRequest resource. */
                    public resource: string;

                    /** SetLabelsVpnGatewayRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsVpnGatewayRequest): google.cloud.compute.v1.SetLabelsVpnGatewayRequest;

                    /**
                     * Encodes the specified SetLabelsVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsVpnGatewayRequest.verify|verify} messages.
                     * @param message SetLabelsVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsVpnGatewayRequest.verify|verify} messages.
                     * @param message SetLabelsVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsVpnGatewayRequest;

                    /**
                     * Decodes a SetLabelsVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsVpnGatewayRequest;

                    /**
                     * Verifies a SetLabelsVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsVpnGatewayRequest;

                    /**
                     * Creates a plain object from a SetLabelsVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetLabelsVpnTunnelRequest. */
                interface ISetLabelsVpnTunnelRequest {

                    /** SetLabelsVpnTunnelRequest project */
                    project?: (string|null);

                    /** SetLabelsVpnTunnelRequest region */
                    region?: (string|null);

                    /** SetLabelsVpnTunnelRequest regionSetLabelsRequestResource */
                    regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsVpnTunnelRequest requestId */
                    requestId?: (string|null);

                    /** SetLabelsVpnTunnelRequest resource */
                    resource?: (string|null);
                }

                /** Represents a SetLabelsVpnTunnelRequest. */
                class SetLabelsVpnTunnelRequest implements ISetLabelsVpnTunnelRequest {

                    /**
                     * Constructs a new SetLabelsVpnTunnelRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetLabelsVpnTunnelRequest);

                    /** SetLabelsVpnTunnelRequest project. */
                    public project: string;

                    /** SetLabelsVpnTunnelRequest region. */
                    public region: string;

                    /** SetLabelsVpnTunnelRequest regionSetLabelsRequestResource. */
                    public regionSetLabelsRequestResource?: (google.cloud.compute.v1.IRegionSetLabelsRequest|null);

                    /** SetLabelsVpnTunnelRequest requestId. */
                    public requestId?: (string|null);

                    /** SetLabelsVpnTunnelRequest resource. */
                    public resource: string;

                    /** SetLabelsVpnTunnelRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetLabelsVpnTunnelRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetLabelsVpnTunnelRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetLabelsVpnTunnelRequest): google.cloud.compute.v1.SetLabelsVpnTunnelRequest;

                    /**
                     * Encodes the specified SetLabelsVpnTunnelRequest message. Does not implicitly {@link google.cloud.compute.v1.SetLabelsVpnTunnelRequest.verify|verify} messages.
                     * @param message SetLabelsVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetLabelsVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetLabelsVpnTunnelRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetLabelsVpnTunnelRequest.verify|verify} messages.
                     * @param message SetLabelsVpnTunnelRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetLabelsVpnTunnelRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetLabelsVpnTunnelRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetLabelsVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetLabelsVpnTunnelRequest;

                    /**
                     * Decodes a SetLabelsVpnTunnelRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetLabelsVpnTunnelRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetLabelsVpnTunnelRequest;

                    /**
                     * Verifies a SetLabelsVpnTunnelRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetLabelsVpnTunnelRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetLabelsVpnTunnelRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetLabelsVpnTunnelRequest;

                    /**
                     * Creates a plain object from a SetLabelsVpnTunnelRequest message. Also converts values to other types if specified.
                     * @param message SetLabelsVpnTunnelRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetLabelsVpnTunnelRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetLabelsVpnTunnelRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetLabelsVpnTunnelRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetMachineResourcesInstanceRequest. */
                interface ISetMachineResourcesInstanceRequest {

                    /** SetMachineResourcesInstanceRequest instance */
                    instance?: (string|null);

                    /** SetMachineResourcesInstanceRequest instancesSetMachineResourcesRequestResource */
                    instancesSetMachineResourcesRequestResource?: (google.cloud.compute.v1.IInstancesSetMachineResourcesRequest|null);

                    /** SetMachineResourcesInstanceRequest project */
                    project?: (string|null);

                    /** SetMachineResourcesInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetMachineResourcesInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetMachineResourcesInstanceRequest. */
                class SetMachineResourcesInstanceRequest implements ISetMachineResourcesInstanceRequest {

                    /**
                     * Constructs a new SetMachineResourcesInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetMachineResourcesInstanceRequest);

                    /** SetMachineResourcesInstanceRequest instance. */
                    public instance: string;

                    /** SetMachineResourcesInstanceRequest instancesSetMachineResourcesRequestResource. */
                    public instancesSetMachineResourcesRequestResource?: (google.cloud.compute.v1.IInstancesSetMachineResourcesRequest|null);

                    /** SetMachineResourcesInstanceRequest project. */
                    public project: string;

                    /** SetMachineResourcesInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetMachineResourcesInstanceRequest zone. */
                    public zone: string;

                    /** SetMachineResourcesInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetMachineResourcesInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetMachineResourcesInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetMachineResourcesInstanceRequest): google.cloud.compute.v1.SetMachineResourcesInstanceRequest;

                    /**
                     * Encodes the specified SetMachineResourcesInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetMachineResourcesInstanceRequest.verify|verify} messages.
                     * @param message SetMachineResourcesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetMachineResourcesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetMachineResourcesInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetMachineResourcesInstanceRequest.verify|verify} messages.
                     * @param message SetMachineResourcesInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetMachineResourcesInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetMachineResourcesInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetMachineResourcesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetMachineResourcesInstanceRequest;

                    /**
                     * Decodes a SetMachineResourcesInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetMachineResourcesInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetMachineResourcesInstanceRequest;

                    /**
                     * Verifies a SetMachineResourcesInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetMachineResourcesInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetMachineResourcesInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetMachineResourcesInstanceRequest;

                    /**
                     * Creates a plain object from a SetMachineResourcesInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetMachineResourcesInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetMachineResourcesInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetMachineResourcesInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetMachineResourcesInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetMachineTypeInstanceRequest. */
                interface ISetMachineTypeInstanceRequest {

                    /** SetMachineTypeInstanceRequest instance */
                    instance?: (string|null);

                    /** SetMachineTypeInstanceRequest instancesSetMachineTypeRequestResource */
                    instancesSetMachineTypeRequestResource?: (google.cloud.compute.v1.IInstancesSetMachineTypeRequest|null);

                    /** SetMachineTypeInstanceRequest project */
                    project?: (string|null);

                    /** SetMachineTypeInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetMachineTypeInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetMachineTypeInstanceRequest. */
                class SetMachineTypeInstanceRequest implements ISetMachineTypeInstanceRequest {

                    /**
                     * Constructs a new SetMachineTypeInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetMachineTypeInstanceRequest);

                    /** SetMachineTypeInstanceRequest instance. */
                    public instance: string;

                    /** SetMachineTypeInstanceRequest instancesSetMachineTypeRequestResource. */
                    public instancesSetMachineTypeRequestResource?: (google.cloud.compute.v1.IInstancesSetMachineTypeRequest|null);

                    /** SetMachineTypeInstanceRequest project. */
                    public project: string;

                    /** SetMachineTypeInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetMachineTypeInstanceRequest zone. */
                    public zone: string;

                    /** SetMachineTypeInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetMachineTypeInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetMachineTypeInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetMachineTypeInstanceRequest): google.cloud.compute.v1.SetMachineTypeInstanceRequest;

                    /**
                     * Encodes the specified SetMachineTypeInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetMachineTypeInstanceRequest.verify|verify} messages.
                     * @param message SetMachineTypeInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetMachineTypeInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetMachineTypeInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetMachineTypeInstanceRequest.verify|verify} messages.
                     * @param message SetMachineTypeInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetMachineTypeInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetMachineTypeInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetMachineTypeInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetMachineTypeInstanceRequest;

                    /**
                     * Decodes a SetMachineTypeInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetMachineTypeInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetMachineTypeInstanceRequest;

                    /**
                     * Verifies a SetMachineTypeInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetMachineTypeInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetMachineTypeInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetMachineTypeInstanceRequest;

                    /**
                     * Creates a plain object from a SetMachineTypeInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetMachineTypeInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetMachineTypeInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetMachineTypeInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetMachineTypeInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetMetadataInstanceRequest. */
                interface ISetMetadataInstanceRequest {

                    /** SetMetadataInstanceRequest instance */
                    instance?: (string|null);

                    /** SetMetadataInstanceRequest metadataResource */
                    metadataResource?: (google.cloud.compute.v1.IMetadata|null);

                    /** SetMetadataInstanceRequest project */
                    project?: (string|null);

                    /** SetMetadataInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetMetadataInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetMetadataInstanceRequest. */
                class SetMetadataInstanceRequest implements ISetMetadataInstanceRequest {

                    /**
                     * Constructs a new SetMetadataInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetMetadataInstanceRequest);

                    /** SetMetadataInstanceRequest instance. */
                    public instance: string;

                    /** SetMetadataInstanceRequest metadataResource. */
                    public metadataResource?: (google.cloud.compute.v1.IMetadata|null);

                    /** SetMetadataInstanceRequest project. */
                    public project: string;

                    /** SetMetadataInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetMetadataInstanceRequest zone. */
                    public zone: string;

                    /** SetMetadataInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetMetadataInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetMetadataInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetMetadataInstanceRequest): google.cloud.compute.v1.SetMetadataInstanceRequest;

                    /**
                     * Encodes the specified SetMetadataInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetMetadataInstanceRequest.verify|verify} messages.
                     * @param message SetMetadataInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetMetadataInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetMetadataInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetMetadataInstanceRequest.verify|verify} messages.
                     * @param message SetMetadataInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetMetadataInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetMetadataInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetMetadataInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetMetadataInstanceRequest;

                    /**
                     * Decodes a SetMetadataInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetMetadataInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetMetadataInstanceRequest;

                    /**
                     * Verifies a SetMetadataInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetMetadataInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetMetadataInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetMetadataInstanceRequest;

                    /**
                     * Creates a plain object from a SetMetadataInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetMetadataInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetMetadataInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetMetadataInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetMetadataInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetMinCpuPlatformInstanceRequest. */
                interface ISetMinCpuPlatformInstanceRequest {

                    /** SetMinCpuPlatformInstanceRequest instance */
                    instance?: (string|null);

                    /** SetMinCpuPlatformInstanceRequest instancesSetMinCpuPlatformRequestResource */
                    instancesSetMinCpuPlatformRequestResource?: (google.cloud.compute.v1.IInstancesSetMinCpuPlatformRequest|null);

                    /** SetMinCpuPlatformInstanceRequest project */
                    project?: (string|null);

                    /** SetMinCpuPlatformInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetMinCpuPlatformInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetMinCpuPlatformInstanceRequest. */
                class SetMinCpuPlatformInstanceRequest implements ISetMinCpuPlatformInstanceRequest {

                    /**
                     * Constructs a new SetMinCpuPlatformInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetMinCpuPlatformInstanceRequest);

                    /** SetMinCpuPlatformInstanceRequest instance. */
                    public instance: string;

                    /** SetMinCpuPlatformInstanceRequest instancesSetMinCpuPlatformRequestResource. */
                    public instancesSetMinCpuPlatformRequestResource?: (google.cloud.compute.v1.IInstancesSetMinCpuPlatformRequest|null);

                    /** SetMinCpuPlatformInstanceRequest project. */
                    public project: string;

                    /** SetMinCpuPlatformInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetMinCpuPlatformInstanceRequest zone. */
                    public zone: string;

                    /** SetMinCpuPlatformInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetMinCpuPlatformInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetMinCpuPlatformInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetMinCpuPlatformInstanceRequest): google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest;

                    /**
                     * Encodes the specified SetMinCpuPlatformInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest.verify|verify} messages.
                     * @param message SetMinCpuPlatformInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetMinCpuPlatformInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetMinCpuPlatformInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest.verify|verify} messages.
                     * @param message SetMinCpuPlatformInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetMinCpuPlatformInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetMinCpuPlatformInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetMinCpuPlatformInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest;

                    /**
                     * Decodes a SetMinCpuPlatformInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetMinCpuPlatformInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest;

                    /**
                     * Verifies a SetMinCpuPlatformInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetMinCpuPlatformInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetMinCpuPlatformInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest;

                    /**
                     * Creates a plain object from a SetMinCpuPlatformInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetMinCpuPlatformInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetMinCpuPlatformInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetMinCpuPlatformInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetMinCpuPlatformInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetNamedPortsInstanceGroupRequest. */
                interface ISetNamedPortsInstanceGroupRequest {

                    /** SetNamedPortsInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** SetNamedPortsInstanceGroupRequest instanceGroupsSetNamedPortsRequestResource */
                    instanceGroupsSetNamedPortsRequestResource?: (google.cloud.compute.v1.IInstanceGroupsSetNamedPortsRequest|null);

                    /** SetNamedPortsInstanceGroupRequest project */
                    project?: (string|null);

                    /** SetNamedPortsInstanceGroupRequest requestId */
                    requestId?: (string|null);

                    /** SetNamedPortsInstanceGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetNamedPortsInstanceGroupRequest. */
                class SetNamedPortsInstanceGroupRequest implements ISetNamedPortsInstanceGroupRequest {

                    /**
                     * Constructs a new SetNamedPortsInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetNamedPortsInstanceGroupRequest);

                    /** SetNamedPortsInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** SetNamedPortsInstanceGroupRequest instanceGroupsSetNamedPortsRequestResource. */
                    public instanceGroupsSetNamedPortsRequestResource?: (google.cloud.compute.v1.IInstanceGroupsSetNamedPortsRequest|null);

                    /** SetNamedPortsInstanceGroupRequest project. */
                    public project: string;

                    /** SetNamedPortsInstanceGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** SetNamedPortsInstanceGroupRequest zone. */
                    public zone: string;

                    /** SetNamedPortsInstanceGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetNamedPortsInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetNamedPortsInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetNamedPortsInstanceGroupRequest): google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest;

                    /**
                     * Encodes the specified SetNamedPortsInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest.verify|verify} messages.
                     * @param message SetNamedPortsInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetNamedPortsInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetNamedPortsInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest.verify|verify} messages.
                     * @param message SetNamedPortsInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetNamedPortsInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetNamedPortsInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetNamedPortsInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest;

                    /**
                     * Decodes a SetNamedPortsInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetNamedPortsInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest;

                    /**
                     * Verifies a SetNamedPortsInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetNamedPortsInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetNamedPortsInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest;

                    /**
                     * Creates a plain object from a SetNamedPortsInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message SetNamedPortsInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetNamedPortsInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetNamedPortsInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetNamedPortsInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetNamedPortsRegionInstanceGroupRequest. */
                interface ISetNamedPortsRegionInstanceGroupRequest {

                    /** SetNamedPortsRegionInstanceGroupRequest instanceGroup */
                    instanceGroup?: (string|null);

                    /** SetNamedPortsRegionInstanceGroupRequest project */
                    project?: (string|null);

                    /** SetNamedPortsRegionInstanceGroupRequest region */
                    region?: (string|null);

                    /** SetNamedPortsRegionInstanceGroupRequest regionInstanceGroupsSetNamedPortsRequestResource */
                    regionInstanceGroupsSetNamedPortsRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupsSetNamedPortsRequest|null);

                    /** SetNamedPortsRegionInstanceGroupRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a SetNamedPortsRegionInstanceGroupRequest. */
                class SetNamedPortsRegionInstanceGroupRequest implements ISetNamedPortsRegionInstanceGroupRequest {

                    /**
                     * Constructs a new SetNamedPortsRegionInstanceGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetNamedPortsRegionInstanceGroupRequest);

                    /** SetNamedPortsRegionInstanceGroupRequest instanceGroup. */
                    public instanceGroup: string;

                    /** SetNamedPortsRegionInstanceGroupRequest project. */
                    public project: string;

                    /** SetNamedPortsRegionInstanceGroupRequest region. */
                    public region: string;

                    /** SetNamedPortsRegionInstanceGroupRequest regionInstanceGroupsSetNamedPortsRequestResource. */
                    public regionInstanceGroupsSetNamedPortsRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupsSetNamedPortsRequest|null);

                    /** SetNamedPortsRegionInstanceGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** SetNamedPortsRegionInstanceGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetNamedPortsRegionInstanceGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetNamedPortsRegionInstanceGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetNamedPortsRegionInstanceGroupRequest): google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest;

                    /**
                     * Encodes the specified SetNamedPortsRegionInstanceGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest.verify|verify} messages.
                     * @param message SetNamedPortsRegionInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetNamedPortsRegionInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetNamedPortsRegionInstanceGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest.verify|verify} messages.
                     * @param message SetNamedPortsRegionInstanceGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetNamedPortsRegionInstanceGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetNamedPortsRegionInstanceGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetNamedPortsRegionInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest;

                    /**
                     * Decodes a SetNamedPortsRegionInstanceGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetNamedPortsRegionInstanceGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest;

                    /**
                     * Verifies a SetNamedPortsRegionInstanceGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetNamedPortsRegionInstanceGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetNamedPortsRegionInstanceGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest;

                    /**
                     * Creates a plain object from a SetNamedPortsRegionInstanceGroupRequest message. Also converts values to other types if specified.
                     * @param message SetNamedPortsRegionInstanceGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetNamedPortsRegionInstanceGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetNamedPortsRegionInstanceGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetNamedPortsRegionInstanceGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetNodeTemplateNodeGroupRequest. */
                interface ISetNodeTemplateNodeGroupRequest {

                    /** SetNodeTemplateNodeGroupRequest nodeGroup */
                    nodeGroup?: (string|null);

                    /** SetNodeTemplateNodeGroupRequest nodeGroupsSetNodeTemplateRequestResource */
                    nodeGroupsSetNodeTemplateRequestResource?: (google.cloud.compute.v1.INodeGroupsSetNodeTemplateRequest|null);

                    /** SetNodeTemplateNodeGroupRequest project */
                    project?: (string|null);

                    /** SetNodeTemplateNodeGroupRequest requestId */
                    requestId?: (string|null);

                    /** SetNodeTemplateNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetNodeTemplateNodeGroupRequest. */
                class SetNodeTemplateNodeGroupRequest implements ISetNodeTemplateNodeGroupRequest {

                    /**
                     * Constructs a new SetNodeTemplateNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest);

                    /** SetNodeTemplateNodeGroupRequest nodeGroup. */
                    public nodeGroup: string;

                    /** SetNodeTemplateNodeGroupRequest nodeGroupsSetNodeTemplateRequestResource. */
                    public nodeGroupsSetNodeTemplateRequestResource?: (google.cloud.compute.v1.INodeGroupsSetNodeTemplateRequest|null);

                    /** SetNodeTemplateNodeGroupRequest project. */
                    public project: string;

                    /** SetNodeTemplateNodeGroupRequest requestId. */
                    public requestId?: (string|null);

                    /** SetNodeTemplateNodeGroupRequest zone. */
                    public zone: string;

                    /** SetNodeTemplateNodeGroupRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetNodeTemplateNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetNodeTemplateNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest): google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest;

                    /**
                     * Encodes the specified SetNodeTemplateNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest.verify|verify} messages.
                     * @param message SetNodeTemplateNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetNodeTemplateNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest.verify|verify} messages.
                     * @param message SetNodeTemplateNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetNodeTemplateNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetNodeTemplateNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest;

                    /**
                     * Decodes a SetNodeTemplateNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetNodeTemplateNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest;

                    /**
                     * Verifies a SetNodeTemplateNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetNodeTemplateNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetNodeTemplateNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest;

                    /**
                     * Creates a plain object from a SetNodeTemplateNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message SetNodeTemplateNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetNodeTemplateNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetNodeTemplateNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetNodeTemplateNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetPrivateIpGoogleAccessSubnetworkRequest. */
                interface ISetPrivateIpGoogleAccessSubnetworkRequest {

                    /** SetPrivateIpGoogleAccessSubnetworkRequest project */
                    project?: (string|null);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest region */
                    region?: (string|null);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest requestId */
                    requestId?: (string|null);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest subnetwork */
                    subnetwork?: (string|null);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest subnetworksSetPrivateIpGoogleAccessRequestResource */
                    subnetworksSetPrivateIpGoogleAccessRequestResource?: (google.cloud.compute.v1.ISubnetworksSetPrivateIpGoogleAccessRequest|null);
                }

                /** Represents a SetPrivateIpGoogleAccessSubnetworkRequest. */
                class SetPrivateIpGoogleAccessSubnetworkRequest implements ISetPrivateIpGoogleAccessSubnetworkRequest {

                    /**
                     * Constructs a new SetPrivateIpGoogleAccessSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest project. */
                    public project: string;

                    /** SetPrivateIpGoogleAccessSubnetworkRequest region. */
                    public region: string;

                    /** SetPrivateIpGoogleAccessSubnetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest subnetwork. */
                    public subnetwork: string;

                    /** SetPrivateIpGoogleAccessSubnetworkRequest subnetworksSetPrivateIpGoogleAccessRequestResource. */
                    public subnetworksSetPrivateIpGoogleAccessRequestResource?: (google.cloud.compute.v1.ISubnetworksSetPrivateIpGoogleAccessRequest|null);

                    /** SetPrivateIpGoogleAccessSubnetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetPrivateIpGoogleAccessSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetPrivateIpGoogleAccessSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest): google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest;

                    /**
                     * Encodes the specified SetPrivateIpGoogleAccessSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest.verify|verify} messages.
                     * @param message SetPrivateIpGoogleAccessSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetPrivateIpGoogleAccessSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest.verify|verify} messages.
                     * @param message SetPrivateIpGoogleAccessSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetPrivateIpGoogleAccessSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetPrivateIpGoogleAccessSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest;

                    /**
                     * Decodes a SetPrivateIpGoogleAccessSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetPrivateIpGoogleAccessSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest;

                    /**
                     * Verifies a SetPrivateIpGoogleAccessSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetPrivateIpGoogleAccessSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetPrivateIpGoogleAccessSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest;

                    /**
                     * Creates a plain object from a SetPrivateIpGoogleAccessSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message SetPrivateIpGoogleAccessSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetPrivateIpGoogleAccessSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetPrivateIpGoogleAccessSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetPrivateIpGoogleAccessSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetProxyHeaderTargetSslProxyRequest. */
                interface ISetProxyHeaderTargetSslProxyRequest {

                    /** SetProxyHeaderTargetSslProxyRequest project */
                    project?: (string|null);

                    /** SetProxyHeaderTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetProxyHeaderTargetSslProxyRequest targetSslProxiesSetProxyHeaderRequestResource */
                    targetSslProxiesSetProxyHeaderRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetProxyHeaderRequest|null);

                    /** SetProxyHeaderTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a SetProxyHeaderTargetSslProxyRequest. */
                class SetProxyHeaderTargetSslProxyRequest implements ISetProxyHeaderTargetSslProxyRequest {

                    /**
                     * Constructs a new SetProxyHeaderTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetProxyHeaderTargetSslProxyRequest);

                    /** SetProxyHeaderTargetSslProxyRequest project. */
                    public project: string;

                    /** SetProxyHeaderTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetProxyHeaderTargetSslProxyRequest targetSslProxiesSetProxyHeaderRequestResource. */
                    public targetSslProxiesSetProxyHeaderRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetProxyHeaderRequest|null);

                    /** SetProxyHeaderTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /** SetProxyHeaderTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetProxyHeaderTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetProxyHeaderTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetProxyHeaderTargetSslProxyRequest): google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest;

                    /**
                     * Encodes the specified SetProxyHeaderTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetProxyHeaderTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetProxyHeaderTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetProxyHeaderTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetProxyHeaderTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetProxyHeaderTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetProxyHeaderTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetProxyHeaderTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest;

                    /**
                     * Decodes a SetProxyHeaderTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetProxyHeaderTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest;

                    /**
                     * Verifies a SetProxyHeaderTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetProxyHeaderTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetProxyHeaderTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a SetProxyHeaderTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message SetProxyHeaderTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetProxyHeaderTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetProxyHeaderTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetProxyHeaderTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetProxyHeaderTargetTcpProxyRequest. */
                interface ISetProxyHeaderTargetTcpProxyRequest {

                    /** SetProxyHeaderTargetTcpProxyRequest project */
                    project?: (string|null);

                    /** SetProxyHeaderTargetTcpProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetProxyHeaderTargetTcpProxyRequest targetTcpProxiesSetProxyHeaderRequestResource */
                    targetTcpProxiesSetProxyHeaderRequestResource?: (google.cloud.compute.v1.ITargetTcpProxiesSetProxyHeaderRequest|null);

                    /** SetProxyHeaderTargetTcpProxyRequest targetTcpProxy */
                    targetTcpProxy?: (string|null);
                }

                /** Represents a SetProxyHeaderTargetTcpProxyRequest. */
                class SetProxyHeaderTargetTcpProxyRequest implements ISetProxyHeaderTargetTcpProxyRequest {

                    /**
                     * Constructs a new SetProxyHeaderTargetTcpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetProxyHeaderTargetTcpProxyRequest);

                    /** SetProxyHeaderTargetTcpProxyRequest project. */
                    public project: string;

                    /** SetProxyHeaderTargetTcpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetProxyHeaderTargetTcpProxyRequest targetTcpProxiesSetProxyHeaderRequestResource. */
                    public targetTcpProxiesSetProxyHeaderRequestResource?: (google.cloud.compute.v1.ITargetTcpProxiesSetProxyHeaderRequest|null);

                    /** SetProxyHeaderTargetTcpProxyRequest targetTcpProxy. */
                    public targetTcpProxy: string;

                    /** SetProxyHeaderTargetTcpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetProxyHeaderTargetTcpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetProxyHeaderTargetTcpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetProxyHeaderTargetTcpProxyRequest): google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest;

                    /**
                     * Encodes the specified SetProxyHeaderTargetTcpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest.verify|verify} messages.
                     * @param message SetProxyHeaderTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetProxyHeaderTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetProxyHeaderTargetTcpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest.verify|verify} messages.
                     * @param message SetProxyHeaderTargetTcpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetProxyHeaderTargetTcpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetProxyHeaderTargetTcpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetProxyHeaderTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest;

                    /**
                     * Decodes a SetProxyHeaderTargetTcpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetProxyHeaderTargetTcpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest;

                    /**
                     * Verifies a SetProxyHeaderTargetTcpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetProxyHeaderTargetTcpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetProxyHeaderTargetTcpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest;

                    /**
                     * Creates a plain object from a SetProxyHeaderTargetTcpProxyRequest message. Also converts values to other types if specified.
                     * @param message SetProxyHeaderTargetTcpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetProxyHeaderTargetTcpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetProxyHeaderTargetTcpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetProxyHeaderTargetTcpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetQuicOverrideTargetHttpsProxyRequest. */
                interface ISetQuicOverrideTargetHttpsProxyRequest {

                    /** SetQuicOverrideTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetQuicOverrideTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetQuicOverrideTargetHttpsProxyRequest targetHttpsProxiesSetQuicOverrideRequestResource */
                    targetHttpsProxiesSetQuicOverrideRequestResource?: (google.cloud.compute.v1.ITargetHttpsProxiesSetQuicOverrideRequest|null);

                    /** SetQuicOverrideTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a SetQuicOverrideTargetHttpsProxyRequest. */
                class SetQuicOverrideTargetHttpsProxyRequest implements ISetQuicOverrideTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetQuicOverrideTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetQuicOverrideTargetHttpsProxyRequest);

                    /** SetQuicOverrideTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetQuicOverrideTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetQuicOverrideTargetHttpsProxyRequest targetHttpsProxiesSetQuicOverrideRequestResource. */
                    public targetHttpsProxiesSetQuicOverrideRequestResource?: (google.cloud.compute.v1.ITargetHttpsProxiesSetQuicOverrideRequest|null);

                    /** SetQuicOverrideTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetQuicOverrideTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetQuicOverrideTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetQuicOverrideTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetQuicOverrideTargetHttpsProxyRequest): google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetQuicOverrideTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetQuicOverrideTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetQuicOverrideTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetQuicOverrideTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetQuicOverrideTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetQuicOverrideTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetQuicOverrideTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetQuicOverrideTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetQuicOverrideTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetQuicOverrideTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetQuicOverrideTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetQuicOverrideTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetQuicOverrideTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetQuicOverrideTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetQuicOverrideTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetQuicOverrideTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetQuicOverrideTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetQuicOverrideTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSchedulingInstanceRequest. */
                interface ISetSchedulingInstanceRequest {

                    /** SetSchedulingInstanceRequest instance */
                    instance?: (string|null);

                    /** SetSchedulingInstanceRequest project */
                    project?: (string|null);

                    /** SetSchedulingInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetSchedulingInstanceRequest schedulingResource */
                    schedulingResource?: (google.cloud.compute.v1.IScheduling|null);

                    /** SetSchedulingInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetSchedulingInstanceRequest. */
                class SetSchedulingInstanceRequest implements ISetSchedulingInstanceRequest {

                    /**
                     * Constructs a new SetSchedulingInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSchedulingInstanceRequest);

                    /** SetSchedulingInstanceRequest instance. */
                    public instance: string;

                    /** SetSchedulingInstanceRequest project. */
                    public project: string;

                    /** SetSchedulingInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSchedulingInstanceRequest schedulingResource. */
                    public schedulingResource?: (google.cloud.compute.v1.IScheduling|null);

                    /** SetSchedulingInstanceRequest zone. */
                    public zone: string;

                    /** SetSchedulingInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSchedulingInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSchedulingInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSchedulingInstanceRequest): google.cloud.compute.v1.SetSchedulingInstanceRequest;

                    /**
                     * Encodes the specified SetSchedulingInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSchedulingInstanceRequest.verify|verify} messages.
                     * @param message SetSchedulingInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSchedulingInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSchedulingInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSchedulingInstanceRequest.verify|verify} messages.
                     * @param message SetSchedulingInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSchedulingInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSchedulingInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSchedulingInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSchedulingInstanceRequest;

                    /**
                     * Decodes a SetSchedulingInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSchedulingInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSchedulingInstanceRequest;

                    /**
                     * Verifies a SetSchedulingInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSchedulingInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSchedulingInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSchedulingInstanceRequest;

                    /**
                     * Creates a plain object from a SetSchedulingInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetSchedulingInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSchedulingInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSchedulingInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSchedulingInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSecurityPolicyBackendServiceRequest. */
                interface ISetSecurityPolicyBackendServiceRequest {

                    /** SetSecurityPolicyBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** SetSecurityPolicyBackendServiceRequest project */
                    project?: (string|null);

                    /** SetSecurityPolicyBackendServiceRequest requestId */
                    requestId?: (string|null);

                    /** SetSecurityPolicyBackendServiceRequest securityPolicyReferenceResource */
                    securityPolicyReferenceResource?: (google.cloud.compute.v1.ISecurityPolicyReference|null);
                }

                /** Represents a SetSecurityPolicyBackendServiceRequest. */
                class SetSecurityPolicyBackendServiceRequest implements ISetSecurityPolicyBackendServiceRequest {

                    /**
                     * Constructs a new SetSecurityPolicyBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSecurityPolicyBackendServiceRequest);

                    /** SetSecurityPolicyBackendServiceRequest backendService. */
                    public backendService: string;

                    /** SetSecurityPolicyBackendServiceRequest project. */
                    public project: string;

                    /** SetSecurityPolicyBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSecurityPolicyBackendServiceRequest securityPolicyReferenceResource. */
                    public securityPolicyReferenceResource?: (google.cloud.compute.v1.ISecurityPolicyReference|null);

                    /** SetSecurityPolicyBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSecurityPolicyBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSecurityPolicyBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSecurityPolicyBackendServiceRequest): google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest;

                    /**
                     * Encodes the specified SetSecurityPolicyBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message SetSecurityPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSecurityPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSecurityPolicyBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest.verify|verify} messages.
                     * @param message SetSecurityPolicyBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSecurityPolicyBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSecurityPolicyBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSecurityPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest;

                    /**
                     * Decodes a SetSecurityPolicyBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSecurityPolicyBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest;

                    /**
                     * Verifies a SetSecurityPolicyBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSecurityPolicyBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSecurityPolicyBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest;

                    /**
                     * Creates a plain object from a SetSecurityPolicyBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message SetSecurityPolicyBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSecurityPolicyBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSecurityPolicyBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSecurityPolicyBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetServiceAccountInstanceRequest. */
                interface ISetServiceAccountInstanceRequest {

                    /** SetServiceAccountInstanceRequest instance */
                    instance?: (string|null);

                    /** SetServiceAccountInstanceRequest instancesSetServiceAccountRequestResource */
                    instancesSetServiceAccountRequestResource?: (google.cloud.compute.v1.IInstancesSetServiceAccountRequest|null);

                    /** SetServiceAccountInstanceRequest project */
                    project?: (string|null);

                    /** SetServiceAccountInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetServiceAccountInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetServiceAccountInstanceRequest. */
                class SetServiceAccountInstanceRequest implements ISetServiceAccountInstanceRequest {

                    /**
                     * Constructs a new SetServiceAccountInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetServiceAccountInstanceRequest);

                    /** SetServiceAccountInstanceRequest instance. */
                    public instance: string;

                    /** SetServiceAccountInstanceRequest instancesSetServiceAccountRequestResource. */
                    public instancesSetServiceAccountRequestResource?: (google.cloud.compute.v1.IInstancesSetServiceAccountRequest|null);

                    /** SetServiceAccountInstanceRequest project. */
                    public project: string;

                    /** SetServiceAccountInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetServiceAccountInstanceRequest zone. */
                    public zone: string;

                    /** SetServiceAccountInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetServiceAccountInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetServiceAccountInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetServiceAccountInstanceRequest): google.cloud.compute.v1.SetServiceAccountInstanceRequest;

                    /**
                     * Encodes the specified SetServiceAccountInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetServiceAccountInstanceRequest.verify|verify} messages.
                     * @param message SetServiceAccountInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetServiceAccountInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetServiceAccountInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetServiceAccountInstanceRequest.verify|verify} messages.
                     * @param message SetServiceAccountInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetServiceAccountInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetServiceAccountInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetServiceAccountInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetServiceAccountInstanceRequest;

                    /**
                     * Decodes a SetServiceAccountInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetServiceAccountInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetServiceAccountInstanceRequest;

                    /**
                     * Verifies a SetServiceAccountInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetServiceAccountInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetServiceAccountInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetServiceAccountInstanceRequest;

                    /**
                     * Creates a plain object from a SetServiceAccountInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetServiceAccountInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetServiceAccountInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetServiceAccountInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetServiceAccountInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetShieldedInstanceIntegrityPolicyInstanceRequest. */
                interface ISetShieldedInstanceIntegrityPolicyInstanceRequest {

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest instance */
                    instance?: (string|null);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest project */
                    project?: (string|null);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest shieldedInstanceIntegrityPolicyResource */
                    shieldedInstanceIntegrityPolicyResource?: (google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy|null);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetShieldedInstanceIntegrityPolicyInstanceRequest. */
                class SetShieldedInstanceIntegrityPolicyInstanceRequest implements ISetShieldedInstanceIntegrityPolicyInstanceRequest {

                    /**
                     * Constructs a new SetShieldedInstanceIntegrityPolicyInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetShieldedInstanceIntegrityPolicyInstanceRequest);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest instance. */
                    public instance: string;

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest project. */
                    public project: string;

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest shieldedInstanceIntegrityPolicyResource. */
                    public shieldedInstanceIntegrityPolicyResource?: (google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy|null);

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest zone. */
                    public zone: string;

                    /** SetShieldedInstanceIntegrityPolicyInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetShieldedInstanceIntegrityPolicyInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetShieldedInstanceIntegrityPolicyInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetShieldedInstanceIntegrityPolicyInstanceRequest): google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest;

                    /**
                     * Encodes the specified SetShieldedInstanceIntegrityPolicyInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest.verify|verify} messages.
                     * @param message SetShieldedInstanceIntegrityPolicyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetShieldedInstanceIntegrityPolicyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetShieldedInstanceIntegrityPolicyInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest.verify|verify} messages.
                     * @param message SetShieldedInstanceIntegrityPolicyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetShieldedInstanceIntegrityPolicyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetShieldedInstanceIntegrityPolicyInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetShieldedInstanceIntegrityPolicyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest;

                    /**
                     * Decodes a SetShieldedInstanceIntegrityPolicyInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetShieldedInstanceIntegrityPolicyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest;

                    /**
                     * Verifies a SetShieldedInstanceIntegrityPolicyInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetShieldedInstanceIntegrityPolicyInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetShieldedInstanceIntegrityPolicyInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest;

                    /**
                     * Creates a plain object from a SetShieldedInstanceIntegrityPolicyInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetShieldedInstanceIntegrityPolicyInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetShieldedInstanceIntegrityPolicyInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetShieldedInstanceIntegrityPolicyInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetShieldedInstanceIntegrityPolicyInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSslCertificatesRegionTargetHttpsProxyRequest. */
                interface ISetSslCertificatesRegionTargetHttpsProxyRequest {

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest region */
                    region?: (string|null);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest regionTargetHttpsProxiesSetSslCertificatesRequestResource */
                    regionTargetHttpsProxiesSetSslCertificatesRequestResource?: (google.cloud.compute.v1.IRegionTargetHttpsProxiesSetSslCertificatesRequest|null);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a SetSslCertificatesRegionTargetHttpsProxyRequest. */
                class SetSslCertificatesRegionTargetHttpsProxyRequest implements ISetSslCertificatesRegionTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetSslCertificatesRegionTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSslCertificatesRegionTargetHttpsProxyRequest);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest region. */
                    public region: string;

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest regionTargetHttpsProxiesSetSslCertificatesRequestResource. */
                    public regionTargetHttpsProxiesSetSslCertificatesRequestResource?: (google.cloud.compute.v1.IRegionTargetHttpsProxiesSetSslCertificatesRequest|null);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetSslCertificatesRegionTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSslCertificatesRegionTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSslCertificatesRegionTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSslCertificatesRegionTargetHttpsProxyRequest): google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetSslCertificatesRegionTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetSslCertificatesRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSslCertificatesRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSslCertificatesRegionTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetSslCertificatesRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSslCertificatesRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSslCertificatesRegionTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSslCertificatesRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetSslCertificatesRegionTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSslCertificatesRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetSslCertificatesRegionTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSslCertificatesRegionTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSslCertificatesRegionTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetSslCertificatesRegionTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetSslCertificatesRegionTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSslCertificatesRegionTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSslCertificatesRegionTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSslCertificatesRegionTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSslCertificatesTargetHttpsProxyRequest. */
                interface ISetSslCertificatesTargetHttpsProxyRequest {

                    /** SetSslCertificatesTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetSslCertificatesTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetSslCertificatesTargetHttpsProxyRequest targetHttpsProxiesSetSslCertificatesRequestResource */
                    targetHttpsProxiesSetSslCertificatesRequestResource?: (google.cloud.compute.v1.ITargetHttpsProxiesSetSslCertificatesRequest|null);

                    /** SetSslCertificatesTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a SetSslCertificatesTargetHttpsProxyRequest. */
                class SetSslCertificatesTargetHttpsProxyRequest implements ISetSslCertificatesTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetSslCertificatesTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSslCertificatesTargetHttpsProxyRequest);

                    /** SetSslCertificatesTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetSslCertificatesTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSslCertificatesTargetHttpsProxyRequest targetHttpsProxiesSetSslCertificatesRequestResource. */
                    public targetHttpsProxiesSetSslCertificatesRequestResource?: (google.cloud.compute.v1.ITargetHttpsProxiesSetSslCertificatesRequest|null);

                    /** SetSslCertificatesTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetSslCertificatesTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSslCertificatesTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSslCertificatesTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSslCertificatesTargetHttpsProxyRequest): google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetSslCertificatesTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetSslCertificatesTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSslCertificatesTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSslCertificatesTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetSslCertificatesTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSslCertificatesTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSslCertificatesTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSslCertificatesTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetSslCertificatesTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSslCertificatesTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetSslCertificatesTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSslCertificatesTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSslCertificatesTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetSslCertificatesTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetSslCertificatesTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSslCertificatesTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSslCertificatesTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSslCertificatesTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSslCertificatesTargetSslProxyRequest. */
                interface ISetSslCertificatesTargetSslProxyRequest {

                    /** SetSslCertificatesTargetSslProxyRequest project */
                    project?: (string|null);

                    /** SetSslCertificatesTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetSslCertificatesTargetSslProxyRequest targetSslProxiesSetSslCertificatesRequestResource */
                    targetSslProxiesSetSslCertificatesRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetSslCertificatesRequest|null);

                    /** SetSslCertificatesTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a SetSslCertificatesTargetSslProxyRequest. */
                class SetSslCertificatesTargetSslProxyRequest implements ISetSslCertificatesTargetSslProxyRequest {

                    /**
                     * Constructs a new SetSslCertificatesTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSslCertificatesTargetSslProxyRequest);

                    /** SetSslCertificatesTargetSslProxyRequest project. */
                    public project: string;

                    /** SetSslCertificatesTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSslCertificatesTargetSslProxyRequest targetSslProxiesSetSslCertificatesRequestResource. */
                    public targetSslProxiesSetSslCertificatesRequestResource?: (google.cloud.compute.v1.ITargetSslProxiesSetSslCertificatesRequest|null);

                    /** SetSslCertificatesTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /** SetSslCertificatesTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSslCertificatesTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSslCertificatesTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSslCertificatesTargetSslProxyRequest): google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest;

                    /**
                     * Encodes the specified SetSslCertificatesTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetSslCertificatesTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSslCertificatesTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSslCertificatesTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetSslCertificatesTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSslCertificatesTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSslCertificatesTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSslCertificatesTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest;

                    /**
                     * Decodes a SetSslCertificatesTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSslCertificatesTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest;

                    /**
                     * Verifies a SetSslCertificatesTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSslCertificatesTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSslCertificatesTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a SetSslCertificatesTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message SetSslCertificatesTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSslCertificatesTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSslCertificatesTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSslCertificatesTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSslPolicyTargetHttpsProxyRequest. */
                interface ISetSslPolicyTargetHttpsProxyRequest {

                    /** SetSslPolicyTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetSslPolicyTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetSslPolicyTargetHttpsProxyRequest sslPolicyReferenceResource */
                    sslPolicyReferenceResource?: (google.cloud.compute.v1.ISslPolicyReference|null);

                    /** SetSslPolicyTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);
                }

                /** Represents a SetSslPolicyTargetHttpsProxyRequest. */
                class SetSslPolicyTargetHttpsProxyRequest implements ISetSslPolicyTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetSslPolicyTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSslPolicyTargetHttpsProxyRequest);

                    /** SetSslPolicyTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetSslPolicyTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSslPolicyTargetHttpsProxyRequest sslPolicyReferenceResource. */
                    public sslPolicyReferenceResource?: (google.cloud.compute.v1.ISslPolicyReference|null);

                    /** SetSslPolicyTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetSslPolicyTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSslPolicyTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSslPolicyTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSslPolicyTargetHttpsProxyRequest): google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetSslPolicyTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetSslPolicyTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSslPolicyTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSslPolicyTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetSslPolicyTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSslPolicyTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSslPolicyTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSslPolicyTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetSslPolicyTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSslPolicyTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetSslPolicyTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSslPolicyTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSslPolicyTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetSslPolicyTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetSslPolicyTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSslPolicyTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSslPolicyTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSslPolicyTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetSslPolicyTargetSslProxyRequest. */
                interface ISetSslPolicyTargetSslProxyRequest {

                    /** SetSslPolicyTargetSslProxyRequest project */
                    project?: (string|null);

                    /** SetSslPolicyTargetSslProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetSslPolicyTargetSslProxyRequest sslPolicyReferenceResource */
                    sslPolicyReferenceResource?: (google.cloud.compute.v1.ISslPolicyReference|null);

                    /** SetSslPolicyTargetSslProxyRequest targetSslProxy */
                    targetSslProxy?: (string|null);
                }

                /** Represents a SetSslPolicyTargetSslProxyRequest. */
                class SetSslPolicyTargetSslProxyRequest implements ISetSslPolicyTargetSslProxyRequest {

                    /**
                     * Constructs a new SetSslPolicyTargetSslProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetSslPolicyTargetSslProxyRequest);

                    /** SetSslPolicyTargetSslProxyRequest project. */
                    public project: string;

                    /** SetSslPolicyTargetSslProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetSslPolicyTargetSslProxyRequest sslPolicyReferenceResource. */
                    public sslPolicyReferenceResource?: (google.cloud.compute.v1.ISslPolicyReference|null);

                    /** SetSslPolicyTargetSslProxyRequest targetSslProxy. */
                    public targetSslProxy: string;

                    /** SetSslPolicyTargetSslProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetSslPolicyTargetSslProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetSslPolicyTargetSslProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetSslPolicyTargetSslProxyRequest): google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest;

                    /**
                     * Encodes the specified SetSslPolicyTargetSslProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetSslPolicyTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetSslPolicyTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetSslPolicyTargetSslProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest.verify|verify} messages.
                     * @param message SetSslPolicyTargetSslProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetSslPolicyTargetSslProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetSslPolicyTargetSslProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetSslPolicyTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest;

                    /**
                     * Decodes a SetSslPolicyTargetSslProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetSslPolicyTargetSslProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest;

                    /**
                     * Verifies a SetSslPolicyTargetSslProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetSslPolicyTargetSslProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetSslPolicyTargetSslProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest;

                    /**
                     * Creates a plain object from a SetSslPolicyTargetSslProxyRequest message. Also converts values to other types if specified.
                     * @param message SetSslPolicyTargetSslProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetSslPolicyTargetSslProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetSslPolicyTargetSslProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetSslPolicyTargetSslProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetTagsInstanceRequest. */
                interface ISetTagsInstanceRequest {

                    /** SetTagsInstanceRequest instance */
                    instance?: (string|null);

                    /** SetTagsInstanceRequest project */
                    project?: (string|null);

                    /** SetTagsInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SetTagsInstanceRequest tagsResource */
                    tagsResource?: (google.cloud.compute.v1.ITags|null);

                    /** SetTagsInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetTagsInstanceRequest. */
                class SetTagsInstanceRequest implements ISetTagsInstanceRequest {

                    /**
                     * Constructs a new SetTagsInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetTagsInstanceRequest);

                    /** SetTagsInstanceRequest instance. */
                    public instance: string;

                    /** SetTagsInstanceRequest project. */
                    public project: string;

                    /** SetTagsInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SetTagsInstanceRequest tagsResource. */
                    public tagsResource?: (google.cloud.compute.v1.ITags|null);

                    /** SetTagsInstanceRequest zone. */
                    public zone: string;

                    /** SetTagsInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetTagsInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetTagsInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetTagsInstanceRequest): google.cloud.compute.v1.SetTagsInstanceRequest;

                    /**
                     * Encodes the specified SetTagsInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SetTagsInstanceRequest.verify|verify} messages.
                     * @param message SetTagsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetTagsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetTagsInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetTagsInstanceRequest.verify|verify} messages.
                     * @param message SetTagsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetTagsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetTagsInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetTagsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetTagsInstanceRequest;

                    /**
                     * Decodes a SetTagsInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetTagsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetTagsInstanceRequest;

                    /**
                     * Verifies a SetTagsInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetTagsInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetTagsInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetTagsInstanceRequest;

                    /**
                     * Creates a plain object from a SetTagsInstanceRequest message. Also converts values to other types if specified.
                     * @param message SetTagsInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetTagsInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetTagsInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetTagsInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetTargetForwardingRuleRequest. */
                interface ISetTargetForwardingRuleRequest {

                    /** SetTargetForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** SetTargetForwardingRuleRequest project */
                    project?: (string|null);

                    /** SetTargetForwardingRuleRequest region */
                    region?: (string|null);

                    /** SetTargetForwardingRuleRequest requestId */
                    requestId?: (string|null);

                    /** SetTargetForwardingRuleRequest targetReferenceResource */
                    targetReferenceResource?: (google.cloud.compute.v1.ITargetReference|null);
                }

                /** Represents a SetTargetForwardingRuleRequest. */
                class SetTargetForwardingRuleRequest implements ISetTargetForwardingRuleRequest {

                    /**
                     * Constructs a new SetTargetForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetTargetForwardingRuleRequest);

                    /** SetTargetForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** SetTargetForwardingRuleRequest project. */
                    public project: string;

                    /** SetTargetForwardingRuleRequest region. */
                    public region: string;

                    /** SetTargetForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** SetTargetForwardingRuleRequest targetReferenceResource. */
                    public targetReferenceResource?: (google.cloud.compute.v1.ITargetReference|null);

                    /** SetTargetForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetTargetForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetTargetForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetTargetForwardingRuleRequest): google.cloud.compute.v1.SetTargetForwardingRuleRequest;

                    /**
                     * Encodes the specified SetTargetForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.SetTargetForwardingRuleRequest.verify|verify} messages.
                     * @param message SetTargetForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetTargetForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetTargetForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetTargetForwardingRuleRequest.verify|verify} messages.
                     * @param message SetTargetForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetTargetForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetTargetForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetTargetForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetTargetForwardingRuleRequest;

                    /**
                     * Decodes a SetTargetForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetTargetForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetTargetForwardingRuleRequest;

                    /**
                     * Verifies a SetTargetForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetTargetForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetTargetForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetTargetForwardingRuleRequest;

                    /**
                     * Creates a plain object from a SetTargetForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message SetTargetForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetTargetForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetTargetForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetTargetForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetTargetGlobalForwardingRuleRequest. */
                interface ISetTargetGlobalForwardingRuleRequest {

                    /** SetTargetGlobalForwardingRuleRequest forwardingRule */
                    forwardingRule?: (string|null);

                    /** SetTargetGlobalForwardingRuleRequest project */
                    project?: (string|null);

                    /** SetTargetGlobalForwardingRuleRequest requestId */
                    requestId?: (string|null);

                    /** SetTargetGlobalForwardingRuleRequest targetReferenceResource */
                    targetReferenceResource?: (google.cloud.compute.v1.ITargetReference|null);
                }

                /** Represents a SetTargetGlobalForwardingRuleRequest. */
                class SetTargetGlobalForwardingRuleRequest implements ISetTargetGlobalForwardingRuleRequest {

                    /**
                     * Constructs a new SetTargetGlobalForwardingRuleRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetTargetGlobalForwardingRuleRequest);

                    /** SetTargetGlobalForwardingRuleRequest forwardingRule. */
                    public forwardingRule: string;

                    /** SetTargetGlobalForwardingRuleRequest project. */
                    public project: string;

                    /** SetTargetGlobalForwardingRuleRequest requestId. */
                    public requestId?: (string|null);

                    /** SetTargetGlobalForwardingRuleRequest targetReferenceResource. */
                    public targetReferenceResource?: (google.cloud.compute.v1.ITargetReference|null);

                    /** SetTargetGlobalForwardingRuleRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetTargetGlobalForwardingRuleRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetTargetGlobalForwardingRuleRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetTargetGlobalForwardingRuleRequest): google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest;

                    /**
                     * Encodes the specified SetTargetGlobalForwardingRuleRequest message. Does not implicitly {@link google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message SetTargetGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetTargetGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetTargetGlobalForwardingRuleRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest.verify|verify} messages.
                     * @param message SetTargetGlobalForwardingRuleRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetTargetGlobalForwardingRuleRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetTargetGlobalForwardingRuleRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetTargetGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest;

                    /**
                     * Decodes a SetTargetGlobalForwardingRuleRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetTargetGlobalForwardingRuleRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest;

                    /**
                     * Verifies a SetTargetGlobalForwardingRuleRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetTargetGlobalForwardingRuleRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetTargetGlobalForwardingRuleRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest;

                    /**
                     * Creates a plain object from a SetTargetGlobalForwardingRuleRequest message. Also converts values to other types if specified.
                     * @param message SetTargetGlobalForwardingRuleRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetTargetGlobalForwardingRuleRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetTargetGlobalForwardingRuleRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetTargetGlobalForwardingRuleRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetTargetPoolsInstanceGroupManagerRequest. */
                interface ISetTargetPoolsInstanceGroupManagerRequest {

                    /** SetTargetPoolsInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** SetTargetPoolsInstanceGroupManagerRequest instanceGroupManagersSetTargetPoolsRequestResource */
                    instanceGroupManagersSetTargetPoolsRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersSetTargetPoolsRequest|null);

                    /** SetTargetPoolsInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** SetTargetPoolsInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** SetTargetPoolsInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SetTargetPoolsInstanceGroupManagerRequest. */
                class SetTargetPoolsInstanceGroupManagerRequest implements ISetTargetPoolsInstanceGroupManagerRequest {

                    /**
                     * Constructs a new SetTargetPoolsInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest);

                    /** SetTargetPoolsInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** SetTargetPoolsInstanceGroupManagerRequest instanceGroupManagersSetTargetPoolsRequestResource. */
                    public instanceGroupManagersSetTargetPoolsRequestResource?: (google.cloud.compute.v1.IInstanceGroupManagersSetTargetPoolsRequest|null);

                    /** SetTargetPoolsInstanceGroupManagerRequest project. */
                    public project: string;

                    /** SetTargetPoolsInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** SetTargetPoolsInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** SetTargetPoolsInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetTargetPoolsInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetTargetPoolsInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest): google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified SetTargetPoolsInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetTargetPoolsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetTargetPoolsInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetTargetPoolsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetTargetPoolsInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetTargetPoolsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest;

                    /**
                     * Decodes a SetTargetPoolsInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetTargetPoolsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest;

                    /**
                     * Verifies a SetTargetPoolsInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetTargetPoolsInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetTargetPoolsInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a SetTargetPoolsInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message SetTargetPoolsInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetTargetPoolsInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetTargetPoolsInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetTargetPoolsInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetTargetPoolsRegionInstanceGroupManagerRequest. */
                interface ISetTargetPoolsRegionInstanceGroupManagerRequest {

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest regionInstanceGroupManagersSetTargetPoolsRequestResource */
                    regionInstanceGroupManagersSetTargetPoolsRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersSetTargetPoolsRequest|null);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a SetTargetPoolsRegionInstanceGroupManagerRequest. */
                class SetTargetPoolsRegionInstanceGroupManagerRequest implements ISetTargetPoolsRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new SetTargetPoolsRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest regionInstanceGroupManagersSetTargetPoolsRequestResource. */
                    public regionInstanceGroupManagersSetTargetPoolsRequestResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagersSetTargetPoolsRequest|null);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** SetTargetPoolsRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetTargetPoolsRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetTargetPoolsRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest): google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified SetTargetPoolsRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetTargetPoolsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetTargetPoolsRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message SetTargetPoolsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetTargetPoolsRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetTargetPoolsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes a SetTargetPoolsRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetTargetPoolsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies a SetTargetPoolsRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetTargetPoolsRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetTargetPoolsRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from a SetTargetPoolsRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message SetTargetPoolsRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetTargetPoolsRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetTargetPoolsRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetTargetPoolsRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetUrlMapRegionTargetHttpProxyRequest. */
                interface ISetUrlMapRegionTargetHttpProxyRequest {

                    /** SetUrlMapRegionTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** SetUrlMapRegionTargetHttpProxyRequest region */
                    region?: (string|null);

                    /** SetUrlMapRegionTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetUrlMapRegionTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);

                    /** SetUrlMapRegionTargetHttpProxyRequest urlMapReferenceResource */
                    urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);
                }

                /** Represents a SetUrlMapRegionTargetHttpProxyRequest. */
                class SetUrlMapRegionTargetHttpProxyRequest implements ISetUrlMapRegionTargetHttpProxyRequest {

                    /**
                     * Constructs a new SetUrlMapRegionTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpProxyRequest);

                    /** SetUrlMapRegionTargetHttpProxyRequest project. */
                    public project: string;

                    /** SetUrlMapRegionTargetHttpProxyRequest region. */
                    public region: string;

                    /** SetUrlMapRegionTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetUrlMapRegionTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /** SetUrlMapRegionTargetHttpProxyRequest urlMapReferenceResource. */
                    public urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);

                    /** SetUrlMapRegionTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetUrlMapRegionTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetUrlMapRegionTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpProxyRequest): google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest;

                    /**
                     * Encodes the specified SetUrlMapRegionTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetUrlMapRegionTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapRegionTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetUrlMapRegionTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetUrlMapRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest;

                    /**
                     * Decodes a SetUrlMapRegionTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetUrlMapRegionTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest;

                    /**
                     * Verifies a SetUrlMapRegionTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetUrlMapRegionTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetUrlMapRegionTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a SetUrlMapRegionTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message SetUrlMapRegionTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetUrlMapRegionTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetUrlMapRegionTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetUrlMapRegionTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetUrlMapRegionTargetHttpsProxyRequest. */
                interface ISetUrlMapRegionTargetHttpsProxyRequest {

                    /** SetUrlMapRegionTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetUrlMapRegionTargetHttpsProxyRequest region */
                    region?: (string|null);

                    /** SetUrlMapRegionTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetUrlMapRegionTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);

                    /** SetUrlMapRegionTargetHttpsProxyRequest urlMapReferenceResource */
                    urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);
                }

                /** Represents a SetUrlMapRegionTargetHttpsProxyRequest. */
                class SetUrlMapRegionTargetHttpsProxyRequest implements ISetUrlMapRegionTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetUrlMapRegionTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpsProxyRequest);

                    /** SetUrlMapRegionTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetUrlMapRegionTargetHttpsProxyRequest region. */
                    public region: string;

                    /** SetUrlMapRegionTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetUrlMapRegionTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetUrlMapRegionTargetHttpsProxyRequest urlMapReferenceResource. */
                    public urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);

                    /** SetUrlMapRegionTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetUrlMapRegionTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetUrlMapRegionTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpsProxyRequest): google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetUrlMapRegionTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetUrlMapRegionTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapRegionTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetUrlMapRegionTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetUrlMapRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetUrlMapRegionTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetUrlMapRegionTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetUrlMapRegionTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetUrlMapRegionTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetUrlMapRegionTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetUrlMapRegionTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetUrlMapRegionTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetUrlMapRegionTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetUrlMapRegionTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetUrlMapRegionTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetUrlMapTargetHttpProxyRequest. */
                interface ISetUrlMapTargetHttpProxyRequest {

                    /** SetUrlMapTargetHttpProxyRequest project */
                    project?: (string|null);

                    /** SetUrlMapTargetHttpProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetUrlMapTargetHttpProxyRequest targetHttpProxy */
                    targetHttpProxy?: (string|null);

                    /** SetUrlMapTargetHttpProxyRequest urlMapReferenceResource */
                    urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);
                }

                /** Represents a SetUrlMapTargetHttpProxyRequest. */
                class SetUrlMapTargetHttpProxyRequest implements ISetUrlMapTargetHttpProxyRequest {

                    /**
                     * Constructs a new SetUrlMapTargetHttpProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetUrlMapTargetHttpProxyRequest);

                    /** SetUrlMapTargetHttpProxyRequest project. */
                    public project: string;

                    /** SetUrlMapTargetHttpProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetUrlMapTargetHttpProxyRequest targetHttpProxy. */
                    public targetHttpProxy: string;

                    /** SetUrlMapTargetHttpProxyRequest urlMapReferenceResource. */
                    public urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);

                    /** SetUrlMapTargetHttpProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetUrlMapTargetHttpProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetUrlMapTargetHttpProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetUrlMapTargetHttpProxyRequest): google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest;

                    /**
                     * Encodes the specified SetUrlMapTargetHttpProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetUrlMapTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetUrlMapTargetHttpProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapTargetHttpProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetUrlMapTargetHttpProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetUrlMapTargetHttpProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetUrlMapTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest;

                    /**
                     * Decodes a SetUrlMapTargetHttpProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetUrlMapTargetHttpProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest;

                    /**
                     * Verifies a SetUrlMapTargetHttpProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetUrlMapTargetHttpProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetUrlMapTargetHttpProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest;

                    /**
                     * Creates a plain object from a SetUrlMapTargetHttpProxyRequest message. Also converts values to other types if specified.
                     * @param message SetUrlMapTargetHttpProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetUrlMapTargetHttpProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetUrlMapTargetHttpProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetUrlMapTargetHttpProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetUrlMapTargetHttpsProxyRequest. */
                interface ISetUrlMapTargetHttpsProxyRequest {

                    /** SetUrlMapTargetHttpsProxyRequest project */
                    project?: (string|null);

                    /** SetUrlMapTargetHttpsProxyRequest requestId */
                    requestId?: (string|null);

                    /** SetUrlMapTargetHttpsProxyRequest targetHttpsProxy */
                    targetHttpsProxy?: (string|null);

                    /** SetUrlMapTargetHttpsProxyRequest urlMapReferenceResource */
                    urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);
                }

                /** Represents a SetUrlMapTargetHttpsProxyRequest. */
                class SetUrlMapTargetHttpsProxyRequest implements ISetUrlMapTargetHttpsProxyRequest {

                    /**
                     * Constructs a new SetUrlMapTargetHttpsProxyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetUrlMapTargetHttpsProxyRequest);

                    /** SetUrlMapTargetHttpsProxyRequest project. */
                    public project: string;

                    /** SetUrlMapTargetHttpsProxyRequest requestId. */
                    public requestId?: (string|null);

                    /** SetUrlMapTargetHttpsProxyRequest targetHttpsProxy. */
                    public targetHttpsProxy: string;

                    /** SetUrlMapTargetHttpsProxyRequest urlMapReferenceResource. */
                    public urlMapReferenceResource?: (google.cloud.compute.v1.IUrlMapReference|null);

                    /** SetUrlMapTargetHttpsProxyRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetUrlMapTargetHttpsProxyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetUrlMapTargetHttpsProxyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetUrlMapTargetHttpsProxyRequest): google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest;

                    /**
                     * Encodes the specified SetUrlMapTargetHttpsProxyRequest message. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetUrlMapTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetUrlMapTargetHttpsProxyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest.verify|verify} messages.
                     * @param message SetUrlMapTargetHttpsProxyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetUrlMapTargetHttpsProxyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetUrlMapTargetHttpsProxyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetUrlMapTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest;

                    /**
                     * Decodes a SetUrlMapTargetHttpsProxyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetUrlMapTargetHttpsProxyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest;

                    /**
                     * Verifies a SetUrlMapTargetHttpsProxyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetUrlMapTargetHttpsProxyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetUrlMapTargetHttpsProxyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest;

                    /**
                     * Creates a plain object from a SetUrlMapTargetHttpsProxyRequest message. Also converts values to other types if specified.
                     * @param message SetUrlMapTargetHttpsProxyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetUrlMapTargetHttpsProxyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetUrlMapTargetHttpsProxyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetUrlMapTargetHttpsProxyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetUsageExportBucketProjectRequest. */
                interface ISetUsageExportBucketProjectRequest {

                    /** SetUsageExportBucketProjectRequest project */
                    project?: (string|null);

                    /** SetUsageExportBucketProjectRequest requestId */
                    requestId?: (string|null);

                    /** SetUsageExportBucketProjectRequest usageExportLocationResource */
                    usageExportLocationResource?: (google.cloud.compute.v1.IUsageExportLocation|null);
                }

                /** Represents a SetUsageExportBucketProjectRequest. */
                class SetUsageExportBucketProjectRequest implements ISetUsageExportBucketProjectRequest {

                    /**
                     * Constructs a new SetUsageExportBucketProjectRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISetUsageExportBucketProjectRequest);

                    /** SetUsageExportBucketProjectRequest project. */
                    public project: string;

                    /** SetUsageExportBucketProjectRequest requestId. */
                    public requestId?: (string|null);

                    /** SetUsageExportBucketProjectRequest usageExportLocationResource. */
                    public usageExportLocationResource?: (google.cloud.compute.v1.IUsageExportLocation|null);

                    /** SetUsageExportBucketProjectRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SetUsageExportBucketProjectRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetUsageExportBucketProjectRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISetUsageExportBucketProjectRequest): google.cloud.compute.v1.SetUsageExportBucketProjectRequest;

                    /**
                     * Encodes the specified SetUsageExportBucketProjectRequest message. Does not implicitly {@link google.cloud.compute.v1.SetUsageExportBucketProjectRequest.verify|verify} messages.
                     * @param message SetUsageExportBucketProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISetUsageExportBucketProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetUsageExportBucketProjectRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SetUsageExportBucketProjectRequest.verify|verify} messages.
                     * @param message SetUsageExportBucketProjectRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISetUsageExportBucketProjectRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetUsageExportBucketProjectRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetUsageExportBucketProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SetUsageExportBucketProjectRequest;

                    /**
                     * Decodes a SetUsageExportBucketProjectRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetUsageExportBucketProjectRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SetUsageExportBucketProjectRequest;

                    /**
                     * Verifies a SetUsageExportBucketProjectRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetUsageExportBucketProjectRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetUsageExportBucketProjectRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SetUsageExportBucketProjectRequest;

                    /**
                     * Creates a plain object from a SetUsageExportBucketProjectRequest message. Also converts values to other types if specified.
                     * @param message SetUsageExportBucketProjectRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SetUsageExportBucketProjectRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetUsageExportBucketProjectRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetUsageExportBucketProjectRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ShareSettings. */
                interface IShareSettings {

                    /** ShareSettings projectMap */
                    projectMap?: ({ [k: string]: google.cloud.compute.v1.IShareSettingsProjectConfig }|null);

                    /** ShareSettings shareType */
                    shareType?: (string|null);
                }

                /** Represents a ShareSettings. */
                class ShareSettings implements IShareSettings {

                    /**
                     * Constructs a new ShareSettings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IShareSettings);

                    /** ShareSettings projectMap. */
                    public projectMap: { [k: string]: google.cloud.compute.v1.IShareSettingsProjectConfig };

                    /** ShareSettings shareType. */
                    public shareType?: (string|null);

                    /** ShareSettings _shareType. */
                    public _shareType?: "shareType";

                    /**
                     * Creates a new ShareSettings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ShareSettings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IShareSettings): google.cloud.compute.v1.ShareSettings;

                    /**
                     * Encodes the specified ShareSettings message. Does not implicitly {@link google.cloud.compute.v1.ShareSettings.verify|verify} messages.
                     * @param message ShareSettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IShareSettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ShareSettings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ShareSettings.verify|verify} messages.
                     * @param message ShareSettings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IShareSettings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ShareSettings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ShareSettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ShareSettings;

                    /**
                     * Decodes a ShareSettings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ShareSettings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ShareSettings;

                    /**
                     * Verifies a ShareSettings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ShareSettings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ShareSettings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ShareSettings;

                    /**
                     * Creates a plain object from a ShareSettings message. Also converts values to other types if specified.
                     * @param message ShareSettings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ShareSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ShareSettings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ShareSettings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ShareSettings {

                    /** ShareType enum. */
                    enum ShareType {
                        UNDEFINED_SHARE_TYPE = 0,
                        LOCAL = 72607563,
                        ORGANIZATION = 274978099,
                        SHARE_TYPE_UNSPECIFIED = 494771730,
                        SPECIFIC_PROJECTS = 347838695
                    }
                }

                /** Properties of a ShareSettingsProjectConfig. */
                interface IShareSettingsProjectConfig {

                    /** ShareSettingsProjectConfig projectId */
                    projectId?: (string|null);
                }

                /** Represents a ShareSettingsProjectConfig. */
                class ShareSettingsProjectConfig implements IShareSettingsProjectConfig {

                    /**
                     * Constructs a new ShareSettingsProjectConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IShareSettingsProjectConfig);

                    /** ShareSettingsProjectConfig projectId. */
                    public projectId?: (string|null);

                    /** ShareSettingsProjectConfig _projectId. */
                    public _projectId?: "projectId";

                    /**
                     * Creates a new ShareSettingsProjectConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ShareSettingsProjectConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IShareSettingsProjectConfig): google.cloud.compute.v1.ShareSettingsProjectConfig;

                    /**
                     * Encodes the specified ShareSettingsProjectConfig message. Does not implicitly {@link google.cloud.compute.v1.ShareSettingsProjectConfig.verify|verify} messages.
                     * @param message ShareSettingsProjectConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IShareSettingsProjectConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ShareSettingsProjectConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ShareSettingsProjectConfig.verify|verify} messages.
                     * @param message ShareSettingsProjectConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IShareSettingsProjectConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ShareSettingsProjectConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ShareSettingsProjectConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ShareSettingsProjectConfig;

                    /**
                     * Decodes a ShareSettingsProjectConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ShareSettingsProjectConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ShareSettingsProjectConfig;

                    /**
                     * Verifies a ShareSettingsProjectConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ShareSettingsProjectConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ShareSettingsProjectConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ShareSettingsProjectConfig;

                    /**
                     * Creates a plain object from a ShareSettingsProjectConfig message. Also converts values to other types if specified.
                     * @param message ShareSettingsProjectConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ShareSettingsProjectConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ShareSettingsProjectConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ShareSettingsProjectConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ShieldedInstanceConfig. */
                interface IShieldedInstanceConfig {

                    /** ShieldedInstanceConfig enableIntegrityMonitoring */
                    enableIntegrityMonitoring?: (boolean|null);

                    /** ShieldedInstanceConfig enableSecureBoot */
                    enableSecureBoot?: (boolean|null);

                    /** ShieldedInstanceConfig enableVtpm */
                    enableVtpm?: (boolean|null);
                }

                /** Represents a ShieldedInstanceConfig. */
                class ShieldedInstanceConfig implements IShieldedInstanceConfig {

                    /**
                     * Constructs a new ShieldedInstanceConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IShieldedInstanceConfig);

                    /** ShieldedInstanceConfig enableIntegrityMonitoring. */
                    public enableIntegrityMonitoring?: (boolean|null);

                    /** ShieldedInstanceConfig enableSecureBoot. */
                    public enableSecureBoot?: (boolean|null);

                    /** ShieldedInstanceConfig enableVtpm. */
                    public enableVtpm?: (boolean|null);

                    /** ShieldedInstanceConfig _enableIntegrityMonitoring. */
                    public _enableIntegrityMonitoring?: "enableIntegrityMonitoring";

                    /** ShieldedInstanceConfig _enableSecureBoot. */
                    public _enableSecureBoot?: "enableSecureBoot";

                    /** ShieldedInstanceConfig _enableVtpm. */
                    public _enableVtpm?: "enableVtpm";

                    /**
                     * Creates a new ShieldedInstanceConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ShieldedInstanceConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IShieldedInstanceConfig): google.cloud.compute.v1.ShieldedInstanceConfig;

                    /**
                     * Encodes the specified ShieldedInstanceConfig message. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceConfig.verify|verify} messages.
                     * @param message ShieldedInstanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IShieldedInstanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ShieldedInstanceConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceConfig.verify|verify} messages.
                     * @param message ShieldedInstanceConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IShieldedInstanceConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ShieldedInstanceConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ShieldedInstanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ShieldedInstanceConfig;

                    /**
                     * Decodes a ShieldedInstanceConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ShieldedInstanceConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ShieldedInstanceConfig;

                    /**
                     * Verifies a ShieldedInstanceConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ShieldedInstanceConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ShieldedInstanceConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ShieldedInstanceConfig;

                    /**
                     * Creates a plain object from a ShieldedInstanceConfig message. Also converts values to other types if specified.
                     * @param message ShieldedInstanceConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ShieldedInstanceConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ShieldedInstanceConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ShieldedInstanceConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ShieldedInstanceIdentity. */
                interface IShieldedInstanceIdentity {

                    /** ShieldedInstanceIdentity encryptionKey */
                    encryptionKey?: (google.cloud.compute.v1.IShieldedInstanceIdentityEntry|null);

                    /** ShieldedInstanceIdentity kind */
                    kind?: (string|null);

                    /** ShieldedInstanceIdentity signingKey */
                    signingKey?: (google.cloud.compute.v1.IShieldedInstanceIdentityEntry|null);
                }

                /** Represents a ShieldedInstanceIdentity. */
                class ShieldedInstanceIdentity implements IShieldedInstanceIdentity {

                    /**
                     * Constructs a new ShieldedInstanceIdentity.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IShieldedInstanceIdentity);

                    /** ShieldedInstanceIdentity encryptionKey. */
                    public encryptionKey?: (google.cloud.compute.v1.IShieldedInstanceIdentityEntry|null);

                    /** ShieldedInstanceIdentity kind. */
                    public kind?: (string|null);

                    /** ShieldedInstanceIdentity signingKey. */
                    public signingKey?: (google.cloud.compute.v1.IShieldedInstanceIdentityEntry|null);

                    /** ShieldedInstanceIdentity _encryptionKey. */
                    public _encryptionKey?: "encryptionKey";

                    /** ShieldedInstanceIdentity _kind. */
                    public _kind?: "kind";

                    /** ShieldedInstanceIdentity _signingKey. */
                    public _signingKey?: "signingKey";

                    /**
                     * Creates a new ShieldedInstanceIdentity instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ShieldedInstanceIdentity instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IShieldedInstanceIdentity): google.cloud.compute.v1.ShieldedInstanceIdentity;

                    /**
                     * Encodes the specified ShieldedInstanceIdentity message. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceIdentity.verify|verify} messages.
                     * @param message ShieldedInstanceIdentity message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IShieldedInstanceIdentity, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ShieldedInstanceIdentity message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceIdentity.verify|verify} messages.
                     * @param message ShieldedInstanceIdentity message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IShieldedInstanceIdentity, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ShieldedInstanceIdentity message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ShieldedInstanceIdentity
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ShieldedInstanceIdentity;

                    /**
                     * Decodes a ShieldedInstanceIdentity message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ShieldedInstanceIdentity
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ShieldedInstanceIdentity;

                    /**
                     * Verifies a ShieldedInstanceIdentity message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ShieldedInstanceIdentity message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ShieldedInstanceIdentity
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ShieldedInstanceIdentity;

                    /**
                     * Creates a plain object from a ShieldedInstanceIdentity message. Also converts values to other types if specified.
                     * @param message ShieldedInstanceIdentity
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ShieldedInstanceIdentity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ShieldedInstanceIdentity to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ShieldedInstanceIdentity
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ShieldedInstanceIdentityEntry. */
                interface IShieldedInstanceIdentityEntry {

                    /** ShieldedInstanceIdentityEntry ekCert */
                    ekCert?: (string|null);

                    /** ShieldedInstanceIdentityEntry ekPub */
                    ekPub?: (string|null);
                }

                /** Represents a ShieldedInstanceIdentityEntry. */
                class ShieldedInstanceIdentityEntry implements IShieldedInstanceIdentityEntry {

                    /**
                     * Constructs a new ShieldedInstanceIdentityEntry.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IShieldedInstanceIdentityEntry);

                    /** ShieldedInstanceIdentityEntry ekCert. */
                    public ekCert?: (string|null);

                    /** ShieldedInstanceIdentityEntry ekPub. */
                    public ekPub?: (string|null);

                    /** ShieldedInstanceIdentityEntry _ekCert. */
                    public _ekCert?: "ekCert";

                    /** ShieldedInstanceIdentityEntry _ekPub. */
                    public _ekPub?: "ekPub";

                    /**
                     * Creates a new ShieldedInstanceIdentityEntry instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ShieldedInstanceIdentityEntry instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IShieldedInstanceIdentityEntry): google.cloud.compute.v1.ShieldedInstanceIdentityEntry;

                    /**
                     * Encodes the specified ShieldedInstanceIdentityEntry message. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceIdentityEntry.verify|verify} messages.
                     * @param message ShieldedInstanceIdentityEntry message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IShieldedInstanceIdentityEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ShieldedInstanceIdentityEntry message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceIdentityEntry.verify|verify} messages.
                     * @param message ShieldedInstanceIdentityEntry message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IShieldedInstanceIdentityEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ShieldedInstanceIdentityEntry message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ShieldedInstanceIdentityEntry
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ShieldedInstanceIdentityEntry;

                    /**
                     * Decodes a ShieldedInstanceIdentityEntry message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ShieldedInstanceIdentityEntry
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ShieldedInstanceIdentityEntry;

                    /**
                     * Verifies a ShieldedInstanceIdentityEntry message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ShieldedInstanceIdentityEntry message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ShieldedInstanceIdentityEntry
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ShieldedInstanceIdentityEntry;

                    /**
                     * Creates a plain object from a ShieldedInstanceIdentityEntry message. Also converts values to other types if specified.
                     * @param message ShieldedInstanceIdentityEntry
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ShieldedInstanceIdentityEntry, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ShieldedInstanceIdentityEntry to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ShieldedInstanceIdentityEntry
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ShieldedInstanceIntegrityPolicy. */
                interface IShieldedInstanceIntegrityPolicy {

                    /** ShieldedInstanceIntegrityPolicy updateAutoLearnPolicy */
                    updateAutoLearnPolicy?: (boolean|null);
                }

                /** Represents a ShieldedInstanceIntegrityPolicy. */
                class ShieldedInstanceIntegrityPolicy implements IShieldedInstanceIntegrityPolicy {

                    /**
                     * Constructs a new ShieldedInstanceIntegrityPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy);

                    /** ShieldedInstanceIntegrityPolicy updateAutoLearnPolicy. */
                    public updateAutoLearnPolicy?: (boolean|null);

                    /** ShieldedInstanceIntegrityPolicy _updateAutoLearnPolicy. */
                    public _updateAutoLearnPolicy?: "updateAutoLearnPolicy";

                    /**
                     * Creates a new ShieldedInstanceIntegrityPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ShieldedInstanceIntegrityPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy): google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy;

                    /**
                     * Encodes the specified ShieldedInstanceIntegrityPolicy message. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy.verify|verify} messages.
                     * @param message ShieldedInstanceIntegrityPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ShieldedInstanceIntegrityPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy.verify|verify} messages.
                     * @param message ShieldedInstanceIntegrityPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IShieldedInstanceIntegrityPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ShieldedInstanceIntegrityPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ShieldedInstanceIntegrityPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy;

                    /**
                     * Decodes a ShieldedInstanceIntegrityPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ShieldedInstanceIntegrityPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy;

                    /**
                     * Verifies a ShieldedInstanceIntegrityPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ShieldedInstanceIntegrityPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ShieldedInstanceIntegrityPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy;

                    /**
                     * Creates a plain object from a ShieldedInstanceIntegrityPolicy message. Also converts values to other types if specified.
                     * @param message ShieldedInstanceIntegrityPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ShieldedInstanceIntegrityPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ShieldedInstanceIntegrityPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ShieldedInstanceIntegrityPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SignedUrlKey. */
                interface ISignedUrlKey {

                    /** SignedUrlKey keyName */
                    keyName?: (string|null);

                    /** SignedUrlKey keyValue */
                    keyValue?: (string|null);
                }

                /** Represents a SignedUrlKey. */
                class SignedUrlKey implements ISignedUrlKey {

                    /**
                     * Constructs a new SignedUrlKey.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISignedUrlKey);

                    /** SignedUrlKey keyName. */
                    public keyName?: (string|null);

                    /** SignedUrlKey keyValue. */
                    public keyValue?: (string|null);

                    /** SignedUrlKey _keyName. */
                    public _keyName?: "keyName";

                    /** SignedUrlKey _keyValue. */
                    public _keyValue?: "keyValue";

                    /**
                     * Creates a new SignedUrlKey instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SignedUrlKey instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISignedUrlKey): google.cloud.compute.v1.SignedUrlKey;

                    /**
                     * Encodes the specified SignedUrlKey message. Does not implicitly {@link google.cloud.compute.v1.SignedUrlKey.verify|verify} messages.
                     * @param message SignedUrlKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISignedUrlKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SignedUrlKey message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SignedUrlKey.verify|verify} messages.
                     * @param message SignedUrlKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISignedUrlKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SignedUrlKey message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SignedUrlKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SignedUrlKey;

                    /**
                     * Decodes a SignedUrlKey message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SignedUrlKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SignedUrlKey;

                    /**
                     * Verifies a SignedUrlKey message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SignedUrlKey message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SignedUrlKey
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SignedUrlKey;

                    /**
                     * Creates a plain object from a SignedUrlKey message. Also converts values to other types if specified.
                     * @param message SignedUrlKey
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SignedUrlKey, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SignedUrlKey to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SignedUrlKey
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SimulateMaintenanceEventInstanceRequest. */
                interface ISimulateMaintenanceEventInstanceRequest {

                    /** SimulateMaintenanceEventInstanceRequest instance */
                    instance?: (string|null);

                    /** SimulateMaintenanceEventInstanceRequest project */
                    project?: (string|null);

                    /** SimulateMaintenanceEventInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SimulateMaintenanceEventInstanceRequest. */
                class SimulateMaintenanceEventInstanceRequest implements ISimulateMaintenanceEventInstanceRequest {

                    /**
                     * Constructs a new SimulateMaintenanceEventInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISimulateMaintenanceEventInstanceRequest);

                    /** SimulateMaintenanceEventInstanceRequest instance. */
                    public instance: string;

                    /** SimulateMaintenanceEventInstanceRequest project. */
                    public project: string;

                    /** SimulateMaintenanceEventInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new SimulateMaintenanceEventInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SimulateMaintenanceEventInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISimulateMaintenanceEventInstanceRequest): google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest;

                    /**
                     * Encodes the specified SimulateMaintenanceEventInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest.verify|verify} messages.
                     * @param message SimulateMaintenanceEventInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISimulateMaintenanceEventInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SimulateMaintenanceEventInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest.verify|verify} messages.
                     * @param message SimulateMaintenanceEventInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISimulateMaintenanceEventInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SimulateMaintenanceEventInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SimulateMaintenanceEventInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest;

                    /**
                     * Decodes a SimulateMaintenanceEventInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SimulateMaintenanceEventInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest;

                    /**
                     * Verifies a SimulateMaintenanceEventInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SimulateMaintenanceEventInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SimulateMaintenanceEventInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest;

                    /**
                     * Creates a plain object from a SimulateMaintenanceEventInstanceRequest message. Also converts values to other types if specified.
                     * @param message SimulateMaintenanceEventInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SimulateMaintenanceEventInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SimulateMaintenanceEventInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SimulateMaintenanceEventInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Snapshot. */
                interface ISnapshot {

                    /** Snapshot architecture */
                    architecture?: (string|null);

                    /** Snapshot autoCreated */
                    autoCreated?: (boolean|null);

                    /** Snapshot chainName */
                    chainName?: (string|null);

                    /** Snapshot creationSizeBytes */
                    creationSizeBytes?: (number|Long|string|null);

                    /** Snapshot creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Snapshot description */
                    description?: (string|null);

                    /** Snapshot diskSizeGb */
                    diskSizeGb?: (number|Long|string|null);

                    /** Snapshot downloadBytes */
                    downloadBytes?: (number|Long|string|null);

                    /** Snapshot id */
                    id?: (number|Long|string|null);

                    /** Snapshot kind */
                    kind?: (string|null);

                    /** Snapshot labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** Snapshot labels */
                    labels?: ({ [k: string]: string }|null);

                    /** Snapshot licenseCodes */
                    licenseCodes?: ((number|Long|string)[]|null);

                    /** Snapshot licenses */
                    licenses?: (string[]|null);

                    /** Snapshot locationHint */
                    locationHint?: (string|null);

                    /** Snapshot name */
                    name?: (string|null);

                    /** Snapshot satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Snapshot selfLink */
                    selfLink?: (string|null);

                    /** Snapshot snapshotEncryptionKey */
                    snapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Snapshot snapshotType */
                    snapshotType?: (string|null);

                    /** Snapshot sourceDisk */
                    sourceDisk?: (string|null);

                    /** Snapshot sourceDiskEncryptionKey */
                    sourceDiskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Snapshot sourceDiskId */
                    sourceDiskId?: (string|null);

                    /** Snapshot sourceSnapshotSchedulePolicy */
                    sourceSnapshotSchedulePolicy?: (string|null);

                    /** Snapshot sourceSnapshotSchedulePolicyId */
                    sourceSnapshotSchedulePolicyId?: (string|null);

                    /** Snapshot status */
                    status?: (string|null);

                    /** Snapshot storageBytes */
                    storageBytes?: (number|Long|string|null);

                    /** Snapshot storageBytesStatus */
                    storageBytesStatus?: (string|null);

                    /** Snapshot storageLocations */
                    storageLocations?: (string[]|null);
                }

                /** Represents a Snapshot. */
                class Snapshot implements ISnapshot {

                    /**
                     * Constructs a new Snapshot.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISnapshot);

                    /** Snapshot architecture. */
                    public architecture?: (string|null);

                    /** Snapshot autoCreated. */
                    public autoCreated?: (boolean|null);

                    /** Snapshot chainName. */
                    public chainName?: (string|null);

                    /** Snapshot creationSizeBytes. */
                    public creationSizeBytes?: (number|Long|string|null);

                    /** Snapshot creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Snapshot description. */
                    public description?: (string|null);

                    /** Snapshot diskSizeGb. */
                    public diskSizeGb?: (number|Long|string|null);

                    /** Snapshot downloadBytes. */
                    public downloadBytes?: (number|Long|string|null);

                    /** Snapshot id. */
                    public id?: (number|Long|string|null);

                    /** Snapshot kind. */
                    public kind?: (string|null);

                    /** Snapshot labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** Snapshot labels. */
                    public labels: { [k: string]: string };

                    /** Snapshot licenseCodes. */
                    public licenseCodes: (number|Long|string)[];

                    /** Snapshot licenses. */
                    public licenses: string[];

                    /** Snapshot locationHint. */
                    public locationHint?: (string|null);

                    /** Snapshot name. */
                    public name?: (string|null);

                    /** Snapshot satisfiesPzs. */
                    public satisfiesPzs?: (boolean|null);

                    /** Snapshot selfLink. */
                    public selfLink?: (string|null);

                    /** Snapshot snapshotEncryptionKey. */
                    public snapshotEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Snapshot snapshotType. */
                    public snapshotType?: (string|null);

                    /** Snapshot sourceDisk. */
                    public sourceDisk?: (string|null);

                    /** Snapshot sourceDiskEncryptionKey. */
                    public sourceDiskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** Snapshot sourceDiskId. */
                    public sourceDiskId?: (string|null);

                    /** Snapshot sourceSnapshotSchedulePolicy. */
                    public sourceSnapshotSchedulePolicy?: (string|null);

                    /** Snapshot sourceSnapshotSchedulePolicyId. */
                    public sourceSnapshotSchedulePolicyId?: (string|null);

                    /** Snapshot status. */
                    public status?: (string|null);

                    /** Snapshot storageBytes. */
                    public storageBytes?: (number|Long|string|null);

                    /** Snapshot storageBytesStatus. */
                    public storageBytesStatus?: (string|null);

                    /** Snapshot storageLocations. */
                    public storageLocations: string[];

                    /** Snapshot _architecture. */
                    public _architecture?: "architecture";

                    /** Snapshot _autoCreated. */
                    public _autoCreated?: "autoCreated";

                    /** Snapshot _chainName. */
                    public _chainName?: "chainName";

                    /** Snapshot _creationSizeBytes. */
                    public _creationSizeBytes?: "creationSizeBytes";

                    /** Snapshot _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Snapshot _description. */
                    public _description?: "description";

                    /** Snapshot _diskSizeGb. */
                    public _diskSizeGb?: "diskSizeGb";

                    /** Snapshot _downloadBytes. */
                    public _downloadBytes?: "downloadBytes";

                    /** Snapshot _id. */
                    public _id?: "id";

                    /** Snapshot _kind. */
                    public _kind?: "kind";

                    /** Snapshot _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** Snapshot _locationHint. */
                    public _locationHint?: "locationHint";

                    /** Snapshot _name. */
                    public _name?: "name";

                    /** Snapshot _satisfiesPzs. */
                    public _satisfiesPzs?: "satisfiesPzs";

                    /** Snapshot _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Snapshot _snapshotEncryptionKey. */
                    public _snapshotEncryptionKey?: "snapshotEncryptionKey";

                    /** Snapshot _snapshotType. */
                    public _snapshotType?: "snapshotType";

                    /** Snapshot _sourceDisk. */
                    public _sourceDisk?: "sourceDisk";

                    /** Snapshot _sourceDiskEncryptionKey. */
                    public _sourceDiskEncryptionKey?: "sourceDiskEncryptionKey";

                    /** Snapshot _sourceDiskId. */
                    public _sourceDiskId?: "sourceDiskId";

                    /** Snapshot _sourceSnapshotSchedulePolicy. */
                    public _sourceSnapshotSchedulePolicy?: "sourceSnapshotSchedulePolicy";

                    /** Snapshot _sourceSnapshotSchedulePolicyId. */
                    public _sourceSnapshotSchedulePolicyId?: "sourceSnapshotSchedulePolicyId";

                    /** Snapshot _status. */
                    public _status?: "status";

                    /** Snapshot _storageBytes. */
                    public _storageBytes?: "storageBytes";

                    /** Snapshot _storageBytesStatus. */
                    public _storageBytesStatus?: "storageBytesStatus";

                    /**
                     * Creates a new Snapshot instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Snapshot instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISnapshot): google.cloud.compute.v1.Snapshot;

                    /**
                     * Encodes the specified Snapshot message. Does not implicitly {@link google.cloud.compute.v1.Snapshot.verify|verify} messages.
                     * @param message Snapshot message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISnapshot, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Snapshot message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Snapshot.verify|verify} messages.
                     * @param message Snapshot message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISnapshot, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Snapshot message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Snapshot
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Snapshot;

                    /**
                     * Decodes a Snapshot message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Snapshot
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Snapshot;

                    /**
                     * Verifies a Snapshot message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Snapshot message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Snapshot
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Snapshot;

                    /**
                     * Creates a plain object from a Snapshot message. Also converts values to other types if specified.
                     * @param message Snapshot
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Snapshot, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Snapshot to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Snapshot
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Snapshot {

                    /** Architecture enum. */
                    enum Architecture {
                        UNDEFINED_ARCHITECTURE = 0,
                        ARCHITECTURE_UNSPECIFIED = 394750507,
                        ARM64 = 62547450,
                        X86_64 = 425300551
                    }

                    /** SnapshotType enum. */
                    enum SnapshotType {
                        UNDEFINED_SNAPSHOT_TYPE = 0,
                        ARCHIVE = 506752162,
                        STANDARD = 484642493
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        FAILED = 455706685,
                        READY = 77848963,
                        UPLOADING = 267603489
                    }

                    /** StorageBytesStatus enum. */
                    enum StorageBytesStatus {
                        UNDEFINED_STORAGE_BYTES_STATUS = 0,
                        UPDATING = 494614342,
                        UP_TO_DATE = 101306702
                    }
                }

                /** Properties of a SnapshotList. */
                interface ISnapshotList {

                    /** SnapshotList id */
                    id?: (string|null);

                    /** SnapshotList items */
                    items?: (google.cloud.compute.v1.ISnapshot[]|null);

                    /** SnapshotList kind */
                    kind?: (string|null);

                    /** SnapshotList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SnapshotList selfLink */
                    selfLink?: (string|null);

                    /** SnapshotList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SnapshotList. */
                class SnapshotList implements ISnapshotList {

                    /**
                     * Constructs a new SnapshotList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISnapshotList);

                    /** SnapshotList id. */
                    public id?: (string|null);

                    /** SnapshotList items. */
                    public items: google.cloud.compute.v1.ISnapshot[];

                    /** SnapshotList kind. */
                    public kind?: (string|null);

                    /** SnapshotList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SnapshotList selfLink. */
                    public selfLink?: (string|null);

                    /** SnapshotList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SnapshotList _id. */
                    public _id?: "id";

                    /** SnapshotList _kind. */
                    public _kind?: "kind";

                    /** SnapshotList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SnapshotList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SnapshotList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SnapshotList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SnapshotList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISnapshotList): google.cloud.compute.v1.SnapshotList;

                    /**
                     * Encodes the specified SnapshotList message. Does not implicitly {@link google.cloud.compute.v1.SnapshotList.verify|verify} messages.
                     * @param message SnapshotList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISnapshotList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SnapshotList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SnapshotList.verify|verify} messages.
                     * @param message SnapshotList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISnapshotList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SnapshotList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SnapshotList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SnapshotList;

                    /**
                     * Decodes a SnapshotList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SnapshotList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SnapshotList;

                    /**
                     * Verifies a SnapshotList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SnapshotList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SnapshotList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SnapshotList;

                    /**
                     * Creates a plain object from a SnapshotList message. Also converts values to other types if specified.
                     * @param message SnapshotList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SnapshotList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SnapshotList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SnapshotList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SourceDiskEncryptionKey. */
                interface ISourceDiskEncryptionKey {

                    /** SourceDiskEncryptionKey diskEncryptionKey */
                    diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** SourceDiskEncryptionKey sourceDisk */
                    sourceDisk?: (string|null);
                }

                /** Represents a SourceDiskEncryptionKey. */
                class SourceDiskEncryptionKey implements ISourceDiskEncryptionKey {

                    /**
                     * Constructs a new SourceDiskEncryptionKey.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISourceDiskEncryptionKey);

                    /** SourceDiskEncryptionKey diskEncryptionKey. */
                    public diskEncryptionKey?: (google.cloud.compute.v1.ICustomerEncryptionKey|null);

                    /** SourceDiskEncryptionKey sourceDisk. */
                    public sourceDisk?: (string|null);

                    /** SourceDiskEncryptionKey _diskEncryptionKey. */
                    public _diskEncryptionKey?: "diskEncryptionKey";

                    /** SourceDiskEncryptionKey _sourceDisk. */
                    public _sourceDisk?: "sourceDisk";

                    /**
                     * Creates a new SourceDiskEncryptionKey instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SourceDiskEncryptionKey instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISourceDiskEncryptionKey): google.cloud.compute.v1.SourceDiskEncryptionKey;

                    /**
                     * Encodes the specified SourceDiskEncryptionKey message. Does not implicitly {@link google.cloud.compute.v1.SourceDiskEncryptionKey.verify|verify} messages.
                     * @param message SourceDiskEncryptionKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISourceDiskEncryptionKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SourceDiskEncryptionKey message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SourceDiskEncryptionKey.verify|verify} messages.
                     * @param message SourceDiskEncryptionKey message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISourceDiskEncryptionKey, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SourceDiskEncryptionKey message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SourceDiskEncryptionKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SourceDiskEncryptionKey;

                    /**
                     * Decodes a SourceDiskEncryptionKey message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SourceDiskEncryptionKey
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SourceDiskEncryptionKey;

                    /**
                     * Verifies a SourceDiskEncryptionKey message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SourceDiskEncryptionKey message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SourceDiskEncryptionKey
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SourceDiskEncryptionKey;

                    /**
                     * Creates a plain object from a SourceDiskEncryptionKey message. Also converts values to other types if specified.
                     * @param message SourceDiskEncryptionKey
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SourceDiskEncryptionKey, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SourceDiskEncryptionKey to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SourceDiskEncryptionKey
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SourceInstanceParams. */
                interface ISourceInstanceParams {

                    /** SourceInstanceParams diskConfigs */
                    diskConfigs?: (google.cloud.compute.v1.IDiskInstantiationConfig[]|null);
                }

                /** Represents a SourceInstanceParams. */
                class SourceInstanceParams implements ISourceInstanceParams {

                    /**
                     * Constructs a new SourceInstanceParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISourceInstanceParams);

                    /** SourceInstanceParams diskConfigs. */
                    public diskConfigs: google.cloud.compute.v1.IDiskInstantiationConfig[];

                    /**
                     * Creates a new SourceInstanceParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SourceInstanceParams instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISourceInstanceParams): google.cloud.compute.v1.SourceInstanceParams;

                    /**
                     * Encodes the specified SourceInstanceParams message. Does not implicitly {@link google.cloud.compute.v1.SourceInstanceParams.verify|verify} messages.
                     * @param message SourceInstanceParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISourceInstanceParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SourceInstanceParams message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SourceInstanceParams.verify|verify} messages.
                     * @param message SourceInstanceParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISourceInstanceParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SourceInstanceParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SourceInstanceParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SourceInstanceParams;

                    /**
                     * Decodes a SourceInstanceParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SourceInstanceParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SourceInstanceParams;

                    /**
                     * Verifies a SourceInstanceParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SourceInstanceParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SourceInstanceParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SourceInstanceParams;

                    /**
                     * Creates a plain object from a SourceInstanceParams message. Also converts values to other types if specified.
                     * @param message SourceInstanceParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SourceInstanceParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SourceInstanceParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SourceInstanceParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SourceInstanceProperties. */
                interface ISourceInstanceProperties {

                    /** SourceInstanceProperties canIpForward */
                    canIpForward?: (boolean|null);

                    /** SourceInstanceProperties deletionProtection */
                    deletionProtection?: (boolean|null);

                    /** SourceInstanceProperties description */
                    description?: (string|null);

                    /** SourceInstanceProperties disks */
                    disks?: (google.cloud.compute.v1.ISavedAttachedDisk[]|null);

                    /** SourceInstanceProperties guestAccelerators */
                    guestAccelerators?: (google.cloud.compute.v1.IAcceleratorConfig[]|null);

                    /** SourceInstanceProperties keyRevocationActionType */
                    keyRevocationActionType?: (string|null);

                    /** SourceInstanceProperties labels */
                    labels?: ({ [k: string]: string }|null);

                    /** SourceInstanceProperties machineType */
                    machineType?: (string|null);

                    /** SourceInstanceProperties metadata */
                    metadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** SourceInstanceProperties minCpuPlatform */
                    minCpuPlatform?: (string|null);

                    /** SourceInstanceProperties networkInterfaces */
                    networkInterfaces?: (google.cloud.compute.v1.INetworkInterface[]|null);

                    /** SourceInstanceProperties scheduling */
                    scheduling?: (google.cloud.compute.v1.IScheduling|null);

                    /** SourceInstanceProperties serviceAccounts */
                    serviceAccounts?: (google.cloud.compute.v1.IServiceAccount[]|null);

                    /** SourceInstanceProperties tags */
                    tags?: (google.cloud.compute.v1.ITags|null);
                }

                /** Represents a SourceInstanceProperties. */
                class SourceInstanceProperties implements ISourceInstanceProperties {

                    /**
                     * Constructs a new SourceInstanceProperties.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISourceInstanceProperties);

                    /** SourceInstanceProperties canIpForward. */
                    public canIpForward?: (boolean|null);

                    /** SourceInstanceProperties deletionProtection. */
                    public deletionProtection?: (boolean|null);

                    /** SourceInstanceProperties description. */
                    public description?: (string|null);

                    /** SourceInstanceProperties disks. */
                    public disks: google.cloud.compute.v1.ISavedAttachedDisk[];

                    /** SourceInstanceProperties guestAccelerators. */
                    public guestAccelerators: google.cloud.compute.v1.IAcceleratorConfig[];

                    /** SourceInstanceProperties keyRevocationActionType. */
                    public keyRevocationActionType?: (string|null);

                    /** SourceInstanceProperties labels. */
                    public labels: { [k: string]: string };

                    /** SourceInstanceProperties machineType. */
                    public machineType?: (string|null);

                    /** SourceInstanceProperties metadata. */
                    public metadata?: (google.cloud.compute.v1.IMetadata|null);

                    /** SourceInstanceProperties minCpuPlatform. */
                    public minCpuPlatform?: (string|null);

                    /** SourceInstanceProperties networkInterfaces. */
                    public networkInterfaces: google.cloud.compute.v1.INetworkInterface[];

                    /** SourceInstanceProperties scheduling. */
                    public scheduling?: (google.cloud.compute.v1.IScheduling|null);

                    /** SourceInstanceProperties serviceAccounts. */
                    public serviceAccounts: google.cloud.compute.v1.IServiceAccount[];

                    /** SourceInstanceProperties tags. */
                    public tags?: (google.cloud.compute.v1.ITags|null);

                    /** SourceInstanceProperties _canIpForward. */
                    public _canIpForward?: "canIpForward";

                    /** SourceInstanceProperties _deletionProtection. */
                    public _deletionProtection?: "deletionProtection";

                    /** SourceInstanceProperties _description. */
                    public _description?: "description";

                    /** SourceInstanceProperties _keyRevocationActionType. */
                    public _keyRevocationActionType?: "keyRevocationActionType";

                    /** SourceInstanceProperties _machineType. */
                    public _machineType?: "machineType";

                    /** SourceInstanceProperties _metadata. */
                    public _metadata?: "metadata";

                    /** SourceInstanceProperties _minCpuPlatform. */
                    public _minCpuPlatform?: "minCpuPlatform";

                    /** SourceInstanceProperties _scheduling. */
                    public _scheduling?: "scheduling";

                    /** SourceInstanceProperties _tags. */
                    public _tags?: "tags";

                    /**
                     * Creates a new SourceInstanceProperties instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SourceInstanceProperties instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISourceInstanceProperties): google.cloud.compute.v1.SourceInstanceProperties;

                    /**
                     * Encodes the specified SourceInstanceProperties message. Does not implicitly {@link google.cloud.compute.v1.SourceInstanceProperties.verify|verify} messages.
                     * @param message SourceInstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISourceInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SourceInstanceProperties message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SourceInstanceProperties.verify|verify} messages.
                     * @param message SourceInstanceProperties message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISourceInstanceProperties, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SourceInstanceProperties message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SourceInstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SourceInstanceProperties;

                    /**
                     * Decodes a SourceInstanceProperties message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SourceInstanceProperties
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SourceInstanceProperties;

                    /**
                     * Verifies a SourceInstanceProperties message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SourceInstanceProperties message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SourceInstanceProperties
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SourceInstanceProperties;

                    /**
                     * Creates a plain object from a SourceInstanceProperties message. Also converts values to other types if specified.
                     * @param message SourceInstanceProperties
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SourceInstanceProperties, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SourceInstanceProperties to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SourceInstanceProperties
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SourceInstanceProperties {

                    /** KeyRevocationActionType enum. */
                    enum KeyRevocationActionType {
                        UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0,
                        KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467110106,
                        NONE = 2402104,
                        STOP = 2555906
                    }
                }

                /** Properties of a SslCertificate. */
                interface ISslCertificate {

                    /** SslCertificate certificate */
                    certificate?: (string|null);

                    /** SslCertificate creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** SslCertificate description */
                    description?: (string|null);

                    /** SslCertificate expireTime */
                    expireTime?: (string|null);

                    /** SslCertificate id */
                    id?: (number|Long|string|null);

                    /** SslCertificate kind */
                    kind?: (string|null);

                    /** SslCertificate managed */
                    managed?: (google.cloud.compute.v1.ISslCertificateManagedSslCertificate|null);

                    /** SslCertificate name */
                    name?: (string|null);

                    /** SslCertificate privateKey */
                    privateKey?: (string|null);

                    /** SslCertificate region */
                    region?: (string|null);

                    /** SslCertificate selfLink */
                    selfLink?: (string|null);

                    /** SslCertificate selfManaged */
                    selfManaged?: (google.cloud.compute.v1.ISslCertificateSelfManagedSslCertificate|null);

                    /** SslCertificate subjectAlternativeNames */
                    subjectAlternativeNames?: (string[]|null);

                    /** SslCertificate type */
                    type?: (string|null);
                }

                /** Represents a SslCertificate. */
                class SslCertificate implements ISslCertificate {

                    /**
                     * Constructs a new SslCertificate.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslCertificate);

                    /** SslCertificate certificate. */
                    public certificate?: (string|null);

                    /** SslCertificate creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** SslCertificate description. */
                    public description?: (string|null);

                    /** SslCertificate expireTime. */
                    public expireTime?: (string|null);

                    /** SslCertificate id. */
                    public id?: (number|Long|string|null);

                    /** SslCertificate kind. */
                    public kind?: (string|null);

                    /** SslCertificate managed. */
                    public managed?: (google.cloud.compute.v1.ISslCertificateManagedSslCertificate|null);

                    /** SslCertificate name. */
                    public name?: (string|null);

                    /** SslCertificate privateKey. */
                    public privateKey?: (string|null);

                    /** SslCertificate region. */
                    public region?: (string|null);

                    /** SslCertificate selfLink. */
                    public selfLink?: (string|null);

                    /** SslCertificate selfManaged. */
                    public selfManaged?: (google.cloud.compute.v1.ISslCertificateSelfManagedSslCertificate|null);

                    /** SslCertificate subjectAlternativeNames. */
                    public subjectAlternativeNames: string[];

                    /** SslCertificate type. */
                    public type?: (string|null);

                    /** SslCertificate _certificate. */
                    public _certificate?: "certificate";

                    /** SslCertificate _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** SslCertificate _description. */
                    public _description?: "description";

                    /** SslCertificate _expireTime. */
                    public _expireTime?: "expireTime";

                    /** SslCertificate _id. */
                    public _id?: "id";

                    /** SslCertificate _kind. */
                    public _kind?: "kind";

                    /** SslCertificate _managed. */
                    public _managed?: "managed";

                    /** SslCertificate _name. */
                    public _name?: "name";

                    /** SslCertificate _privateKey. */
                    public _privateKey?: "privateKey";

                    /** SslCertificate _region. */
                    public _region?: "region";

                    /** SslCertificate _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SslCertificate _selfManaged. */
                    public _selfManaged?: "selfManaged";

                    /** SslCertificate _type. */
                    public _type?: "type";

                    /**
                     * Creates a new SslCertificate instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslCertificate instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslCertificate): google.cloud.compute.v1.SslCertificate;

                    /**
                     * Encodes the specified SslCertificate message. Does not implicitly {@link google.cloud.compute.v1.SslCertificate.verify|verify} messages.
                     * @param message SslCertificate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslCertificate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslCertificate message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslCertificate.verify|verify} messages.
                     * @param message SslCertificate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslCertificate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslCertificate message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslCertificate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslCertificate;

                    /**
                     * Decodes a SslCertificate message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslCertificate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslCertificate;

                    /**
                     * Verifies a SslCertificate message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslCertificate message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslCertificate
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslCertificate;

                    /**
                     * Creates a plain object from a SslCertificate message. Also converts values to other types if specified.
                     * @param message SslCertificate
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslCertificate, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslCertificate to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslCertificate
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SslCertificate {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        MANAGED = 479501183,
                        SELF_MANAGED = 434437516,
                        TYPE_UNSPECIFIED = 437714322
                    }
                }

                /** Properties of a SslCertificateAggregatedList. */
                interface ISslCertificateAggregatedList {

                    /** SslCertificateAggregatedList id */
                    id?: (string|null);

                    /** SslCertificateAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ISslCertificatesScopedList }|null);

                    /** SslCertificateAggregatedList kind */
                    kind?: (string|null);

                    /** SslCertificateAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SslCertificateAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** SslCertificateAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** SslCertificateAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SslCertificateAggregatedList. */
                class SslCertificateAggregatedList implements ISslCertificateAggregatedList {

                    /**
                     * Constructs a new SslCertificateAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslCertificateAggregatedList);

                    /** SslCertificateAggregatedList id. */
                    public id?: (string|null);

                    /** SslCertificateAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ISslCertificatesScopedList };

                    /** SslCertificateAggregatedList kind. */
                    public kind?: (string|null);

                    /** SslCertificateAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SslCertificateAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** SslCertificateAggregatedList unreachables. */
                    public unreachables: string[];

                    /** SslCertificateAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SslCertificateAggregatedList _id. */
                    public _id?: "id";

                    /** SslCertificateAggregatedList _kind. */
                    public _kind?: "kind";

                    /** SslCertificateAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SslCertificateAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SslCertificateAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SslCertificateAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslCertificateAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslCertificateAggregatedList): google.cloud.compute.v1.SslCertificateAggregatedList;

                    /**
                     * Encodes the specified SslCertificateAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.SslCertificateAggregatedList.verify|verify} messages.
                     * @param message SslCertificateAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslCertificateAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslCertificateAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslCertificateAggregatedList.verify|verify} messages.
                     * @param message SslCertificateAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslCertificateAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslCertificateAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslCertificateAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslCertificateAggregatedList;

                    /**
                     * Decodes a SslCertificateAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslCertificateAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslCertificateAggregatedList;

                    /**
                     * Verifies a SslCertificateAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslCertificateAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslCertificateAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslCertificateAggregatedList;

                    /**
                     * Creates a plain object from a SslCertificateAggregatedList message. Also converts values to other types if specified.
                     * @param message SslCertificateAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslCertificateAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslCertificateAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslCertificateAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslCertificateList. */
                interface ISslCertificateList {

                    /** SslCertificateList id */
                    id?: (string|null);

                    /** SslCertificateList items */
                    items?: (google.cloud.compute.v1.ISslCertificate[]|null);

                    /** SslCertificateList kind */
                    kind?: (string|null);

                    /** SslCertificateList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SslCertificateList selfLink */
                    selfLink?: (string|null);

                    /** SslCertificateList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SslCertificateList. */
                class SslCertificateList implements ISslCertificateList {

                    /**
                     * Constructs a new SslCertificateList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslCertificateList);

                    /** SslCertificateList id. */
                    public id?: (string|null);

                    /** SslCertificateList items. */
                    public items: google.cloud.compute.v1.ISslCertificate[];

                    /** SslCertificateList kind. */
                    public kind?: (string|null);

                    /** SslCertificateList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SslCertificateList selfLink. */
                    public selfLink?: (string|null);

                    /** SslCertificateList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SslCertificateList _id. */
                    public _id?: "id";

                    /** SslCertificateList _kind. */
                    public _kind?: "kind";

                    /** SslCertificateList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SslCertificateList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SslCertificateList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SslCertificateList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslCertificateList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslCertificateList): google.cloud.compute.v1.SslCertificateList;

                    /**
                     * Encodes the specified SslCertificateList message. Does not implicitly {@link google.cloud.compute.v1.SslCertificateList.verify|verify} messages.
                     * @param message SslCertificateList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslCertificateList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslCertificateList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslCertificateList.verify|verify} messages.
                     * @param message SslCertificateList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslCertificateList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslCertificateList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslCertificateList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslCertificateList;

                    /**
                     * Decodes a SslCertificateList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslCertificateList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslCertificateList;

                    /**
                     * Verifies a SslCertificateList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslCertificateList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslCertificateList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslCertificateList;

                    /**
                     * Creates a plain object from a SslCertificateList message. Also converts values to other types if specified.
                     * @param message SslCertificateList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslCertificateList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslCertificateList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslCertificateList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslCertificateManagedSslCertificate. */
                interface ISslCertificateManagedSslCertificate {

                    /** SslCertificateManagedSslCertificate domainStatus */
                    domainStatus?: ({ [k: string]: string }|null);

                    /** SslCertificateManagedSslCertificate domains */
                    domains?: (string[]|null);

                    /** SslCertificateManagedSslCertificate status */
                    status?: (string|null);
                }

                /** Represents a SslCertificateManagedSslCertificate. */
                class SslCertificateManagedSslCertificate implements ISslCertificateManagedSslCertificate {

                    /**
                     * Constructs a new SslCertificateManagedSslCertificate.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslCertificateManagedSslCertificate);

                    /** SslCertificateManagedSslCertificate domainStatus. */
                    public domainStatus: { [k: string]: string };

                    /** SslCertificateManagedSslCertificate domains. */
                    public domains: string[];

                    /** SslCertificateManagedSslCertificate status. */
                    public status?: (string|null);

                    /** SslCertificateManagedSslCertificate _status. */
                    public _status?: "status";

                    /**
                     * Creates a new SslCertificateManagedSslCertificate instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslCertificateManagedSslCertificate instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslCertificateManagedSslCertificate): google.cloud.compute.v1.SslCertificateManagedSslCertificate;

                    /**
                     * Encodes the specified SslCertificateManagedSslCertificate message. Does not implicitly {@link google.cloud.compute.v1.SslCertificateManagedSslCertificate.verify|verify} messages.
                     * @param message SslCertificateManagedSslCertificate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslCertificateManagedSslCertificate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslCertificateManagedSslCertificate message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslCertificateManagedSslCertificate.verify|verify} messages.
                     * @param message SslCertificateManagedSslCertificate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslCertificateManagedSslCertificate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslCertificateManagedSslCertificate message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslCertificateManagedSslCertificate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslCertificateManagedSslCertificate;

                    /**
                     * Decodes a SslCertificateManagedSslCertificate message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslCertificateManagedSslCertificate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslCertificateManagedSslCertificate;

                    /**
                     * Verifies a SslCertificateManagedSslCertificate message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslCertificateManagedSslCertificate message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslCertificateManagedSslCertificate
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslCertificateManagedSslCertificate;

                    /**
                     * Creates a plain object from a SslCertificateManagedSslCertificate message. Also converts values to other types if specified.
                     * @param message SslCertificateManagedSslCertificate
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslCertificateManagedSslCertificate, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslCertificateManagedSslCertificate to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslCertificateManagedSslCertificate
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SslCertificateManagedSslCertificate {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ACTIVE = 314733318,
                        MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474800850,
                        PROVISIONING = 290896621,
                        PROVISIONING_FAILED = 76813775,
                        PROVISIONING_FAILED_PERMANENTLY = 275036203,
                        RENEWAL_FAILED = 434659076
                    }
                }

                /** Properties of a SslCertificateSelfManagedSslCertificate. */
                interface ISslCertificateSelfManagedSslCertificate {

                    /** SslCertificateSelfManagedSslCertificate certificate */
                    certificate?: (string|null);

                    /** SslCertificateSelfManagedSslCertificate privateKey */
                    privateKey?: (string|null);
                }

                /** Represents a SslCertificateSelfManagedSslCertificate. */
                class SslCertificateSelfManagedSslCertificate implements ISslCertificateSelfManagedSslCertificate {

                    /**
                     * Constructs a new SslCertificateSelfManagedSslCertificate.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslCertificateSelfManagedSslCertificate);

                    /** SslCertificateSelfManagedSslCertificate certificate. */
                    public certificate?: (string|null);

                    /** SslCertificateSelfManagedSslCertificate privateKey. */
                    public privateKey?: (string|null);

                    /** SslCertificateSelfManagedSslCertificate _certificate. */
                    public _certificate?: "certificate";

                    /** SslCertificateSelfManagedSslCertificate _privateKey. */
                    public _privateKey?: "privateKey";

                    /**
                     * Creates a new SslCertificateSelfManagedSslCertificate instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslCertificateSelfManagedSslCertificate instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslCertificateSelfManagedSslCertificate): google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate;

                    /**
                     * Encodes the specified SslCertificateSelfManagedSslCertificate message. Does not implicitly {@link google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate.verify|verify} messages.
                     * @param message SslCertificateSelfManagedSslCertificate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslCertificateSelfManagedSslCertificate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslCertificateSelfManagedSslCertificate message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate.verify|verify} messages.
                     * @param message SslCertificateSelfManagedSslCertificate message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslCertificateSelfManagedSslCertificate, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslCertificateSelfManagedSslCertificate message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslCertificateSelfManagedSslCertificate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate;

                    /**
                     * Decodes a SslCertificateSelfManagedSslCertificate message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslCertificateSelfManagedSslCertificate
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate;

                    /**
                     * Verifies a SslCertificateSelfManagedSslCertificate message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslCertificateSelfManagedSslCertificate message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslCertificateSelfManagedSslCertificate
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate;

                    /**
                     * Creates a plain object from a SslCertificateSelfManagedSslCertificate message. Also converts values to other types if specified.
                     * @param message SslCertificateSelfManagedSslCertificate
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslCertificateSelfManagedSslCertificate, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslCertificateSelfManagedSslCertificate to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslCertificateSelfManagedSslCertificate
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslCertificatesScopedList. */
                interface ISslCertificatesScopedList {

                    /** SslCertificatesScopedList sslCertificates */
                    sslCertificates?: (google.cloud.compute.v1.ISslCertificate[]|null);

                    /** SslCertificatesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SslCertificatesScopedList. */
                class SslCertificatesScopedList implements ISslCertificatesScopedList {

                    /**
                     * Constructs a new SslCertificatesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslCertificatesScopedList);

                    /** SslCertificatesScopedList sslCertificates. */
                    public sslCertificates: google.cloud.compute.v1.ISslCertificate[];

                    /** SslCertificatesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SslCertificatesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SslCertificatesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslCertificatesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslCertificatesScopedList): google.cloud.compute.v1.SslCertificatesScopedList;

                    /**
                     * Encodes the specified SslCertificatesScopedList message. Does not implicitly {@link google.cloud.compute.v1.SslCertificatesScopedList.verify|verify} messages.
                     * @param message SslCertificatesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslCertificatesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslCertificatesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslCertificatesScopedList.verify|verify} messages.
                     * @param message SslCertificatesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslCertificatesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslCertificatesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslCertificatesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslCertificatesScopedList;

                    /**
                     * Decodes a SslCertificatesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslCertificatesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslCertificatesScopedList;

                    /**
                     * Verifies a SslCertificatesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslCertificatesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslCertificatesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslCertificatesScopedList;

                    /**
                     * Creates a plain object from a SslCertificatesScopedList message. Also converts values to other types if specified.
                     * @param message SslCertificatesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslCertificatesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslCertificatesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslCertificatesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslPoliciesAggregatedList. */
                interface ISslPoliciesAggregatedList {

                    /** SslPoliciesAggregatedList etag */
                    etag?: (string|null);

                    /** SslPoliciesAggregatedList id */
                    id?: (string|null);

                    /** SslPoliciesAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ISslPoliciesScopedList }|null);

                    /** SslPoliciesAggregatedList kind */
                    kind?: (string|null);

                    /** SslPoliciesAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SslPoliciesAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** SslPoliciesAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** SslPoliciesAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SslPoliciesAggregatedList. */
                class SslPoliciesAggregatedList implements ISslPoliciesAggregatedList {

                    /**
                     * Constructs a new SslPoliciesAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslPoliciesAggregatedList);

                    /** SslPoliciesAggregatedList etag. */
                    public etag?: (string|null);

                    /** SslPoliciesAggregatedList id. */
                    public id?: (string|null);

                    /** SslPoliciesAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ISslPoliciesScopedList };

                    /** SslPoliciesAggregatedList kind. */
                    public kind?: (string|null);

                    /** SslPoliciesAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SslPoliciesAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** SslPoliciesAggregatedList unreachables. */
                    public unreachables: string[];

                    /** SslPoliciesAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SslPoliciesAggregatedList _etag. */
                    public _etag?: "etag";

                    /** SslPoliciesAggregatedList _id. */
                    public _id?: "id";

                    /** SslPoliciesAggregatedList _kind. */
                    public _kind?: "kind";

                    /** SslPoliciesAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SslPoliciesAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SslPoliciesAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SslPoliciesAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslPoliciesAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslPoliciesAggregatedList): google.cloud.compute.v1.SslPoliciesAggregatedList;

                    /**
                     * Encodes the specified SslPoliciesAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesAggregatedList.verify|verify} messages.
                     * @param message SslPoliciesAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslPoliciesAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslPoliciesAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesAggregatedList.verify|verify} messages.
                     * @param message SslPoliciesAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslPoliciesAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslPoliciesAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslPoliciesAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslPoliciesAggregatedList;

                    /**
                     * Decodes a SslPoliciesAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslPoliciesAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslPoliciesAggregatedList;

                    /**
                     * Verifies a SslPoliciesAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslPoliciesAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslPoliciesAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslPoliciesAggregatedList;

                    /**
                     * Creates a plain object from a SslPoliciesAggregatedList message. Also converts values to other types if specified.
                     * @param message SslPoliciesAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslPoliciesAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslPoliciesAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslPoliciesAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslPoliciesList. */
                interface ISslPoliciesList {

                    /** SslPoliciesList id */
                    id?: (string|null);

                    /** SslPoliciesList items */
                    items?: (google.cloud.compute.v1.ISslPolicy[]|null);

                    /** SslPoliciesList kind */
                    kind?: (string|null);

                    /** SslPoliciesList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SslPoliciesList selfLink */
                    selfLink?: (string|null);

                    /** SslPoliciesList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SslPoliciesList. */
                class SslPoliciesList implements ISslPoliciesList {

                    /**
                     * Constructs a new SslPoliciesList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslPoliciesList);

                    /** SslPoliciesList id. */
                    public id?: (string|null);

                    /** SslPoliciesList items. */
                    public items: google.cloud.compute.v1.ISslPolicy[];

                    /** SslPoliciesList kind. */
                    public kind?: (string|null);

                    /** SslPoliciesList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SslPoliciesList selfLink. */
                    public selfLink?: (string|null);

                    /** SslPoliciesList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SslPoliciesList _id. */
                    public _id?: "id";

                    /** SslPoliciesList _kind. */
                    public _kind?: "kind";

                    /** SslPoliciesList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SslPoliciesList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SslPoliciesList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SslPoliciesList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslPoliciesList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslPoliciesList): google.cloud.compute.v1.SslPoliciesList;

                    /**
                     * Encodes the specified SslPoliciesList message. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesList.verify|verify} messages.
                     * @param message SslPoliciesList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslPoliciesList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslPoliciesList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesList.verify|verify} messages.
                     * @param message SslPoliciesList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslPoliciesList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslPoliciesList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslPoliciesList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslPoliciesList;

                    /**
                     * Decodes a SslPoliciesList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslPoliciesList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslPoliciesList;

                    /**
                     * Verifies a SslPoliciesList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslPoliciesList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslPoliciesList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslPoliciesList;

                    /**
                     * Creates a plain object from a SslPoliciesList message. Also converts values to other types if specified.
                     * @param message SslPoliciesList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslPoliciesList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslPoliciesList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslPoliciesList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslPoliciesListAvailableFeaturesResponse. */
                interface ISslPoliciesListAvailableFeaturesResponse {

                    /** SslPoliciesListAvailableFeaturesResponse features */
                    features?: (string[]|null);
                }

                /** Represents a SslPoliciesListAvailableFeaturesResponse. */
                class SslPoliciesListAvailableFeaturesResponse implements ISslPoliciesListAvailableFeaturesResponse {

                    /**
                     * Constructs a new SslPoliciesListAvailableFeaturesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslPoliciesListAvailableFeaturesResponse);

                    /** SslPoliciesListAvailableFeaturesResponse features. */
                    public features: string[];

                    /**
                     * Creates a new SslPoliciesListAvailableFeaturesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslPoliciesListAvailableFeaturesResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslPoliciesListAvailableFeaturesResponse): google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse;

                    /**
                     * Encodes the specified SslPoliciesListAvailableFeaturesResponse message. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse.verify|verify} messages.
                     * @param message SslPoliciesListAvailableFeaturesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslPoliciesListAvailableFeaturesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslPoliciesListAvailableFeaturesResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse.verify|verify} messages.
                     * @param message SslPoliciesListAvailableFeaturesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslPoliciesListAvailableFeaturesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslPoliciesListAvailableFeaturesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslPoliciesListAvailableFeaturesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse;

                    /**
                     * Decodes a SslPoliciesListAvailableFeaturesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslPoliciesListAvailableFeaturesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse;

                    /**
                     * Verifies a SslPoliciesListAvailableFeaturesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslPoliciesListAvailableFeaturesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslPoliciesListAvailableFeaturesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse;

                    /**
                     * Creates a plain object from a SslPoliciesListAvailableFeaturesResponse message. Also converts values to other types if specified.
                     * @param message SslPoliciesListAvailableFeaturesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslPoliciesListAvailableFeaturesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslPoliciesListAvailableFeaturesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslPoliciesScopedList. */
                interface ISslPoliciesScopedList {

                    /** SslPoliciesScopedList sslPolicies */
                    sslPolicies?: (google.cloud.compute.v1.ISslPolicy[]|null);

                    /** SslPoliciesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SslPoliciesScopedList. */
                class SslPoliciesScopedList implements ISslPoliciesScopedList {

                    /**
                     * Constructs a new SslPoliciesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslPoliciesScopedList);

                    /** SslPoliciesScopedList sslPolicies. */
                    public sslPolicies: google.cloud.compute.v1.ISslPolicy[];

                    /** SslPoliciesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SslPoliciesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SslPoliciesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslPoliciesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslPoliciesScopedList): google.cloud.compute.v1.SslPoliciesScopedList;

                    /**
                     * Encodes the specified SslPoliciesScopedList message. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesScopedList.verify|verify} messages.
                     * @param message SslPoliciesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslPoliciesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslPoliciesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslPoliciesScopedList.verify|verify} messages.
                     * @param message SslPoliciesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslPoliciesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslPoliciesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslPoliciesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslPoliciesScopedList;

                    /**
                     * Decodes a SslPoliciesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslPoliciesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslPoliciesScopedList;

                    /**
                     * Verifies a SslPoliciesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslPoliciesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslPoliciesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslPoliciesScopedList;

                    /**
                     * Creates a plain object from a SslPoliciesScopedList message. Also converts values to other types if specified.
                     * @param message SslPoliciesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslPoliciesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslPoliciesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslPoliciesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SslPolicy. */
                interface ISslPolicy {

                    /** SslPolicy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** SslPolicy customFeatures */
                    customFeatures?: (string[]|null);

                    /** SslPolicy description */
                    description?: (string|null);

                    /** SslPolicy enabledFeatures */
                    enabledFeatures?: (string[]|null);

                    /** SslPolicy fingerprint */
                    fingerprint?: (string|null);

                    /** SslPolicy id */
                    id?: (number|Long|string|null);

                    /** SslPolicy kind */
                    kind?: (string|null);

                    /** SslPolicy minTlsVersion */
                    minTlsVersion?: (string|null);

                    /** SslPolicy name */
                    name?: (string|null);

                    /** SslPolicy profile */
                    profile?: (string|null);

                    /** SslPolicy region */
                    region?: (string|null);

                    /** SslPolicy selfLink */
                    selfLink?: (string|null);

                    /** SslPolicy warnings */
                    warnings?: (google.cloud.compute.v1.IWarnings[]|null);
                }

                /** Represents a SslPolicy. */
                class SslPolicy implements ISslPolicy {

                    /**
                     * Constructs a new SslPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslPolicy);

                    /** SslPolicy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** SslPolicy customFeatures. */
                    public customFeatures: string[];

                    /** SslPolicy description. */
                    public description?: (string|null);

                    /** SslPolicy enabledFeatures. */
                    public enabledFeatures: string[];

                    /** SslPolicy fingerprint. */
                    public fingerprint?: (string|null);

                    /** SslPolicy id. */
                    public id?: (number|Long|string|null);

                    /** SslPolicy kind. */
                    public kind?: (string|null);

                    /** SslPolicy minTlsVersion. */
                    public minTlsVersion?: (string|null);

                    /** SslPolicy name. */
                    public name?: (string|null);

                    /** SslPolicy profile. */
                    public profile?: (string|null);

                    /** SslPolicy region. */
                    public region?: (string|null);

                    /** SslPolicy selfLink. */
                    public selfLink?: (string|null);

                    /** SslPolicy warnings. */
                    public warnings: google.cloud.compute.v1.IWarnings[];

                    /** SslPolicy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** SslPolicy _description. */
                    public _description?: "description";

                    /** SslPolicy _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** SslPolicy _id. */
                    public _id?: "id";

                    /** SslPolicy _kind. */
                    public _kind?: "kind";

                    /** SslPolicy _minTlsVersion. */
                    public _minTlsVersion?: "minTlsVersion";

                    /** SslPolicy _name. */
                    public _name?: "name";

                    /** SslPolicy _profile. */
                    public _profile?: "profile";

                    /** SslPolicy _region. */
                    public _region?: "region";

                    /** SslPolicy _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new SslPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslPolicy): google.cloud.compute.v1.SslPolicy;

                    /**
                     * Encodes the specified SslPolicy message. Does not implicitly {@link google.cloud.compute.v1.SslPolicy.verify|verify} messages.
                     * @param message SslPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslPolicy.verify|verify} messages.
                     * @param message SslPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslPolicy;

                    /**
                     * Decodes a SslPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslPolicy;

                    /**
                     * Verifies a SslPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslPolicy;

                    /**
                     * Creates a plain object from a SslPolicy message. Also converts values to other types if specified.
                     * @param message SslPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SslPolicy {

                    /** MinTlsVersion enum. */
                    enum MinTlsVersion {
                        UNDEFINED_MIN_TLS_VERSION = 0,
                        TLS_1_0 = 33116734,
                        TLS_1_1 = 33116735,
                        TLS_1_2 = 33116736
                    }

                    /** Profile enum. */
                    enum Profile {
                        UNDEFINED_PROFILE = 0,
                        COMPATIBLE = 179357396,
                        CUSTOM = 388595569,
                        MODERN = 132013855,
                        RESTRICTED = 261551195
                    }
                }

                /** Properties of a SslPolicyReference. */
                interface ISslPolicyReference {

                    /** SslPolicyReference sslPolicy */
                    sslPolicy?: (string|null);
                }

                /** Represents a SslPolicyReference. */
                class SslPolicyReference implements ISslPolicyReference {

                    /**
                     * Constructs a new SslPolicyReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISslPolicyReference);

                    /** SslPolicyReference sslPolicy. */
                    public sslPolicy?: (string|null);

                    /** SslPolicyReference _sslPolicy. */
                    public _sslPolicy?: "sslPolicy";

                    /**
                     * Creates a new SslPolicyReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SslPolicyReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISslPolicyReference): google.cloud.compute.v1.SslPolicyReference;

                    /**
                     * Encodes the specified SslPolicyReference message. Does not implicitly {@link google.cloud.compute.v1.SslPolicyReference.verify|verify} messages.
                     * @param message SslPolicyReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISslPolicyReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SslPolicyReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SslPolicyReference.verify|verify} messages.
                     * @param message SslPolicyReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISslPolicyReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SslPolicyReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SslPolicyReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SslPolicyReference;

                    /**
                     * Decodes a SslPolicyReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SslPolicyReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SslPolicyReference;

                    /**
                     * Verifies a SslPolicyReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SslPolicyReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SslPolicyReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SslPolicyReference;

                    /**
                     * Creates a plain object from a SslPolicyReference message. Also converts values to other types if specified.
                     * @param message SslPolicyReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SslPolicyReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SslPolicyReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SslPolicyReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a StartInstanceRequest. */
                interface IStartInstanceRequest {

                    /** StartInstanceRequest instance */
                    instance?: (string|null);

                    /** StartInstanceRequest project */
                    project?: (string|null);

                    /** StartInstanceRequest requestId */
                    requestId?: (string|null);

                    /** StartInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a StartInstanceRequest. */
                class StartInstanceRequest implements IStartInstanceRequest {

                    /**
                     * Constructs a new StartInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IStartInstanceRequest);

                    /** StartInstanceRequest instance. */
                    public instance: string;

                    /** StartInstanceRequest project. */
                    public project: string;

                    /** StartInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** StartInstanceRequest zone. */
                    public zone: string;

                    /** StartInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new StartInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns StartInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IStartInstanceRequest): google.cloud.compute.v1.StartInstanceRequest;

                    /**
                     * Encodes the specified StartInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.StartInstanceRequest.verify|verify} messages.
                     * @param message StartInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IStartInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified StartInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.StartInstanceRequest.verify|verify} messages.
                     * @param message StartInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IStartInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a StartInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns StartInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.StartInstanceRequest;

                    /**
                     * Decodes a StartInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns StartInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.StartInstanceRequest;

                    /**
                     * Verifies a StartInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a StartInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns StartInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.StartInstanceRequest;

                    /**
                     * Creates a plain object from a StartInstanceRequest message. Also converts values to other types if specified.
                     * @param message StartInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.StartInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this StartInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for StartInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a StartWithEncryptionKeyInstanceRequest. */
                interface IStartWithEncryptionKeyInstanceRequest {

                    /** StartWithEncryptionKeyInstanceRequest instance */
                    instance?: (string|null);

                    /** StartWithEncryptionKeyInstanceRequest instancesStartWithEncryptionKeyRequestResource */
                    instancesStartWithEncryptionKeyRequestResource?: (google.cloud.compute.v1.IInstancesStartWithEncryptionKeyRequest|null);

                    /** StartWithEncryptionKeyInstanceRequest project */
                    project?: (string|null);

                    /** StartWithEncryptionKeyInstanceRequest requestId */
                    requestId?: (string|null);

                    /** StartWithEncryptionKeyInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a StartWithEncryptionKeyInstanceRequest. */
                class StartWithEncryptionKeyInstanceRequest implements IStartWithEncryptionKeyInstanceRequest {

                    /**
                     * Constructs a new StartWithEncryptionKeyInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IStartWithEncryptionKeyInstanceRequest);

                    /** StartWithEncryptionKeyInstanceRequest instance. */
                    public instance: string;

                    /** StartWithEncryptionKeyInstanceRequest instancesStartWithEncryptionKeyRequestResource. */
                    public instancesStartWithEncryptionKeyRequestResource?: (google.cloud.compute.v1.IInstancesStartWithEncryptionKeyRequest|null);

                    /** StartWithEncryptionKeyInstanceRequest project. */
                    public project: string;

                    /** StartWithEncryptionKeyInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** StartWithEncryptionKeyInstanceRequest zone. */
                    public zone: string;

                    /** StartWithEncryptionKeyInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new StartWithEncryptionKeyInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns StartWithEncryptionKeyInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IStartWithEncryptionKeyInstanceRequest): google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest;

                    /**
                     * Encodes the specified StartWithEncryptionKeyInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest.verify|verify} messages.
                     * @param message StartWithEncryptionKeyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IStartWithEncryptionKeyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified StartWithEncryptionKeyInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest.verify|verify} messages.
                     * @param message StartWithEncryptionKeyInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IStartWithEncryptionKeyInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a StartWithEncryptionKeyInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns StartWithEncryptionKeyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest;

                    /**
                     * Decodes a StartWithEncryptionKeyInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns StartWithEncryptionKeyInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest;

                    /**
                     * Verifies a StartWithEncryptionKeyInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a StartWithEncryptionKeyInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns StartWithEncryptionKeyInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest;

                    /**
                     * Creates a plain object from a StartWithEncryptionKeyInstanceRequest message. Also converts values to other types if specified.
                     * @param message StartWithEncryptionKeyInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.StartWithEncryptionKeyInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this StartWithEncryptionKeyInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for StartWithEncryptionKeyInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a StatefulPolicy. */
                interface IStatefulPolicy {

                    /** StatefulPolicy preservedState */
                    preservedState?: (google.cloud.compute.v1.IStatefulPolicyPreservedState|null);
                }

                /** Represents a StatefulPolicy. */
                class StatefulPolicy implements IStatefulPolicy {

                    /**
                     * Constructs a new StatefulPolicy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IStatefulPolicy);

                    /** StatefulPolicy preservedState. */
                    public preservedState?: (google.cloud.compute.v1.IStatefulPolicyPreservedState|null);

                    /** StatefulPolicy _preservedState. */
                    public _preservedState?: "preservedState";

                    /**
                     * Creates a new StatefulPolicy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns StatefulPolicy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IStatefulPolicy): google.cloud.compute.v1.StatefulPolicy;

                    /**
                     * Encodes the specified StatefulPolicy message. Does not implicitly {@link google.cloud.compute.v1.StatefulPolicy.verify|verify} messages.
                     * @param message StatefulPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IStatefulPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified StatefulPolicy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.StatefulPolicy.verify|verify} messages.
                     * @param message StatefulPolicy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IStatefulPolicy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a StatefulPolicy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns StatefulPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.StatefulPolicy;

                    /**
                     * Decodes a StatefulPolicy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns StatefulPolicy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.StatefulPolicy;

                    /**
                     * Verifies a StatefulPolicy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a StatefulPolicy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns StatefulPolicy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.StatefulPolicy;

                    /**
                     * Creates a plain object from a StatefulPolicy message. Also converts values to other types if specified.
                     * @param message StatefulPolicy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.StatefulPolicy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this StatefulPolicy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for StatefulPolicy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a StatefulPolicyPreservedState. */
                interface IStatefulPolicyPreservedState {

                    /** StatefulPolicyPreservedState disks */
                    disks?: ({ [k: string]: google.cloud.compute.v1.IStatefulPolicyPreservedStateDiskDevice }|null);
                }

                /** Represents a StatefulPolicyPreservedState. */
                class StatefulPolicyPreservedState implements IStatefulPolicyPreservedState {

                    /**
                     * Constructs a new StatefulPolicyPreservedState.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IStatefulPolicyPreservedState);

                    /** StatefulPolicyPreservedState disks. */
                    public disks: { [k: string]: google.cloud.compute.v1.IStatefulPolicyPreservedStateDiskDevice };

                    /**
                     * Creates a new StatefulPolicyPreservedState instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns StatefulPolicyPreservedState instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IStatefulPolicyPreservedState): google.cloud.compute.v1.StatefulPolicyPreservedState;

                    /**
                     * Encodes the specified StatefulPolicyPreservedState message. Does not implicitly {@link google.cloud.compute.v1.StatefulPolicyPreservedState.verify|verify} messages.
                     * @param message StatefulPolicyPreservedState message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IStatefulPolicyPreservedState, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified StatefulPolicyPreservedState message, length delimited. Does not implicitly {@link google.cloud.compute.v1.StatefulPolicyPreservedState.verify|verify} messages.
                     * @param message StatefulPolicyPreservedState message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IStatefulPolicyPreservedState, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a StatefulPolicyPreservedState message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns StatefulPolicyPreservedState
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.StatefulPolicyPreservedState;

                    /**
                     * Decodes a StatefulPolicyPreservedState message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns StatefulPolicyPreservedState
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.StatefulPolicyPreservedState;

                    /**
                     * Verifies a StatefulPolicyPreservedState message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a StatefulPolicyPreservedState message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns StatefulPolicyPreservedState
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.StatefulPolicyPreservedState;

                    /**
                     * Creates a plain object from a StatefulPolicyPreservedState message. Also converts values to other types if specified.
                     * @param message StatefulPolicyPreservedState
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.StatefulPolicyPreservedState, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this StatefulPolicyPreservedState to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for StatefulPolicyPreservedState
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a StatefulPolicyPreservedStateDiskDevice. */
                interface IStatefulPolicyPreservedStateDiskDevice {

                    /** StatefulPolicyPreservedStateDiskDevice autoDelete */
                    autoDelete?: (string|null);
                }

                /** Represents a StatefulPolicyPreservedStateDiskDevice. */
                class StatefulPolicyPreservedStateDiskDevice implements IStatefulPolicyPreservedStateDiskDevice {

                    /**
                     * Constructs a new StatefulPolicyPreservedStateDiskDevice.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IStatefulPolicyPreservedStateDiskDevice);

                    /** StatefulPolicyPreservedStateDiskDevice autoDelete. */
                    public autoDelete?: (string|null);

                    /** StatefulPolicyPreservedStateDiskDevice _autoDelete. */
                    public _autoDelete?: "autoDelete";

                    /**
                     * Creates a new StatefulPolicyPreservedStateDiskDevice instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns StatefulPolicyPreservedStateDiskDevice instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IStatefulPolicyPreservedStateDiskDevice): google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice;

                    /**
                     * Encodes the specified StatefulPolicyPreservedStateDiskDevice message. Does not implicitly {@link google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice.verify|verify} messages.
                     * @param message StatefulPolicyPreservedStateDiskDevice message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IStatefulPolicyPreservedStateDiskDevice, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified StatefulPolicyPreservedStateDiskDevice message, length delimited. Does not implicitly {@link google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice.verify|verify} messages.
                     * @param message StatefulPolicyPreservedStateDiskDevice message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IStatefulPolicyPreservedStateDiskDevice, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a StatefulPolicyPreservedStateDiskDevice message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns StatefulPolicyPreservedStateDiskDevice
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice;

                    /**
                     * Decodes a StatefulPolicyPreservedStateDiskDevice message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns StatefulPolicyPreservedStateDiskDevice
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice;

                    /**
                     * Verifies a StatefulPolicyPreservedStateDiskDevice message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a StatefulPolicyPreservedStateDiskDevice message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns StatefulPolicyPreservedStateDiskDevice
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice;

                    /**
                     * Creates a plain object from a StatefulPolicyPreservedStateDiskDevice message. Also converts values to other types if specified.
                     * @param message StatefulPolicyPreservedStateDiskDevice
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.StatefulPolicyPreservedStateDiskDevice, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this StatefulPolicyPreservedStateDiskDevice to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for StatefulPolicyPreservedStateDiskDevice
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace StatefulPolicyPreservedStateDiskDevice {

                    /** AutoDelete enum. */
                    enum AutoDelete {
                        UNDEFINED_AUTO_DELETE = 0,
                        NEVER = 74175084,
                        ON_PERMANENT_INSTANCE_DELETION = 95727719
                    }
                }

                /** Properties of a StopInstanceRequest. */
                interface IStopInstanceRequest {

                    /** StopInstanceRequest instance */
                    instance?: (string|null);

                    /** StopInstanceRequest project */
                    project?: (string|null);

                    /** StopInstanceRequest requestId */
                    requestId?: (string|null);

                    /** StopInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a StopInstanceRequest. */
                class StopInstanceRequest implements IStopInstanceRequest {

                    /**
                     * Constructs a new StopInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IStopInstanceRequest);

                    /** StopInstanceRequest instance. */
                    public instance: string;

                    /** StopInstanceRequest project. */
                    public project: string;

                    /** StopInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** StopInstanceRequest zone. */
                    public zone: string;

                    /** StopInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new StopInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns StopInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IStopInstanceRequest): google.cloud.compute.v1.StopInstanceRequest;

                    /**
                     * Encodes the specified StopInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.StopInstanceRequest.verify|verify} messages.
                     * @param message StopInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IStopInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified StopInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.StopInstanceRequest.verify|verify} messages.
                     * @param message StopInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IStopInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a StopInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns StopInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.StopInstanceRequest;

                    /**
                     * Decodes a StopInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns StopInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.StopInstanceRequest;

                    /**
                     * Verifies a StopInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a StopInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns StopInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.StopInstanceRequest;

                    /**
                     * Creates a plain object from a StopInstanceRequest message. Also converts values to other types if specified.
                     * @param message StopInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.StopInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this StopInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for StopInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Subnetwork. */
                interface ISubnetwork {

                    /** Subnetwork creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Subnetwork description */
                    description?: (string|null);

                    /** Subnetwork enableFlowLogs */
                    enableFlowLogs?: (boolean|null);

                    /** Subnetwork externalIpv6Prefix */
                    externalIpv6Prefix?: (string|null);

                    /** Subnetwork fingerprint */
                    fingerprint?: (string|null);

                    /** Subnetwork gatewayAddress */
                    gatewayAddress?: (string|null);

                    /** Subnetwork id */
                    id?: (number|Long|string|null);

                    /** Subnetwork internalIpv6Prefix */
                    internalIpv6Prefix?: (string|null);

                    /** Subnetwork ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** Subnetwork ipv6AccessType */
                    ipv6AccessType?: (string|null);

                    /** Subnetwork ipv6CidrRange */
                    ipv6CidrRange?: (string|null);

                    /** Subnetwork kind */
                    kind?: (string|null);

                    /** Subnetwork logConfig */
                    logConfig?: (google.cloud.compute.v1.ISubnetworkLogConfig|null);

                    /** Subnetwork name */
                    name?: (string|null);

                    /** Subnetwork network */
                    network?: (string|null);

                    /** Subnetwork privateIpGoogleAccess */
                    privateIpGoogleAccess?: (boolean|null);

                    /** Subnetwork privateIpv6GoogleAccess */
                    privateIpv6GoogleAccess?: (string|null);

                    /** Subnetwork purpose */
                    purpose?: (string|null);

                    /** Subnetwork region */
                    region?: (string|null);

                    /** Subnetwork role */
                    role?: (string|null);

                    /** Subnetwork secondaryIpRanges */
                    secondaryIpRanges?: (google.cloud.compute.v1.ISubnetworkSecondaryRange[]|null);

                    /** Subnetwork selfLink */
                    selfLink?: (string|null);

                    /** Subnetwork stackType */
                    stackType?: (string|null);

                    /** Subnetwork state */
                    state?: (string|null);
                }

                /** Represents a Subnetwork. */
                class Subnetwork implements ISubnetwork {

                    /**
                     * Constructs a new Subnetwork.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetwork);

                    /** Subnetwork creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Subnetwork description. */
                    public description?: (string|null);

                    /** Subnetwork enableFlowLogs. */
                    public enableFlowLogs?: (boolean|null);

                    /** Subnetwork externalIpv6Prefix. */
                    public externalIpv6Prefix?: (string|null);

                    /** Subnetwork fingerprint. */
                    public fingerprint?: (string|null);

                    /** Subnetwork gatewayAddress. */
                    public gatewayAddress?: (string|null);

                    /** Subnetwork id. */
                    public id?: (number|Long|string|null);

                    /** Subnetwork internalIpv6Prefix. */
                    public internalIpv6Prefix?: (string|null);

                    /** Subnetwork ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** Subnetwork ipv6AccessType. */
                    public ipv6AccessType?: (string|null);

                    /** Subnetwork ipv6CidrRange. */
                    public ipv6CidrRange?: (string|null);

                    /** Subnetwork kind. */
                    public kind?: (string|null);

                    /** Subnetwork logConfig. */
                    public logConfig?: (google.cloud.compute.v1.ISubnetworkLogConfig|null);

                    /** Subnetwork name. */
                    public name?: (string|null);

                    /** Subnetwork network. */
                    public network?: (string|null);

                    /** Subnetwork privateIpGoogleAccess. */
                    public privateIpGoogleAccess?: (boolean|null);

                    /** Subnetwork privateIpv6GoogleAccess. */
                    public privateIpv6GoogleAccess?: (string|null);

                    /** Subnetwork purpose. */
                    public purpose?: (string|null);

                    /** Subnetwork region. */
                    public region?: (string|null);

                    /** Subnetwork role. */
                    public role?: (string|null);

                    /** Subnetwork secondaryIpRanges. */
                    public secondaryIpRanges: google.cloud.compute.v1.ISubnetworkSecondaryRange[];

                    /** Subnetwork selfLink. */
                    public selfLink?: (string|null);

                    /** Subnetwork stackType. */
                    public stackType?: (string|null);

                    /** Subnetwork state. */
                    public state?: (string|null);

                    /** Subnetwork _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Subnetwork _description. */
                    public _description?: "description";

                    /** Subnetwork _enableFlowLogs. */
                    public _enableFlowLogs?: "enableFlowLogs";

                    /** Subnetwork _externalIpv6Prefix. */
                    public _externalIpv6Prefix?: "externalIpv6Prefix";

                    /** Subnetwork _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** Subnetwork _gatewayAddress. */
                    public _gatewayAddress?: "gatewayAddress";

                    /** Subnetwork _id. */
                    public _id?: "id";

                    /** Subnetwork _internalIpv6Prefix. */
                    public _internalIpv6Prefix?: "internalIpv6Prefix";

                    /** Subnetwork _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** Subnetwork _ipv6AccessType. */
                    public _ipv6AccessType?: "ipv6AccessType";

                    /** Subnetwork _ipv6CidrRange. */
                    public _ipv6CidrRange?: "ipv6CidrRange";

                    /** Subnetwork _kind. */
                    public _kind?: "kind";

                    /** Subnetwork _logConfig. */
                    public _logConfig?: "logConfig";

                    /** Subnetwork _name. */
                    public _name?: "name";

                    /** Subnetwork _network. */
                    public _network?: "network";

                    /** Subnetwork _privateIpGoogleAccess. */
                    public _privateIpGoogleAccess?: "privateIpGoogleAccess";

                    /** Subnetwork _privateIpv6GoogleAccess. */
                    public _privateIpv6GoogleAccess?: "privateIpv6GoogleAccess";

                    /** Subnetwork _purpose. */
                    public _purpose?: "purpose";

                    /** Subnetwork _region. */
                    public _region?: "region";

                    /** Subnetwork _role. */
                    public _role?: "role";

                    /** Subnetwork _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Subnetwork _stackType. */
                    public _stackType?: "stackType";

                    /** Subnetwork _state. */
                    public _state?: "state";

                    /**
                     * Creates a new Subnetwork instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Subnetwork instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetwork): google.cloud.compute.v1.Subnetwork;

                    /**
                     * Encodes the specified Subnetwork message. Does not implicitly {@link google.cloud.compute.v1.Subnetwork.verify|verify} messages.
                     * @param message Subnetwork message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetwork, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Subnetwork message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Subnetwork.verify|verify} messages.
                     * @param message Subnetwork message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetwork, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Subnetwork message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Subnetwork
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Subnetwork;

                    /**
                     * Decodes a Subnetwork message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Subnetwork
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Subnetwork;

                    /**
                     * Verifies a Subnetwork message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Subnetwork message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Subnetwork
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Subnetwork;

                    /**
                     * Creates a plain object from a Subnetwork message. Also converts values to other types if specified.
                     * @param message Subnetwork
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Subnetwork, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Subnetwork to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Subnetwork
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Subnetwork {

                    /** Ipv6AccessType enum. */
                    enum Ipv6AccessType {
                        UNDEFINED_IPV6_ACCESS_TYPE = 0,
                        EXTERNAL = 35607499,
                        INTERNAL = 279295677,
                        UNSPECIFIED_IPV6_ACCESS_TYPE = 313080613
                    }

                    /** PrivateIpv6GoogleAccess enum. */
                    enum PrivateIpv6GoogleAccess {
                        UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS = 0,
                        DISABLE_GOOGLE_ACCESS = 450958579,
                        ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 427975994,
                        ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 288210263
                    }

                    /** Purpose enum. */
                    enum Purpose {
                        UNDEFINED_PURPOSE = 0,
                        INTERNAL_HTTPS_LOAD_BALANCER = 248748889,
                        PRIVATE = 403485027,
                        PRIVATE_RFC_1918 = 254902107,
                        PRIVATE_SERVICE_CONNECT = 48134724,
                        REGIONAL_MANAGED_PROXY = 153049966
                    }

                    /** Role enum. */
                    enum Role {
                        UNDEFINED_ROLE = 0,
                        ACTIVE = 314733318,
                        BACKUP = 341010882
                    }

                    /** StackType enum. */
                    enum StackType {
                        UNDEFINED_STACK_TYPE = 0,
                        IPV4_IPV6 = 22197249,
                        IPV4_ONLY = 22373798,
                        UNSPECIFIED_STACK_TYPE = 298084569
                    }

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        DRAINING = 480455402,
                        READY = 77848963
                    }
                }

                /** Properties of a SubnetworkAggregatedList. */
                interface ISubnetworkAggregatedList {

                    /** SubnetworkAggregatedList id */
                    id?: (string|null);

                    /** SubnetworkAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ISubnetworksScopedList }|null);

                    /** SubnetworkAggregatedList kind */
                    kind?: (string|null);

                    /** SubnetworkAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SubnetworkAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** SubnetworkAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** SubnetworkAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SubnetworkAggregatedList. */
                class SubnetworkAggregatedList implements ISubnetworkAggregatedList {

                    /**
                     * Constructs a new SubnetworkAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworkAggregatedList);

                    /** SubnetworkAggregatedList id. */
                    public id?: (string|null);

                    /** SubnetworkAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ISubnetworksScopedList };

                    /** SubnetworkAggregatedList kind. */
                    public kind?: (string|null);

                    /** SubnetworkAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SubnetworkAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** SubnetworkAggregatedList unreachables. */
                    public unreachables: string[];

                    /** SubnetworkAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SubnetworkAggregatedList _id. */
                    public _id?: "id";

                    /** SubnetworkAggregatedList _kind. */
                    public _kind?: "kind";

                    /** SubnetworkAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SubnetworkAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SubnetworkAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SubnetworkAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworkAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworkAggregatedList): google.cloud.compute.v1.SubnetworkAggregatedList;

                    /**
                     * Encodes the specified SubnetworkAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.SubnetworkAggregatedList.verify|verify} messages.
                     * @param message SubnetworkAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworkAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworkAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworkAggregatedList.verify|verify} messages.
                     * @param message SubnetworkAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworkAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworkAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworkAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworkAggregatedList;

                    /**
                     * Decodes a SubnetworkAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworkAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworkAggregatedList;

                    /**
                     * Verifies a SubnetworkAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworkAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworkAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworkAggregatedList;

                    /**
                     * Creates a plain object from a SubnetworkAggregatedList message. Also converts values to other types if specified.
                     * @param message SubnetworkAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworkAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworkAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworkAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SubnetworkList. */
                interface ISubnetworkList {

                    /** SubnetworkList id */
                    id?: (string|null);

                    /** SubnetworkList items */
                    items?: (google.cloud.compute.v1.ISubnetwork[]|null);

                    /** SubnetworkList kind */
                    kind?: (string|null);

                    /** SubnetworkList nextPageToken */
                    nextPageToken?: (string|null);

                    /** SubnetworkList selfLink */
                    selfLink?: (string|null);

                    /** SubnetworkList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SubnetworkList. */
                class SubnetworkList implements ISubnetworkList {

                    /**
                     * Constructs a new SubnetworkList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworkList);

                    /** SubnetworkList id. */
                    public id?: (string|null);

                    /** SubnetworkList items. */
                    public items: google.cloud.compute.v1.ISubnetwork[];

                    /** SubnetworkList kind. */
                    public kind?: (string|null);

                    /** SubnetworkList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** SubnetworkList selfLink. */
                    public selfLink?: (string|null);

                    /** SubnetworkList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SubnetworkList _id. */
                    public _id?: "id";

                    /** SubnetworkList _kind. */
                    public _kind?: "kind";

                    /** SubnetworkList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** SubnetworkList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** SubnetworkList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SubnetworkList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworkList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworkList): google.cloud.compute.v1.SubnetworkList;

                    /**
                     * Encodes the specified SubnetworkList message. Does not implicitly {@link google.cloud.compute.v1.SubnetworkList.verify|verify} messages.
                     * @param message SubnetworkList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworkList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworkList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworkList.verify|verify} messages.
                     * @param message SubnetworkList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworkList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworkList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworkList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworkList;

                    /**
                     * Decodes a SubnetworkList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworkList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworkList;

                    /**
                     * Verifies a SubnetworkList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworkList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworkList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworkList;

                    /**
                     * Creates a plain object from a SubnetworkList message. Also converts values to other types if specified.
                     * @param message SubnetworkList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworkList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworkList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworkList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SubnetworkLogConfig. */
                interface ISubnetworkLogConfig {

                    /** SubnetworkLogConfig aggregationInterval */
                    aggregationInterval?: (string|null);

                    /** SubnetworkLogConfig enable */
                    enable?: (boolean|null);

                    /** SubnetworkLogConfig filterExpr */
                    filterExpr?: (string|null);

                    /** SubnetworkLogConfig flowSampling */
                    flowSampling?: (number|null);

                    /** SubnetworkLogConfig metadata */
                    metadata?: (string|null);

                    /** SubnetworkLogConfig metadataFields */
                    metadataFields?: (string[]|null);
                }

                /** Represents a SubnetworkLogConfig. */
                class SubnetworkLogConfig implements ISubnetworkLogConfig {

                    /**
                     * Constructs a new SubnetworkLogConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworkLogConfig);

                    /** SubnetworkLogConfig aggregationInterval. */
                    public aggregationInterval?: (string|null);

                    /** SubnetworkLogConfig enable. */
                    public enable?: (boolean|null);

                    /** SubnetworkLogConfig filterExpr. */
                    public filterExpr?: (string|null);

                    /** SubnetworkLogConfig flowSampling. */
                    public flowSampling?: (number|null);

                    /** SubnetworkLogConfig metadata. */
                    public metadata?: (string|null);

                    /** SubnetworkLogConfig metadataFields. */
                    public metadataFields: string[];

                    /** SubnetworkLogConfig _aggregationInterval. */
                    public _aggregationInterval?: "aggregationInterval";

                    /** SubnetworkLogConfig _enable. */
                    public _enable?: "enable";

                    /** SubnetworkLogConfig _filterExpr. */
                    public _filterExpr?: "filterExpr";

                    /** SubnetworkLogConfig _flowSampling. */
                    public _flowSampling?: "flowSampling";

                    /** SubnetworkLogConfig _metadata. */
                    public _metadata?: "metadata";

                    /**
                     * Creates a new SubnetworkLogConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworkLogConfig instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworkLogConfig): google.cloud.compute.v1.SubnetworkLogConfig;

                    /**
                     * Encodes the specified SubnetworkLogConfig message. Does not implicitly {@link google.cloud.compute.v1.SubnetworkLogConfig.verify|verify} messages.
                     * @param message SubnetworkLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworkLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworkLogConfig message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworkLogConfig.verify|verify} messages.
                     * @param message SubnetworkLogConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworkLogConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworkLogConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworkLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworkLogConfig;

                    /**
                     * Decodes a SubnetworkLogConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworkLogConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworkLogConfig;

                    /**
                     * Verifies a SubnetworkLogConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworkLogConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworkLogConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworkLogConfig;

                    /**
                     * Creates a plain object from a SubnetworkLogConfig message. Also converts values to other types if specified.
                     * @param message SubnetworkLogConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworkLogConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworkLogConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworkLogConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SubnetworkLogConfig {

                    /** AggregationInterval enum. */
                    enum AggregationInterval {
                        UNDEFINED_AGGREGATION_INTERVAL = 0,
                        INTERVAL_10_MIN = 487155916,
                        INTERVAL_15_MIN = 491773521,
                        INTERVAL_1_MIN = 69052714,
                        INTERVAL_30_SEC = 7548937,
                        INTERVAL_5_MIN = 72746798,
                        INTERVAL_5_SEC = 72752429
                    }

                    /** Metadata enum. */
                    enum Metadata {
                        UNDEFINED_METADATA = 0,
                        CUSTOM_METADATA = 62450749,
                        EXCLUDE_ALL_METADATA = 334519954,
                        INCLUDE_ALL_METADATA = 164619908
                    }
                }

                /** Properties of a SubnetworkSecondaryRange. */
                interface ISubnetworkSecondaryRange {

                    /** SubnetworkSecondaryRange ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** SubnetworkSecondaryRange rangeName */
                    rangeName?: (string|null);
                }

                /** Represents a SubnetworkSecondaryRange. */
                class SubnetworkSecondaryRange implements ISubnetworkSecondaryRange {

                    /**
                     * Constructs a new SubnetworkSecondaryRange.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworkSecondaryRange);

                    /** SubnetworkSecondaryRange ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** SubnetworkSecondaryRange rangeName. */
                    public rangeName?: (string|null);

                    /** SubnetworkSecondaryRange _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** SubnetworkSecondaryRange _rangeName. */
                    public _rangeName?: "rangeName";

                    /**
                     * Creates a new SubnetworkSecondaryRange instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworkSecondaryRange instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworkSecondaryRange): google.cloud.compute.v1.SubnetworkSecondaryRange;

                    /**
                     * Encodes the specified SubnetworkSecondaryRange message. Does not implicitly {@link google.cloud.compute.v1.SubnetworkSecondaryRange.verify|verify} messages.
                     * @param message SubnetworkSecondaryRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworkSecondaryRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworkSecondaryRange message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworkSecondaryRange.verify|verify} messages.
                     * @param message SubnetworkSecondaryRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworkSecondaryRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworkSecondaryRange message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworkSecondaryRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworkSecondaryRange;

                    /**
                     * Decodes a SubnetworkSecondaryRange message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworkSecondaryRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworkSecondaryRange;

                    /**
                     * Verifies a SubnetworkSecondaryRange message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworkSecondaryRange message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworkSecondaryRange
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworkSecondaryRange;

                    /**
                     * Creates a plain object from a SubnetworkSecondaryRange message. Also converts values to other types if specified.
                     * @param message SubnetworkSecondaryRange
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworkSecondaryRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworkSecondaryRange to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworkSecondaryRange
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SubnetworksExpandIpCidrRangeRequest. */
                interface ISubnetworksExpandIpCidrRangeRequest {

                    /** SubnetworksExpandIpCidrRangeRequest ipCidrRange */
                    ipCidrRange?: (string|null);
                }

                /** Represents a SubnetworksExpandIpCidrRangeRequest. */
                class SubnetworksExpandIpCidrRangeRequest implements ISubnetworksExpandIpCidrRangeRequest {

                    /**
                     * Constructs a new SubnetworksExpandIpCidrRangeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworksExpandIpCidrRangeRequest);

                    /** SubnetworksExpandIpCidrRangeRequest ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** SubnetworksExpandIpCidrRangeRequest _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /**
                     * Creates a new SubnetworksExpandIpCidrRangeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworksExpandIpCidrRangeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworksExpandIpCidrRangeRequest): google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest;

                    /**
                     * Encodes the specified SubnetworksExpandIpCidrRangeRequest message. Does not implicitly {@link google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest.verify|verify} messages.
                     * @param message SubnetworksExpandIpCidrRangeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworksExpandIpCidrRangeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworksExpandIpCidrRangeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest.verify|verify} messages.
                     * @param message SubnetworksExpandIpCidrRangeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworksExpandIpCidrRangeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworksExpandIpCidrRangeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworksExpandIpCidrRangeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest;

                    /**
                     * Decodes a SubnetworksExpandIpCidrRangeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworksExpandIpCidrRangeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest;

                    /**
                     * Verifies a SubnetworksExpandIpCidrRangeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworksExpandIpCidrRangeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworksExpandIpCidrRangeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest;

                    /**
                     * Creates a plain object from a SubnetworksExpandIpCidrRangeRequest message. Also converts values to other types if specified.
                     * @param message SubnetworksExpandIpCidrRangeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworksExpandIpCidrRangeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworksExpandIpCidrRangeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworksExpandIpCidrRangeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SubnetworksScopedList. */
                interface ISubnetworksScopedList {

                    /** SubnetworksScopedList subnetworks */
                    subnetworks?: (google.cloud.compute.v1.ISubnetwork[]|null);

                    /** SubnetworksScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a SubnetworksScopedList. */
                class SubnetworksScopedList implements ISubnetworksScopedList {

                    /**
                     * Constructs a new SubnetworksScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworksScopedList);

                    /** SubnetworksScopedList subnetworks. */
                    public subnetworks: google.cloud.compute.v1.ISubnetwork[];

                    /** SubnetworksScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** SubnetworksScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new SubnetworksScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworksScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworksScopedList): google.cloud.compute.v1.SubnetworksScopedList;

                    /**
                     * Encodes the specified SubnetworksScopedList message. Does not implicitly {@link google.cloud.compute.v1.SubnetworksScopedList.verify|verify} messages.
                     * @param message SubnetworksScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworksScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworksScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworksScopedList.verify|verify} messages.
                     * @param message SubnetworksScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworksScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworksScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworksScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworksScopedList;

                    /**
                     * Decodes a SubnetworksScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworksScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworksScopedList;

                    /**
                     * Verifies a SubnetworksScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworksScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworksScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworksScopedList;

                    /**
                     * Creates a plain object from a SubnetworksScopedList message. Also converts values to other types if specified.
                     * @param message SubnetworksScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworksScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworksScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworksScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SubnetworksSetPrivateIpGoogleAccessRequest. */
                interface ISubnetworksSetPrivateIpGoogleAccessRequest {

                    /** SubnetworksSetPrivateIpGoogleAccessRequest privateIpGoogleAccess */
                    privateIpGoogleAccess?: (boolean|null);
                }

                /** Represents a SubnetworksSetPrivateIpGoogleAccessRequest. */
                class SubnetworksSetPrivateIpGoogleAccessRequest implements ISubnetworksSetPrivateIpGoogleAccessRequest {

                    /**
                     * Constructs a new SubnetworksSetPrivateIpGoogleAccessRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubnetworksSetPrivateIpGoogleAccessRequest);

                    /** SubnetworksSetPrivateIpGoogleAccessRequest privateIpGoogleAccess. */
                    public privateIpGoogleAccess?: (boolean|null);

                    /** SubnetworksSetPrivateIpGoogleAccessRequest _privateIpGoogleAccess. */
                    public _privateIpGoogleAccess?: "privateIpGoogleAccess";

                    /**
                     * Creates a new SubnetworksSetPrivateIpGoogleAccessRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SubnetworksSetPrivateIpGoogleAccessRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubnetworksSetPrivateIpGoogleAccessRequest): google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest;

                    /**
                     * Encodes the specified SubnetworksSetPrivateIpGoogleAccessRequest message. Does not implicitly {@link google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest.verify|verify} messages.
                     * @param message SubnetworksSetPrivateIpGoogleAccessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubnetworksSetPrivateIpGoogleAccessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SubnetworksSetPrivateIpGoogleAccessRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest.verify|verify} messages.
                     * @param message SubnetworksSetPrivateIpGoogleAccessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubnetworksSetPrivateIpGoogleAccessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SubnetworksSetPrivateIpGoogleAccessRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SubnetworksSetPrivateIpGoogleAccessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest;

                    /**
                     * Decodes a SubnetworksSetPrivateIpGoogleAccessRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SubnetworksSetPrivateIpGoogleAccessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest;

                    /**
                     * Verifies a SubnetworksSetPrivateIpGoogleAccessRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SubnetworksSetPrivateIpGoogleAccessRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SubnetworksSetPrivateIpGoogleAccessRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest;

                    /**
                     * Creates a plain object from a SubnetworksSetPrivateIpGoogleAccessRequest message. Also converts values to other types if specified.
                     * @param message SubnetworksSetPrivateIpGoogleAccessRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SubnetworksSetPrivateIpGoogleAccessRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SubnetworksSetPrivateIpGoogleAccessRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SubnetworksSetPrivateIpGoogleAccessRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Subsetting. */
                interface ISubsetting {

                    /** Subsetting policy */
                    policy?: (string|null);
                }

                /** Represents a Subsetting. */
                class Subsetting implements ISubsetting {

                    /**
                     * Constructs a new Subsetting.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISubsetting);

                    /** Subsetting policy. */
                    public policy?: (string|null);

                    /** Subsetting _policy. */
                    public _policy?: "policy";

                    /**
                     * Creates a new Subsetting instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Subsetting instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISubsetting): google.cloud.compute.v1.Subsetting;

                    /**
                     * Encodes the specified Subsetting message. Does not implicitly {@link google.cloud.compute.v1.Subsetting.verify|verify} messages.
                     * @param message Subsetting message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISubsetting, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Subsetting message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Subsetting.verify|verify} messages.
                     * @param message Subsetting message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISubsetting, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Subsetting message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Subsetting
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Subsetting;

                    /**
                     * Decodes a Subsetting message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Subsetting
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Subsetting;

                    /**
                     * Verifies a Subsetting message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Subsetting message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Subsetting
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Subsetting;

                    /**
                     * Creates a plain object from a Subsetting message. Also converts values to other types if specified.
                     * @param message Subsetting
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Subsetting, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Subsetting to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Subsetting
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Subsetting {

                    /** Policy enum. */
                    enum Policy {
                        UNDEFINED_POLICY = 0,
                        CONSISTENT_HASH_SUBSETTING = 108989492,
                        NONE = 2402104
                    }
                }

                /** Properties of a SuspendInstanceRequest. */
                interface ISuspendInstanceRequest {

                    /** SuspendInstanceRequest instance */
                    instance?: (string|null);

                    /** SuspendInstanceRequest project */
                    project?: (string|null);

                    /** SuspendInstanceRequest requestId */
                    requestId?: (string|null);

                    /** SuspendInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a SuspendInstanceRequest. */
                class SuspendInstanceRequest implements ISuspendInstanceRequest {

                    /**
                     * Constructs a new SuspendInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISuspendInstanceRequest);

                    /** SuspendInstanceRequest instance. */
                    public instance: string;

                    /** SuspendInstanceRequest project. */
                    public project: string;

                    /** SuspendInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** SuspendInstanceRequest zone. */
                    public zone: string;

                    /** SuspendInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SuspendInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SuspendInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISuspendInstanceRequest): google.cloud.compute.v1.SuspendInstanceRequest;

                    /**
                     * Encodes the specified SuspendInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.SuspendInstanceRequest.verify|verify} messages.
                     * @param message SuspendInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISuspendInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SuspendInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SuspendInstanceRequest.verify|verify} messages.
                     * @param message SuspendInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISuspendInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SuspendInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SuspendInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SuspendInstanceRequest;

                    /**
                     * Decodes a SuspendInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SuspendInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SuspendInstanceRequest;

                    /**
                     * Verifies a SuspendInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SuspendInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SuspendInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SuspendInstanceRequest;

                    /**
                     * Creates a plain object from a SuspendInstanceRequest message. Also converts values to other types if specified.
                     * @param message SuspendInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SuspendInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SuspendInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SuspendInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SwitchToCustomModeNetworkRequest. */
                interface ISwitchToCustomModeNetworkRequest {

                    /** SwitchToCustomModeNetworkRequest network */
                    network?: (string|null);

                    /** SwitchToCustomModeNetworkRequest project */
                    project?: (string|null);

                    /** SwitchToCustomModeNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a SwitchToCustomModeNetworkRequest. */
                class SwitchToCustomModeNetworkRequest implements ISwitchToCustomModeNetworkRequest {

                    /**
                     * Constructs a new SwitchToCustomModeNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest);

                    /** SwitchToCustomModeNetworkRequest network. */
                    public network: string;

                    /** SwitchToCustomModeNetworkRequest project. */
                    public project: string;

                    /** SwitchToCustomModeNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** SwitchToCustomModeNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new SwitchToCustomModeNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SwitchToCustomModeNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest): google.cloud.compute.v1.SwitchToCustomModeNetworkRequest;

                    /**
                     * Encodes the specified SwitchToCustomModeNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.SwitchToCustomModeNetworkRequest.verify|verify} messages.
                     * @param message SwitchToCustomModeNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SwitchToCustomModeNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.SwitchToCustomModeNetworkRequest.verify|verify} messages.
                     * @param message SwitchToCustomModeNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SwitchToCustomModeNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SwitchToCustomModeNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.SwitchToCustomModeNetworkRequest;

                    /**
                     * Decodes a SwitchToCustomModeNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SwitchToCustomModeNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.SwitchToCustomModeNetworkRequest;

                    /**
                     * Verifies a SwitchToCustomModeNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SwitchToCustomModeNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SwitchToCustomModeNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.SwitchToCustomModeNetworkRequest;

                    /**
                     * Creates a plain object from a SwitchToCustomModeNetworkRequest message. Also converts values to other types if specified.
                     * @param message SwitchToCustomModeNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.SwitchToCustomModeNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SwitchToCustomModeNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SwitchToCustomModeNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TCPHealthCheck. */
                interface ITCPHealthCheck {

                    /** TCPHealthCheck port */
                    port?: (number|null);

                    /** TCPHealthCheck portName */
                    portName?: (string|null);

                    /** TCPHealthCheck portSpecification */
                    portSpecification?: (string|null);

                    /** TCPHealthCheck proxyHeader */
                    proxyHeader?: (string|null);

                    /** TCPHealthCheck request */
                    request?: (string|null);

                    /** TCPHealthCheck response */
                    response?: (string|null);
                }

                /** Represents a TCPHealthCheck. */
                class TCPHealthCheck implements ITCPHealthCheck {

                    /**
                     * Constructs a new TCPHealthCheck.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITCPHealthCheck);

                    /** TCPHealthCheck port. */
                    public port?: (number|null);

                    /** TCPHealthCheck portName. */
                    public portName?: (string|null);

                    /** TCPHealthCheck portSpecification. */
                    public portSpecification?: (string|null);

                    /** TCPHealthCheck proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** TCPHealthCheck request. */
                    public request?: (string|null);

                    /** TCPHealthCheck response. */
                    public response?: (string|null);

                    /** TCPHealthCheck _port. */
                    public _port?: "port";

                    /** TCPHealthCheck _portName. */
                    public _portName?: "portName";

                    /** TCPHealthCheck _portSpecification. */
                    public _portSpecification?: "portSpecification";

                    /** TCPHealthCheck _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** TCPHealthCheck _request. */
                    public _request?: "request";

                    /** TCPHealthCheck _response. */
                    public _response?: "response";

                    /**
                     * Creates a new TCPHealthCheck instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TCPHealthCheck instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITCPHealthCheck): google.cloud.compute.v1.TCPHealthCheck;

                    /**
                     * Encodes the specified TCPHealthCheck message. Does not implicitly {@link google.cloud.compute.v1.TCPHealthCheck.verify|verify} messages.
                     * @param message TCPHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITCPHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TCPHealthCheck message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TCPHealthCheck.verify|verify} messages.
                     * @param message TCPHealthCheck message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITCPHealthCheck, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TCPHealthCheck message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TCPHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TCPHealthCheck;

                    /**
                     * Decodes a TCPHealthCheck message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TCPHealthCheck
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TCPHealthCheck;

                    /**
                     * Verifies a TCPHealthCheck message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TCPHealthCheck message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TCPHealthCheck
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TCPHealthCheck;

                    /**
                     * Creates a plain object from a TCPHealthCheck message. Also converts values to other types if specified.
                     * @param message TCPHealthCheck
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TCPHealthCheck, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TCPHealthCheck to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TCPHealthCheck
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TCPHealthCheck {

                    /** PortSpecification enum. */
                    enum PortSpecification {
                        UNDEFINED_PORT_SPECIFICATION = 0,
                        USE_FIXED_PORT = 190235748,
                        USE_NAMED_PORT = 349300671,
                        USE_SERVING_PORT = 362637516
                    }

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a Tags. */
                interface ITags {

                    /** Tags fingerprint */
                    fingerprint?: (string|null);

                    /** Tags items */
                    items?: (string[]|null);
                }

                /** Represents a Tags. */
                class Tags implements ITags {

                    /**
                     * Constructs a new Tags.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITags);

                    /** Tags fingerprint. */
                    public fingerprint?: (string|null);

                    /** Tags items. */
                    public items: string[];

                    /** Tags _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /**
                     * Creates a new Tags instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Tags instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITags): google.cloud.compute.v1.Tags;

                    /**
                     * Encodes the specified Tags message. Does not implicitly {@link google.cloud.compute.v1.Tags.verify|verify} messages.
                     * @param message Tags message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITags, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Tags message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Tags.verify|verify} messages.
                     * @param message Tags message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITags, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Tags message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Tags
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Tags;

                    /**
                     * Decodes a Tags message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Tags
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Tags;

                    /**
                     * Verifies a Tags message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Tags message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Tags
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Tags;

                    /**
                     * Creates a plain object from a Tags message. Also converts values to other types if specified.
                     * @param message Tags
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Tags, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Tags to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Tags
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetGrpcProxy. */
                interface ITargetGrpcProxy {

                    /** TargetGrpcProxy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetGrpcProxy description */
                    description?: (string|null);

                    /** TargetGrpcProxy fingerprint */
                    fingerprint?: (string|null);

                    /** TargetGrpcProxy id */
                    id?: (number|Long|string|null);

                    /** TargetGrpcProxy kind */
                    kind?: (string|null);

                    /** TargetGrpcProxy name */
                    name?: (string|null);

                    /** TargetGrpcProxy selfLink */
                    selfLink?: (string|null);

                    /** TargetGrpcProxy selfLinkWithId */
                    selfLinkWithId?: (string|null);

                    /** TargetGrpcProxy urlMap */
                    urlMap?: (string|null);

                    /** TargetGrpcProxy validateForProxyless */
                    validateForProxyless?: (boolean|null);
                }

                /** Represents a TargetGrpcProxy. */
                class TargetGrpcProxy implements ITargetGrpcProxy {

                    /**
                     * Constructs a new TargetGrpcProxy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetGrpcProxy);

                    /** TargetGrpcProxy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetGrpcProxy description. */
                    public description?: (string|null);

                    /** TargetGrpcProxy fingerprint. */
                    public fingerprint?: (string|null);

                    /** TargetGrpcProxy id. */
                    public id?: (number|Long|string|null);

                    /** TargetGrpcProxy kind. */
                    public kind?: (string|null);

                    /** TargetGrpcProxy name. */
                    public name?: (string|null);

                    /** TargetGrpcProxy selfLink. */
                    public selfLink?: (string|null);

                    /** TargetGrpcProxy selfLinkWithId. */
                    public selfLinkWithId?: (string|null);

                    /** TargetGrpcProxy urlMap. */
                    public urlMap?: (string|null);

                    /** TargetGrpcProxy validateForProxyless. */
                    public validateForProxyless?: (boolean|null);

                    /** TargetGrpcProxy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetGrpcProxy _description. */
                    public _description?: "description";

                    /** TargetGrpcProxy _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** TargetGrpcProxy _id. */
                    public _id?: "id";

                    /** TargetGrpcProxy _kind. */
                    public _kind?: "kind";

                    /** TargetGrpcProxy _name. */
                    public _name?: "name";

                    /** TargetGrpcProxy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetGrpcProxy _selfLinkWithId. */
                    public _selfLinkWithId?: "selfLinkWithId";

                    /** TargetGrpcProxy _urlMap. */
                    public _urlMap?: "urlMap";

                    /** TargetGrpcProxy _validateForProxyless. */
                    public _validateForProxyless?: "validateForProxyless";

                    /**
                     * Creates a new TargetGrpcProxy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetGrpcProxy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetGrpcProxy): google.cloud.compute.v1.TargetGrpcProxy;

                    /**
                     * Encodes the specified TargetGrpcProxy message. Does not implicitly {@link google.cloud.compute.v1.TargetGrpcProxy.verify|verify} messages.
                     * @param message TargetGrpcProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetGrpcProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetGrpcProxy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetGrpcProxy.verify|verify} messages.
                     * @param message TargetGrpcProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetGrpcProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetGrpcProxy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetGrpcProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetGrpcProxy;

                    /**
                     * Decodes a TargetGrpcProxy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetGrpcProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetGrpcProxy;

                    /**
                     * Verifies a TargetGrpcProxy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetGrpcProxy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetGrpcProxy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetGrpcProxy;

                    /**
                     * Creates a plain object from a TargetGrpcProxy message. Also converts values to other types if specified.
                     * @param message TargetGrpcProxy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetGrpcProxy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetGrpcProxy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetGrpcProxy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetGrpcProxyList. */
                interface ITargetGrpcProxyList {

                    /** TargetGrpcProxyList id */
                    id?: (string|null);

                    /** TargetGrpcProxyList items */
                    items?: (google.cloud.compute.v1.ITargetGrpcProxy[]|null);

                    /** TargetGrpcProxyList kind */
                    kind?: (string|null);

                    /** TargetGrpcProxyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetGrpcProxyList selfLink */
                    selfLink?: (string|null);

                    /** TargetGrpcProxyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetGrpcProxyList. */
                class TargetGrpcProxyList implements ITargetGrpcProxyList {

                    /**
                     * Constructs a new TargetGrpcProxyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetGrpcProxyList);

                    /** TargetGrpcProxyList id. */
                    public id?: (string|null);

                    /** TargetGrpcProxyList items. */
                    public items: google.cloud.compute.v1.ITargetGrpcProxy[];

                    /** TargetGrpcProxyList kind. */
                    public kind?: (string|null);

                    /** TargetGrpcProxyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetGrpcProxyList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetGrpcProxyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetGrpcProxyList _id. */
                    public _id?: "id";

                    /** TargetGrpcProxyList _kind. */
                    public _kind?: "kind";

                    /** TargetGrpcProxyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetGrpcProxyList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetGrpcProxyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetGrpcProxyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetGrpcProxyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetGrpcProxyList): google.cloud.compute.v1.TargetGrpcProxyList;

                    /**
                     * Encodes the specified TargetGrpcProxyList message. Does not implicitly {@link google.cloud.compute.v1.TargetGrpcProxyList.verify|verify} messages.
                     * @param message TargetGrpcProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetGrpcProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetGrpcProxyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetGrpcProxyList.verify|verify} messages.
                     * @param message TargetGrpcProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetGrpcProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetGrpcProxyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetGrpcProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetGrpcProxyList;

                    /**
                     * Decodes a TargetGrpcProxyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetGrpcProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetGrpcProxyList;

                    /**
                     * Verifies a TargetGrpcProxyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetGrpcProxyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetGrpcProxyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetGrpcProxyList;

                    /**
                     * Creates a plain object from a TargetGrpcProxyList message. Also converts values to other types if specified.
                     * @param message TargetGrpcProxyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetGrpcProxyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetGrpcProxyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetGrpcProxyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpProxiesScopedList. */
                interface ITargetHttpProxiesScopedList {

                    /** TargetHttpProxiesScopedList targetHttpProxies */
                    targetHttpProxies?: (google.cloud.compute.v1.ITargetHttpProxy[]|null);

                    /** TargetHttpProxiesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetHttpProxiesScopedList. */
                class TargetHttpProxiesScopedList implements ITargetHttpProxiesScopedList {

                    /**
                     * Constructs a new TargetHttpProxiesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpProxiesScopedList);

                    /** TargetHttpProxiesScopedList targetHttpProxies. */
                    public targetHttpProxies: google.cloud.compute.v1.ITargetHttpProxy[];

                    /** TargetHttpProxiesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetHttpProxiesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetHttpProxiesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpProxiesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpProxiesScopedList): google.cloud.compute.v1.TargetHttpProxiesScopedList;

                    /**
                     * Encodes the specified TargetHttpProxiesScopedList message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxiesScopedList.verify|verify} messages.
                     * @param message TargetHttpProxiesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpProxiesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpProxiesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxiesScopedList.verify|verify} messages.
                     * @param message TargetHttpProxiesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpProxiesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpProxiesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpProxiesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpProxiesScopedList;

                    /**
                     * Decodes a TargetHttpProxiesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpProxiesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpProxiesScopedList;

                    /**
                     * Verifies a TargetHttpProxiesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpProxiesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpProxiesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpProxiesScopedList;

                    /**
                     * Creates a plain object from a TargetHttpProxiesScopedList message. Also converts values to other types if specified.
                     * @param message TargetHttpProxiesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpProxiesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpProxiesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpProxiesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpProxy. */
                interface ITargetHttpProxy {

                    /** TargetHttpProxy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetHttpProxy description */
                    description?: (string|null);

                    /** TargetHttpProxy fingerprint */
                    fingerprint?: (string|null);

                    /** TargetHttpProxy id */
                    id?: (number|Long|string|null);

                    /** TargetHttpProxy kind */
                    kind?: (string|null);

                    /** TargetHttpProxy name */
                    name?: (string|null);

                    /** TargetHttpProxy proxyBind */
                    proxyBind?: (boolean|null);

                    /** TargetHttpProxy region */
                    region?: (string|null);

                    /** TargetHttpProxy selfLink */
                    selfLink?: (string|null);

                    /** TargetHttpProxy urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a TargetHttpProxy. */
                class TargetHttpProxy implements ITargetHttpProxy {

                    /**
                     * Constructs a new TargetHttpProxy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpProxy);

                    /** TargetHttpProxy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetHttpProxy description. */
                    public description?: (string|null);

                    /** TargetHttpProxy fingerprint. */
                    public fingerprint?: (string|null);

                    /** TargetHttpProxy id. */
                    public id?: (number|Long|string|null);

                    /** TargetHttpProxy kind. */
                    public kind?: (string|null);

                    /** TargetHttpProxy name. */
                    public name?: (string|null);

                    /** TargetHttpProxy proxyBind. */
                    public proxyBind?: (boolean|null);

                    /** TargetHttpProxy region. */
                    public region?: (string|null);

                    /** TargetHttpProxy selfLink. */
                    public selfLink?: (string|null);

                    /** TargetHttpProxy urlMap. */
                    public urlMap?: (string|null);

                    /** TargetHttpProxy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetHttpProxy _description. */
                    public _description?: "description";

                    /** TargetHttpProxy _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** TargetHttpProxy _id. */
                    public _id?: "id";

                    /** TargetHttpProxy _kind. */
                    public _kind?: "kind";

                    /** TargetHttpProxy _name. */
                    public _name?: "name";

                    /** TargetHttpProxy _proxyBind. */
                    public _proxyBind?: "proxyBind";

                    /** TargetHttpProxy _region. */
                    public _region?: "region";

                    /** TargetHttpProxy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetHttpProxy _urlMap. */
                    public _urlMap?: "urlMap";

                    /**
                     * Creates a new TargetHttpProxy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpProxy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpProxy): google.cloud.compute.v1.TargetHttpProxy;

                    /**
                     * Encodes the specified TargetHttpProxy message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxy.verify|verify} messages.
                     * @param message TargetHttpProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpProxy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxy.verify|verify} messages.
                     * @param message TargetHttpProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpProxy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpProxy;

                    /**
                     * Decodes a TargetHttpProxy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpProxy;

                    /**
                     * Verifies a TargetHttpProxy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpProxy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpProxy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpProxy;

                    /**
                     * Creates a plain object from a TargetHttpProxy message. Also converts values to other types if specified.
                     * @param message TargetHttpProxy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpProxy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpProxy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpProxy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpProxyAggregatedList. */
                interface ITargetHttpProxyAggregatedList {

                    /** TargetHttpProxyAggregatedList id */
                    id?: (string|null);

                    /** TargetHttpProxyAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ITargetHttpProxiesScopedList }|null);

                    /** TargetHttpProxyAggregatedList kind */
                    kind?: (string|null);

                    /** TargetHttpProxyAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetHttpProxyAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** TargetHttpProxyAggregatedList unreachables */
                    unreachables?: (string[]|null);
                }

                /** Represents a TargetHttpProxyAggregatedList. */
                class TargetHttpProxyAggregatedList implements ITargetHttpProxyAggregatedList {

                    /**
                     * Constructs a new TargetHttpProxyAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpProxyAggregatedList);

                    /** TargetHttpProxyAggregatedList id. */
                    public id?: (string|null);

                    /** TargetHttpProxyAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ITargetHttpProxiesScopedList };

                    /** TargetHttpProxyAggregatedList kind. */
                    public kind?: (string|null);

                    /** TargetHttpProxyAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetHttpProxyAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetHttpProxyAggregatedList unreachables. */
                    public unreachables: string[];

                    /** TargetHttpProxyAggregatedList _id. */
                    public _id?: "id";

                    /** TargetHttpProxyAggregatedList _kind. */
                    public _kind?: "kind";

                    /** TargetHttpProxyAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetHttpProxyAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new TargetHttpProxyAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpProxyAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpProxyAggregatedList): google.cloud.compute.v1.TargetHttpProxyAggregatedList;

                    /**
                     * Encodes the specified TargetHttpProxyAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxyAggregatedList.verify|verify} messages.
                     * @param message TargetHttpProxyAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpProxyAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpProxyAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxyAggregatedList.verify|verify} messages.
                     * @param message TargetHttpProxyAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpProxyAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpProxyAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpProxyAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpProxyAggregatedList;

                    /**
                     * Decodes a TargetHttpProxyAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpProxyAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpProxyAggregatedList;

                    /**
                     * Verifies a TargetHttpProxyAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpProxyAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpProxyAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpProxyAggregatedList;

                    /**
                     * Creates a plain object from a TargetHttpProxyAggregatedList message. Also converts values to other types if specified.
                     * @param message TargetHttpProxyAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpProxyAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpProxyAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpProxyAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpProxyList. */
                interface ITargetHttpProxyList {

                    /** TargetHttpProxyList id */
                    id?: (string|null);

                    /** TargetHttpProxyList items */
                    items?: (google.cloud.compute.v1.ITargetHttpProxy[]|null);

                    /** TargetHttpProxyList kind */
                    kind?: (string|null);

                    /** TargetHttpProxyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetHttpProxyList selfLink */
                    selfLink?: (string|null);

                    /** TargetHttpProxyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetHttpProxyList. */
                class TargetHttpProxyList implements ITargetHttpProxyList {

                    /**
                     * Constructs a new TargetHttpProxyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpProxyList);

                    /** TargetHttpProxyList id. */
                    public id?: (string|null);

                    /** TargetHttpProxyList items. */
                    public items: google.cloud.compute.v1.ITargetHttpProxy[];

                    /** TargetHttpProxyList kind. */
                    public kind?: (string|null);

                    /** TargetHttpProxyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetHttpProxyList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetHttpProxyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetHttpProxyList _id. */
                    public _id?: "id";

                    /** TargetHttpProxyList _kind. */
                    public _kind?: "kind";

                    /** TargetHttpProxyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetHttpProxyList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetHttpProxyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetHttpProxyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpProxyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpProxyList): google.cloud.compute.v1.TargetHttpProxyList;

                    /**
                     * Encodes the specified TargetHttpProxyList message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxyList.verify|verify} messages.
                     * @param message TargetHttpProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpProxyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpProxyList.verify|verify} messages.
                     * @param message TargetHttpProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpProxyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpProxyList;

                    /**
                     * Decodes a TargetHttpProxyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpProxyList;

                    /**
                     * Verifies a TargetHttpProxyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpProxyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpProxyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpProxyList;

                    /**
                     * Creates a plain object from a TargetHttpProxyList message. Also converts values to other types if specified.
                     * @param message TargetHttpProxyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpProxyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpProxyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpProxyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpsProxiesScopedList. */
                interface ITargetHttpsProxiesScopedList {

                    /** TargetHttpsProxiesScopedList targetHttpsProxies */
                    targetHttpsProxies?: (google.cloud.compute.v1.ITargetHttpsProxy[]|null);

                    /** TargetHttpsProxiesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetHttpsProxiesScopedList. */
                class TargetHttpsProxiesScopedList implements ITargetHttpsProxiesScopedList {

                    /**
                     * Constructs a new TargetHttpsProxiesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxiesScopedList);

                    /** TargetHttpsProxiesScopedList targetHttpsProxies. */
                    public targetHttpsProxies: google.cloud.compute.v1.ITargetHttpsProxy[];

                    /** TargetHttpsProxiesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetHttpsProxiesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetHttpsProxiesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxiesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxiesScopedList): google.cloud.compute.v1.TargetHttpsProxiesScopedList;

                    /**
                     * Encodes the specified TargetHttpsProxiesScopedList message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesScopedList.verify|verify} messages.
                     * @param message TargetHttpsProxiesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxiesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxiesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesScopedList.verify|verify} messages.
                     * @param message TargetHttpsProxiesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxiesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxiesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxiesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxiesScopedList;

                    /**
                     * Decodes a TargetHttpsProxiesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxiesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxiesScopedList;

                    /**
                     * Verifies a TargetHttpsProxiesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxiesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxiesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxiesScopedList;

                    /**
                     * Creates a plain object from a TargetHttpsProxiesScopedList message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxiesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxiesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxiesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxiesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpsProxiesSetCertificateMapRequest. */
                interface ITargetHttpsProxiesSetCertificateMapRequest {

                    /** TargetHttpsProxiesSetCertificateMapRequest certificateMap */
                    certificateMap?: (string|null);
                }

                /** Represents a TargetHttpsProxiesSetCertificateMapRequest. */
                class TargetHttpsProxiesSetCertificateMapRequest implements ITargetHttpsProxiesSetCertificateMapRequest {

                    /**
                     * Constructs a new TargetHttpsProxiesSetCertificateMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxiesSetCertificateMapRequest);

                    /** TargetHttpsProxiesSetCertificateMapRequest certificateMap. */
                    public certificateMap?: (string|null);

                    /** TargetHttpsProxiesSetCertificateMapRequest _certificateMap. */
                    public _certificateMap?: "certificateMap";

                    /**
                     * Creates a new TargetHttpsProxiesSetCertificateMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxiesSetCertificateMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxiesSetCertificateMapRequest): google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest;

                    /**
                     * Encodes the specified TargetHttpsProxiesSetCertificateMapRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest.verify|verify} messages.
                     * @param message TargetHttpsProxiesSetCertificateMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxiesSetCertificateMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxiesSetCertificateMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest.verify|verify} messages.
                     * @param message TargetHttpsProxiesSetCertificateMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxiesSetCertificateMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxiesSetCertificateMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxiesSetCertificateMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest;

                    /**
                     * Decodes a TargetHttpsProxiesSetCertificateMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxiesSetCertificateMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest;

                    /**
                     * Verifies a TargetHttpsProxiesSetCertificateMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxiesSetCertificateMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxiesSetCertificateMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest;

                    /**
                     * Creates a plain object from a TargetHttpsProxiesSetCertificateMapRequest message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxiesSetCertificateMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxiesSetCertificateMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxiesSetCertificateMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxiesSetCertificateMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpsProxiesSetQuicOverrideRequest. */
                interface ITargetHttpsProxiesSetQuicOverrideRequest {

                    /** TargetHttpsProxiesSetQuicOverrideRequest quicOverride */
                    quicOverride?: (string|null);
                }

                /** Represents a TargetHttpsProxiesSetQuicOverrideRequest. */
                class TargetHttpsProxiesSetQuicOverrideRequest implements ITargetHttpsProxiesSetQuicOverrideRequest {

                    /**
                     * Constructs a new TargetHttpsProxiesSetQuicOverrideRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxiesSetQuicOverrideRequest);

                    /** TargetHttpsProxiesSetQuicOverrideRequest quicOverride. */
                    public quicOverride?: (string|null);

                    /** TargetHttpsProxiesSetQuicOverrideRequest _quicOverride. */
                    public _quicOverride?: "quicOverride";

                    /**
                     * Creates a new TargetHttpsProxiesSetQuicOverrideRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxiesSetQuicOverrideRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxiesSetQuicOverrideRequest): google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest;

                    /**
                     * Encodes the specified TargetHttpsProxiesSetQuicOverrideRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest.verify|verify} messages.
                     * @param message TargetHttpsProxiesSetQuicOverrideRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxiesSetQuicOverrideRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxiesSetQuicOverrideRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest.verify|verify} messages.
                     * @param message TargetHttpsProxiesSetQuicOverrideRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxiesSetQuicOverrideRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxiesSetQuicOverrideRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxiesSetQuicOverrideRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest;

                    /**
                     * Decodes a TargetHttpsProxiesSetQuicOverrideRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxiesSetQuicOverrideRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest;

                    /**
                     * Verifies a TargetHttpsProxiesSetQuicOverrideRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxiesSetQuicOverrideRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxiesSetQuicOverrideRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest;

                    /**
                     * Creates a plain object from a TargetHttpsProxiesSetQuicOverrideRequest message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxiesSetQuicOverrideRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxiesSetQuicOverrideRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxiesSetQuicOverrideRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxiesSetQuicOverrideRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetHttpsProxiesSetQuicOverrideRequest {

                    /** QuicOverride enum. */
                    enum QuicOverride {
                        UNDEFINED_QUIC_OVERRIDE = 0,
                        DISABLE = 241807048,
                        ENABLE = 438835587,
                        NONE = 2402104
                    }
                }

                /** Properties of a TargetHttpsProxiesSetSslCertificatesRequest. */
                interface ITargetHttpsProxiesSetSslCertificatesRequest {

                    /** TargetHttpsProxiesSetSslCertificatesRequest sslCertificates */
                    sslCertificates?: (string[]|null);
                }

                /** Represents a TargetHttpsProxiesSetSslCertificatesRequest. */
                class TargetHttpsProxiesSetSslCertificatesRequest implements ITargetHttpsProxiesSetSslCertificatesRequest {

                    /**
                     * Constructs a new TargetHttpsProxiesSetSslCertificatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxiesSetSslCertificatesRequest);

                    /** TargetHttpsProxiesSetSslCertificatesRequest sslCertificates. */
                    public sslCertificates: string[];

                    /**
                     * Creates a new TargetHttpsProxiesSetSslCertificatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxiesSetSslCertificatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxiesSetSslCertificatesRequest): google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Encodes the specified TargetHttpsProxiesSetSslCertificatesRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest.verify|verify} messages.
                     * @param message TargetHttpsProxiesSetSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxiesSetSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxiesSetSslCertificatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest.verify|verify} messages.
                     * @param message TargetHttpsProxiesSetSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxiesSetSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxiesSetSslCertificatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxiesSetSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Decodes a TargetHttpsProxiesSetSslCertificatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxiesSetSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Verifies a TargetHttpsProxiesSetSslCertificatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxiesSetSslCertificatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxiesSetSslCertificatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest;

                    /**
                     * Creates a plain object from a TargetHttpsProxiesSetSslCertificatesRequest message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxiesSetSslCertificatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxiesSetSslCertificatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxiesSetSslCertificatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxiesSetSslCertificatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpsProxy. */
                interface ITargetHttpsProxy {

                    /** TargetHttpsProxy authorizationPolicy */
                    authorizationPolicy?: (string|null);

                    /** TargetHttpsProxy certificateMap */
                    certificateMap?: (string|null);

                    /** TargetHttpsProxy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetHttpsProxy description */
                    description?: (string|null);

                    /** TargetHttpsProxy fingerprint */
                    fingerprint?: (string|null);

                    /** TargetHttpsProxy id */
                    id?: (number|Long|string|null);

                    /** TargetHttpsProxy kind */
                    kind?: (string|null);

                    /** TargetHttpsProxy name */
                    name?: (string|null);

                    /** TargetHttpsProxy proxyBind */
                    proxyBind?: (boolean|null);

                    /** TargetHttpsProxy quicOverride */
                    quicOverride?: (string|null);

                    /** TargetHttpsProxy region */
                    region?: (string|null);

                    /** TargetHttpsProxy selfLink */
                    selfLink?: (string|null);

                    /** TargetHttpsProxy serverTlsPolicy */
                    serverTlsPolicy?: (string|null);

                    /** TargetHttpsProxy sslCertificates */
                    sslCertificates?: (string[]|null);

                    /** TargetHttpsProxy sslPolicy */
                    sslPolicy?: (string|null);

                    /** TargetHttpsProxy urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a TargetHttpsProxy. */
                class TargetHttpsProxy implements ITargetHttpsProxy {

                    /**
                     * Constructs a new TargetHttpsProxy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxy);

                    /** TargetHttpsProxy authorizationPolicy. */
                    public authorizationPolicy?: (string|null);

                    /** TargetHttpsProxy certificateMap. */
                    public certificateMap?: (string|null);

                    /** TargetHttpsProxy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetHttpsProxy description. */
                    public description?: (string|null);

                    /** TargetHttpsProxy fingerprint. */
                    public fingerprint?: (string|null);

                    /** TargetHttpsProxy id. */
                    public id?: (number|Long|string|null);

                    /** TargetHttpsProxy kind. */
                    public kind?: (string|null);

                    /** TargetHttpsProxy name. */
                    public name?: (string|null);

                    /** TargetHttpsProxy proxyBind. */
                    public proxyBind?: (boolean|null);

                    /** TargetHttpsProxy quicOverride. */
                    public quicOverride?: (string|null);

                    /** TargetHttpsProxy region. */
                    public region?: (string|null);

                    /** TargetHttpsProxy selfLink. */
                    public selfLink?: (string|null);

                    /** TargetHttpsProxy serverTlsPolicy. */
                    public serverTlsPolicy?: (string|null);

                    /** TargetHttpsProxy sslCertificates. */
                    public sslCertificates: string[];

                    /** TargetHttpsProxy sslPolicy. */
                    public sslPolicy?: (string|null);

                    /** TargetHttpsProxy urlMap. */
                    public urlMap?: (string|null);

                    /** TargetHttpsProxy _authorizationPolicy. */
                    public _authorizationPolicy?: "authorizationPolicy";

                    /** TargetHttpsProxy _certificateMap. */
                    public _certificateMap?: "certificateMap";

                    /** TargetHttpsProxy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetHttpsProxy _description. */
                    public _description?: "description";

                    /** TargetHttpsProxy _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** TargetHttpsProxy _id. */
                    public _id?: "id";

                    /** TargetHttpsProxy _kind. */
                    public _kind?: "kind";

                    /** TargetHttpsProxy _name. */
                    public _name?: "name";

                    /** TargetHttpsProxy _proxyBind. */
                    public _proxyBind?: "proxyBind";

                    /** TargetHttpsProxy _quicOverride. */
                    public _quicOverride?: "quicOverride";

                    /** TargetHttpsProxy _region. */
                    public _region?: "region";

                    /** TargetHttpsProxy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetHttpsProxy _serverTlsPolicy. */
                    public _serverTlsPolicy?: "serverTlsPolicy";

                    /** TargetHttpsProxy _sslPolicy. */
                    public _sslPolicy?: "sslPolicy";

                    /** TargetHttpsProxy _urlMap. */
                    public _urlMap?: "urlMap";

                    /**
                     * Creates a new TargetHttpsProxy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxy): google.cloud.compute.v1.TargetHttpsProxy;

                    /**
                     * Encodes the specified TargetHttpsProxy message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxy.verify|verify} messages.
                     * @param message TargetHttpsProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxy.verify|verify} messages.
                     * @param message TargetHttpsProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxy;

                    /**
                     * Decodes a TargetHttpsProxy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxy;

                    /**
                     * Verifies a TargetHttpsProxy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxy;

                    /**
                     * Creates a plain object from a TargetHttpsProxy message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetHttpsProxy {

                    /** QuicOverride enum. */
                    enum QuicOverride {
                        UNDEFINED_QUIC_OVERRIDE = 0,
                        DISABLE = 241807048,
                        ENABLE = 438835587,
                        NONE = 2402104
                    }
                }

                /** Properties of a TargetHttpsProxyAggregatedList. */
                interface ITargetHttpsProxyAggregatedList {

                    /** TargetHttpsProxyAggregatedList id */
                    id?: (string|null);

                    /** TargetHttpsProxyAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ITargetHttpsProxiesScopedList }|null);

                    /** TargetHttpsProxyAggregatedList kind */
                    kind?: (string|null);

                    /** TargetHttpsProxyAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetHttpsProxyAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** TargetHttpsProxyAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** TargetHttpsProxyAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetHttpsProxyAggregatedList. */
                class TargetHttpsProxyAggregatedList implements ITargetHttpsProxyAggregatedList {

                    /**
                     * Constructs a new TargetHttpsProxyAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxyAggregatedList);

                    /** TargetHttpsProxyAggregatedList id. */
                    public id?: (string|null);

                    /** TargetHttpsProxyAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ITargetHttpsProxiesScopedList };

                    /** TargetHttpsProxyAggregatedList kind. */
                    public kind?: (string|null);

                    /** TargetHttpsProxyAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetHttpsProxyAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetHttpsProxyAggregatedList unreachables. */
                    public unreachables: string[];

                    /** TargetHttpsProxyAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetHttpsProxyAggregatedList _id. */
                    public _id?: "id";

                    /** TargetHttpsProxyAggregatedList _kind. */
                    public _kind?: "kind";

                    /** TargetHttpsProxyAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetHttpsProxyAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetHttpsProxyAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetHttpsProxyAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxyAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxyAggregatedList): google.cloud.compute.v1.TargetHttpsProxyAggregatedList;

                    /**
                     * Encodes the specified TargetHttpsProxyAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxyAggregatedList.verify|verify} messages.
                     * @param message TargetHttpsProxyAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxyAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxyAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxyAggregatedList.verify|verify} messages.
                     * @param message TargetHttpsProxyAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxyAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxyAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxyAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxyAggregatedList;

                    /**
                     * Decodes a TargetHttpsProxyAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxyAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxyAggregatedList;

                    /**
                     * Verifies a TargetHttpsProxyAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxyAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxyAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxyAggregatedList;

                    /**
                     * Creates a plain object from a TargetHttpsProxyAggregatedList message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxyAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxyAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxyAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxyAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetHttpsProxyList. */
                interface ITargetHttpsProxyList {

                    /** TargetHttpsProxyList id */
                    id?: (string|null);

                    /** TargetHttpsProxyList items */
                    items?: (google.cloud.compute.v1.ITargetHttpsProxy[]|null);

                    /** TargetHttpsProxyList kind */
                    kind?: (string|null);

                    /** TargetHttpsProxyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetHttpsProxyList selfLink */
                    selfLink?: (string|null);

                    /** TargetHttpsProxyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetHttpsProxyList. */
                class TargetHttpsProxyList implements ITargetHttpsProxyList {

                    /**
                     * Constructs a new TargetHttpsProxyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetHttpsProxyList);

                    /** TargetHttpsProxyList id. */
                    public id?: (string|null);

                    /** TargetHttpsProxyList items. */
                    public items: google.cloud.compute.v1.ITargetHttpsProxy[];

                    /** TargetHttpsProxyList kind. */
                    public kind?: (string|null);

                    /** TargetHttpsProxyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetHttpsProxyList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetHttpsProxyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetHttpsProxyList _id. */
                    public _id?: "id";

                    /** TargetHttpsProxyList _kind. */
                    public _kind?: "kind";

                    /** TargetHttpsProxyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetHttpsProxyList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetHttpsProxyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetHttpsProxyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetHttpsProxyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetHttpsProxyList): google.cloud.compute.v1.TargetHttpsProxyList;

                    /**
                     * Encodes the specified TargetHttpsProxyList message. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxyList.verify|verify} messages.
                     * @param message TargetHttpsProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetHttpsProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetHttpsProxyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetHttpsProxyList.verify|verify} messages.
                     * @param message TargetHttpsProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetHttpsProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetHttpsProxyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetHttpsProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetHttpsProxyList;

                    /**
                     * Decodes a TargetHttpsProxyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetHttpsProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetHttpsProxyList;

                    /**
                     * Verifies a TargetHttpsProxyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetHttpsProxyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetHttpsProxyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetHttpsProxyList;

                    /**
                     * Creates a plain object from a TargetHttpsProxyList message. Also converts values to other types if specified.
                     * @param message TargetHttpsProxyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetHttpsProxyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetHttpsProxyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetHttpsProxyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetInstance. */
                interface ITargetInstance {

                    /** TargetInstance creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetInstance description */
                    description?: (string|null);

                    /** TargetInstance id */
                    id?: (number|Long|string|null);

                    /** TargetInstance instance */
                    instance?: (string|null);

                    /** TargetInstance kind */
                    kind?: (string|null);

                    /** TargetInstance name */
                    name?: (string|null);

                    /** TargetInstance natPolicy */
                    natPolicy?: (string|null);

                    /** TargetInstance network */
                    network?: (string|null);

                    /** TargetInstance selfLink */
                    selfLink?: (string|null);

                    /** TargetInstance zone */
                    zone?: (string|null);
                }

                /** Represents a TargetInstance. */
                class TargetInstance implements ITargetInstance {

                    /**
                     * Constructs a new TargetInstance.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetInstance);

                    /** TargetInstance creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetInstance description. */
                    public description?: (string|null);

                    /** TargetInstance id. */
                    public id?: (number|Long|string|null);

                    /** TargetInstance instance. */
                    public instance?: (string|null);

                    /** TargetInstance kind. */
                    public kind?: (string|null);

                    /** TargetInstance name. */
                    public name?: (string|null);

                    /** TargetInstance natPolicy. */
                    public natPolicy?: (string|null);

                    /** TargetInstance network. */
                    public network?: (string|null);

                    /** TargetInstance selfLink. */
                    public selfLink?: (string|null);

                    /** TargetInstance zone. */
                    public zone?: (string|null);

                    /** TargetInstance _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetInstance _description. */
                    public _description?: "description";

                    /** TargetInstance _id. */
                    public _id?: "id";

                    /** TargetInstance _instance. */
                    public _instance?: "instance";

                    /** TargetInstance _kind. */
                    public _kind?: "kind";

                    /** TargetInstance _name. */
                    public _name?: "name";

                    /** TargetInstance _natPolicy. */
                    public _natPolicy?: "natPolicy";

                    /** TargetInstance _network. */
                    public _network?: "network";

                    /** TargetInstance _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetInstance _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new TargetInstance instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetInstance instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetInstance): google.cloud.compute.v1.TargetInstance;

                    /**
                     * Encodes the specified TargetInstance message. Does not implicitly {@link google.cloud.compute.v1.TargetInstance.verify|verify} messages.
                     * @param message TargetInstance message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetInstance, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetInstance message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetInstance.verify|verify} messages.
                     * @param message TargetInstance message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetInstance, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetInstance message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetInstance
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetInstance;

                    /**
                     * Decodes a TargetInstance message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetInstance
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetInstance;

                    /**
                     * Verifies a TargetInstance message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetInstance message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetInstance
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetInstance;

                    /**
                     * Creates a plain object from a TargetInstance message. Also converts values to other types if specified.
                     * @param message TargetInstance
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetInstance, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetInstance to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetInstance
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetInstance {

                    /** NatPolicy enum. */
                    enum NatPolicy {
                        UNDEFINED_NAT_POLICY = 0,
                        NO_NAT = 161455491
                    }
                }

                /** Properties of a TargetInstanceAggregatedList. */
                interface ITargetInstanceAggregatedList {

                    /** TargetInstanceAggregatedList id */
                    id?: (string|null);

                    /** TargetInstanceAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ITargetInstancesScopedList }|null);

                    /** TargetInstanceAggregatedList kind */
                    kind?: (string|null);

                    /** TargetInstanceAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetInstanceAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** TargetInstanceAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** TargetInstanceAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetInstanceAggregatedList. */
                class TargetInstanceAggregatedList implements ITargetInstanceAggregatedList {

                    /**
                     * Constructs a new TargetInstanceAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetInstanceAggregatedList);

                    /** TargetInstanceAggregatedList id. */
                    public id?: (string|null);

                    /** TargetInstanceAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ITargetInstancesScopedList };

                    /** TargetInstanceAggregatedList kind. */
                    public kind?: (string|null);

                    /** TargetInstanceAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetInstanceAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetInstanceAggregatedList unreachables. */
                    public unreachables: string[];

                    /** TargetInstanceAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetInstanceAggregatedList _id. */
                    public _id?: "id";

                    /** TargetInstanceAggregatedList _kind. */
                    public _kind?: "kind";

                    /** TargetInstanceAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetInstanceAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetInstanceAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetInstanceAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetInstanceAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetInstanceAggregatedList): google.cloud.compute.v1.TargetInstanceAggregatedList;

                    /**
                     * Encodes the specified TargetInstanceAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.TargetInstanceAggregatedList.verify|verify} messages.
                     * @param message TargetInstanceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetInstanceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetInstanceAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetInstanceAggregatedList.verify|verify} messages.
                     * @param message TargetInstanceAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetInstanceAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetInstanceAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetInstanceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetInstanceAggregatedList;

                    /**
                     * Decodes a TargetInstanceAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetInstanceAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetInstanceAggregatedList;

                    /**
                     * Verifies a TargetInstanceAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetInstanceAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetInstanceAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetInstanceAggregatedList;

                    /**
                     * Creates a plain object from a TargetInstanceAggregatedList message. Also converts values to other types if specified.
                     * @param message TargetInstanceAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetInstanceAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetInstanceAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetInstanceAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetInstanceList. */
                interface ITargetInstanceList {

                    /** TargetInstanceList id */
                    id?: (string|null);

                    /** TargetInstanceList items */
                    items?: (google.cloud.compute.v1.ITargetInstance[]|null);

                    /** TargetInstanceList kind */
                    kind?: (string|null);

                    /** TargetInstanceList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetInstanceList selfLink */
                    selfLink?: (string|null);

                    /** TargetInstanceList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetInstanceList. */
                class TargetInstanceList implements ITargetInstanceList {

                    /**
                     * Constructs a new TargetInstanceList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetInstanceList);

                    /** TargetInstanceList id. */
                    public id?: (string|null);

                    /** TargetInstanceList items. */
                    public items: google.cloud.compute.v1.ITargetInstance[];

                    /** TargetInstanceList kind. */
                    public kind?: (string|null);

                    /** TargetInstanceList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetInstanceList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetInstanceList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetInstanceList _id. */
                    public _id?: "id";

                    /** TargetInstanceList _kind. */
                    public _kind?: "kind";

                    /** TargetInstanceList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetInstanceList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetInstanceList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetInstanceList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetInstanceList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetInstanceList): google.cloud.compute.v1.TargetInstanceList;

                    /**
                     * Encodes the specified TargetInstanceList message. Does not implicitly {@link google.cloud.compute.v1.TargetInstanceList.verify|verify} messages.
                     * @param message TargetInstanceList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetInstanceList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetInstanceList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetInstanceList.verify|verify} messages.
                     * @param message TargetInstanceList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetInstanceList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetInstanceList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetInstanceList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetInstanceList;

                    /**
                     * Decodes a TargetInstanceList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetInstanceList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetInstanceList;

                    /**
                     * Verifies a TargetInstanceList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetInstanceList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetInstanceList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetInstanceList;

                    /**
                     * Creates a plain object from a TargetInstanceList message. Also converts values to other types if specified.
                     * @param message TargetInstanceList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetInstanceList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetInstanceList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetInstanceList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetInstancesScopedList. */
                interface ITargetInstancesScopedList {

                    /** TargetInstancesScopedList targetInstances */
                    targetInstances?: (google.cloud.compute.v1.ITargetInstance[]|null);

                    /** TargetInstancesScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetInstancesScopedList. */
                class TargetInstancesScopedList implements ITargetInstancesScopedList {

                    /**
                     * Constructs a new TargetInstancesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetInstancesScopedList);

                    /** TargetInstancesScopedList targetInstances. */
                    public targetInstances: google.cloud.compute.v1.ITargetInstance[];

                    /** TargetInstancesScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetInstancesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetInstancesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetInstancesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetInstancesScopedList): google.cloud.compute.v1.TargetInstancesScopedList;

                    /**
                     * Encodes the specified TargetInstancesScopedList message. Does not implicitly {@link google.cloud.compute.v1.TargetInstancesScopedList.verify|verify} messages.
                     * @param message TargetInstancesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetInstancesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetInstancesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetInstancesScopedList.verify|verify} messages.
                     * @param message TargetInstancesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetInstancesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetInstancesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetInstancesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetInstancesScopedList;

                    /**
                     * Decodes a TargetInstancesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetInstancesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetInstancesScopedList;

                    /**
                     * Verifies a TargetInstancesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetInstancesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetInstancesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetInstancesScopedList;

                    /**
                     * Creates a plain object from a TargetInstancesScopedList message. Also converts values to other types if specified.
                     * @param message TargetInstancesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetInstancesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetInstancesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetInstancesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPool. */
                interface ITargetPool {

                    /** TargetPool backupPool */
                    backupPool?: (string|null);

                    /** TargetPool creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetPool description */
                    description?: (string|null);

                    /** TargetPool failoverRatio */
                    failoverRatio?: (number|null);

                    /** TargetPool healthChecks */
                    healthChecks?: (string[]|null);

                    /** TargetPool id */
                    id?: (number|Long|string|null);

                    /** TargetPool instances */
                    instances?: (string[]|null);

                    /** TargetPool kind */
                    kind?: (string|null);

                    /** TargetPool name */
                    name?: (string|null);

                    /** TargetPool region */
                    region?: (string|null);

                    /** TargetPool selfLink */
                    selfLink?: (string|null);

                    /** TargetPool sessionAffinity */
                    sessionAffinity?: (string|null);
                }

                /** Represents a TargetPool. */
                class TargetPool implements ITargetPool {

                    /**
                     * Constructs a new TargetPool.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPool);

                    /** TargetPool backupPool. */
                    public backupPool?: (string|null);

                    /** TargetPool creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetPool description. */
                    public description?: (string|null);

                    /** TargetPool failoverRatio. */
                    public failoverRatio?: (number|null);

                    /** TargetPool healthChecks. */
                    public healthChecks: string[];

                    /** TargetPool id. */
                    public id?: (number|Long|string|null);

                    /** TargetPool instances. */
                    public instances: string[];

                    /** TargetPool kind. */
                    public kind?: (string|null);

                    /** TargetPool name. */
                    public name?: (string|null);

                    /** TargetPool region. */
                    public region?: (string|null);

                    /** TargetPool selfLink. */
                    public selfLink?: (string|null);

                    /** TargetPool sessionAffinity. */
                    public sessionAffinity?: (string|null);

                    /** TargetPool _backupPool. */
                    public _backupPool?: "backupPool";

                    /** TargetPool _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetPool _description. */
                    public _description?: "description";

                    /** TargetPool _failoverRatio. */
                    public _failoverRatio?: "failoverRatio";

                    /** TargetPool _id. */
                    public _id?: "id";

                    /** TargetPool _kind. */
                    public _kind?: "kind";

                    /** TargetPool _name. */
                    public _name?: "name";

                    /** TargetPool _region. */
                    public _region?: "region";

                    /** TargetPool _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetPool _sessionAffinity. */
                    public _sessionAffinity?: "sessionAffinity";

                    /**
                     * Creates a new TargetPool instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPool instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPool): google.cloud.compute.v1.TargetPool;

                    /**
                     * Encodes the specified TargetPool message. Does not implicitly {@link google.cloud.compute.v1.TargetPool.verify|verify} messages.
                     * @param message TargetPool message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPool, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPool message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPool.verify|verify} messages.
                     * @param message TargetPool message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPool, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPool message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPool
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPool;

                    /**
                     * Decodes a TargetPool message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPool
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPool;

                    /**
                     * Verifies a TargetPool message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPool message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPool
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPool;

                    /**
                     * Creates a plain object from a TargetPool message. Also converts values to other types if specified.
                     * @param message TargetPool
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPool, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPool to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPool
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetPool {

                    /** SessionAffinity enum. */
                    enum SessionAffinity {
                        UNDEFINED_SESSION_AFFINITY = 0,
                        CLIENT_IP = 345665051,
                        CLIENT_IP_NO_DESTINATION = 106122516,
                        CLIENT_IP_PORT_PROTO = 221722926,
                        CLIENT_IP_PROTO = 25322148,
                        GENERATED_COOKIE = 370321204,
                        HEADER_FIELD = 200737960,
                        HTTP_COOKIE = 494981627,
                        NONE = 2402104
                    }
                }

                /** Properties of a TargetPoolAggregatedList. */
                interface ITargetPoolAggregatedList {

                    /** TargetPoolAggregatedList id */
                    id?: (string|null);

                    /** TargetPoolAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ITargetPoolsScopedList }|null);

                    /** TargetPoolAggregatedList kind */
                    kind?: (string|null);

                    /** TargetPoolAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetPoolAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** TargetPoolAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** TargetPoolAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetPoolAggregatedList. */
                class TargetPoolAggregatedList implements ITargetPoolAggregatedList {

                    /**
                     * Constructs a new TargetPoolAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolAggregatedList);

                    /** TargetPoolAggregatedList id. */
                    public id?: (string|null);

                    /** TargetPoolAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ITargetPoolsScopedList };

                    /** TargetPoolAggregatedList kind. */
                    public kind?: (string|null);

                    /** TargetPoolAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetPoolAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetPoolAggregatedList unreachables. */
                    public unreachables: string[];

                    /** TargetPoolAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetPoolAggregatedList _id. */
                    public _id?: "id";

                    /** TargetPoolAggregatedList _kind. */
                    public _kind?: "kind";

                    /** TargetPoolAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetPoolAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetPoolAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetPoolAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolAggregatedList): google.cloud.compute.v1.TargetPoolAggregatedList;

                    /**
                     * Encodes the specified TargetPoolAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolAggregatedList.verify|verify} messages.
                     * @param message TargetPoolAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolAggregatedList.verify|verify} messages.
                     * @param message TargetPoolAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolAggregatedList;

                    /**
                     * Decodes a TargetPoolAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolAggregatedList;

                    /**
                     * Verifies a TargetPoolAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolAggregatedList;

                    /**
                     * Creates a plain object from a TargetPoolAggregatedList message. Also converts values to other types if specified.
                     * @param message TargetPoolAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolInstanceHealth. */
                interface ITargetPoolInstanceHealth {

                    /** TargetPoolInstanceHealth healthStatus */
                    healthStatus?: (google.cloud.compute.v1.IHealthStatus[]|null);

                    /** TargetPoolInstanceHealth kind */
                    kind?: (string|null);
                }

                /** Represents a TargetPoolInstanceHealth. */
                class TargetPoolInstanceHealth implements ITargetPoolInstanceHealth {

                    /**
                     * Constructs a new TargetPoolInstanceHealth.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolInstanceHealth);

                    /** TargetPoolInstanceHealth healthStatus. */
                    public healthStatus: google.cloud.compute.v1.IHealthStatus[];

                    /** TargetPoolInstanceHealth kind. */
                    public kind?: (string|null);

                    /** TargetPoolInstanceHealth _kind. */
                    public _kind?: "kind";

                    /**
                     * Creates a new TargetPoolInstanceHealth instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolInstanceHealth instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolInstanceHealth): google.cloud.compute.v1.TargetPoolInstanceHealth;

                    /**
                     * Encodes the specified TargetPoolInstanceHealth message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolInstanceHealth.verify|verify} messages.
                     * @param message TargetPoolInstanceHealth message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolInstanceHealth, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolInstanceHealth message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolInstanceHealth.verify|verify} messages.
                     * @param message TargetPoolInstanceHealth message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolInstanceHealth, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolInstanceHealth message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolInstanceHealth
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolInstanceHealth;

                    /**
                     * Decodes a TargetPoolInstanceHealth message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolInstanceHealth
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolInstanceHealth;

                    /**
                     * Verifies a TargetPoolInstanceHealth message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolInstanceHealth message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolInstanceHealth
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolInstanceHealth;

                    /**
                     * Creates a plain object from a TargetPoolInstanceHealth message. Also converts values to other types if specified.
                     * @param message TargetPoolInstanceHealth
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolInstanceHealth, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolInstanceHealth to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolInstanceHealth
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolList. */
                interface ITargetPoolList {

                    /** TargetPoolList id */
                    id?: (string|null);

                    /** TargetPoolList items */
                    items?: (google.cloud.compute.v1.ITargetPool[]|null);

                    /** TargetPoolList kind */
                    kind?: (string|null);

                    /** TargetPoolList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetPoolList selfLink */
                    selfLink?: (string|null);

                    /** TargetPoolList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetPoolList. */
                class TargetPoolList implements ITargetPoolList {

                    /**
                     * Constructs a new TargetPoolList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolList);

                    /** TargetPoolList id. */
                    public id?: (string|null);

                    /** TargetPoolList items. */
                    public items: google.cloud.compute.v1.ITargetPool[];

                    /** TargetPoolList kind. */
                    public kind?: (string|null);

                    /** TargetPoolList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetPoolList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetPoolList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetPoolList _id. */
                    public _id?: "id";

                    /** TargetPoolList _kind. */
                    public _kind?: "kind";

                    /** TargetPoolList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetPoolList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetPoolList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetPoolList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolList): google.cloud.compute.v1.TargetPoolList;

                    /**
                     * Encodes the specified TargetPoolList message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolList.verify|verify} messages.
                     * @param message TargetPoolList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolList.verify|verify} messages.
                     * @param message TargetPoolList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolList;

                    /**
                     * Decodes a TargetPoolList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolList;

                    /**
                     * Verifies a TargetPoolList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolList;

                    /**
                     * Creates a plain object from a TargetPoolList message. Also converts values to other types if specified.
                     * @param message TargetPoolList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolsAddHealthCheckRequest. */
                interface ITargetPoolsAddHealthCheckRequest {

                    /** TargetPoolsAddHealthCheckRequest healthChecks */
                    healthChecks?: (google.cloud.compute.v1.IHealthCheckReference[]|null);
                }

                /** Represents a TargetPoolsAddHealthCheckRequest. */
                class TargetPoolsAddHealthCheckRequest implements ITargetPoolsAddHealthCheckRequest {

                    /**
                     * Constructs a new TargetPoolsAddHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolsAddHealthCheckRequest);

                    /** TargetPoolsAddHealthCheckRequest healthChecks. */
                    public healthChecks: google.cloud.compute.v1.IHealthCheckReference[];

                    /**
                     * Creates a new TargetPoolsAddHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolsAddHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolsAddHealthCheckRequest): google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest;

                    /**
                     * Encodes the specified TargetPoolsAddHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest.verify|verify} messages.
                     * @param message TargetPoolsAddHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolsAddHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolsAddHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest.verify|verify} messages.
                     * @param message TargetPoolsAddHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolsAddHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolsAddHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolsAddHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest;

                    /**
                     * Decodes a TargetPoolsAddHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolsAddHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest;

                    /**
                     * Verifies a TargetPoolsAddHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolsAddHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolsAddHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest;

                    /**
                     * Creates a plain object from a TargetPoolsAddHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message TargetPoolsAddHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolsAddHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolsAddHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolsAddHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolsAddInstanceRequest. */
                interface ITargetPoolsAddInstanceRequest {

                    /** TargetPoolsAddInstanceRequest instances */
                    instances?: (google.cloud.compute.v1.IInstanceReference[]|null);
                }

                /** Represents a TargetPoolsAddInstanceRequest. */
                class TargetPoolsAddInstanceRequest implements ITargetPoolsAddInstanceRequest {

                    /**
                     * Constructs a new TargetPoolsAddInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolsAddInstanceRequest);

                    /** TargetPoolsAddInstanceRequest instances. */
                    public instances: google.cloud.compute.v1.IInstanceReference[];

                    /**
                     * Creates a new TargetPoolsAddInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolsAddInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolsAddInstanceRequest): google.cloud.compute.v1.TargetPoolsAddInstanceRequest;

                    /**
                     * Encodes the specified TargetPoolsAddInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsAddInstanceRequest.verify|verify} messages.
                     * @param message TargetPoolsAddInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolsAddInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolsAddInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsAddInstanceRequest.verify|verify} messages.
                     * @param message TargetPoolsAddInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolsAddInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolsAddInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolsAddInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolsAddInstanceRequest;

                    /**
                     * Decodes a TargetPoolsAddInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolsAddInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolsAddInstanceRequest;

                    /**
                     * Verifies a TargetPoolsAddInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolsAddInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolsAddInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolsAddInstanceRequest;

                    /**
                     * Creates a plain object from a TargetPoolsAddInstanceRequest message. Also converts values to other types if specified.
                     * @param message TargetPoolsAddInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolsAddInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolsAddInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolsAddInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolsRemoveHealthCheckRequest. */
                interface ITargetPoolsRemoveHealthCheckRequest {

                    /** TargetPoolsRemoveHealthCheckRequest healthChecks */
                    healthChecks?: (google.cloud.compute.v1.IHealthCheckReference[]|null);
                }

                /** Represents a TargetPoolsRemoveHealthCheckRequest. */
                class TargetPoolsRemoveHealthCheckRequest implements ITargetPoolsRemoveHealthCheckRequest {

                    /**
                     * Constructs a new TargetPoolsRemoveHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolsRemoveHealthCheckRequest);

                    /** TargetPoolsRemoveHealthCheckRequest healthChecks. */
                    public healthChecks: google.cloud.compute.v1.IHealthCheckReference[];

                    /**
                     * Creates a new TargetPoolsRemoveHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolsRemoveHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolsRemoveHealthCheckRequest): google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest;

                    /**
                     * Encodes the specified TargetPoolsRemoveHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest.verify|verify} messages.
                     * @param message TargetPoolsRemoveHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolsRemoveHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolsRemoveHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest.verify|verify} messages.
                     * @param message TargetPoolsRemoveHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolsRemoveHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolsRemoveHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolsRemoveHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest;

                    /**
                     * Decodes a TargetPoolsRemoveHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolsRemoveHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest;

                    /**
                     * Verifies a TargetPoolsRemoveHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolsRemoveHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolsRemoveHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest;

                    /**
                     * Creates a plain object from a TargetPoolsRemoveHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message TargetPoolsRemoveHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolsRemoveHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolsRemoveHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolsRemoveHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolsRemoveInstanceRequest. */
                interface ITargetPoolsRemoveInstanceRequest {

                    /** TargetPoolsRemoveInstanceRequest instances */
                    instances?: (google.cloud.compute.v1.IInstanceReference[]|null);
                }

                /** Represents a TargetPoolsRemoveInstanceRequest. */
                class TargetPoolsRemoveInstanceRequest implements ITargetPoolsRemoveInstanceRequest {

                    /**
                     * Constructs a new TargetPoolsRemoveInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolsRemoveInstanceRequest);

                    /** TargetPoolsRemoveInstanceRequest instances. */
                    public instances: google.cloud.compute.v1.IInstanceReference[];

                    /**
                     * Creates a new TargetPoolsRemoveInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolsRemoveInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolsRemoveInstanceRequest): google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest;

                    /**
                     * Encodes the specified TargetPoolsRemoveInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest.verify|verify} messages.
                     * @param message TargetPoolsRemoveInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolsRemoveInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolsRemoveInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest.verify|verify} messages.
                     * @param message TargetPoolsRemoveInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolsRemoveInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolsRemoveInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolsRemoveInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest;

                    /**
                     * Decodes a TargetPoolsRemoveInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolsRemoveInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest;

                    /**
                     * Verifies a TargetPoolsRemoveInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolsRemoveInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolsRemoveInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest;

                    /**
                     * Creates a plain object from a TargetPoolsRemoveInstanceRequest message. Also converts values to other types if specified.
                     * @param message TargetPoolsRemoveInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolsRemoveInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolsRemoveInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolsRemoveInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetPoolsScopedList. */
                interface ITargetPoolsScopedList {

                    /** TargetPoolsScopedList targetPools */
                    targetPools?: (google.cloud.compute.v1.ITargetPool[]|null);

                    /** TargetPoolsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetPoolsScopedList. */
                class TargetPoolsScopedList implements ITargetPoolsScopedList {

                    /**
                     * Constructs a new TargetPoolsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetPoolsScopedList);

                    /** TargetPoolsScopedList targetPools. */
                    public targetPools: google.cloud.compute.v1.ITargetPool[];

                    /** TargetPoolsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetPoolsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetPoolsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetPoolsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetPoolsScopedList): google.cloud.compute.v1.TargetPoolsScopedList;

                    /**
                     * Encodes the specified TargetPoolsScopedList message. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsScopedList.verify|verify} messages.
                     * @param message TargetPoolsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetPoolsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetPoolsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetPoolsScopedList.verify|verify} messages.
                     * @param message TargetPoolsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetPoolsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetPoolsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetPoolsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetPoolsScopedList;

                    /**
                     * Decodes a TargetPoolsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetPoolsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetPoolsScopedList;

                    /**
                     * Verifies a TargetPoolsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetPoolsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetPoolsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetPoolsScopedList;

                    /**
                     * Creates a plain object from a TargetPoolsScopedList message. Also converts values to other types if specified.
                     * @param message TargetPoolsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetPoolsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetPoolsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetPoolsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetReference. */
                interface ITargetReference {

                    /** TargetReference target */
                    target?: (string|null);
                }

                /** Represents a TargetReference. */
                class TargetReference implements ITargetReference {

                    /**
                     * Constructs a new TargetReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetReference);

                    /** TargetReference target. */
                    public target?: (string|null);

                    /** TargetReference _target. */
                    public _target?: "target";

                    /**
                     * Creates a new TargetReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetReference): google.cloud.compute.v1.TargetReference;

                    /**
                     * Encodes the specified TargetReference message. Does not implicitly {@link google.cloud.compute.v1.TargetReference.verify|verify} messages.
                     * @param message TargetReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetReference.verify|verify} messages.
                     * @param message TargetReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetReference;

                    /**
                     * Decodes a TargetReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetReference;

                    /**
                     * Verifies a TargetReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetReference;

                    /**
                     * Creates a plain object from a TargetReference message. Also converts values to other types if specified.
                     * @param message TargetReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetSslProxiesSetBackendServiceRequest. */
                interface ITargetSslProxiesSetBackendServiceRequest {

                    /** TargetSslProxiesSetBackendServiceRequest service */
                    service?: (string|null);
                }

                /** Represents a TargetSslProxiesSetBackendServiceRequest. */
                class TargetSslProxiesSetBackendServiceRequest implements ITargetSslProxiesSetBackendServiceRequest {

                    /**
                     * Constructs a new TargetSslProxiesSetBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetSslProxiesSetBackendServiceRequest);

                    /** TargetSslProxiesSetBackendServiceRequest service. */
                    public service?: (string|null);

                    /** TargetSslProxiesSetBackendServiceRequest _service. */
                    public _service?: "service";

                    /**
                     * Creates a new TargetSslProxiesSetBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetSslProxiesSetBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetSslProxiesSetBackendServiceRequest): google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest;

                    /**
                     * Encodes the specified TargetSslProxiesSetBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetSslProxiesSetBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetSslProxiesSetBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetSslProxiesSetBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetSslProxiesSetBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetSslProxiesSetBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest;

                    /**
                     * Decodes a TargetSslProxiesSetBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetSslProxiesSetBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest;

                    /**
                     * Verifies a TargetSslProxiesSetBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetSslProxiesSetBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetSslProxiesSetBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest;

                    /**
                     * Creates a plain object from a TargetSslProxiesSetBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message TargetSslProxiesSetBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetSslProxiesSetBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetSslProxiesSetBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetSslProxiesSetBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetSslProxiesSetCertificateMapRequest. */
                interface ITargetSslProxiesSetCertificateMapRequest {

                    /** TargetSslProxiesSetCertificateMapRequest certificateMap */
                    certificateMap?: (string|null);
                }

                /** Represents a TargetSslProxiesSetCertificateMapRequest. */
                class TargetSslProxiesSetCertificateMapRequest implements ITargetSslProxiesSetCertificateMapRequest {

                    /**
                     * Constructs a new TargetSslProxiesSetCertificateMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetSslProxiesSetCertificateMapRequest);

                    /** TargetSslProxiesSetCertificateMapRequest certificateMap. */
                    public certificateMap?: (string|null);

                    /** TargetSslProxiesSetCertificateMapRequest _certificateMap. */
                    public _certificateMap?: "certificateMap";

                    /**
                     * Creates a new TargetSslProxiesSetCertificateMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetSslProxiesSetCertificateMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetSslProxiesSetCertificateMapRequest): google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest;

                    /**
                     * Encodes the specified TargetSslProxiesSetCertificateMapRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetCertificateMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetSslProxiesSetCertificateMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetSslProxiesSetCertificateMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetCertificateMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetSslProxiesSetCertificateMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetSslProxiesSetCertificateMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetSslProxiesSetCertificateMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest;

                    /**
                     * Decodes a TargetSslProxiesSetCertificateMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetSslProxiesSetCertificateMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest;

                    /**
                     * Verifies a TargetSslProxiesSetCertificateMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetSslProxiesSetCertificateMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetSslProxiesSetCertificateMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest;

                    /**
                     * Creates a plain object from a TargetSslProxiesSetCertificateMapRequest message. Also converts values to other types if specified.
                     * @param message TargetSslProxiesSetCertificateMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetSslProxiesSetCertificateMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetSslProxiesSetCertificateMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetSslProxiesSetCertificateMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetSslProxiesSetProxyHeaderRequest. */
                interface ITargetSslProxiesSetProxyHeaderRequest {

                    /** TargetSslProxiesSetProxyHeaderRequest proxyHeader */
                    proxyHeader?: (string|null);
                }

                /** Represents a TargetSslProxiesSetProxyHeaderRequest. */
                class TargetSslProxiesSetProxyHeaderRequest implements ITargetSslProxiesSetProxyHeaderRequest {

                    /**
                     * Constructs a new TargetSslProxiesSetProxyHeaderRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetSslProxiesSetProxyHeaderRequest);

                    /** TargetSslProxiesSetProxyHeaderRequest proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** TargetSslProxiesSetProxyHeaderRequest _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /**
                     * Creates a new TargetSslProxiesSetProxyHeaderRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetSslProxiesSetProxyHeaderRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetSslProxiesSetProxyHeaderRequest): google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest;

                    /**
                     * Encodes the specified TargetSslProxiesSetProxyHeaderRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetProxyHeaderRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetSslProxiesSetProxyHeaderRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetSslProxiesSetProxyHeaderRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetProxyHeaderRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetSslProxiesSetProxyHeaderRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetSslProxiesSetProxyHeaderRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetSslProxiesSetProxyHeaderRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest;

                    /**
                     * Decodes a TargetSslProxiesSetProxyHeaderRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetSslProxiesSetProxyHeaderRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest;

                    /**
                     * Verifies a TargetSslProxiesSetProxyHeaderRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetSslProxiesSetProxyHeaderRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetSslProxiesSetProxyHeaderRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest;

                    /**
                     * Creates a plain object from a TargetSslProxiesSetProxyHeaderRequest message. Also converts values to other types if specified.
                     * @param message TargetSslProxiesSetProxyHeaderRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetSslProxiesSetProxyHeaderRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetSslProxiesSetProxyHeaderRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetSslProxiesSetProxyHeaderRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetSslProxiesSetProxyHeaderRequest {

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a TargetSslProxiesSetSslCertificatesRequest. */
                interface ITargetSslProxiesSetSslCertificatesRequest {

                    /** TargetSslProxiesSetSslCertificatesRequest sslCertificates */
                    sslCertificates?: (string[]|null);
                }

                /** Represents a TargetSslProxiesSetSslCertificatesRequest. */
                class TargetSslProxiesSetSslCertificatesRequest implements ITargetSslProxiesSetSslCertificatesRequest {

                    /**
                     * Constructs a new TargetSslProxiesSetSslCertificatesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetSslProxiesSetSslCertificatesRequest);

                    /** TargetSslProxiesSetSslCertificatesRequest sslCertificates. */
                    public sslCertificates: string[];

                    /**
                     * Creates a new TargetSslProxiesSetSslCertificatesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetSslProxiesSetSslCertificatesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetSslProxiesSetSslCertificatesRequest): google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest;

                    /**
                     * Encodes the specified TargetSslProxiesSetSslCertificatesRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetSslProxiesSetSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetSslProxiesSetSslCertificatesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest.verify|verify} messages.
                     * @param message TargetSslProxiesSetSslCertificatesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetSslProxiesSetSslCertificatesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetSslProxiesSetSslCertificatesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetSslProxiesSetSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest;

                    /**
                     * Decodes a TargetSslProxiesSetSslCertificatesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetSslProxiesSetSslCertificatesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest;

                    /**
                     * Verifies a TargetSslProxiesSetSslCertificatesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetSslProxiesSetSslCertificatesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetSslProxiesSetSslCertificatesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest;

                    /**
                     * Creates a plain object from a TargetSslProxiesSetSslCertificatesRequest message. Also converts values to other types if specified.
                     * @param message TargetSslProxiesSetSslCertificatesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetSslProxiesSetSslCertificatesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetSslProxiesSetSslCertificatesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetSslProxiesSetSslCertificatesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetSslProxy. */
                interface ITargetSslProxy {

                    /** TargetSslProxy certificateMap */
                    certificateMap?: (string|null);

                    /** TargetSslProxy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetSslProxy description */
                    description?: (string|null);

                    /** TargetSslProxy id */
                    id?: (number|Long|string|null);

                    /** TargetSslProxy kind */
                    kind?: (string|null);

                    /** TargetSslProxy name */
                    name?: (string|null);

                    /** TargetSslProxy proxyHeader */
                    proxyHeader?: (string|null);

                    /** TargetSslProxy selfLink */
                    selfLink?: (string|null);

                    /** TargetSslProxy service */
                    service?: (string|null);

                    /** TargetSslProxy sslCertificates */
                    sslCertificates?: (string[]|null);

                    /** TargetSslProxy sslPolicy */
                    sslPolicy?: (string|null);
                }

                /** Represents a TargetSslProxy. */
                class TargetSslProxy implements ITargetSslProxy {

                    /**
                     * Constructs a new TargetSslProxy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetSslProxy);

                    /** TargetSslProxy certificateMap. */
                    public certificateMap?: (string|null);

                    /** TargetSslProxy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetSslProxy description. */
                    public description?: (string|null);

                    /** TargetSslProxy id. */
                    public id?: (number|Long|string|null);

                    /** TargetSslProxy kind. */
                    public kind?: (string|null);

                    /** TargetSslProxy name. */
                    public name?: (string|null);

                    /** TargetSslProxy proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** TargetSslProxy selfLink. */
                    public selfLink?: (string|null);

                    /** TargetSslProxy service. */
                    public service?: (string|null);

                    /** TargetSslProxy sslCertificates. */
                    public sslCertificates: string[];

                    /** TargetSslProxy sslPolicy. */
                    public sslPolicy?: (string|null);

                    /** TargetSslProxy _certificateMap. */
                    public _certificateMap?: "certificateMap";

                    /** TargetSslProxy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetSslProxy _description. */
                    public _description?: "description";

                    /** TargetSslProxy _id. */
                    public _id?: "id";

                    /** TargetSslProxy _kind. */
                    public _kind?: "kind";

                    /** TargetSslProxy _name. */
                    public _name?: "name";

                    /** TargetSslProxy _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** TargetSslProxy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetSslProxy _service. */
                    public _service?: "service";

                    /** TargetSslProxy _sslPolicy. */
                    public _sslPolicy?: "sslPolicy";

                    /**
                     * Creates a new TargetSslProxy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetSslProxy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetSslProxy): google.cloud.compute.v1.TargetSslProxy;

                    /**
                     * Encodes the specified TargetSslProxy message. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxy.verify|verify} messages.
                     * @param message TargetSslProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetSslProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetSslProxy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxy.verify|verify} messages.
                     * @param message TargetSslProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetSslProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetSslProxy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetSslProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetSslProxy;

                    /**
                     * Decodes a TargetSslProxy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetSslProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetSslProxy;

                    /**
                     * Verifies a TargetSslProxy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetSslProxy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetSslProxy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetSslProxy;

                    /**
                     * Creates a plain object from a TargetSslProxy message. Also converts values to other types if specified.
                     * @param message TargetSslProxy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetSslProxy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetSslProxy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetSslProxy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetSslProxy {

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a TargetSslProxyList. */
                interface ITargetSslProxyList {

                    /** TargetSslProxyList id */
                    id?: (string|null);

                    /** TargetSslProxyList items */
                    items?: (google.cloud.compute.v1.ITargetSslProxy[]|null);

                    /** TargetSslProxyList kind */
                    kind?: (string|null);

                    /** TargetSslProxyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetSslProxyList selfLink */
                    selfLink?: (string|null);

                    /** TargetSslProxyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetSslProxyList. */
                class TargetSslProxyList implements ITargetSslProxyList {

                    /**
                     * Constructs a new TargetSslProxyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetSslProxyList);

                    /** TargetSslProxyList id. */
                    public id?: (string|null);

                    /** TargetSslProxyList items. */
                    public items: google.cloud.compute.v1.ITargetSslProxy[];

                    /** TargetSslProxyList kind. */
                    public kind?: (string|null);

                    /** TargetSslProxyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetSslProxyList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetSslProxyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetSslProxyList _id. */
                    public _id?: "id";

                    /** TargetSslProxyList _kind. */
                    public _kind?: "kind";

                    /** TargetSslProxyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetSslProxyList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetSslProxyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetSslProxyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetSslProxyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetSslProxyList): google.cloud.compute.v1.TargetSslProxyList;

                    /**
                     * Encodes the specified TargetSslProxyList message. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxyList.verify|verify} messages.
                     * @param message TargetSslProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetSslProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetSslProxyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetSslProxyList.verify|verify} messages.
                     * @param message TargetSslProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetSslProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetSslProxyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetSslProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetSslProxyList;

                    /**
                     * Decodes a TargetSslProxyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetSslProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetSslProxyList;

                    /**
                     * Verifies a TargetSslProxyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetSslProxyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetSslProxyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetSslProxyList;

                    /**
                     * Creates a plain object from a TargetSslProxyList message. Also converts values to other types if specified.
                     * @param message TargetSslProxyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetSslProxyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetSslProxyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetSslProxyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetTcpProxiesSetBackendServiceRequest. */
                interface ITargetTcpProxiesSetBackendServiceRequest {

                    /** TargetTcpProxiesSetBackendServiceRequest service */
                    service?: (string|null);
                }

                /** Represents a TargetTcpProxiesSetBackendServiceRequest. */
                class TargetTcpProxiesSetBackendServiceRequest implements ITargetTcpProxiesSetBackendServiceRequest {

                    /**
                     * Constructs a new TargetTcpProxiesSetBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetTcpProxiesSetBackendServiceRequest);

                    /** TargetTcpProxiesSetBackendServiceRequest service. */
                    public service?: (string|null);

                    /** TargetTcpProxiesSetBackendServiceRequest _service. */
                    public _service?: "service";

                    /**
                     * Creates a new TargetTcpProxiesSetBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetTcpProxiesSetBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetTcpProxiesSetBackendServiceRequest): google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest;

                    /**
                     * Encodes the specified TargetTcpProxiesSetBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest.verify|verify} messages.
                     * @param message TargetTcpProxiesSetBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetTcpProxiesSetBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetTcpProxiesSetBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest.verify|verify} messages.
                     * @param message TargetTcpProxiesSetBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetTcpProxiesSetBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetTcpProxiesSetBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetTcpProxiesSetBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest;

                    /**
                     * Decodes a TargetTcpProxiesSetBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetTcpProxiesSetBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest;

                    /**
                     * Verifies a TargetTcpProxiesSetBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetTcpProxiesSetBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetTcpProxiesSetBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest;

                    /**
                     * Creates a plain object from a TargetTcpProxiesSetBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message TargetTcpProxiesSetBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetTcpProxiesSetBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetTcpProxiesSetBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetTcpProxiesSetBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetTcpProxiesSetProxyHeaderRequest. */
                interface ITargetTcpProxiesSetProxyHeaderRequest {

                    /** TargetTcpProxiesSetProxyHeaderRequest proxyHeader */
                    proxyHeader?: (string|null);
                }

                /** Represents a TargetTcpProxiesSetProxyHeaderRequest. */
                class TargetTcpProxiesSetProxyHeaderRequest implements ITargetTcpProxiesSetProxyHeaderRequest {

                    /**
                     * Constructs a new TargetTcpProxiesSetProxyHeaderRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetTcpProxiesSetProxyHeaderRequest);

                    /** TargetTcpProxiesSetProxyHeaderRequest proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** TargetTcpProxiesSetProxyHeaderRequest _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /**
                     * Creates a new TargetTcpProxiesSetProxyHeaderRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetTcpProxiesSetProxyHeaderRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetTcpProxiesSetProxyHeaderRequest): google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest;

                    /**
                     * Encodes the specified TargetTcpProxiesSetProxyHeaderRequest message. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest.verify|verify} messages.
                     * @param message TargetTcpProxiesSetProxyHeaderRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetTcpProxiesSetProxyHeaderRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetTcpProxiesSetProxyHeaderRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest.verify|verify} messages.
                     * @param message TargetTcpProxiesSetProxyHeaderRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetTcpProxiesSetProxyHeaderRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetTcpProxiesSetProxyHeaderRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetTcpProxiesSetProxyHeaderRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest;

                    /**
                     * Decodes a TargetTcpProxiesSetProxyHeaderRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetTcpProxiesSetProxyHeaderRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest;

                    /**
                     * Verifies a TargetTcpProxiesSetProxyHeaderRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetTcpProxiesSetProxyHeaderRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetTcpProxiesSetProxyHeaderRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest;

                    /**
                     * Creates a plain object from a TargetTcpProxiesSetProxyHeaderRequest message. Also converts values to other types if specified.
                     * @param message TargetTcpProxiesSetProxyHeaderRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetTcpProxiesSetProxyHeaderRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetTcpProxiesSetProxyHeaderRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetTcpProxiesSetProxyHeaderRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetTcpProxiesSetProxyHeaderRequest {

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a TargetTcpProxy. */
                interface ITargetTcpProxy {

                    /** TargetTcpProxy creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetTcpProxy description */
                    description?: (string|null);

                    /** TargetTcpProxy id */
                    id?: (number|Long|string|null);

                    /** TargetTcpProxy kind */
                    kind?: (string|null);

                    /** TargetTcpProxy name */
                    name?: (string|null);

                    /** TargetTcpProxy proxyBind */
                    proxyBind?: (boolean|null);

                    /** TargetTcpProxy proxyHeader */
                    proxyHeader?: (string|null);

                    /** TargetTcpProxy region */
                    region?: (string|null);

                    /** TargetTcpProxy selfLink */
                    selfLink?: (string|null);

                    /** TargetTcpProxy service */
                    service?: (string|null);
                }

                /** Represents a TargetTcpProxy. */
                class TargetTcpProxy implements ITargetTcpProxy {

                    /**
                     * Constructs a new TargetTcpProxy.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetTcpProxy);

                    /** TargetTcpProxy creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetTcpProxy description. */
                    public description?: (string|null);

                    /** TargetTcpProxy id. */
                    public id?: (number|Long|string|null);

                    /** TargetTcpProxy kind. */
                    public kind?: (string|null);

                    /** TargetTcpProxy name. */
                    public name?: (string|null);

                    /** TargetTcpProxy proxyBind. */
                    public proxyBind?: (boolean|null);

                    /** TargetTcpProxy proxyHeader. */
                    public proxyHeader?: (string|null);

                    /** TargetTcpProxy region. */
                    public region?: (string|null);

                    /** TargetTcpProxy selfLink. */
                    public selfLink?: (string|null);

                    /** TargetTcpProxy service. */
                    public service?: (string|null);

                    /** TargetTcpProxy _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetTcpProxy _description. */
                    public _description?: "description";

                    /** TargetTcpProxy _id. */
                    public _id?: "id";

                    /** TargetTcpProxy _kind. */
                    public _kind?: "kind";

                    /** TargetTcpProxy _name. */
                    public _name?: "name";

                    /** TargetTcpProxy _proxyBind. */
                    public _proxyBind?: "proxyBind";

                    /** TargetTcpProxy _proxyHeader. */
                    public _proxyHeader?: "proxyHeader";

                    /** TargetTcpProxy _region. */
                    public _region?: "region";

                    /** TargetTcpProxy _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetTcpProxy _service. */
                    public _service?: "service";

                    /**
                     * Creates a new TargetTcpProxy instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetTcpProxy instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetTcpProxy): google.cloud.compute.v1.TargetTcpProxy;

                    /**
                     * Encodes the specified TargetTcpProxy message. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxy.verify|verify} messages.
                     * @param message TargetTcpProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetTcpProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetTcpProxy message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxy.verify|verify} messages.
                     * @param message TargetTcpProxy message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetTcpProxy, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetTcpProxy message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetTcpProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetTcpProxy;

                    /**
                     * Decodes a TargetTcpProxy message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetTcpProxy
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetTcpProxy;

                    /**
                     * Verifies a TargetTcpProxy message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetTcpProxy message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetTcpProxy
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetTcpProxy;

                    /**
                     * Creates a plain object from a TargetTcpProxy message. Also converts values to other types if specified.
                     * @param message TargetTcpProxy
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetTcpProxy, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetTcpProxy to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetTcpProxy
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetTcpProxy {

                    /** ProxyHeader enum. */
                    enum ProxyHeader {
                        UNDEFINED_PROXY_HEADER = 0,
                        NONE = 2402104,
                        PROXY_V1 = 334352940
                    }
                }

                /** Properties of a TargetTcpProxyList. */
                interface ITargetTcpProxyList {

                    /** TargetTcpProxyList id */
                    id?: (string|null);

                    /** TargetTcpProxyList items */
                    items?: (google.cloud.compute.v1.ITargetTcpProxy[]|null);

                    /** TargetTcpProxyList kind */
                    kind?: (string|null);

                    /** TargetTcpProxyList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetTcpProxyList selfLink */
                    selfLink?: (string|null);

                    /** TargetTcpProxyList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetTcpProxyList. */
                class TargetTcpProxyList implements ITargetTcpProxyList {

                    /**
                     * Constructs a new TargetTcpProxyList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetTcpProxyList);

                    /** TargetTcpProxyList id. */
                    public id?: (string|null);

                    /** TargetTcpProxyList items. */
                    public items: google.cloud.compute.v1.ITargetTcpProxy[];

                    /** TargetTcpProxyList kind. */
                    public kind?: (string|null);

                    /** TargetTcpProxyList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetTcpProxyList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetTcpProxyList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetTcpProxyList _id. */
                    public _id?: "id";

                    /** TargetTcpProxyList _kind. */
                    public _kind?: "kind";

                    /** TargetTcpProxyList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetTcpProxyList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetTcpProxyList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetTcpProxyList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetTcpProxyList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetTcpProxyList): google.cloud.compute.v1.TargetTcpProxyList;

                    /**
                     * Encodes the specified TargetTcpProxyList message. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxyList.verify|verify} messages.
                     * @param message TargetTcpProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetTcpProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetTcpProxyList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetTcpProxyList.verify|verify} messages.
                     * @param message TargetTcpProxyList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetTcpProxyList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetTcpProxyList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetTcpProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetTcpProxyList;

                    /**
                     * Decodes a TargetTcpProxyList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetTcpProxyList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetTcpProxyList;

                    /**
                     * Verifies a TargetTcpProxyList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetTcpProxyList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetTcpProxyList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetTcpProxyList;

                    /**
                     * Creates a plain object from a TargetTcpProxyList message. Also converts values to other types if specified.
                     * @param message TargetTcpProxyList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetTcpProxyList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetTcpProxyList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetTcpProxyList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetVpnGateway. */
                interface ITargetVpnGateway {

                    /** TargetVpnGateway creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** TargetVpnGateway description */
                    description?: (string|null);

                    /** TargetVpnGateway forwardingRules */
                    forwardingRules?: (string[]|null);

                    /** TargetVpnGateway id */
                    id?: (number|Long|string|null);

                    /** TargetVpnGateway kind */
                    kind?: (string|null);

                    /** TargetVpnGateway name */
                    name?: (string|null);

                    /** TargetVpnGateway network */
                    network?: (string|null);

                    /** TargetVpnGateway region */
                    region?: (string|null);

                    /** TargetVpnGateway selfLink */
                    selfLink?: (string|null);

                    /** TargetVpnGateway status */
                    status?: (string|null);

                    /** TargetVpnGateway tunnels */
                    tunnels?: (string[]|null);
                }

                /** Represents a TargetVpnGateway. */
                class TargetVpnGateway implements ITargetVpnGateway {

                    /**
                     * Constructs a new TargetVpnGateway.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetVpnGateway);

                    /** TargetVpnGateway creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** TargetVpnGateway description. */
                    public description?: (string|null);

                    /** TargetVpnGateway forwardingRules. */
                    public forwardingRules: string[];

                    /** TargetVpnGateway id. */
                    public id?: (number|Long|string|null);

                    /** TargetVpnGateway kind. */
                    public kind?: (string|null);

                    /** TargetVpnGateway name. */
                    public name?: (string|null);

                    /** TargetVpnGateway network. */
                    public network?: (string|null);

                    /** TargetVpnGateway region. */
                    public region?: (string|null);

                    /** TargetVpnGateway selfLink. */
                    public selfLink?: (string|null);

                    /** TargetVpnGateway status. */
                    public status?: (string|null);

                    /** TargetVpnGateway tunnels. */
                    public tunnels: string[];

                    /** TargetVpnGateway _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** TargetVpnGateway _description. */
                    public _description?: "description";

                    /** TargetVpnGateway _id. */
                    public _id?: "id";

                    /** TargetVpnGateway _kind. */
                    public _kind?: "kind";

                    /** TargetVpnGateway _name. */
                    public _name?: "name";

                    /** TargetVpnGateway _network. */
                    public _network?: "network";

                    /** TargetVpnGateway _region. */
                    public _region?: "region";

                    /** TargetVpnGateway _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetVpnGateway _status. */
                    public _status?: "status";

                    /**
                     * Creates a new TargetVpnGateway instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetVpnGateway instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetVpnGateway): google.cloud.compute.v1.TargetVpnGateway;

                    /**
                     * Encodes the specified TargetVpnGateway message. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGateway.verify|verify} messages.
                     * @param message TargetVpnGateway message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetVpnGateway, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetVpnGateway message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGateway.verify|verify} messages.
                     * @param message TargetVpnGateway message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetVpnGateway, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetVpnGateway message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetVpnGateway
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetVpnGateway;

                    /**
                     * Decodes a TargetVpnGateway message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetVpnGateway
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetVpnGateway;

                    /**
                     * Verifies a TargetVpnGateway message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetVpnGateway message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetVpnGateway
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetVpnGateway;

                    /**
                     * Creates a plain object from a TargetVpnGateway message. Also converts values to other types if specified.
                     * @param message TargetVpnGateway
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetVpnGateway, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetVpnGateway to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetVpnGateway
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TargetVpnGateway {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        CREATING = 455564985,
                        DELETING = 528602024,
                        FAILED = 455706685,
                        READY = 77848963
                    }
                }

                /** Properties of a TargetVpnGatewayAggregatedList. */
                interface ITargetVpnGatewayAggregatedList {

                    /** TargetVpnGatewayAggregatedList id */
                    id?: (string|null);

                    /** TargetVpnGatewayAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.ITargetVpnGatewaysScopedList }|null);

                    /** TargetVpnGatewayAggregatedList kind */
                    kind?: (string|null);

                    /** TargetVpnGatewayAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetVpnGatewayAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** TargetVpnGatewayAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** TargetVpnGatewayAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetVpnGatewayAggregatedList. */
                class TargetVpnGatewayAggregatedList implements ITargetVpnGatewayAggregatedList {

                    /**
                     * Constructs a new TargetVpnGatewayAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetVpnGatewayAggregatedList);

                    /** TargetVpnGatewayAggregatedList id. */
                    public id?: (string|null);

                    /** TargetVpnGatewayAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.ITargetVpnGatewaysScopedList };

                    /** TargetVpnGatewayAggregatedList kind. */
                    public kind?: (string|null);

                    /** TargetVpnGatewayAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetVpnGatewayAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetVpnGatewayAggregatedList unreachables. */
                    public unreachables: string[];

                    /** TargetVpnGatewayAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetVpnGatewayAggregatedList _id. */
                    public _id?: "id";

                    /** TargetVpnGatewayAggregatedList _kind. */
                    public _kind?: "kind";

                    /** TargetVpnGatewayAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetVpnGatewayAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetVpnGatewayAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetVpnGatewayAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetVpnGatewayAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetVpnGatewayAggregatedList): google.cloud.compute.v1.TargetVpnGatewayAggregatedList;

                    /**
                     * Encodes the specified TargetVpnGatewayAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGatewayAggregatedList.verify|verify} messages.
                     * @param message TargetVpnGatewayAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetVpnGatewayAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetVpnGatewayAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGatewayAggregatedList.verify|verify} messages.
                     * @param message TargetVpnGatewayAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetVpnGatewayAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetVpnGatewayAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetVpnGatewayAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetVpnGatewayAggregatedList;

                    /**
                     * Decodes a TargetVpnGatewayAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetVpnGatewayAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetVpnGatewayAggregatedList;

                    /**
                     * Verifies a TargetVpnGatewayAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetVpnGatewayAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetVpnGatewayAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetVpnGatewayAggregatedList;

                    /**
                     * Creates a plain object from a TargetVpnGatewayAggregatedList message. Also converts values to other types if specified.
                     * @param message TargetVpnGatewayAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetVpnGatewayAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetVpnGatewayAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetVpnGatewayAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetVpnGatewayList. */
                interface ITargetVpnGatewayList {

                    /** TargetVpnGatewayList id */
                    id?: (string|null);

                    /** TargetVpnGatewayList items */
                    items?: (google.cloud.compute.v1.ITargetVpnGateway[]|null);

                    /** TargetVpnGatewayList kind */
                    kind?: (string|null);

                    /** TargetVpnGatewayList nextPageToken */
                    nextPageToken?: (string|null);

                    /** TargetVpnGatewayList selfLink */
                    selfLink?: (string|null);

                    /** TargetVpnGatewayList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetVpnGatewayList. */
                class TargetVpnGatewayList implements ITargetVpnGatewayList {

                    /**
                     * Constructs a new TargetVpnGatewayList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetVpnGatewayList);

                    /** TargetVpnGatewayList id. */
                    public id?: (string|null);

                    /** TargetVpnGatewayList items. */
                    public items: google.cloud.compute.v1.ITargetVpnGateway[];

                    /** TargetVpnGatewayList kind. */
                    public kind?: (string|null);

                    /** TargetVpnGatewayList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** TargetVpnGatewayList selfLink. */
                    public selfLink?: (string|null);

                    /** TargetVpnGatewayList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetVpnGatewayList _id. */
                    public _id?: "id";

                    /** TargetVpnGatewayList _kind. */
                    public _kind?: "kind";

                    /** TargetVpnGatewayList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** TargetVpnGatewayList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** TargetVpnGatewayList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetVpnGatewayList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetVpnGatewayList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetVpnGatewayList): google.cloud.compute.v1.TargetVpnGatewayList;

                    /**
                     * Encodes the specified TargetVpnGatewayList message. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGatewayList.verify|verify} messages.
                     * @param message TargetVpnGatewayList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetVpnGatewayList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetVpnGatewayList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGatewayList.verify|verify} messages.
                     * @param message TargetVpnGatewayList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetVpnGatewayList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetVpnGatewayList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetVpnGatewayList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetVpnGatewayList;

                    /**
                     * Decodes a TargetVpnGatewayList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetVpnGatewayList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetVpnGatewayList;

                    /**
                     * Verifies a TargetVpnGatewayList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetVpnGatewayList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetVpnGatewayList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetVpnGatewayList;

                    /**
                     * Creates a plain object from a TargetVpnGatewayList message. Also converts values to other types if specified.
                     * @param message TargetVpnGatewayList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetVpnGatewayList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetVpnGatewayList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetVpnGatewayList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TargetVpnGatewaysScopedList. */
                interface ITargetVpnGatewaysScopedList {

                    /** TargetVpnGatewaysScopedList targetVpnGateways */
                    targetVpnGateways?: (google.cloud.compute.v1.ITargetVpnGateway[]|null);

                    /** TargetVpnGatewaysScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a TargetVpnGatewaysScopedList. */
                class TargetVpnGatewaysScopedList implements ITargetVpnGatewaysScopedList {

                    /**
                     * Constructs a new TargetVpnGatewaysScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITargetVpnGatewaysScopedList);

                    /** TargetVpnGatewaysScopedList targetVpnGateways. */
                    public targetVpnGateways: google.cloud.compute.v1.ITargetVpnGateway[];

                    /** TargetVpnGatewaysScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** TargetVpnGatewaysScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new TargetVpnGatewaysScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TargetVpnGatewaysScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITargetVpnGatewaysScopedList): google.cloud.compute.v1.TargetVpnGatewaysScopedList;

                    /**
                     * Encodes the specified TargetVpnGatewaysScopedList message. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGatewaysScopedList.verify|verify} messages.
                     * @param message TargetVpnGatewaysScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITargetVpnGatewaysScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TargetVpnGatewaysScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TargetVpnGatewaysScopedList.verify|verify} messages.
                     * @param message TargetVpnGatewaysScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITargetVpnGatewaysScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TargetVpnGatewaysScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TargetVpnGatewaysScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TargetVpnGatewaysScopedList;

                    /**
                     * Decodes a TargetVpnGatewaysScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TargetVpnGatewaysScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TargetVpnGatewaysScopedList;

                    /**
                     * Verifies a TargetVpnGatewaysScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TargetVpnGatewaysScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TargetVpnGatewaysScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TargetVpnGatewaysScopedList;

                    /**
                     * Creates a plain object from a TargetVpnGatewaysScopedList message. Also converts values to other types if specified.
                     * @param message TargetVpnGatewaysScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TargetVpnGatewaysScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TargetVpnGatewaysScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TargetVpnGatewaysScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestFailure. */
                interface ITestFailure {

                    /** TestFailure actualOutputUrl */
                    actualOutputUrl?: (string|null);

                    /** TestFailure actualRedirectResponseCode */
                    actualRedirectResponseCode?: (number|null);

                    /** TestFailure actualService */
                    actualService?: (string|null);

                    /** TestFailure expectedOutputUrl */
                    expectedOutputUrl?: (string|null);

                    /** TestFailure expectedRedirectResponseCode */
                    expectedRedirectResponseCode?: (number|null);

                    /** TestFailure expectedService */
                    expectedService?: (string|null);

                    /** TestFailure headers */
                    headers?: (google.cloud.compute.v1.IUrlMapTestHeader[]|null);

                    /** TestFailure host */
                    host?: (string|null);

                    /** TestFailure path */
                    path?: (string|null);
                }

                /** Represents a TestFailure. */
                class TestFailure implements ITestFailure {

                    /**
                     * Constructs a new TestFailure.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestFailure);

                    /** TestFailure actualOutputUrl. */
                    public actualOutputUrl?: (string|null);

                    /** TestFailure actualRedirectResponseCode. */
                    public actualRedirectResponseCode?: (number|null);

                    /** TestFailure actualService. */
                    public actualService?: (string|null);

                    /** TestFailure expectedOutputUrl. */
                    public expectedOutputUrl?: (string|null);

                    /** TestFailure expectedRedirectResponseCode. */
                    public expectedRedirectResponseCode?: (number|null);

                    /** TestFailure expectedService. */
                    public expectedService?: (string|null);

                    /** TestFailure headers. */
                    public headers: google.cloud.compute.v1.IUrlMapTestHeader[];

                    /** TestFailure host. */
                    public host?: (string|null);

                    /** TestFailure path. */
                    public path?: (string|null);

                    /** TestFailure _actualOutputUrl. */
                    public _actualOutputUrl?: "actualOutputUrl";

                    /** TestFailure _actualRedirectResponseCode. */
                    public _actualRedirectResponseCode?: "actualRedirectResponseCode";

                    /** TestFailure _actualService. */
                    public _actualService?: "actualService";

                    /** TestFailure _expectedOutputUrl. */
                    public _expectedOutputUrl?: "expectedOutputUrl";

                    /** TestFailure _expectedRedirectResponseCode. */
                    public _expectedRedirectResponseCode?: "expectedRedirectResponseCode";

                    /** TestFailure _expectedService. */
                    public _expectedService?: "expectedService";

                    /** TestFailure _host. */
                    public _host?: "host";

                    /** TestFailure _path. */
                    public _path?: "path";

                    /**
                     * Creates a new TestFailure instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestFailure instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestFailure): google.cloud.compute.v1.TestFailure;

                    /**
                     * Encodes the specified TestFailure message. Does not implicitly {@link google.cloud.compute.v1.TestFailure.verify|verify} messages.
                     * @param message TestFailure message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestFailure, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestFailure message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestFailure.verify|verify} messages.
                     * @param message TestFailure message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestFailure, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestFailure message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestFailure
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestFailure;

                    /**
                     * Decodes a TestFailure message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestFailure
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestFailure;

                    /**
                     * Verifies a TestFailure message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestFailure message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestFailure
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestFailure;

                    /**
                     * Creates a plain object from a TestFailure message. Also converts values to other types if specified.
                     * @param message TestFailure
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestFailure, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestFailure to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestFailure
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsDiskRequest. */
                interface ITestIamPermissionsDiskRequest {

                    /** TestIamPermissionsDiskRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsDiskRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsDiskRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsDiskRequest zone */
                    zone?: (string|null);
                }

                /** Represents a TestIamPermissionsDiskRequest. */
                class TestIamPermissionsDiskRequest implements ITestIamPermissionsDiskRequest {

                    /**
                     * Constructs a new TestIamPermissionsDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsDiskRequest);

                    /** TestIamPermissionsDiskRequest project. */
                    public project: string;

                    /** TestIamPermissionsDiskRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsDiskRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsDiskRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new TestIamPermissionsDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsDiskRequest): google.cloud.compute.v1.TestIamPermissionsDiskRequest;

                    /**
                     * Encodes the specified TestIamPermissionsDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsDiskRequest.verify|verify} messages.
                     * @param message TestIamPermissionsDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsDiskRequest.verify|verify} messages.
                     * @param message TestIamPermissionsDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsDiskRequest;

                    /**
                     * Decodes a TestIamPermissionsDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsDiskRequest;

                    /**
                     * Verifies a TestIamPermissionsDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsDiskRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsDiskRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsExternalVpnGatewayRequest. */
                interface ITestIamPermissionsExternalVpnGatewayRequest {

                    /** TestIamPermissionsExternalVpnGatewayRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsExternalVpnGatewayRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsExternalVpnGatewayRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsExternalVpnGatewayRequest. */
                class TestIamPermissionsExternalVpnGatewayRequest implements ITestIamPermissionsExternalVpnGatewayRequest {

                    /**
                     * Constructs a new TestIamPermissionsExternalVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsExternalVpnGatewayRequest);

                    /** TestIamPermissionsExternalVpnGatewayRequest project. */
                    public project: string;

                    /** TestIamPermissionsExternalVpnGatewayRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsExternalVpnGatewayRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsExternalVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsExternalVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsExternalVpnGatewayRequest): google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest;

                    /**
                     * Encodes the specified TestIamPermissionsExternalVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message TestIamPermissionsExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsExternalVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest.verify|verify} messages.
                     * @param message TestIamPermissionsExternalVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsExternalVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsExternalVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest;

                    /**
                     * Decodes a TestIamPermissionsExternalVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsExternalVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest;

                    /**
                     * Verifies a TestIamPermissionsExternalVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsExternalVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsExternalVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsExternalVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsExternalVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsExternalVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsExternalVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsExternalVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsFirewallPolicyRequest. */
                interface ITestIamPermissionsFirewallPolicyRequest {

                    /** TestIamPermissionsFirewallPolicyRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsFirewallPolicyRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsFirewallPolicyRequest. */
                class TestIamPermissionsFirewallPolicyRequest implements ITestIamPermissionsFirewallPolicyRequest {

                    /**
                     * Constructs a new TestIamPermissionsFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsFirewallPolicyRequest);

                    /** TestIamPermissionsFirewallPolicyRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsFirewallPolicyRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsFirewallPolicyRequest): google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest;

                    /**
                     * Encodes the specified TestIamPermissionsFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest;

                    /**
                     * Decodes a TestIamPermissionsFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest;

                    /**
                     * Verifies a TestIamPermissionsFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsImageRequest. */
                interface ITestIamPermissionsImageRequest {

                    /** TestIamPermissionsImageRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsImageRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsImageRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsImageRequest. */
                class TestIamPermissionsImageRequest implements ITestIamPermissionsImageRequest {

                    /**
                     * Constructs a new TestIamPermissionsImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsImageRequest);

                    /** TestIamPermissionsImageRequest project. */
                    public project: string;

                    /** TestIamPermissionsImageRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsImageRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsImageRequest): google.cloud.compute.v1.TestIamPermissionsImageRequest;

                    /**
                     * Encodes the specified TestIamPermissionsImageRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsImageRequest.verify|verify} messages.
                     * @param message TestIamPermissionsImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsImageRequest.verify|verify} messages.
                     * @param message TestIamPermissionsImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsImageRequest;

                    /**
                     * Decodes a TestIamPermissionsImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsImageRequest;

                    /**
                     * Verifies a TestIamPermissionsImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsImageRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsImageRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsInstanceRequest. */
                interface ITestIamPermissionsInstanceRequest {

                    /** TestIamPermissionsInstanceRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsInstanceRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsInstanceRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents a TestIamPermissionsInstanceRequest. */
                class TestIamPermissionsInstanceRequest implements ITestIamPermissionsInstanceRequest {

                    /**
                     * Constructs a new TestIamPermissionsInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsInstanceRequest);

                    /** TestIamPermissionsInstanceRequest project. */
                    public project: string;

                    /** TestIamPermissionsInstanceRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsInstanceRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsInstanceRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new TestIamPermissionsInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsInstanceRequest): google.cloud.compute.v1.TestIamPermissionsInstanceRequest;

                    /**
                     * Encodes the specified TestIamPermissionsInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsInstanceRequest.verify|verify} messages.
                     * @param message TestIamPermissionsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsInstanceRequest.verify|verify} messages.
                     * @param message TestIamPermissionsInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsInstanceRequest;

                    /**
                     * Decodes a TestIamPermissionsInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsInstanceRequest;

                    /**
                     * Verifies a TestIamPermissionsInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsInstanceRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsInstanceRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsInstanceTemplateRequest. */
                interface ITestIamPermissionsInstanceTemplateRequest {

                    /** TestIamPermissionsInstanceTemplateRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsInstanceTemplateRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsInstanceTemplateRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsInstanceTemplateRequest. */
                class TestIamPermissionsInstanceTemplateRequest implements ITestIamPermissionsInstanceTemplateRequest {

                    /**
                     * Constructs a new TestIamPermissionsInstanceTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsInstanceTemplateRequest);

                    /** TestIamPermissionsInstanceTemplateRequest project. */
                    public project: string;

                    /** TestIamPermissionsInstanceTemplateRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsInstanceTemplateRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsInstanceTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsInstanceTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsInstanceTemplateRequest): google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest;

                    /**
                     * Encodes the specified TestIamPermissionsInstanceTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest.verify|verify} messages.
                     * @param message TestIamPermissionsInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsInstanceTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest.verify|verify} messages.
                     * @param message TestIamPermissionsInstanceTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsInstanceTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsInstanceTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest;

                    /**
                     * Decodes a TestIamPermissionsInstanceTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsInstanceTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest;

                    /**
                     * Verifies a TestIamPermissionsInstanceTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsInstanceTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsInstanceTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsInstanceTemplateRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsInstanceTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsInstanceTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsInstanceTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsInstanceTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsLicenseCodeRequest. */
                interface ITestIamPermissionsLicenseCodeRequest {

                    /** TestIamPermissionsLicenseCodeRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsLicenseCodeRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsLicenseCodeRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsLicenseCodeRequest. */
                class TestIamPermissionsLicenseCodeRequest implements ITestIamPermissionsLicenseCodeRequest {

                    /**
                     * Constructs a new TestIamPermissionsLicenseCodeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsLicenseCodeRequest);

                    /** TestIamPermissionsLicenseCodeRequest project. */
                    public project: string;

                    /** TestIamPermissionsLicenseCodeRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsLicenseCodeRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsLicenseCodeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsLicenseCodeRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsLicenseCodeRequest): google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest;

                    /**
                     * Encodes the specified TestIamPermissionsLicenseCodeRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest.verify|verify} messages.
                     * @param message TestIamPermissionsLicenseCodeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsLicenseCodeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsLicenseCodeRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest.verify|verify} messages.
                     * @param message TestIamPermissionsLicenseCodeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsLicenseCodeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsLicenseCodeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsLicenseCodeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest;

                    /**
                     * Decodes a TestIamPermissionsLicenseCodeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsLicenseCodeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest;

                    /**
                     * Verifies a TestIamPermissionsLicenseCodeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsLicenseCodeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsLicenseCodeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsLicenseCodeRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsLicenseCodeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsLicenseCodeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsLicenseCodeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsLicenseCodeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsLicenseRequest. */
                interface ITestIamPermissionsLicenseRequest {

                    /** TestIamPermissionsLicenseRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsLicenseRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsLicenseRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsLicenseRequest. */
                class TestIamPermissionsLicenseRequest implements ITestIamPermissionsLicenseRequest {

                    /**
                     * Constructs a new TestIamPermissionsLicenseRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsLicenseRequest);

                    /** TestIamPermissionsLicenseRequest project. */
                    public project: string;

                    /** TestIamPermissionsLicenseRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsLicenseRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsLicenseRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsLicenseRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsLicenseRequest): google.cloud.compute.v1.TestIamPermissionsLicenseRequest;

                    /**
                     * Encodes the specified TestIamPermissionsLicenseRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsLicenseRequest.verify|verify} messages.
                     * @param message TestIamPermissionsLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsLicenseRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsLicenseRequest.verify|verify} messages.
                     * @param message TestIamPermissionsLicenseRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsLicenseRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsLicenseRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsLicenseRequest;

                    /**
                     * Decodes a TestIamPermissionsLicenseRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsLicenseRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsLicenseRequest;

                    /**
                     * Verifies a TestIamPermissionsLicenseRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsLicenseRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsLicenseRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsLicenseRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsLicenseRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsLicenseRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsLicenseRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsLicenseRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsLicenseRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsMachineImageRequest. */
                interface ITestIamPermissionsMachineImageRequest {

                    /** TestIamPermissionsMachineImageRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsMachineImageRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsMachineImageRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsMachineImageRequest. */
                class TestIamPermissionsMachineImageRequest implements ITestIamPermissionsMachineImageRequest {

                    /**
                     * Constructs a new TestIamPermissionsMachineImageRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsMachineImageRequest);

                    /** TestIamPermissionsMachineImageRequest project. */
                    public project: string;

                    /** TestIamPermissionsMachineImageRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsMachineImageRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsMachineImageRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsMachineImageRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsMachineImageRequest): google.cloud.compute.v1.TestIamPermissionsMachineImageRequest;

                    /**
                     * Encodes the specified TestIamPermissionsMachineImageRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsMachineImageRequest.verify|verify} messages.
                     * @param message TestIamPermissionsMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsMachineImageRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsMachineImageRequest.verify|verify} messages.
                     * @param message TestIamPermissionsMachineImageRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsMachineImageRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsMachineImageRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsMachineImageRequest;

                    /**
                     * Decodes a TestIamPermissionsMachineImageRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsMachineImageRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsMachineImageRequest;

                    /**
                     * Verifies a TestIamPermissionsMachineImageRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsMachineImageRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsMachineImageRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsMachineImageRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsMachineImageRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsMachineImageRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsMachineImageRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsMachineImageRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsMachineImageRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsNetworkEndpointGroupRequest. */
                interface ITestIamPermissionsNetworkEndpointGroupRequest {

                    /** TestIamPermissionsNetworkEndpointGroupRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsNetworkEndpointGroupRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsNetworkEndpointGroupRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsNetworkEndpointGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a TestIamPermissionsNetworkEndpointGroupRequest. */
                class TestIamPermissionsNetworkEndpointGroupRequest implements ITestIamPermissionsNetworkEndpointGroupRequest {

                    /**
                     * Constructs a new TestIamPermissionsNetworkEndpointGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsNetworkEndpointGroupRequest);

                    /** TestIamPermissionsNetworkEndpointGroupRequest project. */
                    public project: string;

                    /** TestIamPermissionsNetworkEndpointGroupRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsNetworkEndpointGroupRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsNetworkEndpointGroupRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new TestIamPermissionsNetworkEndpointGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsNetworkEndpointGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsNetworkEndpointGroupRequest): google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest;

                    /**
                     * Encodes the specified TestIamPermissionsNetworkEndpointGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsNetworkEndpointGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNetworkEndpointGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsNetworkEndpointGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsNetworkEndpointGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest;

                    /**
                     * Decodes a TestIamPermissionsNetworkEndpointGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsNetworkEndpointGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest;

                    /**
                     * Verifies a TestIamPermissionsNetworkEndpointGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsNetworkEndpointGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsNetworkEndpointGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsNetworkEndpointGroupRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsNetworkEndpointGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsNetworkEndpointGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsNetworkEndpointGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsNetworkEndpointGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsNetworkFirewallPolicyRequest. */
                interface ITestIamPermissionsNetworkFirewallPolicyRequest {

                    /** TestIamPermissionsNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsNetworkFirewallPolicyRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsNetworkFirewallPolicyRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsNetworkFirewallPolicyRequest. */
                class TestIamPermissionsNetworkFirewallPolicyRequest implements ITestIamPermissionsNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new TestIamPermissionsNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsNetworkFirewallPolicyRequest);

                    /** TestIamPermissionsNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** TestIamPermissionsNetworkFirewallPolicyRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsNetworkFirewallPolicyRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsNetworkFirewallPolicyRequest): google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified TestIamPermissionsNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a TestIamPermissionsNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a TestIamPermissionsNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsNodeGroupRequest. */
                interface ITestIamPermissionsNodeGroupRequest {

                    /** TestIamPermissionsNodeGroupRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsNodeGroupRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsNodeGroupRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsNodeGroupRequest zone */
                    zone?: (string|null);
                }

                /** Represents a TestIamPermissionsNodeGroupRequest. */
                class TestIamPermissionsNodeGroupRequest implements ITestIamPermissionsNodeGroupRequest {

                    /**
                     * Constructs a new TestIamPermissionsNodeGroupRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest);

                    /** TestIamPermissionsNodeGroupRequest project. */
                    public project: string;

                    /** TestIamPermissionsNodeGroupRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsNodeGroupRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsNodeGroupRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new TestIamPermissionsNodeGroupRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsNodeGroupRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest): google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest;

                    /**
                     * Encodes the specified TestIamPermissionsNodeGroupRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsNodeGroupRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNodeGroupRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsNodeGroupRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest;

                    /**
                     * Decodes a TestIamPermissionsNodeGroupRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsNodeGroupRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest;

                    /**
                     * Verifies a TestIamPermissionsNodeGroupRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsNodeGroupRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsNodeGroupRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsNodeGroupRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsNodeGroupRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsNodeGroupRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsNodeGroupRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsNodeGroupRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsNodeTemplateRequest. */
                interface ITestIamPermissionsNodeTemplateRequest {

                    /** TestIamPermissionsNodeTemplateRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsNodeTemplateRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsNodeTemplateRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsNodeTemplateRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsNodeTemplateRequest. */
                class TestIamPermissionsNodeTemplateRequest implements ITestIamPermissionsNodeTemplateRequest {

                    /**
                     * Constructs a new TestIamPermissionsNodeTemplateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsNodeTemplateRequest);

                    /** TestIamPermissionsNodeTemplateRequest project. */
                    public project: string;

                    /** TestIamPermissionsNodeTemplateRequest region. */
                    public region: string;

                    /** TestIamPermissionsNodeTemplateRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsNodeTemplateRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsNodeTemplateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsNodeTemplateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsNodeTemplateRequest): google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest;

                    /**
                     * Encodes the specified TestIamPermissionsNodeTemplateRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsNodeTemplateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest.verify|verify} messages.
                     * @param message TestIamPermissionsNodeTemplateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsNodeTemplateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsNodeTemplateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest;

                    /**
                     * Decodes a TestIamPermissionsNodeTemplateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsNodeTemplateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest;

                    /**
                     * Verifies a TestIamPermissionsNodeTemplateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsNodeTemplateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsNodeTemplateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsNodeTemplateRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsNodeTemplateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsNodeTemplateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsNodeTemplateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsNodeTemplateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsPacketMirroringRequest. */
                interface ITestIamPermissionsPacketMirroringRequest {

                    /** TestIamPermissionsPacketMirroringRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsPacketMirroringRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsPacketMirroringRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsPacketMirroringRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsPacketMirroringRequest. */
                class TestIamPermissionsPacketMirroringRequest implements ITestIamPermissionsPacketMirroringRequest {

                    /**
                     * Constructs a new TestIamPermissionsPacketMirroringRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsPacketMirroringRequest);

                    /** TestIamPermissionsPacketMirroringRequest project. */
                    public project: string;

                    /** TestIamPermissionsPacketMirroringRequest region. */
                    public region: string;

                    /** TestIamPermissionsPacketMirroringRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsPacketMirroringRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsPacketMirroringRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsPacketMirroringRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsPacketMirroringRequest): google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest;

                    /**
                     * Encodes the specified TestIamPermissionsPacketMirroringRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest.verify|verify} messages.
                     * @param message TestIamPermissionsPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsPacketMirroringRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest.verify|verify} messages.
                     * @param message TestIamPermissionsPacketMirroringRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsPacketMirroringRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsPacketMirroringRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest;

                    /**
                     * Decodes a TestIamPermissionsPacketMirroringRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsPacketMirroringRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest;

                    /**
                     * Verifies a TestIamPermissionsPacketMirroringRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsPacketMirroringRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsPacketMirroringRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsPacketMirroringRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsPacketMirroringRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsPacketMirroringRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsPacketMirroringRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsPacketMirroringRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsRegionDiskRequest. */
                interface ITestIamPermissionsRegionDiskRequest {

                    /** TestIamPermissionsRegionDiskRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsRegionDiskRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsRegionDiskRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsRegionDiskRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsRegionDiskRequest. */
                class TestIamPermissionsRegionDiskRequest implements ITestIamPermissionsRegionDiskRequest {

                    /**
                     * Constructs a new TestIamPermissionsRegionDiskRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsRegionDiskRequest);

                    /** TestIamPermissionsRegionDiskRequest project. */
                    public project: string;

                    /** TestIamPermissionsRegionDiskRequest region. */
                    public region: string;

                    /** TestIamPermissionsRegionDiskRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsRegionDiskRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsRegionDiskRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsRegionDiskRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsRegionDiskRequest): google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest;

                    /**
                     * Encodes the specified TestIamPermissionsRegionDiskRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest.verify|verify} messages.
                     * @param message TestIamPermissionsRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsRegionDiskRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest.verify|verify} messages.
                     * @param message TestIamPermissionsRegionDiskRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsRegionDiskRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsRegionDiskRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest;

                    /**
                     * Decodes a TestIamPermissionsRegionDiskRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsRegionDiskRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest;

                    /**
                     * Verifies a TestIamPermissionsRegionDiskRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsRegionDiskRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsRegionDiskRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsRegionDiskRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsRegionDiskRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsRegionDiskRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsRegionDiskRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsRegionDiskRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsRegionNetworkFirewallPolicyRequest. */
                interface ITestIamPermissionsRegionNetworkFirewallPolicyRequest {

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsRegionNetworkFirewallPolicyRequest. */
                class TestIamPermissionsRegionNetworkFirewallPolicyRequest implements ITestIamPermissionsRegionNetworkFirewallPolicyRequest {

                    /**
                     * Constructs a new TestIamPermissionsRegionNetworkFirewallPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsRegionNetworkFirewallPolicyRequest);

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest project. */
                    public project: string;

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest region. */
                    public region: string;

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsRegionNetworkFirewallPolicyRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsRegionNetworkFirewallPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsRegionNetworkFirewallPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsRegionNetworkFirewallPolicyRequest): google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Encodes the specified TestIamPermissionsRegionNetworkFirewallPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsRegionNetworkFirewallPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsRegionNetworkFirewallPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsRegionNetworkFirewallPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsRegionNetworkFirewallPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Decodes a TestIamPermissionsRegionNetworkFirewallPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsRegionNetworkFirewallPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Verifies a TestIamPermissionsRegionNetworkFirewallPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsRegionNetworkFirewallPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsRegionNetworkFirewallPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsRegionNetworkFirewallPolicyRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsRegionNetworkFirewallPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsRegionNetworkFirewallPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsRegionNetworkFirewallPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsRegionNetworkFirewallPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsReservationRequest. */
                interface ITestIamPermissionsReservationRequest {

                    /** TestIamPermissionsReservationRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsReservationRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsReservationRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a TestIamPermissionsReservationRequest. */
                class TestIamPermissionsReservationRequest implements ITestIamPermissionsReservationRequest {

                    /**
                     * Constructs a new TestIamPermissionsReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsReservationRequest);

                    /** TestIamPermissionsReservationRequest project. */
                    public project: string;

                    /** TestIamPermissionsReservationRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsReservationRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /** TestIamPermissionsReservationRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new TestIamPermissionsReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsReservationRequest): google.cloud.compute.v1.TestIamPermissionsReservationRequest;

                    /**
                     * Encodes the specified TestIamPermissionsReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsReservationRequest.verify|verify} messages.
                     * @param message TestIamPermissionsReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsReservationRequest.verify|verify} messages.
                     * @param message TestIamPermissionsReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsReservationRequest;

                    /**
                     * Decodes a TestIamPermissionsReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsReservationRequest;

                    /**
                     * Verifies a TestIamPermissionsReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsReservationRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsReservationRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsResourcePolicyRequest. */
                interface ITestIamPermissionsResourcePolicyRequest {

                    /** TestIamPermissionsResourcePolicyRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsResourcePolicyRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsResourcePolicyRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsResourcePolicyRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsResourcePolicyRequest. */
                class TestIamPermissionsResourcePolicyRequest implements ITestIamPermissionsResourcePolicyRequest {

                    /**
                     * Constructs a new TestIamPermissionsResourcePolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsResourcePolicyRequest);

                    /** TestIamPermissionsResourcePolicyRequest project. */
                    public project: string;

                    /** TestIamPermissionsResourcePolicyRequest region. */
                    public region: string;

                    /** TestIamPermissionsResourcePolicyRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsResourcePolicyRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsResourcePolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsResourcePolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsResourcePolicyRequest): google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest;

                    /**
                     * Encodes the specified TestIamPermissionsResourcePolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsResourcePolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest.verify|verify} messages.
                     * @param message TestIamPermissionsResourcePolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsResourcePolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsResourcePolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest;

                    /**
                     * Decodes a TestIamPermissionsResourcePolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsResourcePolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest;

                    /**
                     * Verifies a TestIamPermissionsResourcePolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsResourcePolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsResourcePolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsResourcePolicyRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsResourcePolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsResourcePolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsResourcePolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsResourcePolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsServiceAttachmentRequest. */
                interface ITestIamPermissionsServiceAttachmentRequest {

                    /** TestIamPermissionsServiceAttachmentRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsServiceAttachmentRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsServiceAttachmentRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsServiceAttachmentRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsServiceAttachmentRequest. */
                class TestIamPermissionsServiceAttachmentRequest implements ITestIamPermissionsServiceAttachmentRequest {

                    /**
                     * Constructs a new TestIamPermissionsServiceAttachmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsServiceAttachmentRequest);

                    /** TestIamPermissionsServiceAttachmentRequest project. */
                    public project: string;

                    /** TestIamPermissionsServiceAttachmentRequest region. */
                    public region: string;

                    /** TestIamPermissionsServiceAttachmentRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsServiceAttachmentRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsServiceAttachmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsServiceAttachmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsServiceAttachmentRequest): google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest;

                    /**
                     * Encodes the specified TestIamPermissionsServiceAttachmentRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest.verify|verify} messages.
                     * @param message TestIamPermissionsServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsServiceAttachmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest.verify|verify} messages.
                     * @param message TestIamPermissionsServiceAttachmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsServiceAttachmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsServiceAttachmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest;

                    /**
                     * Decodes a TestIamPermissionsServiceAttachmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsServiceAttachmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest;

                    /**
                     * Verifies a TestIamPermissionsServiceAttachmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsServiceAttachmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsServiceAttachmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsServiceAttachmentRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsServiceAttachmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsServiceAttachmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsServiceAttachmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsServiceAttachmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsSnapshotRequest. */
                interface ITestIamPermissionsSnapshotRequest {

                    /** TestIamPermissionsSnapshotRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsSnapshotRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsSnapshotRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsSnapshotRequest. */
                class TestIamPermissionsSnapshotRequest implements ITestIamPermissionsSnapshotRequest {

                    /**
                     * Constructs a new TestIamPermissionsSnapshotRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsSnapshotRequest);

                    /** TestIamPermissionsSnapshotRequest project. */
                    public project: string;

                    /** TestIamPermissionsSnapshotRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsSnapshotRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsSnapshotRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsSnapshotRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsSnapshotRequest): google.cloud.compute.v1.TestIamPermissionsSnapshotRequest;

                    /**
                     * Encodes the specified TestIamPermissionsSnapshotRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsSnapshotRequest.verify|verify} messages.
                     * @param message TestIamPermissionsSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsSnapshotRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsSnapshotRequest.verify|verify} messages.
                     * @param message TestIamPermissionsSnapshotRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsSnapshotRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsSnapshotRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsSnapshotRequest;

                    /**
                     * Decodes a TestIamPermissionsSnapshotRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsSnapshotRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsSnapshotRequest;

                    /**
                     * Verifies a TestIamPermissionsSnapshotRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsSnapshotRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsSnapshotRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsSnapshotRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsSnapshotRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsSnapshotRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsSnapshotRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsSnapshotRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsSnapshotRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsSubnetworkRequest. */
                interface ITestIamPermissionsSubnetworkRequest {

                    /** TestIamPermissionsSubnetworkRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsSubnetworkRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsSubnetworkRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsSubnetworkRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsSubnetworkRequest. */
                class TestIamPermissionsSubnetworkRequest implements ITestIamPermissionsSubnetworkRequest {

                    /**
                     * Constructs a new TestIamPermissionsSubnetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest);

                    /** TestIamPermissionsSubnetworkRequest project. */
                    public project: string;

                    /** TestIamPermissionsSubnetworkRequest region. */
                    public region: string;

                    /** TestIamPermissionsSubnetworkRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsSubnetworkRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsSubnetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsSubnetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest): google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest;

                    /**
                     * Encodes the specified TestIamPermissionsSubnetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest.verify|verify} messages.
                     * @param message TestIamPermissionsSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsSubnetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest.verify|verify} messages.
                     * @param message TestIamPermissionsSubnetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsSubnetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest;

                    /**
                     * Decodes a TestIamPermissionsSubnetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsSubnetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest;

                    /**
                     * Verifies a TestIamPermissionsSubnetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsSubnetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsSubnetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsSubnetworkRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsSubnetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsSubnetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsSubnetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsSubnetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestIamPermissionsVpnGatewayRequest. */
                interface ITestIamPermissionsVpnGatewayRequest {

                    /** TestIamPermissionsVpnGatewayRequest project */
                    project?: (string|null);

                    /** TestIamPermissionsVpnGatewayRequest region */
                    region?: (string|null);

                    /** TestIamPermissionsVpnGatewayRequest resource */
                    resource?: (string|null);

                    /** TestIamPermissionsVpnGatewayRequest testPermissionsRequestResource */
                    testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);
                }

                /** Represents a TestIamPermissionsVpnGatewayRequest. */
                class TestIamPermissionsVpnGatewayRequest implements ITestIamPermissionsVpnGatewayRequest {

                    /**
                     * Constructs a new TestIamPermissionsVpnGatewayRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestIamPermissionsVpnGatewayRequest);

                    /** TestIamPermissionsVpnGatewayRequest project. */
                    public project: string;

                    /** TestIamPermissionsVpnGatewayRequest region. */
                    public region: string;

                    /** TestIamPermissionsVpnGatewayRequest resource. */
                    public resource: string;

                    /** TestIamPermissionsVpnGatewayRequest testPermissionsRequestResource. */
                    public testPermissionsRequestResource?: (google.cloud.compute.v1.ITestPermissionsRequest|null);

                    /**
                     * Creates a new TestIamPermissionsVpnGatewayRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestIamPermissionsVpnGatewayRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestIamPermissionsVpnGatewayRequest): google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest;

                    /**
                     * Encodes the specified TestIamPermissionsVpnGatewayRequest message. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest.verify|verify} messages.
                     * @param message TestIamPermissionsVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestIamPermissionsVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestIamPermissionsVpnGatewayRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest.verify|verify} messages.
                     * @param message TestIamPermissionsVpnGatewayRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestIamPermissionsVpnGatewayRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestIamPermissionsVpnGatewayRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestIamPermissionsVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest;

                    /**
                     * Decodes a TestIamPermissionsVpnGatewayRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestIamPermissionsVpnGatewayRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest;

                    /**
                     * Verifies a TestIamPermissionsVpnGatewayRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestIamPermissionsVpnGatewayRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestIamPermissionsVpnGatewayRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest;

                    /**
                     * Creates a plain object from a TestIamPermissionsVpnGatewayRequest message. Also converts values to other types if specified.
                     * @param message TestIamPermissionsVpnGatewayRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestIamPermissionsVpnGatewayRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestIamPermissionsVpnGatewayRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestIamPermissionsVpnGatewayRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestPermissionsRequest. */
                interface ITestPermissionsRequest {

                    /** TestPermissionsRequest permissions */
                    permissions?: (string[]|null);
                }

                /** Represents a TestPermissionsRequest. */
                class TestPermissionsRequest implements ITestPermissionsRequest {

                    /**
                     * Constructs a new TestPermissionsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestPermissionsRequest);

                    /** TestPermissionsRequest permissions. */
                    public permissions: string[];

                    /**
                     * Creates a new TestPermissionsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestPermissionsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestPermissionsRequest): google.cloud.compute.v1.TestPermissionsRequest;

                    /**
                     * Encodes the specified TestPermissionsRequest message. Does not implicitly {@link google.cloud.compute.v1.TestPermissionsRequest.verify|verify} messages.
                     * @param message TestPermissionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestPermissionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestPermissionsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestPermissionsRequest.verify|verify} messages.
                     * @param message TestPermissionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestPermissionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestPermissionsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestPermissionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestPermissionsRequest;

                    /**
                     * Decodes a TestPermissionsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestPermissionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestPermissionsRequest;

                    /**
                     * Verifies a TestPermissionsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestPermissionsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestPermissionsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestPermissionsRequest;

                    /**
                     * Creates a plain object from a TestPermissionsRequest message. Also converts values to other types if specified.
                     * @param message TestPermissionsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestPermissionsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestPermissionsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestPermissionsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TestPermissionsResponse. */
                interface ITestPermissionsResponse {

                    /** TestPermissionsResponse permissions */
                    permissions?: (string[]|null);
                }

                /** Represents a TestPermissionsResponse. */
                class TestPermissionsResponse implements ITestPermissionsResponse {

                    /**
                     * Constructs a new TestPermissionsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.ITestPermissionsResponse);

                    /** TestPermissionsResponse permissions. */
                    public permissions: string[];

                    /**
                     * Creates a new TestPermissionsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TestPermissionsResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.ITestPermissionsResponse): google.cloud.compute.v1.TestPermissionsResponse;

                    /**
                     * Encodes the specified TestPermissionsResponse message. Does not implicitly {@link google.cloud.compute.v1.TestPermissionsResponse.verify|verify} messages.
                     * @param message TestPermissionsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.ITestPermissionsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TestPermissionsResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.TestPermissionsResponse.verify|verify} messages.
                     * @param message TestPermissionsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.ITestPermissionsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TestPermissionsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TestPermissionsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.TestPermissionsResponse;

                    /**
                     * Decodes a TestPermissionsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TestPermissionsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.TestPermissionsResponse;

                    /**
                     * Verifies a TestPermissionsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TestPermissionsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TestPermissionsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.TestPermissionsResponse;

                    /**
                     * Creates a plain object from a TestPermissionsResponse message. Also converts values to other types if specified.
                     * @param message TestPermissionsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.TestPermissionsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TestPermissionsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TestPermissionsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Uint128. */
                interface IUint128 {

                    /** Uint128 high */
                    high?: (number|Long|string|null);

                    /** Uint128 low */
                    low?: (number|Long|string|null);
                }

                /** Represents an Uint128. */
                class Uint128 implements IUint128 {

                    /**
                     * Constructs a new Uint128.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUint128);

                    /** Uint128 high. */
                    public high?: (number|Long|string|null);

                    /** Uint128 low. */
                    public low?: (number|Long|string|null);

                    /** Uint128 _high. */
                    public _high?: "high";

                    /** Uint128 _low. */
                    public _low?: "low";

                    /**
                     * Creates a new Uint128 instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Uint128 instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUint128): google.cloud.compute.v1.Uint128;

                    /**
                     * Encodes the specified Uint128 message. Does not implicitly {@link google.cloud.compute.v1.Uint128.verify|verify} messages.
                     * @param message Uint128 message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUint128, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Uint128 message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Uint128.verify|verify} messages.
                     * @param message Uint128 message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUint128, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Uint128 message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Uint128
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Uint128;

                    /**
                     * Decodes an Uint128 message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Uint128
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Uint128;

                    /**
                     * Verifies an Uint128 message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Uint128 message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Uint128
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Uint128;

                    /**
                     * Creates a plain object from an Uint128 message. Also converts values to other types if specified.
                     * @param message Uint128
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Uint128, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Uint128 to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Uint128
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateAccessConfigInstanceRequest. */
                interface IUpdateAccessConfigInstanceRequest {

                    /** UpdateAccessConfigInstanceRequest accessConfigResource */
                    accessConfigResource?: (google.cloud.compute.v1.IAccessConfig|null);

                    /** UpdateAccessConfigInstanceRequest instance */
                    instance?: (string|null);

                    /** UpdateAccessConfigInstanceRequest networkInterface */
                    networkInterface?: (string|null);

                    /** UpdateAccessConfigInstanceRequest project */
                    project?: (string|null);

                    /** UpdateAccessConfigInstanceRequest requestId */
                    requestId?: (string|null);

                    /** UpdateAccessConfigInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateAccessConfigInstanceRequest. */
                class UpdateAccessConfigInstanceRequest implements IUpdateAccessConfigInstanceRequest {

                    /**
                     * Constructs a new UpdateAccessConfigInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateAccessConfigInstanceRequest);

                    /** UpdateAccessConfigInstanceRequest accessConfigResource. */
                    public accessConfigResource?: (google.cloud.compute.v1.IAccessConfig|null);

                    /** UpdateAccessConfigInstanceRequest instance. */
                    public instance: string;

                    /** UpdateAccessConfigInstanceRequest networkInterface. */
                    public networkInterface: string;

                    /** UpdateAccessConfigInstanceRequest project. */
                    public project: string;

                    /** UpdateAccessConfigInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateAccessConfigInstanceRequest zone. */
                    public zone: string;

                    /** UpdateAccessConfigInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateAccessConfigInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateAccessConfigInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateAccessConfigInstanceRequest): google.cloud.compute.v1.UpdateAccessConfigInstanceRequest;

                    /**
                     * Encodes the specified UpdateAccessConfigInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateAccessConfigInstanceRequest.verify|verify} messages.
                     * @param message UpdateAccessConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateAccessConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateAccessConfigInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateAccessConfigInstanceRequest.verify|verify} messages.
                     * @param message UpdateAccessConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateAccessConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateAccessConfigInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateAccessConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateAccessConfigInstanceRequest;

                    /**
                     * Decodes an UpdateAccessConfigInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateAccessConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateAccessConfigInstanceRequest;

                    /**
                     * Verifies an UpdateAccessConfigInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateAccessConfigInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateAccessConfigInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateAccessConfigInstanceRequest;

                    /**
                     * Creates a plain object from an UpdateAccessConfigInstanceRequest message. Also converts values to other types if specified.
                     * @param message UpdateAccessConfigInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateAccessConfigInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateAccessConfigInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateAccessConfigInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateAutoscalerRequest. */
                interface IUpdateAutoscalerRequest {

                    /** UpdateAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** UpdateAutoscalerRequest autoscalerResource */
                    autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** UpdateAutoscalerRequest project */
                    project?: (string|null);

                    /** UpdateAutoscalerRequest requestId */
                    requestId?: (string|null);

                    /** UpdateAutoscalerRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateAutoscalerRequest. */
                class UpdateAutoscalerRequest implements IUpdateAutoscalerRequest {

                    /**
                     * Constructs a new UpdateAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateAutoscalerRequest);

                    /** UpdateAutoscalerRequest autoscaler. */
                    public autoscaler?: (string|null);

                    /** UpdateAutoscalerRequest autoscalerResource. */
                    public autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** UpdateAutoscalerRequest project. */
                    public project: string;

                    /** UpdateAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateAutoscalerRequest zone. */
                    public zone: string;

                    /** UpdateAutoscalerRequest _autoscaler. */
                    public _autoscaler?: "autoscaler";

                    /** UpdateAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateAutoscalerRequest): google.cloud.compute.v1.UpdateAutoscalerRequest;

                    /**
                     * Encodes the specified UpdateAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateAutoscalerRequest.verify|verify} messages.
                     * @param message UpdateAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateAutoscalerRequest.verify|verify} messages.
                     * @param message UpdateAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateAutoscalerRequest;

                    /**
                     * Decodes an UpdateAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateAutoscalerRequest;

                    /**
                     * Verifies an UpdateAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateAutoscalerRequest;

                    /**
                     * Creates a plain object from an UpdateAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message UpdateAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateBackendBucketRequest. */
                interface IUpdateBackendBucketRequest {

                    /** UpdateBackendBucketRequest backendBucket */
                    backendBucket?: (string|null);

                    /** UpdateBackendBucketRequest backendBucketResource */
                    backendBucketResource?: (google.cloud.compute.v1.IBackendBucket|null);

                    /** UpdateBackendBucketRequest project */
                    project?: (string|null);

                    /** UpdateBackendBucketRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateBackendBucketRequest. */
                class UpdateBackendBucketRequest implements IUpdateBackendBucketRequest {

                    /**
                     * Constructs a new UpdateBackendBucketRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateBackendBucketRequest);

                    /** UpdateBackendBucketRequest backendBucket. */
                    public backendBucket: string;

                    /** UpdateBackendBucketRequest backendBucketResource. */
                    public backendBucketResource?: (google.cloud.compute.v1.IBackendBucket|null);

                    /** UpdateBackendBucketRequest project. */
                    public project: string;

                    /** UpdateBackendBucketRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateBackendBucketRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateBackendBucketRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateBackendBucketRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateBackendBucketRequest): google.cloud.compute.v1.UpdateBackendBucketRequest;

                    /**
                     * Encodes the specified UpdateBackendBucketRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateBackendBucketRequest.verify|verify} messages.
                     * @param message UpdateBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateBackendBucketRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateBackendBucketRequest.verify|verify} messages.
                     * @param message UpdateBackendBucketRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateBackendBucketRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateBackendBucketRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateBackendBucketRequest;

                    /**
                     * Decodes an UpdateBackendBucketRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateBackendBucketRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateBackendBucketRequest;

                    /**
                     * Verifies an UpdateBackendBucketRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateBackendBucketRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateBackendBucketRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateBackendBucketRequest;

                    /**
                     * Creates a plain object from an UpdateBackendBucketRequest message. Also converts values to other types if specified.
                     * @param message UpdateBackendBucketRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateBackendBucketRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateBackendBucketRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateBackendBucketRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateBackendServiceRequest. */
                interface IUpdateBackendServiceRequest {

                    /** UpdateBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** UpdateBackendServiceRequest backendServiceResource */
                    backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** UpdateBackendServiceRequest project */
                    project?: (string|null);

                    /** UpdateBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateBackendServiceRequest. */
                class UpdateBackendServiceRequest implements IUpdateBackendServiceRequest {

                    /**
                     * Constructs a new UpdateBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateBackendServiceRequest);

                    /** UpdateBackendServiceRequest backendService. */
                    public backendService: string;

                    /** UpdateBackendServiceRequest backendServiceResource. */
                    public backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** UpdateBackendServiceRequest project. */
                    public project: string;

                    /** UpdateBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateBackendServiceRequest): google.cloud.compute.v1.UpdateBackendServiceRequest;

                    /**
                     * Encodes the specified UpdateBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateBackendServiceRequest.verify|verify} messages.
                     * @param message UpdateBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateBackendServiceRequest.verify|verify} messages.
                     * @param message UpdateBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateBackendServiceRequest;

                    /**
                     * Decodes an UpdateBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateBackendServiceRequest;

                    /**
                     * Verifies an UpdateBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateBackendServiceRequest;

                    /**
                     * Creates a plain object from an UpdateBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message UpdateBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateDisplayDeviceInstanceRequest. */
                interface IUpdateDisplayDeviceInstanceRequest {

                    /** UpdateDisplayDeviceInstanceRequest displayDeviceResource */
                    displayDeviceResource?: (google.cloud.compute.v1.IDisplayDevice|null);

                    /** UpdateDisplayDeviceInstanceRequest instance */
                    instance?: (string|null);

                    /** UpdateDisplayDeviceInstanceRequest project */
                    project?: (string|null);

                    /** UpdateDisplayDeviceInstanceRequest requestId */
                    requestId?: (string|null);

                    /** UpdateDisplayDeviceInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateDisplayDeviceInstanceRequest. */
                class UpdateDisplayDeviceInstanceRequest implements IUpdateDisplayDeviceInstanceRequest {

                    /**
                     * Constructs a new UpdateDisplayDeviceInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateDisplayDeviceInstanceRequest);

                    /** UpdateDisplayDeviceInstanceRequest displayDeviceResource. */
                    public displayDeviceResource?: (google.cloud.compute.v1.IDisplayDevice|null);

                    /** UpdateDisplayDeviceInstanceRequest instance. */
                    public instance: string;

                    /** UpdateDisplayDeviceInstanceRequest project. */
                    public project: string;

                    /** UpdateDisplayDeviceInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateDisplayDeviceInstanceRequest zone. */
                    public zone: string;

                    /** UpdateDisplayDeviceInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateDisplayDeviceInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateDisplayDeviceInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateDisplayDeviceInstanceRequest): google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest;

                    /**
                     * Encodes the specified UpdateDisplayDeviceInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest.verify|verify} messages.
                     * @param message UpdateDisplayDeviceInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateDisplayDeviceInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateDisplayDeviceInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest.verify|verify} messages.
                     * @param message UpdateDisplayDeviceInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateDisplayDeviceInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateDisplayDeviceInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateDisplayDeviceInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest;

                    /**
                     * Decodes an UpdateDisplayDeviceInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateDisplayDeviceInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest;

                    /**
                     * Verifies an UpdateDisplayDeviceInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateDisplayDeviceInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateDisplayDeviceInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest;

                    /**
                     * Creates a plain object from an UpdateDisplayDeviceInstanceRequest message. Also converts values to other types if specified.
                     * @param message UpdateDisplayDeviceInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateDisplayDeviceInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateDisplayDeviceInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateDisplayDeviceInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateFirewallRequest. */
                interface IUpdateFirewallRequest {

                    /** UpdateFirewallRequest firewall */
                    firewall?: (string|null);

                    /** UpdateFirewallRequest firewallResource */
                    firewallResource?: (google.cloud.compute.v1.IFirewall|null);

                    /** UpdateFirewallRequest project */
                    project?: (string|null);

                    /** UpdateFirewallRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateFirewallRequest. */
                class UpdateFirewallRequest implements IUpdateFirewallRequest {

                    /**
                     * Constructs a new UpdateFirewallRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateFirewallRequest);

                    /** UpdateFirewallRequest firewall. */
                    public firewall: string;

                    /** UpdateFirewallRequest firewallResource. */
                    public firewallResource?: (google.cloud.compute.v1.IFirewall|null);

                    /** UpdateFirewallRequest project. */
                    public project: string;

                    /** UpdateFirewallRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateFirewallRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateFirewallRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateFirewallRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateFirewallRequest): google.cloud.compute.v1.UpdateFirewallRequest;

                    /**
                     * Encodes the specified UpdateFirewallRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateFirewallRequest.verify|verify} messages.
                     * @param message UpdateFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateFirewallRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateFirewallRequest.verify|verify} messages.
                     * @param message UpdateFirewallRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateFirewallRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateFirewallRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateFirewallRequest;

                    /**
                     * Decodes an UpdateFirewallRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateFirewallRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateFirewallRequest;

                    /**
                     * Verifies an UpdateFirewallRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateFirewallRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateFirewallRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateFirewallRequest;

                    /**
                     * Creates a plain object from an UpdateFirewallRequest message. Also converts values to other types if specified.
                     * @param message UpdateFirewallRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateFirewallRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateFirewallRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateFirewallRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateHealthCheckRequest. */
                interface IUpdateHealthCheckRequest {

                    /** UpdateHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** UpdateHealthCheckRequest healthCheckResource */
                    healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** UpdateHealthCheckRequest project */
                    project?: (string|null);

                    /** UpdateHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateHealthCheckRequest. */
                class UpdateHealthCheckRequest implements IUpdateHealthCheckRequest {

                    /**
                     * Constructs a new UpdateHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateHealthCheckRequest);

                    /** UpdateHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** UpdateHealthCheckRequest healthCheckResource. */
                    public healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** UpdateHealthCheckRequest project. */
                    public project: string;

                    /** UpdateHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateHealthCheckRequest): google.cloud.compute.v1.UpdateHealthCheckRequest;

                    /**
                     * Encodes the specified UpdateHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateHealthCheckRequest.verify|verify} messages.
                     * @param message UpdateHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateHealthCheckRequest.verify|verify} messages.
                     * @param message UpdateHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateHealthCheckRequest;

                    /**
                     * Decodes an UpdateHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateHealthCheckRequest;

                    /**
                     * Verifies an UpdateHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateHealthCheckRequest;

                    /**
                     * Creates a plain object from an UpdateHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message UpdateHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateInstanceRequest. */
                interface IUpdateInstanceRequest {

                    /** UpdateInstanceRequest instance */
                    instance?: (string|null);

                    /** UpdateInstanceRequest instanceResource */
                    instanceResource?: (google.cloud.compute.v1.IInstance|null);

                    /** UpdateInstanceRequest minimalAction */
                    minimalAction?: (string|null);

                    /** UpdateInstanceRequest mostDisruptiveAllowedAction */
                    mostDisruptiveAllowedAction?: (string|null);

                    /** UpdateInstanceRequest project */
                    project?: (string|null);

                    /** UpdateInstanceRequest requestId */
                    requestId?: (string|null);

                    /** UpdateInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateInstanceRequest. */
                class UpdateInstanceRequest implements IUpdateInstanceRequest {

                    /**
                     * Constructs a new UpdateInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateInstanceRequest);

                    /** UpdateInstanceRequest instance. */
                    public instance: string;

                    /** UpdateInstanceRequest instanceResource. */
                    public instanceResource?: (google.cloud.compute.v1.IInstance|null);

                    /** UpdateInstanceRequest minimalAction. */
                    public minimalAction?: (string|null);

                    /** UpdateInstanceRequest mostDisruptiveAllowedAction. */
                    public mostDisruptiveAllowedAction?: (string|null);

                    /** UpdateInstanceRequest project. */
                    public project: string;

                    /** UpdateInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateInstanceRequest zone. */
                    public zone: string;

                    /** UpdateInstanceRequest _minimalAction. */
                    public _minimalAction?: "minimalAction";

                    /** UpdateInstanceRequest _mostDisruptiveAllowedAction. */
                    public _mostDisruptiveAllowedAction?: "mostDisruptiveAllowedAction";

                    /** UpdateInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateInstanceRequest): google.cloud.compute.v1.UpdateInstanceRequest;

                    /**
                     * Encodes the specified UpdateInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateInstanceRequest.verify|verify} messages.
                     * @param message UpdateInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateInstanceRequest.verify|verify} messages.
                     * @param message UpdateInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateInstanceRequest;

                    /**
                     * Decodes an UpdateInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateInstanceRequest;

                    /**
                     * Verifies an UpdateInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateInstanceRequest;

                    /**
                     * Creates a plain object from an UpdateInstanceRequest message. Also converts values to other types if specified.
                     * @param message UpdateInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace UpdateInstanceRequest {

                    /** MinimalAction enum. */
                    enum MinimalAction {
                        UNDEFINED_MINIMAL_ACTION = 0
                    }

                    /** MostDisruptiveAllowedAction enum. */
                    enum MostDisruptiveAllowedAction {
                        UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
                    }
                }

                /** Properties of an UpdateNetworkInterfaceInstanceRequest. */
                interface IUpdateNetworkInterfaceInstanceRequest {

                    /** UpdateNetworkInterfaceInstanceRequest instance */
                    instance?: (string|null);

                    /** UpdateNetworkInterfaceInstanceRequest networkInterface */
                    networkInterface?: (string|null);

                    /** UpdateNetworkInterfaceInstanceRequest networkInterfaceResource */
                    networkInterfaceResource?: (google.cloud.compute.v1.INetworkInterface|null);

                    /** UpdateNetworkInterfaceInstanceRequest project */
                    project?: (string|null);

                    /** UpdateNetworkInterfaceInstanceRequest requestId */
                    requestId?: (string|null);

                    /** UpdateNetworkInterfaceInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateNetworkInterfaceInstanceRequest. */
                class UpdateNetworkInterfaceInstanceRequest implements IUpdateNetworkInterfaceInstanceRequest {

                    /**
                     * Constructs a new UpdateNetworkInterfaceInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateNetworkInterfaceInstanceRequest);

                    /** UpdateNetworkInterfaceInstanceRequest instance. */
                    public instance: string;

                    /** UpdateNetworkInterfaceInstanceRequest networkInterface. */
                    public networkInterface: string;

                    /** UpdateNetworkInterfaceInstanceRequest networkInterfaceResource. */
                    public networkInterfaceResource?: (google.cloud.compute.v1.INetworkInterface|null);

                    /** UpdateNetworkInterfaceInstanceRequest project. */
                    public project: string;

                    /** UpdateNetworkInterfaceInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateNetworkInterfaceInstanceRequest zone. */
                    public zone: string;

                    /** UpdateNetworkInterfaceInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateNetworkInterfaceInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateNetworkInterfaceInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateNetworkInterfaceInstanceRequest): google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest;

                    /**
                     * Encodes the specified UpdateNetworkInterfaceInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest.verify|verify} messages.
                     * @param message UpdateNetworkInterfaceInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateNetworkInterfaceInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateNetworkInterfaceInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest.verify|verify} messages.
                     * @param message UpdateNetworkInterfaceInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateNetworkInterfaceInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateNetworkInterfaceInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateNetworkInterfaceInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest;

                    /**
                     * Decodes an UpdateNetworkInterfaceInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateNetworkInterfaceInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest;

                    /**
                     * Verifies an UpdateNetworkInterfaceInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateNetworkInterfaceInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateNetworkInterfaceInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest;

                    /**
                     * Creates a plain object from an UpdateNetworkInterfaceInstanceRequest message. Also converts values to other types if specified.
                     * @param message UpdateNetworkInterfaceInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateNetworkInterfaceInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateNetworkInterfaceInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateNetworkInterfaceInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdatePeeringNetworkRequest. */
                interface IUpdatePeeringNetworkRequest {

                    /** UpdatePeeringNetworkRequest network */
                    network?: (string|null);

                    /** UpdatePeeringNetworkRequest networksUpdatePeeringRequestResource */
                    networksUpdatePeeringRequestResource?: (google.cloud.compute.v1.INetworksUpdatePeeringRequest|null);

                    /** UpdatePeeringNetworkRequest project */
                    project?: (string|null);

                    /** UpdatePeeringNetworkRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdatePeeringNetworkRequest. */
                class UpdatePeeringNetworkRequest implements IUpdatePeeringNetworkRequest {

                    /**
                     * Constructs a new UpdatePeeringNetworkRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdatePeeringNetworkRequest);

                    /** UpdatePeeringNetworkRequest network. */
                    public network: string;

                    /** UpdatePeeringNetworkRequest networksUpdatePeeringRequestResource. */
                    public networksUpdatePeeringRequestResource?: (google.cloud.compute.v1.INetworksUpdatePeeringRequest|null);

                    /** UpdatePeeringNetworkRequest project. */
                    public project: string;

                    /** UpdatePeeringNetworkRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdatePeeringNetworkRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdatePeeringNetworkRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdatePeeringNetworkRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdatePeeringNetworkRequest): google.cloud.compute.v1.UpdatePeeringNetworkRequest;

                    /**
                     * Encodes the specified UpdatePeeringNetworkRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdatePeeringNetworkRequest.verify|verify} messages.
                     * @param message UpdatePeeringNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdatePeeringNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdatePeeringNetworkRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdatePeeringNetworkRequest.verify|verify} messages.
                     * @param message UpdatePeeringNetworkRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdatePeeringNetworkRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdatePeeringNetworkRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdatePeeringNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdatePeeringNetworkRequest;

                    /**
                     * Decodes an UpdatePeeringNetworkRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdatePeeringNetworkRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdatePeeringNetworkRequest;

                    /**
                     * Verifies an UpdatePeeringNetworkRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdatePeeringNetworkRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdatePeeringNetworkRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdatePeeringNetworkRequest;

                    /**
                     * Creates a plain object from an UpdatePeeringNetworkRequest message. Also converts values to other types if specified.
                     * @param message UpdatePeeringNetworkRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdatePeeringNetworkRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdatePeeringNetworkRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdatePeeringNetworkRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdatePerInstanceConfigsInstanceGroupManagerRequest. */
                interface IUpdatePerInstanceConfigsInstanceGroupManagerRequest {

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManagersUpdatePerInstanceConfigsReqResource */
                    instanceGroupManagersUpdatePerInstanceConfigsReqResource?: (google.cloud.compute.v1.IInstanceGroupManagersUpdatePerInstanceConfigsReq|null);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdatePerInstanceConfigsInstanceGroupManagerRequest. */
                class UpdatePerInstanceConfigsInstanceGroupManagerRequest implements IUpdatePerInstanceConfigsInstanceGroupManagerRequest {

                    /**
                     * Constructs a new UpdatePerInstanceConfigsInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest instanceGroupManagersUpdatePerInstanceConfigsReqResource. */
                    public instanceGroupManagersUpdatePerInstanceConfigsReqResource?: (google.cloud.compute.v1.IInstanceGroupManagersUpdatePerInstanceConfigsReq|null);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest project. */
                    public project: string;

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest zone. */
                    public zone: string;

                    /** UpdatePerInstanceConfigsInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdatePerInstanceConfigsInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdatePerInstanceConfigsInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest): google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified UpdatePerInstanceConfigsInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message UpdatePerInstanceConfigsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdatePerInstanceConfigsInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message UpdatePerInstanceConfigsInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdatePerInstanceConfigsInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdatePerInstanceConfigsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Decodes an UpdatePerInstanceConfigsInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdatePerInstanceConfigsInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Verifies an UpdatePerInstanceConfigsInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdatePerInstanceConfigsInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdatePerInstanceConfigsInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an UpdatePerInstanceConfigsInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message UpdatePerInstanceConfigsInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdatePerInstanceConfigsInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdatePerInstanceConfigsInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdatePerInstanceConfigsInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest. */
                interface IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest {

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest instanceGroupManager */
                    instanceGroupManager?: (string|null);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest project */
                    project?: (string|null);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest region */
                    region?: (string|null);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest regionInstanceGroupManagerUpdateInstanceConfigReqResource */
                    regionInstanceGroupManagerUpdateInstanceConfigReqResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagerUpdateInstanceConfigReq|null);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest. */
                class UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest implements IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest {

                    /**
                     * Constructs a new UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest instanceGroupManager. */
                    public instanceGroupManager: string;

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest project. */
                    public project: string;

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest region. */
                    public region: string;

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest regionInstanceGroupManagerUpdateInstanceConfigReqResource. */
                    public regionInstanceGroupManagerUpdateInstanceConfigReqResource?: (google.cloud.compute.v1.IRegionInstanceGroupManagerUpdateInstanceConfigReq|null);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest): google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Encodes the specified UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest.verify|verify} messages.
                     * @param message UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Decodes an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Verifies an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest;

                    /**
                     * Creates a plain object from an UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message. Also converts values to other types if specified.
                     * @param message UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateRegionAutoscalerRequest. */
                interface IUpdateRegionAutoscalerRequest {

                    /** UpdateRegionAutoscalerRequest autoscaler */
                    autoscaler?: (string|null);

                    /** UpdateRegionAutoscalerRequest autoscalerResource */
                    autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** UpdateRegionAutoscalerRequest project */
                    project?: (string|null);

                    /** UpdateRegionAutoscalerRequest region */
                    region?: (string|null);

                    /** UpdateRegionAutoscalerRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateRegionAutoscalerRequest. */
                class UpdateRegionAutoscalerRequest implements IUpdateRegionAutoscalerRequest {

                    /**
                     * Constructs a new UpdateRegionAutoscalerRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateRegionAutoscalerRequest);

                    /** UpdateRegionAutoscalerRequest autoscaler. */
                    public autoscaler?: (string|null);

                    /** UpdateRegionAutoscalerRequest autoscalerResource. */
                    public autoscalerResource?: (google.cloud.compute.v1.IAutoscaler|null);

                    /** UpdateRegionAutoscalerRequest project. */
                    public project: string;

                    /** UpdateRegionAutoscalerRequest region. */
                    public region: string;

                    /** UpdateRegionAutoscalerRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateRegionAutoscalerRequest _autoscaler. */
                    public _autoscaler?: "autoscaler";

                    /** UpdateRegionAutoscalerRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateRegionAutoscalerRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateRegionAutoscalerRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateRegionAutoscalerRequest): google.cloud.compute.v1.UpdateRegionAutoscalerRequest;

                    /**
                     * Encodes the specified UpdateRegionAutoscalerRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionAutoscalerRequest.verify|verify} messages.
                     * @param message UpdateRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateRegionAutoscalerRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionAutoscalerRequest.verify|verify} messages.
                     * @param message UpdateRegionAutoscalerRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateRegionAutoscalerRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateRegionAutoscalerRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateRegionAutoscalerRequest;

                    /**
                     * Decodes an UpdateRegionAutoscalerRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateRegionAutoscalerRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateRegionAutoscalerRequest;

                    /**
                     * Verifies an UpdateRegionAutoscalerRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateRegionAutoscalerRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateRegionAutoscalerRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateRegionAutoscalerRequest;

                    /**
                     * Creates a plain object from an UpdateRegionAutoscalerRequest message. Also converts values to other types if specified.
                     * @param message UpdateRegionAutoscalerRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateRegionAutoscalerRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateRegionAutoscalerRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateRegionAutoscalerRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateRegionBackendServiceRequest. */
                interface IUpdateRegionBackendServiceRequest {

                    /** UpdateRegionBackendServiceRequest backendService */
                    backendService?: (string|null);

                    /** UpdateRegionBackendServiceRequest backendServiceResource */
                    backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** UpdateRegionBackendServiceRequest project */
                    project?: (string|null);

                    /** UpdateRegionBackendServiceRequest region */
                    region?: (string|null);

                    /** UpdateRegionBackendServiceRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateRegionBackendServiceRequest. */
                class UpdateRegionBackendServiceRequest implements IUpdateRegionBackendServiceRequest {

                    /**
                     * Constructs a new UpdateRegionBackendServiceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateRegionBackendServiceRequest);

                    /** UpdateRegionBackendServiceRequest backendService. */
                    public backendService: string;

                    /** UpdateRegionBackendServiceRequest backendServiceResource. */
                    public backendServiceResource?: (google.cloud.compute.v1.IBackendService|null);

                    /** UpdateRegionBackendServiceRequest project. */
                    public project: string;

                    /** UpdateRegionBackendServiceRequest region. */
                    public region: string;

                    /** UpdateRegionBackendServiceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateRegionBackendServiceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateRegionBackendServiceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateRegionBackendServiceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateRegionBackendServiceRequest): google.cloud.compute.v1.UpdateRegionBackendServiceRequest;

                    /**
                     * Encodes the specified UpdateRegionBackendServiceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionBackendServiceRequest.verify|verify} messages.
                     * @param message UpdateRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateRegionBackendServiceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionBackendServiceRequest.verify|verify} messages.
                     * @param message UpdateRegionBackendServiceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateRegionBackendServiceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateRegionBackendServiceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateRegionBackendServiceRequest;

                    /**
                     * Decodes an UpdateRegionBackendServiceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateRegionBackendServiceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateRegionBackendServiceRequest;

                    /**
                     * Verifies an UpdateRegionBackendServiceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateRegionBackendServiceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateRegionBackendServiceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateRegionBackendServiceRequest;

                    /**
                     * Creates a plain object from an UpdateRegionBackendServiceRequest message. Also converts values to other types if specified.
                     * @param message UpdateRegionBackendServiceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateRegionBackendServiceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateRegionBackendServiceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateRegionBackendServiceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateRegionCommitmentRequest. */
                interface IUpdateRegionCommitmentRequest {

                    /** UpdateRegionCommitmentRequest commitment */
                    commitment?: (string|null);

                    /** UpdateRegionCommitmentRequest commitmentResource */
                    commitmentResource?: (google.cloud.compute.v1.ICommitment|null);

                    /** UpdateRegionCommitmentRequest paths */
                    paths?: (string|null);

                    /** UpdateRegionCommitmentRequest project */
                    project?: (string|null);

                    /** UpdateRegionCommitmentRequest region */
                    region?: (string|null);

                    /** UpdateRegionCommitmentRequest requestId */
                    requestId?: (string|null);

                    /** UpdateRegionCommitmentRequest updateMask */
                    updateMask?: (string|null);
                }

                /** Represents an UpdateRegionCommitmentRequest. */
                class UpdateRegionCommitmentRequest implements IUpdateRegionCommitmentRequest {

                    /**
                     * Constructs a new UpdateRegionCommitmentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateRegionCommitmentRequest);

                    /** UpdateRegionCommitmentRequest commitment. */
                    public commitment: string;

                    /** UpdateRegionCommitmentRequest commitmentResource. */
                    public commitmentResource?: (google.cloud.compute.v1.ICommitment|null);

                    /** UpdateRegionCommitmentRequest paths. */
                    public paths?: (string|null);

                    /** UpdateRegionCommitmentRequest project. */
                    public project: string;

                    /** UpdateRegionCommitmentRequest region. */
                    public region: string;

                    /** UpdateRegionCommitmentRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateRegionCommitmentRequest updateMask. */
                    public updateMask?: (string|null);

                    /** UpdateRegionCommitmentRequest _paths. */
                    public _paths?: "paths";

                    /** UpdateRegionCommitmentRequest _requestId. */
                    public _requestId?: "requestId";

                    /** UpdateRegionCommitmentRequest _updateMask. */
                    public _updateMask?: "updateMask";

                    /**
                     * Creates a new UpdateRegionCommitmentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateRegionCommitmentRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateRegionCommitmentRequest): google.cloud.compute.v1.UpdateRegionCommitmentRequest;

                    /**
                     * Encodes the specified UpdateRegionCommitmentRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionCommitmentRequest.verify|verify} messages.
                     * @param message UpdateRegionCommitmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateRegionCommitmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateRegionCommitmentRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionCommitmentRequest.verify|verify} messages.
                     * @param message UpdateRegionCommitmentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateRegionCommitmentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateRegionCommitmentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateRegionCommitmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateRegionCommitmentRequest;

                    /**
                     * Decodes an UpdateRegionCommitmentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateRegionCommitmentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateRegionCommitmentRequest;

                    /**
                     * Verifies an UpdateRegionCommitmentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateRegionCommitmentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateRegionCommitmentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateRegionCommitmentRequest;

                    /**
                     * Creates a plain object from an UpdateRegionCommitmentRequest message. Also converts values to other types if specified.
                     * @param message UpdateRegionCommitmentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateRegionCommitmentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateRegionCommitmentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateRegionCommitmentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateRegionHealthCheckRequest. */
                interface IUpdateRegionHealthCheckRequest {

                    /** UpdateRegionHealthCheckRequest healthCheck */
                    healthCheck?: (string|null);

                    /** UpdateRegionHealthCheckRequest healthCheckResource */
                    healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** UpdateRegionHealthCheckRequest project */
                    project?: (string|null);

                    /** UpdateRegionHealthCheckRequest region */
                    region?: (string|null);

                    /** UpdateRegionHealthCheckRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an UpdateRegionHealthCheckRequest. */
                class UpdateRegionHealthCheckRequest implements IUpdateRegionHealthCheckRequest {

                    /**
                     * Constructs a new UpdateRegionHealthCheckRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateRegionHealthCheckRequest);

                    /** UpdateRegionHealthCheckRequest healthCheck. */
                    public healthCheck: string;

                    /** UpdateRegionHealthCheckRequest healthCheckResource. */
                    public healthCheckResource?: (google.cloud.compute.v1.IHealthCheck|null);

                    /** UpdateRegionHealthCheckRequest project. */
                    public project: string;

                    /** UpdateRegionHealthCheckRequest region. */
                    public region: string;

                    /** UpdateRegionHealthCheckRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateRegionHealthCheckRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateRegionHealthCheckRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateRegionHealthCheckRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateRegionHealthCheckRequest): google.cloud.compute.v1.UpdateRegionHealthCheckRequest;

                    /**
                     * Encodes the specified UpdateRegionHealthCheckRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionHealthCheckRequest.verify|verify} messages.
                     * @param message UpdateRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateRegionHealthCheckRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionHealthCheckRequest.verify|verify} messages.
                     * @param message UpdateRegionHealthCheckRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateRegionHealthCheckRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateRegionHealthCheckRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateRegionHealthCheckRequest;

                    /**
                     * Decodes an UpdateRegionHealthCheckRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateRegionHealthCheckRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateRegionHealthCheckRequest;

                    /**
                     * Verifies an UpdateRegionHealthCheckRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateRegionHealthCheckRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateRegionHealthCheckRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateRegionHealthCheckRequest;

                    /**
                     * Creates a plain object from an UpdateRegionHealthCheckRequest message. Also converts values to other types if specified.
                     * @param message UpdateRegionHealthCheckRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateRegionHealthCheckRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateRegionHealthCheckRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateRegionHealthCheckRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateRegionUrlMapRequest. */
                interface IUpdateRegionUrlMapRequest {

                    /** UpdateRegionUrlMapRequest project */
                    project?: (string|null);

                    /** UpdateRegionUrlMapRequest region */
                    region?: (string|null);

                    /** UpdateRegionUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** UpdateRegionUrlMapRequest urlMap */
                    urlMap?: (string|null);

                    /** UpdateRegionUrlMapRequest urlMapResource */
                    urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents an UpdateRegionUrlMapRequest. */
                class UpdateRegionUrlMapRequest implements IUpdateRegionUrlMapRequest {

                    /**
                     * Constructs a new UpdateRegionUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateRegionUrlMapRequest);

                    /** UpdateRegionUrlMapRequest project. */
                    public project: string;

                    /** UpdateRegionUrlMapRequest region. */
                    public region: string;

                    /** UpdateRegionUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateRegionUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** UpdateRegionUrlMapRequest urlMapResource. */
                    public urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** UpdateRegionUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateRegionUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateRegionUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateRegionUrlMapRequest): google.cloud.compute.v1.UpdateRegionUrlMapRequest;

                    /**
                     * Encodes the specified UpdateRegionUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionUrlMapRequest.verify|verify} messages.
                     * @param message UpdateRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateRegionUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateRegionUrlMapRequest.verify|verify} messages.
                     * @param message UpdateRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateRegionUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateRegionUrlMapRequest;

                    /**
                     * Decodes an UpdateRegionUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateRegionUrlMapRequest;

                    /**
                     * Verifies an UpdateRegionUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateRegionUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateRegionUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateRegionUrlMapRequest;

                    /**
                     * Creates a plain object from an UpdateRegionUrlMapRequest message. Also converts values to other types if specified.
                     * @param message UpdateRegionUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateRegionUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateRegionUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateRegionUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateReservationRequest. */
                interface IUpdateReservationRequest {

                    /** UpdateReservationRequest paths */
                    paths?: (string|null);

                    /** UpdateReservationRequest project */
                    project?: (string|null);

                    /** UpdateReservationRequest requestId */
                    requestId?: (string|null);

                    /** UpdateReservationRequest reservation */
                    reservation?: (string|null);

                    /** UpdateReservationRequest reservationResource */
                    reservationResource?: (google.cloud.compute.v1.IReservation|null);

                    /** UpdateReservationRequest updateMask */
                    updateMask?: (string|null);

                    /** UpdateReservationRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateReservationRequest. */
                class UpdateReservationRequest implements IUpdateReservationRequest {

                    /**
                     * Constructs a new UpdateReservationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateReservationRequest);

                    /** UpdateReservationRequest paths. */
                    public paths?: (string|null);

                    /** UpdateReservationRequest project. */
                    public project: string;

                    /** UpdateReservationRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateReservationRequest reservation. */
                    public reservation: string;

                    /** UpdateReservationRequest reservationResource. */
                    public reservationResource?: (google.cloud.compute.v1.IReservation|null);

                    /** UpdateReservationRequest updateMask. */
                    public updateMask?: (string|null);

                    /** UpdateReservationRequest zone. */
                    public zone: string;

                    /** UpdateReservationRequest _paths. */
                    public _paths?: "paths";

                    /** UpdateReservationRequest _requestId. */
                    public _requestId?: "requestId";

                    /** UpdateReservationRequest _updateMask. */
                    public _updateMask?: "updateMask";

                    /**
                     * Creates a new UpdateReservationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateReservationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateReservationRequest): google.cloud.compute.v1.UpdateReservationRequest;

                    /**
                     * Encodes the specified UpdateReservationRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateReservationRequest.verify|verify} messages.
                     * @param message UpdateReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateReservationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateReservationRequest.verify|verify} messages.
                     * @param message UpdateReservationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateReservationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateReservationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateReservationRequest;

                    /**
                     * Decodes an UpdateReservationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateReservationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateReservationRequest;

                    /**
                     * Verifies an UpdateReservationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateReservationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateReservationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateReservationRequest;

                    /**
                     * Creates a plain object from an UpdateReservationRequest message. Also converts values to other types if specified.
                     * @param message UpdateReservationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateReservationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateReservationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateReservationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateRouterRequest. */
                interface IUpdateRouterRequest {

                    /** UpdateRouterRequest project */
                    project?: (string|null);

                    /** UpdateRouterRequest region */
                    region?: (string|null);

                    /** UpdateRouterRequest requestId */
                    requestId?: (string|null);

                    /** UpdateRouterRequest router */
                    router?: (string|null);

                    /** UpdateRouterRequest routerResource */
                    routerResource?: (google.cloud.compute.v1.IRouter|null);
                }

                /** Represents an UpdateRouterRequest. */
                class UpdateRouterRequest implements IUpdateRouterRequest {

                    /**
                     * Constructs a new UpdateRouterRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateRouterRequest);

                    /** UpdateRouterRequest project. */
                    public project: string;

                    /** UpdateRouterRequest region. */
                    public region: string;

                    /** UpdateRouterRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateRouterRequest router. */
                    public router: string;

                    /** UpdateRouterRequest routerResource. */
                    public routerResource?: (google.cloud.compute.v1.IRouter|null);

                    /** UpdateRouterRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateRouterRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateRouterRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateRouterRequest): google.cloud.compute.v1.UpdateRouterRequest;

                    /**
                     * Encodes the specified UpdateRouterRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateRouterRequest.verify|verify} messages.
                     * @param message UpdateRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateRouterRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateRouterRequest.verify|verify} messages.
                     * @param message UpdateRouterRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateRouterRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateRouterRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateRouterRequest;

                    /**
                     * Decodes an UpdateRouterRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateRouterRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateRouterRequest;

                    /**
                     * Verifies an UpdateRouterRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateRouterRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateRouterRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateRouterRequest;

                    /**
                     * Creates a plain object from an UpdateRouterRequest message. Also converts values to other types if specified.
                     * @param message UpdateRouterRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateRouterRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateRouterRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateRouterRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateShieldedInstanceConfigInstanceRequest. */
                interface IUpdateShieldedInstanceConfigInstanceRequest {

                    /** UpdateShieldedInstanceConfigInstanceRequest instance */
                    instance?: (string|null);

                    /** UpdateShieldedInstanceConfigInstanceRequest project */
                    project?: (string|null);

                    /** UpdateShieldedInstanceConfigInstanceRequest requestId */
                    requestId?: (string|null);

                    /** UpdateShieldedInstanceConfigInstanceRequest shieldedInstanceConfigResource */
                    shieldedInstanceConfigResource?: (google.cloud.compute.v1.IShieldedInstanceConfig|null);

                    /** UpdateShieldedInstanceConfigInstanceRequest zone */
                    zone?: (string|null);
                }

                /** Represents an UpdateShieldedInstanceConfigInstanceRequest. */
                class UpdateShieldedInstanceConfigInstanceRequest implements IUpdateShieldedInstanceConfigInstanceRequest {

                    /**
                     * Constructs a new UpdateShieldedInstanceConfigInstanceRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateShieldedInstanceConfigInstanceRequest);

                    /** UpdateShieldedInstanceConfigInstanceRequest instance. */
                    public instance: string;

                    /** UpdateShieldedInstanceConfigInstanceRequest project. */
                    public project: string;

                    /** UpdateShieldedInstanceConfigInstanceRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateShieldedInstanceConfigInstanceRequest shieldedInstanceConfigResource. */
                    public shieldedInstanceConfigResource?: (google.cloud.compute.v1.IShieldedInstanceConfig|null);

                    /** UpdateShieldedInstanceConfigInstanceRequest zone. */
                    public zone: string;

                    /** UpdateShieldedInstanceConfigInstanceRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateShieldedInstanceConfigInstanceRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateShieldedInstanceConfigInstanceRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateShieldedInstanceConfigInstanceRequest): google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest;

                    /**
                     * Encodes the specified UpdateShieldedInstanceConfigInstanceRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest.verify|verify} messages.
                     * @param message UpdateShieldedInstanceConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateShieldedInstanceConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateShieldedInstanceConfigInstanceRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest.verify|verify} messages.
                     * @param message UpdateShieldedInstanceConfigInstanceRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateShieldedInstanceConfigInstanceRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateShieldedInstanceConfigInstanceRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateShieldedInstanceConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest;

                    /**
                     * Decodes an UpdateShieldedInstanceConfigInstanceRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateShieldedInstanceConfigInstanceRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest;

                    /**
                     * Verifies an UpdateShieldedInstanceConfigInstanceRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateShieldedInstanceConfigInstanceRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateShieldedInstanceConfigInstanceRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest;

                    /**
                     * Creates a plain object from an UpdateShieldedInstanceConfigInstanceRequest message. Also converts values to other types if specified.
                     * @param message UpdateShieldedInstanceConfigInstanceRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateShieldedInstanceConfigInstanceRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateShieldedInstanceConfigInstanceRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateShieldedInstanceConfigInstanceRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateUrlMapRequest. */
                interface IUpdateUrlMapRequest {

                    /** UpdateUrlMapRequest project */
                    project?: (string|null);

                    /** UpdateUrlMapRequest requestId */
                    requestId?: (string|null);

                    /** UpdateUrlMapRequest urlMap */
                    urlMap?: (string|null);

                    /** UpdateUrlMapRequest urlMapResource */
                    urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents an UpdateUrlMapRequest. */
                class UpdateUrlMapRequest implements IUpdateUrlMapRequest {

                    /**
                     * Constructs a new UpdateUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUpdateUrlMapRequest);

                    /** UpdateUrlMapRequest project. */
                    public project: string;

                    /** UpdateUrlMapRequest requestId. */
                    public requestId?: (string|null);

                    /** UpdateUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** UpdateUrlMapRequest urlMapResource. */
                    public urlMapResource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** UpdateUrlMapRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new UpdateUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUpdateUrlMapRequest): google.cloud.compute.v1.UpdateUrlMapRequest;

                    /**
                     * Encodes the specified UpdateUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.UpdateUrlMapRequest.verify|verify} messages.
                     * @param message UpdateUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUpdateUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UpdateUrlMapRequest.verify|verify} messages.
                     * @param message UpdateUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUpdateUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UpdateUrlMapRequest;

                    /**
                     * Decodes an UpdateUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UpdateUrlMapRequest;

                    /**
                     * Verifies an UpdateUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UpdateUrlMapRequest;

                    /**
                     * Creates a plain object from an UpdateUrlMapRequest message. Also converts values to other types if specified.
                     * @param message UpdateUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UpdateUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMap. */
                interface IUrlMap {

                    /** UrlMap creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** UrlMap defaultRouteAction */
                    defaultRouteAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** UrlMap defaultService */
                    defaultService?: (string|null);

                    /** UrlMap defaultUrlRedirect */
                    defaultUrlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);

                    /** UrlMap description */
                    description?: (string|null);

                    /** UrlMap fingerprint */
                    fingerprint?: (string|null);

                    /** UrlMap headerAction */
                    headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** UrlMap hostRules */
                    hostRules?: (google.cloud.compute.v1.IHostRule[]|null);

                    /** UrlMap id */
                    id?: (number|Long|string|null);

                    /** UrlMap kind */
                    kind?: (string|null);

                    /** UrlMap name */
                    name?: (string|null);

                    /** UrlMap pathMatchers */
                    pathMatchers?: (google.cloud.compute.v1.IPathMatcher[]|null);

                    /** UrlMap region */
                    region?: (string|null);

                    /** UrlMap selfLink */
                    selfLink?: (string|null);

                    /** UrlMap tests */
                    tests?: (google.cloud.compute.v1.IUrlMapTest[]|null);
                }

                /** Represents an UrlMap. */
                class UrlMap implements IUrlMap {

                    /**
                     * Constructs a new UrlMap.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMap);

                    /** UrlMap creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** UrlMap defaultRouteAction. */
                    public defaultRouteAction?: (google.cloud.compute.v1.IHttpRouteAction|null);

                    /** UrlMap defaultService. */
                    public defaultService?: (string|null);

                    /** UrlMap defaultUrlRedirect. */
                    public defaultUrlRedirect?: (google.cloud.compute.v1.IHttpRedirectAction|null);

                    /** UrlMap description. */
                    public description?: (string|null);

                    /** UrlMap fingerprint. */
                    public fingerprint?: (string|null);

                    /** UrlMap headerAction. */
                    public headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** UrlMap hostRules. */
                    public hostRules: google.cloud.compute.v1.IHostRule[];

                    /** UrlMap id. */
                    public id?: (number|Long|string|null);

                    /** UrlMap kind. */
                    public kind?: (string|null);

                    /** UrlMap name. */
                    public name?: (string|null);

                    /** UrlMap pathMatchers. */
                    public pathMatchers: google.cloud.compute.v1.IPathMatcher[];

                    /** UrlMap region. */
                    public region?: (string|null);

                    /** UrlMap selfLink. */
                    public selfLink?: (string|null);

                    /** UrlMap tests. */
                    public tests: google.cloud.compute.v1.IUrlMapTest[];

                    /** UrlMap _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** UrlMap _defaultRouteAction. */
                    public _defaultRouteAction?: "defaultRouteAction";

                    /** UrlMap _defaultService. */
                    public _defaultService?: "defaultService";

                    /** UrlMap _defaultUrlRedirect. */
                    public _defaultUrlRedirect?: "defaultUrlRedirect";

                    /** UrlMap _description. */
                    public _description?: "description";

                    /** UrlMap _fingerprint. */
                    public _fingerprint?: "fingerprint";

                    /** UrlMap _headerAction. */
                    public _headerAction?: "headerAction";

                    /** UrlMap _id. */
                    public _id?: "id";

                    /** UrlMap _kind. */
                    public _kind?: "kind";

                    /** UrlMap _name. */
                    public _name?: "name";

                    /** UrlMap _region. */
                    public _region?: "region";

                    /** UrlMap _selfLink. */
                    public _selfLink?: "selfLink";

                    /**
                     * Creates a new UrlMap instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMap instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMap): google.cloud.compute.v1.UrlMap;

                    /**
                     * Encodes the specified UrlMap message. Does not implicitly {@link google.cloud.compute.v1.UrlMap.verify|verify} messages.
                     * @param message UrlMap message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMap, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMap message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMap.verify|verify} messages.
                     * @param message UrlMap message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMap, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMap message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMap
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMap;

                    /**
                     * Decodes an UrlMap message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMap
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMap;

                    /**
                     * Verifies an UrlMap message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMap message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMap
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMap;

                    /**
                     * Creates a plain object from an UrlMap message. Also converts values to other types if specified.
                     * @param message UrlMap
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMap, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMap to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMap
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapList. */
                interface IUrlMapList {

                    /** UrlMapList id */
                    id?: (string|null);

                    /** UrlMapList items */
                    items?: (google.cloud.compute.v1.IUrlMap[]|null);

                    /** UrlMapList kind */
                    kind?: (string|null);

                    /** UrlMapList nextPageToken */
                    nextPageToken?: (string|null);

                    /** UrlMapList selfLink */
                    selfLink?: (string|null);

                    /** UrlMapList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an UrlMapList. */
                class UrlMapList implements IUrlMapList {

                    /**
                     * Constructs a new UrlMapList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapList);

                    /** UrlMapList id. */
                    public id?: (string|null);

                    /** UrlMapList items. */
                    public items: google.cloud.compute.v1.IUrlMap[];

                    /** UrlMapList kind. */
                    public kind?: (string|null);

                    /** UrlMapList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** UrlMapList selfLink. */
                    public selfLink?: (string|null);

                    /** UrlMapList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** UrlMapList _id. */
                    public _id?: "id";

                    /** UrlMapList _kind. */
                    public _kind?: "kind";

                    /** UrlMapList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** UrlMapList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** UrlMapList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new UrlMapList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapList): google.cloud.compute.v1.UrlMapList;

                    /**
                     * Encodes the specified UrlMapList message. Does not implicitly {@link google.cloud.compute.v1.UrlMapList.verify|verify} messages.
                     * @param message UrlMapList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapList.verify|verify} messages.
                     * @param message UrlMapList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapList;

                    /**
                     * Decodes an UrlMapList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapList;

                    /**
                     * Verifies an UrlMapList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapList;

                    /**
                     * Creates a plain object from an UrlMapList message. Also converts values to other types if specified.
                     * @param message UrlMapList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapReference. */
                interface IUrlMapReference {

                    /** UrlMapReference urlMap */
                    urlMap?: (string|null);
                }

                /** Represents an UrlMapReference. */
                class UrlMapReference implements IUrlMapReference {

                    /**
                     * Constructs a new UrlMapReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapReference);

                    /** UrlMapReference urlMap. */
                    public urlMap?: (string|null);

                    /** UrlMapReference _urlMap. */
                    public _urlMap?: "urlMap";

                    /**
                     * Creates a new UrlMapReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapReference instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapReference): google.cloud.compute.v1.UrlMapReference;

                    /**
                     * Encodes the specified UrlMapReference message. Does not implicitly {@link google.cloud.compute.v1.UrlMapReference.verify|verify} messages.
                     * @param message UrlMapReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapReference message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapReference.verify|verify} messages.
                     * @param message UrlMapReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapReference;

                    /**
                     * Decodes an UrlMapReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapReference;

                    /**
                     * Verifies an UrlMapReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapReference;

                    /**
                     * Creates a plain object from an UrlMapReference message. Also converts values to other types if specified.
                     * @param message UrlMapReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapTest. */
                interface IUrlMapTest {

                    /** UrlMapTest description */
                    description?: (string|null);

                    /** UrlMapTest expectedOutputUrl */
                    expectedOutputUrl?: (string|null);

                    /** UrlMapTest expectedRedirectResponseCode */
                    expectedRedirectResponseCode?: (number|null);

                    /** UrlMapTest headers */
                    headers?: (google.cloud.compute.v1.IUrlMapTestHeader[]|null);

                    /** UrlMapTest host */
                    host?: (string|null);

                    /** UrlMapTest path */
                    path?: (string|null);

                    /** UrlMapTest service */
                    service?: (string|null);
                }

                /** Represents an UrlMapTest. */
                class UrlMapTest implements IUrlMapTest {

                    /**
                     * Constructs a new UrlMapTest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapTest);

                    /** UrlMapTest description. */
                    public description?: (string|null);

                    /** UrlMapTest expectedOutputUrl. */
                    public expectedOutputUrl?: (string|null);

                    /** UrlMapTest expectedRedirectResponseCode. */
                    public expectedRedirectResponseCode?: (number|null);

                    /** UrlMapTest headers. */
                    public headers: google.cloud.compute.v1.IUrlMapTestHeader[];

                    /** UrlMapTest host. */
                    public host?: (string|null);

                    /** UrlMapTest path. */
                    public path?: (string|null);

                    /** UrlMapTest service. */
                    public service?: (string|null);

                    /** UrlMapTest _description. */
                    public _description?: "description";

                    /** UrlMapTest _expectedOutputUrl. */
                    public _expectedOutputUrl?: "expectedOutputUrl";

                    /** UrlMapTest _expectedRedirectResponseCode. */
                    public _expectedRedirectResponseCode?: "expectedRedirectResponseCode";

                    /** UrlMapTest _host. */
                    public _host?: "host";

                    /** UrlMapTest _path. */
                    public _path?: "path";

                    /** UrlMapTest _service. */
                    public _service?: "service";

                    /**
                     * Creates a new UrlMapTest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapTest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapTest): google.cloud.compute.v1.UrlMapTest;

                    /**
                     * Encodes the specified UrlMapTest message. Does not implicitly {@link google.cloud.compute.v1.UrlMapTest.verify|verify} messages.
                     * @param message UrlMapTest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapTest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapTest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapTest.verify|verify} messages.
                     * @param message UrlMapTest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapTest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapTest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapTest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapTest;

                    /**
                     * Decodes an UrlMapTest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapTest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapTest;

                    /**
                     * Verifies an UrlMapTest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapTest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapTest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapTest;

                    /**
                     * Creates a plain object from an UrlMapTest message. Also converts values to other types if specified.
                     * @param message UrlMapTest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapTest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapTest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapTest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapTestHeader. */
                interface IUrlMapTestHeader {

                    /** UrlMapTestHeader name */
                    name?: (string|null);

                    /** UrlMapTestHeader value */
                    value?: (string|null);
                }

                /** Represents an UrlMapTestHeader. */
                class UrlMapTestHeader implements IUrlMapTestHeader {

                    /**
                     * Constructs a new UrlMapTestHeader.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapTestHeader);

                    /** UrlMapTestHeader name. */
                    public name?: (string|null);

                    /** UrlMapTestHeader value. */
                    public value?: (string|null);

                    /** UrlMapTestHeader _name. */
                    public _name?: "name";

                    /** UrlMapTestHeader _value. */
                    public _value?: "value";

                    /**
                     * Creates a new UrlMapTestHeader instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapTestHeader instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapTestHeader): google.cloud.compute.v1.UrlMapTestHeader;

                    /**
                     * Encodes the specified UrlMapTestHeader message. Does not implicitly {@link google.cloud.compute.v1.UrlMapTestHeader.verify|verify} messages.
                     * @param message UrlMapTestHeader message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapTestHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapTestHeader message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapTestHeader.verify|verify} messages.
                     * @param message UrlMapTestHeader message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapTestHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapTestHeader message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapTestHeader
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapTestHeader;

                    /**
                     * Decodes an UrlMapTestHeader message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapTestHeader
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapTestHeader;

                    /**
                     * Verifies an UrlMapTestHeader message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapTestHeader message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapTestHeader
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapTestHeader;

                    /**
                     * Creates a plain object from an UrlMapTestHeader message. Also converts values to other types if specified.
                     * @param message UrlMapTestHeader
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapTestHeader, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapTestHeader to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapTestHeader
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapValidationResult. */
                interface IUrlMapValidationResult {

                    /** UrlMapValidationResult loadErrors */
                    loadErrors?: (string[]|null);

                    /** UrlMapValidationResult loadSucceeded */
                    loadSucceeded?: (boolean|null);

                    /** UrlMapValidationResult testFailures */
                    testFailures?: (google.cloud.compute.v1.ITestFailure[]|null);

                    /** UrlMapValidationResult testPassed */
                    testPassed?: (boolean|null);
                }

                /** Represents an UrlMapValidationResult. */
                class UrlMapValidationResult implements IUrlMapValidationResult {

                    /**
                     * Constructs a new UrlMapValidationResult.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapValidationResult);

                    /** UrlMapValidationResult loadErrors. */
                    public loadErrors: string[];

                    /** UrlMapValidationResult loadSucceeded. */
                    public loadSucceeded?: (boolean|null);

                    /** UrlMapValidationResult testFailures. */
                    public testFailures: google.cloud.compute.v1.ITestFailure[];

                    /** UrlMapValidationResult testPassed. */
                    public testPassed?: (boolean|null);

                    /** UrlMapValidationResult _loadSucceeded. */
                    public _loadSucceeded?: "loadSucceeded";

                    /** UrlMapValidationResult _testPassed. */
                    public _testPassed?: "testPassed";

                    /**
                     * Creates a new UrlMapValidationResult instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapValidationResult instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapValidationResult): google.cloud.compute.v1.UrlMapValidationResult;

                    /**
                     * Encodes the specified UrlMapValidationResult message. Does not implicitly {@link google.cloud.compute.v1.UrlMapValidationResult.verify|verify} messages.
                     * @param message UrlMapValidationResult message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapValidationResult, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapValidationResult message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapValidationResult.verify|verify} messages.
                     * @param message UrlMapValidationResult message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapValidationResult, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapValidationResult message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapValidationResult
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapValidationResult;

                    /**
                     * Decodes an UrlMapValidationResult message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapValidationResult
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapValidationResult;

                    /**
                     * Verifies an UrlMapValidationResult message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapValidationResult message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapValidationResult
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapValidationResult;

                    /**
                     * Creates a plain object from an UrlMapValidationResult message. Also converts values to other types if specified.
                     * @param message UrlMapValidationResult
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapValidationResult, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapValidationResult to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapValidationResult
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapsAggregatedList. */
                interface IUrlMapsAggregatedList {

                    /** UrlMapsAggregatedList id */
                    id?: (string|null);

                    /** UrlMapsAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IUrlMapsScopedList }|null);

                    /** UrlMapsAggregatedList kind */
                    kind?: (string|null);

                    /** UrlMapsAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** UrlMapsAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** UrlMapsAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** UrlMapsAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an UrlMapsAggregatedList. */
                class UrlMapsAggregatedList implements IUrlMapsAggregatedList {

                    /**
                     * Constructs a new UrlMapsAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapsAggregatedList);

                    /** UrlMapsAggregatedList id. */
                    public id?: (string|null);

                    /** UrlMapsAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IUrlMapsScopedList };

                    /** UrlMapsAggregatedList kind. */
                    public kind?: (string|null);

                    /** UrlMapsAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** UrlMapsAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** UrlMapsAggregatedList unreachables. */
                    public unreachables: string[];

                    /** UrlMapsAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** UrlMapsAggregatedList _id. */
                    public _id?: "id";

                    /** UrlMapsAggregatedList _kind. */
                    public _kind?: "kind";

                    /** UrlMapsAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** UrlMapsAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** UrlMapsAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new UrlMapsAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapsAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapsAggregatedList): google.cloud.compute.v1.UrlMapsAggregatedList;

                    /**
                     * Encodes the specified UrlMapsAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.UrlMapsAggregatedList.verify|verify} messages.
                     * @param message UrlMapsAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapsAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapsAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapsAggregatedList.verify|verify} messages.
                     * @param message UrlMapsAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapsAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapsAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapsAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapsAggregatedList;

                    /**
                     * Decodes an UrlMapsAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapsAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapsAggregatedList;

                    /**
                     * Verifies an UrlMapsAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapsAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapsAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapsAggregatedList;

                    /**
                     * Creates a plain object from an UrlMapsAggregatedList message. Also converts values to other types if specified.
                     * @param message UrlMapsAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapsAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapsAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapsAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapsScopedList. */
                interface IUrlMapsScopedList {

                    /** UrlMapsScopedList urlMaps */
                    urlMaps?: (google.cloud.compute.v1.IUrlMap[]|null);

                    /** UrlMapsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents an UrlMapsScopedList. */
                class UrlMapsScopedList implements IUrlMapsScopedList {

                    /**
                     * Constructs a new UrlMapsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapsScopedList);

                    /** UrlMapsScopedList urlMaps. */
                    public urlMaps: google.cloud.compute.v1.IUrlMap[];

                    /** UrlMapsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** UrlMapsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new UrlMapsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapsScopedList): google.cloud.compute.v1.UrlMapsScopedList;

                    /**
                     * Encodes the specified UrlMapsScopedList message. Does not implicitly {@link google.cloud.compute.v1.UrlMapsScopedList.verify|verify} messages.
                     * @param message UrlMapsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapsScopedList.verify|verify} messages.
                     * @param message UrlMapsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapsScopedList;

                    /**
                     * Decodes an UrlMapsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapsScopedList;

                    /**
                     * Verifies an UrlMapsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapsScopedList;

                    /**
                     * Creates a plain object from an UrlMapsScopedList message. Also converts values to other types if specified.
                     * @param message UrlMapsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlMapsValidateRequest. */
                interface IUrlMapsValidateRequest {

                    /** UrlMapsValidateRequest loadBalancingSchemes */
                    loadBalancingSchemes?: (string[]|null);

                    /** UrlMapsValidateRequest resource */
                    resource?: (google.cloud.compute.v1.IUrlMap|null);
                }

                /** Represents an UrlMapsValidateRequest. */
                class UrlMapsValidateRequest implements IUrlMapsValidateRequest {

                    /**
                     * Constructs a new UrlMapsValidateRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapsValidateRequest);

                    /** UrlMapsValidateRequest loadBalancingSchemes. */
                    public loadBalancingSchemes: string[];

                    /** UrlMapsValidateRequest resource. */
                    public resource?: (google.cloud.compute.v1.IUrlMap|null);

                    /** UrlMapsValidateRequest _resource. */
                    public _resource?: "resource";

                    /**
                     * Creates a new UrlMapsValidateRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapsValidateRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapsValidateRequest): google.cloud.compute.v1.UrlMapsValidateRequest;

                    /**
                     * Encodes the specified UrlMapsValidateRequest message. Does not implicitly {@link google.cloud.compute.v1.UrlMapsValidateRequest.verify|verify} messages.
                     * @param message UrlMapsValidateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapsValidateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapsValidateRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapsValidateRequest.verify|verify} messages.
                     * @param message UrlMapsValidateRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapsValidateRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapsValidateRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapsValidateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapsValidateRequest;

                    /**
                     * Decodes an UrlMapsValidateRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapsValidateRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapsValidateRequest;

                    /**
                     * Verifies an UrlMapsValidateRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapsValidateRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapsValidateRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapsValidateRequest;

                    /**
                     * Creates a plain object from an UrlMapsValidateRequest message. Also converts values to other types if specified.
                     * @param message UrlMapsValidateRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapsValidateRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapsValidateRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapsValidateRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace UrlMapsValidateRequest {

                    /** LoadBalancingSchemes enum. */
                    enum LoadBalancingSchemes {
                        UNDEFINED_LOAD_BALANCING_SCHEMES = 0,
                        EXTERNAL = 35607499,
                        EXTERNAL_MANAGED = 512006923,
                        LOAD_BALANCING_SCHEME_UNSPECIFIED = 526507452
                    }
                }

                /** Properties of an UrlMapsValidateResponse. */
                interface IUrlMapsValidateResponse {

                    /** UrlMapsValidateResponse result */
                    result?: (google.cloud.compute.v1.IUrlMapValidationResult|null);
                }

                /** Represents an UrlMapsValidateResponse. */
                class UrlMapsValidateResponse implements IUrlMapsValidateResponse {

                    /**
                     * Constructs a new UrlMapsValidateResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlMapsValidateResponse);

                    /** UrlMapsValidateResponse result. */
                    public result?: (google.cloud.compute.v1.IUrlMapValidationResult|null);

                    /** UrlMapsValidateResponse _result. */
                    public _result?: "result";

                    /**
                     * Creates a new UrlMapsValidateResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlMapsValidateResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlMapsValidateResponse): google.cloud.compute.v1.UrlMapsValidateResponse;

                    /**
                     * Encodes the specified UrlMapsValidateResponse message. Does not implicitly {@link google.cloud.compute.v1.UrlMapsValidateResponse.verify|verify} messages.
                     * @param message UrlMapsValidateResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlMapsValidateResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlMapsValidateResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlMapsValidateResponse.verify|verify} messages.
                     * @param message UrlMapsValidateResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlMapsValidateResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlMapsValidateResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlMapsValidateResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlMapsValidateResponse;

                    /**
                     * Decodes an UrlMapsValidateResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlMapsValidateResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlMapsValidateResponse;

                    /**
                     * Verifies an UrlMapsValidateResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlMapsValidateResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlMapsValidateResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlMapsValidateResponse;

                    /**
                     * Creates a plain object from an UrlMapsValidateResponse message. Also converts values to other types if specified.
                     * @param message UrlMapsValidateResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlMapsValidateResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlMapsValidateResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlMapsValidateResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UrlRewrite. */
                interface IUrlRewrite {

                    /** UrlRewrite hostRewrite */
                    hostRewrite?: (string|null);

                    /** UrlRewrite pathPrefixRewrite */
                    pathPrefixRewrite?: (string|null);
                }

                /** Represents an UrlRewrite. */
                class UrlRewrite implements IUrlRewrite {

                    /**
                     * Constructs a new UrlRewrite.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUrlRewrite);

                    /** UrlRewrite hostRewrite. */
                    public hostRewrite?: (string|null);

                    /** UrlRewrite pathPrefixRewrite. */
                    public pathPrefixRewrite?: (string|null);

                    /** UrlRewrite _hostRewrite. */
                    public _hostRewrite?: "hostRewrite";

                    /** UrlRewrite _pathPrefixRewrite. */
                    public _pathPrefixRewrite?: "pathPrefixRewrite";

                    /**
                     * Creates a new UrlRewrite instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UrlRewrite instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUrlRewrite): google.cloud.compute.v1.UrlRewrite;

                    /**
                     * Encodes the specified UrlRewrite message. Does not implicitly {@link google.cloud.compute.v1.UrlRewrite.verify|verify} messages.
                     * @param message UrlRewrite message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUrlRewrite, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UrlRewrite message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UrlRewrite.verify|verify} messages.
                     * @param message UrlRewrite message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUrlRewrite, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UrlRewrite message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UrlRewrite
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UrlRewrite;

                    /**
                     * Decodes an UrlRewrite message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UrlRewrite
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UrlRewrite;

                    /**
                     * Verifies an UrlRewrite message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UrlRewrite message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UrlRewrite
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UrlRewrite;

                    /**
                     * Creates a plain object from an UrlRewrite message. Also converts values to other types if specified.
                     * @param message UrlRewrite
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UrlRewrite, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UrlRewrite to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UrlRewrite
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a UsableSubnetwork. */
                interface IUsableSubnetwork {

                    /** UsableSubnetwork externalIpv6Prefix */
                    externalIpv6Prefix?: (string|null);

                    /** UsableSubnetwork internalIpv6Prefix */
                    internalIpv6Prefix?: (string|null);

                    /** UsableSubnetwork ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** UsableSubnetwork ipv6AccessType */
                    ipv6AccessType?: (string|null);

                    /** UsableSubnetwork network */
                    network?: (string|null);

                    /** UsableSubnetwork purpose */
                    purpose?: (string|null);

                    /** UsableSubnetwork role */
                    role?: (string|null);

                    /** UsableSubnetwork secondaryIpRanges */
                    secondaryIpRanges?: (google.cloud.compute.v1.IUsableSubnetworkSecondaryRange[]|null);

                    /** UsableSubnetwork stackType */
                    stackType?: (string|null);

                    /** UsableSubnetwork subnetwork */
                    subnetwork?: (string|null);
                }

                /** Represents a UsableSubnetwork. */
                class UsableSubnetwork implements IUsableSubnetwork {

                    /**
                     * Constructs a new UsableSubnetwork.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUsableSubnetwork);

                    /** UsableSubnetwork externalIpv6Prefix. */
                    public externalIpv6Prefix?: (string|null);

                    /** UsableSubnetwork internalIpv6Prefix. */
                    public internalIpv6Prefix?: (string|null);

                    /** UsableSubnetwork ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** UsableSubnetwork ipv6AccessType. */
                    public ipv6AccessType?: (string|null);

                    /** UsableSubnetwork network. */
                    public network?: (string|null);

                    /** UsableSubnetwork purpose. */
                    public purpose?: (string|null);

                    /** UsableSubnetwork role. */
                    public role?: (string|null);

                    /** UsableSubnetwork secondaryIpRanges. */
                    public secondaryIpRanges: google.cloud.compute.v1.IUsableSubnetworkSecondaryRange[];

                    /** UsableSubnetwork stackType. */
                    public stackType?: (string|null);

                    /** UsableSubnetwork subnetwork. */
                    public subnetwork?: (string|null);

                    /** UsableSubnetwork _externalIpv6Prefix. */
                    public _externalIpv6Prefix?: "externalIpv6Prefix";

                    /** UsableSubnetwork _internalIpv6Prefix. */
                    public _internalIpv6Prefix?: "internalIpv6Prefix";

                    /** UsableSubnetwork _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** UsableSubnetwork _ipv6AccessType. */
                    public _ipv6AccessType?: "ipv6AccessType";

                    /** UsableSubnetwork _network. */
                    public _network?: "network";

                    /** UsableSubnetwork _purpose. */
                    public _purpose?: "purpose";

                    /** UsableSubnetwork _role. */
                    public _role?: "role";

                    /** UsableSubnetwork _stackType. */
                    public _stackType?: "stackType";

                    /** UsableSubnetwork _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /**
                     * Creates a new UsableSubnetwork instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UsableSubnetwork instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUsableSubnetwork): google.cloud.compute.v1.UsableSubnetwork;

                    /**
                     * Encodes the specified UsableSubnetwork message. Does not implicitly {@link google.cloud.compute.v1.UsableSubnetwork.verify|verify} messages.
                     * @param message UsableSubnetwork message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUsableSubnetwork, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UsableSubnetwork message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UsableSubnetwork.verify|verify} messages.
                     * @param message UsableSubnetwork message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUsableSubnetwork, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a UsableSubnetwork message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UsableSubnetwork
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UsableSubnetwork;

                    /**
                     * Decodes a UsableSubnetwork message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UsableSubnetwork
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UsableSubnetwork;

                    /**
                     * Verifies a UsableSubnetwork message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a UsableSubnetwork message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UsableSubnetwork
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UsableSubnetwork;

                    /**
                     * Creates a plain object from a UsableSubnetwork message. Also converts values to other types if specified.
                     * @param message UsableSubnetwork
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UsableSubnetwork, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UsableSubnetwork to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UsableSubnetwork
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace UsableSubnetwork {

                    /** Ipv6AccessType enum. */
                    enum Ipv6AccessType {
                        UNDEFINED_IPV6_ACCESS_TYPE = 0,
                        EXTERNAL = 35607499,
                        INTERNAL = 279295677
                    }

                    /** Purpose enum. */
                    enum Purpose {
                        UNDEFINED_PURPOSE = 0,
                        INTERNAL_HTTPS_LOAD_BALANCER = 248748889,
                        PRIVATE = 403485027,
                        PRIVATE_RFC_1918 = 254902107,
                        PRIVATE_SERVICE_CONNECT = 48134724,
                        REGIONAL_MANAGED_PROXY = 153049966
                    }

                    /** Role enum. */
                    enum Role {
                        UNDEFINED_ROLE = 0,
                        ACTIVE = 314733318,
                        BACKUP = 341010882
                    }

                    /** StackType enum. */
                    enum StackType {
                        UNDEFINED_STACK_TYPE = 0,
                        IPV4_IPV6 = 22197249,
                        IPV4_ONLY = 22373798
                    }
                }

                /** Properties of a UsableSubnetworkSecondaryRange. */
                interface IUsableSubnetworkSecondaryRange {

                    /** UsableSubnetworkSecondaryRange ipCidrRange */
                    ipCidrRange?: (string|null);

                    /** UsableSubnetworkSecondaryRange rangeName */
                    rangeName?: (string|null);
                }

                /** Represents a UsableSubnetworkSecondaryRange. */
                class UsableSubnetworkSecondaryRange implements IUsableSubnetworkSecondaryRange {

                    /**
                     * Constructs a new UsableSubnetworkSecondaryRange.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUsableSubnetworkSecondaryRange);

                    /** UsableSubnetworkSecondaryRange ipCidrRange. */
                    public ipCidrRange?: (string|null);

                    /** UsableSubnetworkSecondaryRange rangeName. */
                    public rangeName?: (string|null);

                    /** UsableSubnetworkSecondaryRange _ipCidrRange. */
                    public _ipCidrRange?: "ipCidrRange";

                    /** UsableSubnetworkSecondaryRange _rangeName. */
                    public _rangeName?: "rangeName";

                    /**
                     * Creates a new UsableSubnetworkSecondaryRange instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UsableSubnetworkSecondaryRange instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUsableSubnetworkSecondaryRange): google.cloud.compute.v1.UsableSubnetworkSecondaryRange;

                    /**
                     * Encodes the specified UsableSubnetworkSecondaryRange message. Does not implicitly {@link google.cloud.compute.v1.UsableSubnetworkSecondaryRange.verify|verify} messages.
                     * @param message UsableSubnetworkSecondaryRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUsableSubnetworkSecondaryRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UsableSubnetworkSecondaryRange message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UsableSubnetworkSecondaryRange.verify|verify} messages.
                     * @param message UsableSubnetworkSecondaryRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUsableSubnetworkSecondaryRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a UsableSubnetworkSecondaryRange message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UsableSubnetworkSecondaryRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UsableSubnetworkSecondaryRange;

                    /**
                     * Decodes a UsableSubnetworkSecondaryRange message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UsableSubnetworkSecondaryRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UsableSubnetworkSecondaryRange;

                    /**
                     * Verifies a UsableSubnetworkSecondaryRange message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a UsableSubnetworkSecondaryRange message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UsableSubnetworkSecondaryRange
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UsableSubnetworkSecondaryRange;

                    /**
                     * Creates a plain object from a UsableSubnetworkSecondaryRange message. Also converts values to other types if specified.
                     * @param message UsableSubnetworkSecondaryRange
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UsableSubnetworkSecondaryRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UsableSubnetworkSecondaryRange to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UsableSubnetworkSecondaryRange
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a UsableSubnetworksAggregatedList. */
                interface IUsableSubnetworksAggregatedList {

                    /** UsableSubnetworksAggregatedList id */
                    id?: (string|null);

                    /** UsableSubnetworksAggregatedList items */
                    items?: (google.cloud.compute.v1.IUsableSubnetwork[]|null);

                    /** UsableSubnetworksAggregatedList kind */
                    kind?: (string|null);

                    /** UsableSubnetworksAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** UsableSubnetworksAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** UsableSubnetworksAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a UsableSubnetworksAggregatedList. */
                class UsableSubnetworksAggregatedList implements IUsableSubnetworksAggregatedList {

                    /**
                     * Constructs a new UsableSubnetworksAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUsableSubnetworksAggregatedList);

                    /** UsableSubnetworksAggregatedList id. */
                    public id?: (string|null);

                    /** UsableSubnetworksAggregatedList items. */
                    public items: google.cloud.compute.v1.IUsableSubnetwork[];

                    /** UsableSubnetworksAggregatedList kind. */
                    public kind?: (string|null);

                    /** UsableSubnetworksAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** UsableSubnetworksAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** UsableSubnetworksAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** UsableSubnetworksAggregatedList _id. */
                    public _id?: "id";

                    /** UsableSubnetworksAggregatedList _kind. */
                    public _kind?: "kind";

                    /** UsableSubnetworksAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** UsableSubnetworksAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** UsableSubnetworksAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new UsableSubnetworksAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UsableSubnetworksAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUsableSubnetworksAggregatedList): google.cloud.compute.v1.UsableSubnetworksAggregatedList;

                    /**
                     * Encodes the specified UsableSubnetworksAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.UsableSubnetworksAggregatedList.verify|verify} messages.
                     * @param message UsableSubnetworksAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUsableSubnetworksAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UsableSubnetworksAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UsableSubnetworksAggregatedList.verify|verify} messages.
                     * @param message UsableSubnetworksAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUsableSubnetworksAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a UsableSubnetworksAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UsableSubnetworksAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UsableSubnetworksAggregatedList;

                    /**
                     * Decodes a UsableSubnetworksAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UsableSubnetworksAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UsableSubnetworksAggregatedList;

                    /**
                     * Verifies a UsableSubnetworksAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a UsableSubnetworksAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UsableSubnetworksAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UsableSubnetworksAggregatedList;

                    /**
                     * Creates a plain object from a UsableSubnetworksAggregatedList message. Also converts values to other types if specified.
                     * @param message UsableSubnetworksAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UsableSubnetworksAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UsableSubnetworksAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UsableSubnetworksAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a UsageExportLocation. */
                interface IUsageExportLocation {

                    /** UsageExportLocation bucketName */
                    bucketName?: (string|null);

                    /** UsageExportLocation reportNamePrefix */
                    reportNamePrefix?: (string|null);
                }

                /** Represents a UsageExportLocation. */
                class UsageExportLocation implements IUsageExportLocation {

                    /**
                     * Constructs a new UsageExportLocation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IUsageExportLocation);

                    /** UsageExportLocation bucketName. */
                    public bucketName?: (string|null);

                    /** UsageExportLocation reportNamePrefix. */
                    public reportNamePrefix?: (string|null);

                    /** UsageExportLocation _bucketName. */
                    public _bucketName?: "bucketName";

                    /** UsageExportLocation _reportNamePrefix. */
                    public _reportNamePrefix?: "reportNamePrefix";

                    /**
                     * Creates a new UsageExportLocation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UsageExportLocation instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IUsageExportLocation): google.cloud.compute.v1.UsageExportLocation;

                    /**
                     * Encodes the specified UsageExportLocation message. Does not implicitly {@link google.cloud.compute.v1.UsageExportLocation.verify|verify} messages.
                     * @param message UsageExportLocation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IUsageExportLocation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UsageExportLocation message, length delimited. Does not implicitly {@link google.cloud.compute.v1.UsageExportLocation.verify|verify} messages.
                     * @param message UsageExportLocation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IUsageExportLocation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a UsageExportLocation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UsageExportLocation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.UsageExportLocation;

                    /**
                     * Decodes a UsageExportLocation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UsageExportLocation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.UsageExportLocation;

                    /**
                     * Verifies a UsageExportLocation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a UsageExportLocation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UsageExportLocation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.UsageExportLocation;

                    /**
                     * Creates a plain object from a UsageExportLocation message. Also converts values to other types if specified.
                     * @param message UsageExportLocation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.UsageExportLocation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UsageExportLocation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UsageExportLocation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ValidateRegionUrlMapRequest. */
                interface IValidateRegionUrlMapRequest {

                    /** ValidateRegionUrlMapRequest project */
                    project?: (string|null);

                    /** ValidateRegionUrlMapRequest region */
                    region?: (string|null);

                    /** ValidateRegionUrlMapRequest regionUrlMapsValidateRequestResource */
                    regionUrlMapsValidateRequestResource?: (google.cloud.compute.v1.IRegionUrlMapsValidateRequest|null);

                    /** ValidateRegionUrlMapRequest urlMap */
                    urlMap?: (string|null);
                }

                /** Represents a ValidateRegionUrlMapRequest. */
                class ValidateRegionUrlMapRequest implements IValidateRegionUrlMapRequest {

                    /**
                     * Constructs a new ValidateRegionUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IValidateRegionUrlMapRequest);

                    /** ValidateRegionUrlMapRequest project. */
                    public project: string;

                    /** ValidateRegionUrlMapRequest region. */
                    public region: string;

                    /** ValidateRegionUrlMapRequest regionUrlMapsValidateRequestResource. */
                    public regionUrlMapsValidateRequestResource?: (google.cloud.compute.v1.IRegionUrlMapsValidateRequest|null);

                    /** ValidateRegionUrlMapRequest urlMap. */
                    public urlMap: string;

                    /**
                     * Creates a new ValidateRegionUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ValidateRegionUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IValidateRegionUrlMapRequest): google.cloud.compute.v1.ValidateRegionUrlMapRequest;

                    /**
                     * Encodes the specified ValidateRegionUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.ValidateRegionUrlMapRequest.verify|verify} messages.
                     * @param message ValidateRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IValidateRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ValidateRegionUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ValidateRegionUrlMapRequest.verify|verify} messages.
                     * @param message ValidateRegionUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IValidateRegionUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ValidateRegionUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ValidateRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ValidateRegionUrlMapRequest;

                    /**
                     * Decodes a ValidateRegionUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ValidateRegionUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ValidateRegionUrlMapRequest;

                    /**
                     * Verifies a ValidateRegionUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ValidateRegionUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ValidateRegionUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ValidateRegionUrlMapRequest;

                    /**
                     * Creates a plain object from a ValidateRegionUrlMapRequest message. Also converts values to other types if specified.
                     * @param message ValidateRegionUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ValidateRegionUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ValidateRegionUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ValidateRegionUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ValidateUrlMapRequest. */
                interface IValidateUrlMapRequest {

                    /** ValidateUrlMapRequest project */
                    project?: (string|null);

                    /** ValidateUrlMapRequest urlMap */
                    urlMap?: (string|null);

                    /** ValidateUrlMapRequest urlMapsValidateRequestResource */
                    urlMapsValidateRequestResource?: (google.cloud.compute.v1.IUrlMapsValidateRequest|null);
                }

                /** Represents a ValidateUrlMapRequest. */
                class ValidateUrlMapRequest implements IValidateUrlMapRequest {

                    /**
                     * Constructs a new ValidateUrlMapRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IValidateUrlMapRequest);

                    /** ValidateUrlMapRequest project. */
                    public project: string;

                    /** ValidateUrlMapRequest urlMap. */
                    public urlMap: string;

                    /** ValidateUrlMapRequest urlMapsValidateRequestResource. */
                    public urlMapsValidateRequestResource?: (google.cloud.compute.v1.IUrlMapsValidateRequest|null);

                    /**
                     * Creates a new ValidateUrlMapRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ValidateUrlMapRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IValidateUrlMapRequest): google.cloud.compute.v1.ValidateUrlMapRequest;

                    /**
                     * Encodes the specified ValidateUrlMapRequest message. Does not implicitly {@link google.cloud.compute.v1.ValidateUrlMapRequest.verify|verify} messages.
                     * @param message ValidateUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IValidateUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ValidateUrlMapRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ValidateUrlMapRequest.verify|verify} messages.
                     * @param message ValidateUrlMapRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IValidateUrlMapRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ValidateUrlMapRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ValidateUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ValidateUrlMapRequest;

                    /**
                     * Decodes a ValidateUrlMapRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ValidateUrlMapRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ValidateUrlMapRequest;

                    /**
                     * Verifies a ValidateUrlMapRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ValidateUrlMapRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ValidateUrlMapRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ValidateUrlMapRequest;

                    /**
                     * Creates a plain object from a ValidateUrlMapRequest message. Also converts values to other types if specified.
                     * @param message ValidateUrlMapRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ValidateUrlMapRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ValidateUrlMapRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ValidateUrlMapRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VmEndpointNatMappings. */
                interface IVmEndpointNatMappings {

                    /** VmEndpointNatMappings instanceName */
                    instanceName?: (string|null);

                    /** VmEndpointNatMappings interfaceNatMappings */
                    interfaceNatMappings?: (google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappings[]|null);
                }

                /** Represents a VmEndpointNatMappings. */
                class VmEndpointNatMappings implements IVmEndpointNatMappings {

                    /**
                     * Constructs a new VmEndpointNatMappings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVmEndpointNatMappings);

                    /** VmEndpointNatMappings instanceName. */
                    public instanceName?: (string|null);

                    /** VmEndpointNatMappings interfaceNatMappings. */
                    public interfaceNatMappings: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappings[];

                    /** VmEndpointNatMappings _instanceName. */
                    public _instanceName?: "instanceName";

                    /**
                     * Creates a new VmEndpointNatMappings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VmEndpointNatMappings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVmEndpointNatMappings): google.cloud.compute.v1.VmEndpointNatMappings;

                    /**
                     * Encodes the specified VmEndpointNatMappings message. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappings.verify|verify} messages.
                     * @param message VmEndpointNatMappings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVmEndpointNatMappings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VmEndpointNatMappings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappings.verify|verify} messages.
                     * @param message VmEndpointNatMappings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVmEndpointNatMappings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VmEndpointNatMappings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VmEndpointNatMappings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VmEndpointNatMappings;

                    /**
                     * Decodes a VmEndpointNatMappings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VmEndpointNatMappings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VmEndpointNatMappings;

                    /**
                     * Verifies a VmEndpointNatMappings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VmEndpointNatMappings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VmEndpointNatMappings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VmEndpointNatMappings;

                    /**
                     * Creates a plain object from a VmEndpointNatMappings message. Also converts values to other types if specified.
                     * @param message VmEndpointNatMappings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VmEndpointNatMappings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VmEndpointNatMappings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VmEndpointNatMappings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VmEndpointNatMappingsInterfaceNatMappings. */
                interface IVmEndpointNatMappingsInterfaceNatMappings {

                    /** VmEndpointNatMappingsInterfaceNatMappings drainNatIpPortRanges */
                    drainNatIpPortRanges?: (string[]|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings natIpPortRanges */
                    natIpPortRanges?: (string[]|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings numTotalDrainNatPorts */
                    numTotalDrainNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings numTotalNatPorts */
                    numTotalNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings ruleMappings */
                    ruleMappings?: (google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings[]|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings sourceAliasIpRange */
                    sourceAliasIpRange?: (string|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings sourceVirtualIp */
                    sourceVirtualIp?: (string|null);
                }

                /** Represents a VmEndpointNatMappingsInterfaceNatMappings. */
                class VmEndpointNatMappingsInterfaceNatMappings implements IVmEndpointNatMappingsInterfaceNatMappings {

                    /**
                     * Constructs a new VmEndpointNatMappingsInterfaceNatMappings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappings);

                    /** VmEndpointNatMappingsInterfaceNatMappings drainNatIpPortRanges. */
                    public drainNatIpPortRanges: string[];

                    /** VmEndpointNatMappingsInterfaceNatMappings natIpPortRanges. */
                    public natIpPortRanges: string[];

                    /** VmEndpointNatMappingsInterfaceNatMappings numTotalDrainNatPorts. */
                    public numTotalDrainNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings numTotalNatPorts. */
                    public numTotalNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings ruleMappings. */
                    public ruleMappings: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings[];

                    /** VmEndpointNatMappingsInterfaceNatMappings sourceAliasIpRange. */
                    public sourceAliasIpRange?: (string|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings sourceVirtualIp. */
                    public sourceVirtualIp?: (string|null);

                    /** VmEndpointNatMappingsInterfaceNatMappings _numTotalDrainNatPorts. */
                    public _numTotalDrainNatPorts?: "numTotalDrainNatPorts";

                    /** VmEndpointNatMappingsInterfaceNatMappings _numTotalNatPorts. */
                    public _numTotalNatPorts?: "numTotalNatPorts";

                    /** VmEndpointNatMappingsInterfaceNatMappings _sourceAliasIpRange. */
                    public _sourceAliasIpRange?: "sourceAliasIpRange";

                    /** VmEndpointNatMappingsInterfaceNatMappings _sourceVirtualIp. */
                    public _sourceVirtualIp?: "sourceVirtualIp";

                    /**
                     * Creates a new VmEndpointNatMappingsInterfaceNatMappings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VmEndpointNatMappingsInterfaceNatMappings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappings): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings;

                    /**
                     * Encodes the specified VmEndpointNatMappingsInterfaceNatMappings message. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings.verify|verify} messages.
                     * @param message VmEndpointNatMappingsInterfaceNatMappings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VmEndpointNatMappingsInterfaceNatMappings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings.verify|verify} messages.
                     * @param message VmEndpointNatMappingsInterfaceNatMappings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VmEndpointNatMappingsInterfaceNatMappings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VmEndpointNatMappingsInterfaceNatMappings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings;

                    /**
                     * Decodes a VmEndpointNatMappingsInterfaceNatMappings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VmEndpointNatMappingsInterfaceNatMappings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings;

                    /**
                     * Verifies a VmEndpointNatMappingsInterfaceNatMappings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VmEndpointNatMappingsInterfaceNatMappings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VmEndpointNatMappingsInterfaceNatMappings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings;

                    /**
                     * Creates a plain object from a VmEndpointNatMappingsInterfaceNatMappings message. Also converts values to other types if specified.
                     * @param message VmEndpointNatMappingsInterfaceNatMappings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VmEndpointNatMappingsInterfaceNatMappings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VmEndpointNatMappingsInterfaceNatMappings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings. */
                interface IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings {

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings drainNatIpPortRanges */
                    drainNatIpPortRanges?: (string[]|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings natIpPortRanges */
                    natIpPortRanges?: (string[]|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings numTotalDrainNatPorts */
                    numTotalDrainNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings numTotalNatPorts */
                    numTotalNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings ruleNumber */
                    ruleNumber?: (number|null);
                }

                /** Represents a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings. */
                class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings implements IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings {

                    /**
                     * Constructs a new VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings drainNatIpPortRanges. */
                    public drainNatIpPortRanges: string[];

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings natIpPortRanges. */
                    public natIpPortRanges: string[];

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings numTotalDrainNatPorts. */
                    public numTotalDrainNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings numTotalNatPorts. */
                    public numTotalNatPorts?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings ruleNumber. */
                    public ruleNumber?: (number|null);

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings _numTotalDrainNatPorts. */
                    public _numTotalDrainNatPorts?: "numTotalDrainNatPorts";

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings _numTotalNatPorts. */
                    public _numTotalNatPorts?: "numTotalNatPorts";

                    /** VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings _ruleNumber. */
                    public _ruleNumber?: "ruleNumber";

                    /**
                     * Creates a new VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings;

                    /**
                     * Encodes the specified VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.verify|verify} messages.
                     * @param message VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.verify|verify} messages.
                     * @param message VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings;

                    /**
                     * Decodes a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings;

                    /**
                     * Verifies a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings;

                    /**
                     * Creates a plain object from a VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings message. Also converts values to other types if specified.
                     * @param message VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VmEndpointNatMappingsList. */
                interface IVmEndpointNatMappingsList {

                    /** VmEndpointNatMappingsList id */
                    id?: (string|null);

                    /** VmEndpointNatMappingsList kind */
                    kind?: (string|null);

                    /** VmEndpointNatMappingsList nextPageToken */
                    nextPageToken?: (string|null);

                    /** VmEndpointNatMappingsList result */
                    result?: (google.cloud.compute.v1.IVmEndpointNatMappings[]|null);

                    /** VmEndpointNatMappingsList selfLink */
                    selfLink?: (string|null);

                    /** VmEndpointNatMappingsList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VmEndpointNatMappingsList. */
                class VmEndpointNatMappingsList implements IVmEndpointNatMappingsList {

                    /**
                     * Constructs a new VmEndpointNatMappingsList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVmEndpointNatMappingsList);

                    /** VmEndpointNatMappingsList id. */
                    public id?: (string|null);

                    /** VmEndpointNatMappingsList kind. */
                    public kind?: (string|null);

                    /** VmEndpointNatMappingsList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** VmEndpointNatMappingsList result. */
                    public result: google.cloud.compute.v1.IVmEndpointNatMappings[];

                    /** VmEndpointNatMappingsList selfLink. */
                    public selfLink?: (string|null);

                    /** VmEndpointNatMappingsList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VmEndpointNatMappingsList _id. */
                    public _id?: "id";

                    /** VmEndpointNatMappingsList _kind. */
                    public _kind?: "kind";

                    /** VmEndpointNatMappingsList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** VmEndpointNatMappingsList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VmEndpointNatMappingsList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VmEndpointNatMappingsList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VmEndpointNatMappingsList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVmEndpointNatMappingsList): google.cloud.compute.v1.VmEndpointNatMappingsList;

                    /**
                     * Encodes the specified VmEndpointNatMappingsList message. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappingsList.verify|verify} messages.
                     * @param message VmEndpointNatMappingsList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVmEndpointNatMappingsList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VmEndpointNatMappingsList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VmEndpointNatMappingsList.verify|verify} messages.
                     * @param message VmEndpointNatMappingsList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVmEndpointNatMappingsList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VmEndpointNatMappingsList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VmEndpointNatMappingsList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VmEndpointNatMappingsList;

                    /**
                     * Decodes a VmEndpointNatMappingsList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VmEndpointNatMappingsList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VmEndpointNatMappingsList;

                    /**
                     * Verifies a VmEndpointNatMappingsList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VmEndpointNatMappingsList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VmEndpointNatMappingsList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VmEndpointNatMappingsList;

                    /**
                     * Creates a plain object from a VmEndpointNatMappingsList message. Also converts values to other types if specified.
                     * @param message VmEndpointNatMappingsList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VmEndpointNatMappingsList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VmEndpointNatMappingsList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VmEndpointNatMappingsList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGateway. */
                interface IVpnGateway {

                    /** VpnGateway creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** VpnGateway description */
                    description?: (string|null);

                    /** VpnGateway id */
                    id?: (number|Long|string|null);

                    /** VpnGateway kind */
                    kind?: (string|null);

                    /** VpnGateway labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** VpnGateway labels */
                    labels?: ({ [k: string]: string }|null);

                    /** VpnGateway name */
                    name?: (string|null);

                    /** VpnGateway network */
                    network?: (string|null);

                    /** VpnGateway region */
                    region?: (string|null);

                    /** VpnGateway selfLink */
                    selfLink?: (string|null);

                    /** VpnGateway stackType */
                    stackType?: (string|null);

                    /** VpnGateway vpnInterfaces */
                    vpnInterfaces?: (google.cloud.compute.v1.IVpnGatewayVpnGatewayInterface[]|null);
                }

                /** Represents a VpnGateway. */
                class VpnGateway implements IVpnGateway {

                    /**
                     * Constructs a new VpnGateway.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGateway);

                    /** VpnGateway creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** VpnGateway description. */
                    public description?: (string|null);

                    /** VpnGateway id. */
                    public id?: (number|Long|string|null);

                    /** VpnGateway kind. */
                    public kind?: (string|null);

                    /** VpnGateway labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** VpnGateway labels. */
                    public labels: { [k: string]: string };

                    /** VpnGateway name. */
                    public name?: (string|null);

                    /** VpnGateway network. */
                    public network?: (string|null);

                    /** VpnGateway region. */
                    public region?: (string|null);

                    /** VpnGateway selfLink. */
                    public selfLink?: (string|null);

                    /** VpnGateway stackType. */
                    public stackType?: (string|null);

                    /** VpnGateway vpnInterfaces. */
                    public vpnInterfaces: google.cloud.compute.v1.IVpnGatewayVpnGatewayInterface[];

                    /** VpnGateway _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** VpnGateway _description. */
                    public _description?: "description";

                    /** VpnGateway _id. */
                    public _id?: "id";

                    /** VpnGateway _kind. */
                    public _kind?: "kind";

                    /** VpnGateway _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /** VpnGateway _name. */
                    public _name?: "name";

                    /** VpnGateway _network. */
                    public _network?: "network";

                    /** VpnGateway _region. */
                    public _region?: "region";

                    /** VpnGateway _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VpnGateway _stackType. */
                    public _stackType?: "stackType";

                    /**
                     * Creates a new VpnGateway instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGateway instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGateway): google.cloud.compute.v1.VpnGateway;

                    /**
                     * Encodes the specified VpnGateway message. Does not implicitly {@link google.cloud.compute.v1.VpnGateway.verify|verify} messages.
                     * @param message VpnGateway message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGateway, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGateway message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGateway.verify|verify} messages.
                     * @param message VpnGateway message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGateway, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGateway message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGateway
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGateway;

                    /**
                     * Decodes a VpnGateway message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGateway
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGateway;

                    /**
                     * Verifies a VpnGateway message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGateway message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGateway
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGateway;

                    /**
                     * Creates a plain object from a VpnGateway message. Also converts values to other types if specified.
                     * @param message VpnGateway
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGateway, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGateway to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGateway
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace VpnGateway {

                    /** StackType enum. */
                    enum StackType {
                        UNDEFINED_STACK_TYPE = 0,
                        IPV4_IPV6 = 22197249,
                        IPV4_ONLY = 22373798
                    }
                }

                /** Properties of a VpnGatewayAggregatedList. */
                interface IVpnGatewayAggregatedList {

                    /** VpnGatewayAggregatedList id */
                    id?: (string|null);

                    /** VpnGatewayAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IVpnGatewaysScopedList }|null);

                    /** VpnGatewayAggregatedList kind */
                    kind?: (string|null);

                    /** VpnGatewayAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** VpnGatewayAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** VpnGatewayAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** VpnGatewayAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VpnGatewayAggregatedList. */
                class VpnGatewayAggregatedList implements IVpnGatewayAggregatedList {

                    /**
                     * Constructs a new VpnGatewayAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayAggregatedList);

                    /** VpnGatewayAggregatedList id. */
                    public id?: (string|null);

                    /** VpnGatewayAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IVpnGatewaysScopedList };

                    /** VpnGatewayAggregatedList kind. */
                    public kind?: (string|null);

                    /** VpnGatewayAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** VpnGatewayAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** VpnGatewayAggregatedList unreachables. */
                    public unreachables: string[];

                    /** VpnGatewayAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VpnGatewayAggregatedList _id. */
                    public _id?: "id";

                    /** VpnGatewayAggregatedList _kind. */
                    public _kind?: "kind";

                    /** VpnGatewayAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** VpnGatewayAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VpnGatewayAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VpnGatewayAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayAggregatedList): google.cloud.compute.v1.VpnGatewayAggregatedList;

                    /**
                     * Encodes the specified VpnGatewayAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayAggregatedList.verify|verify} messages.
                     * @param message VpnGatewayAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayAggregatedList.verify|verify} messages.
                     * @param message VpnGatewayAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayAggregatedList;

                    /**
                     * Decodes a VpnGatewayAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayAggregatedList;

                    /**
                     * Verifies a VpnGatewayAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayAggregatedList;

                    /**
                     * Creates a plain object from a VpnGatewayAggregatedList message. Also converts values to other types if specified.
                     * @param message VpnGatewayAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewayList. */
                interface IVpnGatewayList {

                    /** VpnGatewayList id */
                    id?: (string|null);

                    /** VpnGatewayList items */
                    items?: (google.cloud.compute.v1.IVpnGateway[]|null);

                    /** VpnGatewayList kind */
                    kind?: (string|null);

                    /** VpnGatewayList nextPageToken */
                    nextPageToken?: (string|null);

                    /** VpnGatewayList selfLink */
                    selfLink?: (string|null);

                    /** VpnGatewayList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VpnGatewayList. */
                class VpnGatewayList implements IVpnGatewayList {

                    /**
                     * Constructs a new VpnGatewayList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayList);

                    /** VpnGatewayList id. */
                    public id?: (string|null);

                    /** VpnGatewayList items. */
                    public items: google.cloud.compute.v1.IVpnGateway[];

                    /** VpnGatewayList kind. */
                    public kind?: (string|null);

                    /** VpnGatewayList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** VpnGatewayList selfLink. */
                    public selfLink?: (string|null);

                    /** VpnGatewayList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VpnGatewayList _id. */
                    public _id?: "id";

                    /** VpnGatewayList _kind. */
                    public _kind?: "kind";

                    /** VpnGatewayList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** VpnGatewayList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VpnGatewayList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VpnGatewayList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayList): google.cloud.compute.v1.VpnGatewayList;

                    /**
                     * Encodes the specified VpnGatewayList message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayList.verify|verify} messages.
                     * @param message VpnGatewayList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayList.verify|verify} messages.
                     * @param message VpnGatewayList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayList;

                    /**
                     * Decodes a VpnGatewayList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayList;

                    /**
                     * Verifies a VpnGatewayList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayList;

                    /**
                     * Creates a plain object from a VpnGatewayList message. Also converts values to other types if specified.
                     * @param message VpnGatewayList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewayStatus. */
                interface IVpnGatewayStatus {

                    /** VpnGatewayStatus vpnConnections */
                    vpnConnections?: (google.cloud.compute.v1.IVpnGatewayStatusVpnConnection[]|null);
                }

                /** Represents a VpnGatewayStatus. */
                class VpnGatewayStatus implements IVpnGatewayStatus {

                    /**
                     * Constructs a new VpnGatewayStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayStatus);

                    /** VpnGatewayStatus vpnConnections. */
                    public vpnConnections: google.cloud.compute.v1.IVpnGatewayStatusVpnConnection[];

                    /**
                     * Creates a new VpnGatewayStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayStatus instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayStatus): google.cloud.compute.v1.VpnGatewayStatus;

                    /**
                     * Encodes the specified VpnGatewayStatus message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatus.verify|verify} messages.
                     * @param message VpnGatewayStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayStatus message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatus.verify|verify} messages.
                     * @param message VpnGatewayStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayStatus;

                    /**
                     * Decodes a VpnGatewayStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayStatus;

                    /**
                     * Verifies a VpnGatewayStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayStatus;

                    /**
                     * Creates a plain object from a VpnGatewayStatus message. Also converts values to other types if specified.
                     * @param message VpnGatewayStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewayStatusHighAvailabilityRequirementState. */
                interface IVpnGatewayStatusHighAvailabilityRequirementState {

                    /** VpnGatewayStatusHighAvailabilityRequirementState state */
                    state?: (string|null);

                    /** VpnGatewayStatusHighAvailabilityRequirementState unsatisfiedReason */
                    unsatisfiedReason?: (string|null);
                }

                /** Represents a VpnGatewayStatusHighAvailabilityRequirementState. */
                class VpnGatewayStatusHighAvailabilityRequirementState implements IVpnGatewayStatusHighAvailabilityRequirementState {

                    /**
                     * Constructs a new VpnGatewayStatusHighAvailabilityRequirementState.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayStatusHighAvailabilityRequirementState);

                    /** VpnGatewayStatusHighAvailabilityRequirementState state. */
                    public state?: (string|null);

                    /** VpnGatewayStatusHighAvailabilityRequirementState unsatisfiedReason. */
                    public unsatisfiedReason?: (string|null);

                    /** VpnGatewayStatusHighAvailabilityRequirementState _state. */
                    public _state?: "state";

                    /** VpnGatewayStatusHighAvailabilityRequirementState _unsatisfiedReason. */
                    public _unsatisfiedReason?: "unsatisfiedReason";

                    /**
                     * Creates a new VpnGatewayStatusHighAvailabilityRequirementState instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayStatusHighAvailabilityRequirementState instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayStatusHighAvailabilityRequirementState): google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState;

                    /**
                     * Encodes the specified VpnGatewayStatusHighAvailabilityRequirementState message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState.verify|verify} messages.
                     * @param message VpnGatewayStatusHighAvailabilityRequirementState message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayStatusHighAvailabilityRequirementState, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayStatusHighAvailabilityRequirementState message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState.verify|verify} messages.
                     * @param message VpnGatewayStatusHighAvailabilityRequirementState message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayStatusHighAvailabilityRequirementState, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayStatusHighAvailabilityRequirementState message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayStatusHighAvailabilityRequirementState
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState;

                    /**
                     * Decodes a VpnGatewayStatusHighAvailabilityRequirementState message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayStatusHighAvailabilityRequirementState
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState;

                    /**
                     * Verifies a VpnGatewayStatusHighAvailabilityRequirementState message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayStatusHighAvailabilityRequirementState message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayStatusHighAvailabilityRequirementState
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState;

                    /**
                     * Creates a plain object from a VpnGatewayStatusHighAvailabilityRequirementState message. Also converts values to other types if specified.
                     * @param message VpnGatewayStatusHighAvailabilityRequirementState
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayStatusHighAvailabilityRequirementState, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayStatusHighAvailabilityRequirementState to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayStatusHighAvailabilityRequirementState
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace VpnGatewayStatusHighAvailabilityRequirementState {

                    /** State enum. */
                    enum State {
                        UNDEFINED_STATE = 0,
                        CONNECTION_REDUNDANCY_MET = 505242907,
                        CONNECTION_REDUNDANCY_NOT_MET = 511863311
                    }

                    /** UnsatisfiedReason enum. */
                    enum UnsatisfiedReason {
                        UNDEFINED_UNSATISFIED_REASON = 0,
                        INCOMPLETE_TUNNELS_COVERAGE = 55917437
                    }
                }

                /** Properties of a VpnGatewayStatusTunnel. */
                interface IVpnGatewayStatusTunnel {

                    /** VpnGatewayStatusTunnel localGatewayInterface */
                    localGatewayInterface?: (number|null);

                    /** VpnGatewayStatusTunnel peerGatewayInterface */
                    peerGatewayInterface?: (number|null);

                    /** VpnGatewayStatusTunnel tunnelUrl */
                    tunnelUrl?: (string|null);
                }

                /** Represents a VpnGatewayStatusTunnel. */
                class VpnGatewayStatusTunnel implements IVpnGatewayStatusTunnel {

                    /**
                     * Constructs a new VpnGatewayStatusTunnel.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayStatusTunnel);

                    /** VpnGatewayStatusTunnel localGatewayInterface. */
                    public localGatewayInterface?: (number|null);

                    /** VpnGatewayStatusTunnel peerGatewayInterface. */
                    public peerGatewayInterface?: (number|null);

                    /** VpnGatewayStatusTunnel tunnelUrl. */
                    public tunnelUrl?: (string|null);

                    /** VpnGatewayStatusTunnel _localGatewayInterface. */
                    public _localGatewayInterface?: "localGatewayInterface";

                    /** VpnGatewayStatusTunnel _peerGatewayInterface. */
                    public _peerGatewayInterface?: "peerGatewayInterface";

                    /** VpnGatewayStatusTunnel _tunnelUrl. */
                    public _tunnelUrl?: "tunnelUrl";

                    /**
                     * Creates a new VpnGatewayStatusTunnel instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayStatusTunnel instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayStatusTunnel): google.cloud.compute.v1.VpnGatewayStatusTunnel;

                    /**
                     * Encodes the specified VpnGatewayStatusTunnel message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatusTunnel.verify|verify} messages.
                     * @param message VpnGatewayStatusTunnel message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayStatusTunnel, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayStatusTunnel message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatusTunnel.verify|verify} messages.
                     * @param message VpnGatewayStatusTunnel message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayStatusTunnel, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayStatusTunnel message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayStatusTunnel
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayStatusTunnel;

                    /**
                     * Decodes a VpnGatewayStatusTunnel message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayStatusTunnel
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayStatusTunnel;

                    /**
                     * Verifies a VpnGatewayStatusTunnel message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayStatusTunnel message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayStatusTunnel
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayStatusTunnel;

                    /**
                     * Creates a plain object from a VpnGatewayStatusTunnel message. Also converts values to other types if specified.
                     * @param message VpnGatewayStatusTunnel
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayStatusTunnel, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayStatusTunnel to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayStatusTunnel
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewayStatusVpnConnection. */
                interface IVpnGatewayStatusVpnConnection {

                    /** VpnGatewayStatusVpnConnection peerExternalGateway */
                    peerExternalGateway?: (string|null);

                    /** VpnGatewayStatusVpnConnection peerGcpGateway */
                    peerGcpGateway?: (string|null);

                    /** VpnGatewayStatusVpnConnection state */
                    state?: (google.cloud.compute.v1.IVpnGatewayStatusHighAvailabilityRequirementState|null);

                    /** VpnGatewayStatusVpnConnection tunnels */
                    tunnels?: (google.cloud.compute.v1.IVpnGatewayStatusTunnel[]|null);
                }

                /** Represents a VpnGatewayStatusVpnConnection. */
                class VpnGatewayStatusVpnConnection implements IVpnGatewayStatusVpnConnection {

                    /**
                     * Constructs a new VpnGatewayStatusVpnConnection.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayStatusVpnConnection);

                    /** VpnGatewayStatusVpnConnection peerExternalGateway. */
                    public peerExternalGateway?: (string|null);

                    /** VpnGatewayStatusVpnConnection peerGcpGateway. */
                    public peerGcpGateway?: (string|null);

                    /** VpnGatewayStatusVpnConnection state. */
                    public state?: (google.cloud.compute.v1.IVpnGatewayStatusHighAvailabilityRequirementState|null);

                    /** VpnGatewayStatusVpnConnection tunnels. */
                    public tunnels: google.cloud.compute.v1.IVpnGatewayStatusTunnel[];

                    /** VpnGatewayStatusVpnConnection _peerExternalGateway. */
                    public _peerExternalGateway?: "peerExternalGateway";

                    /** VpnGatewayStatusVpnConnection _peerGcpGateway. */
                    public _peerGcpGateway?: "peerGcpGateway";

                    /** VpnGatewayStatusVpnConnection _state. */
                    public _state?: "state";

                    /**
                     * Creates a new VpnGatewayStatusVpnConnection instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayStatusVpnConnection instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayStatusVpnConnection): google.cloud.compute.v1.VpnGatewayStatusVpnConnection;

                    /**
                     * Encodes the specified VpnGatewayStatusVpnConnection message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatusVpnConnection.verify|verify} messages.
                     * @param message VpnGatewayStatusVpnConnection message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayStatusVpnConnection, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayStatusVpnConnection message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayStatusVpnConnection.verify|verify} messages.
                     * @param message VpnGatewayStatusVpnConnection message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayStatusVpnConnection, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayStatusVpnConnection message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayStatusVpnConnection
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayStatusVpnConnection;

                    /**
                     * Decodes a VpnGatewayStatusVpnConnection message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayStatusVpnConnection
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayStatusVpnConnection;

                    /**
                     * Verifies a VpnGatewayStatusVpnConnection message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayStatusVpnConnection message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayStatusVpnConnection
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayStatusVpnConnection;

                    /**
                     * Creates a plain object from a VpnGatewayStatusVpnConnection message. Also converts values to other types if specified.
                     * @param message VpnGatewayStatusVpnConnection
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayStatusVpnConnection, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayStatusVpnConnection to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayStatusVpnConnection
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewayVpnGatewayInterface. */
                interface IVpnGatewayVpnGatewayInterface {

                    /** VpnGatewayVpnGatewayInterface id */
                    id?: (number|null);

                    /** VpnGatewayVpnGatewayInterface interconnectAttachment */
                    interconnectAttachment?: (string|null);

                    /** VpnGatewayVpnGatewayInterface ipAddress */
                    ipAddress?: (string|null);
                }

                /** Represents a VpnGatewayVpnGatewayInterface. */
                class VpnGatewayVpnGatewayInterface implements IVpnGatewayVpnGatewayInterface {

                    /**
                     * Constructs a new VpnGatewayVpnGatewayInterface.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewayVpnGatewayInterface);

                    /** VpnGatewayVpnGatewayInterface id. */
                    public id?: (number|null);

                    /** VpnGatewayVpnGatewayInterface interconnectAttachment. */
                    public interconnectAttachment?: (string|null);

                    /** VpnGatewayVpnGatewayInterface ipAddress. */
                    public ipAddress?: (string|null);

                    /** VpnGatewayVpnGatewayInterface _id. */
                    public _id?: "id";

                    /** VpnGatewayVpnGatewayInterface _interconnectAttachment. */
                    public _interconnectAttachment?: "interconnectAttachment";

                    /** VpnGatewayVpnGatewayInterface _ipAddress. */
                    public _ipAddress?: "ipAddress";

                    /**
                     * Creates a new VpnGatewayVpnGatewayInterface instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewayVpnGatewayInterface instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewayVpnGatewayInterface): google.cloud.compute.v1.VpnGatewayVpnGatewayInterface;

                    /**
                     * Encodes the specified VpnGatewayVpnGatewayInterface message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayVpnGatewayInterface.verify|verify} messages.
                     * @param message VpnGatewayVpnGatewayInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewayVpnGatewayInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewayVpnGatewayInterface message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewayVpnGatewayInterface.verify|verify} messages.
                     * @param message VpnGatewayVpnGatewayInterface message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewayVpnGatewayInterface, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewayVpnGatewayInterface message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewayVpnGatewayInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewayVpnGatewayInterface;

                    /**
                     * Decodes a VpnGatewayVpnGatewayInterface message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewayVpnGatewayInterface
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewayVpnGatewayInterface;

                    /**
                     * Verifies a VpnGatewayVpnGatewayInterface message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewayVpnGatewayInterface message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewayVpnGatewayInterface
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewayVpnGatewayInterface;

                    /**
                     * Creates a plain object from a VpnGatewayVpnGatewayInterface message. Also converts values to other types if specified.
                     * @param message VpnGatewayVpnGatewayInterface
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewayVpnGatewayInterface, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewayVpnGatewayInterface to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewayVpnGatewayInterface
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewaysGetStatusResponse. */
                interface IVpnGatewaysGetStatusResponse {

                    /** VpnGatewaysGetStatusResponse result */
                    result?: (google.cloud.compute.v1.IVpnGatewayStatus|null);
                }

                /** Represents a VpnGatewaysGetStatusResponse. */
                class VpnGatewaysGetStatusResponse implements IVpnGatewaysGetStatusResponse {

                    /**
                     * Constructs a new VpnGatewaysGetStatusResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewaysGetStatusResponse);

                    /** VpnGatewaysGetStatusResponse result. */
                    public result?: (google.cloud.compute.v1.IVpnGatewayStatus|null);

                    /** VpnGatewaysGetStatusResponse _result. */
                    public _result?: "result";

                    /**
                     * Creates a new VpnGatewaysGetStatusResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewaysGetStatusResponse instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewaysGetStatusResponse): google.cloud.compute.v1.VpnGatewaysGetStatusResponse;

                    /**
                     * Encodes the specified VpnGatewaysGetStatusResponse message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewaysGetStatusResponse.verify|verify} messages.
                     * @param message VpnGatewaysGetStatusResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewaysGetStatusResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewaysGetStatusResponse message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewaysGetStatusResponse.verify|verify} messages.
                     * @param message VpnGatewaysGetStatusResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewaysGetStatusResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewaysGetStatusResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewaysGetStatusResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewaysGetStatusResponse;

                    /**
                     * Decodes a VpnGatewaysGetStatusResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewaysGetStatusResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewaysGetStatusResponse;

                    /**
                     * Verifies a VpnGatewaysGetStatusResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewaysGetStatusResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewaysGetStatusResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewaysGetStatusResponse;

                    /**
                     * Creates a plain object from a VpnGatewaysGetStatusResponse message. Also converts values to other types if specified.
                     * @param message VpnGatewaysGetStatusResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewaysGetStatusResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewaysGetStatusResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewaysGetStatusResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnGatewaysScopedList. */
                interface IVpnGatewaysScopedList {

                    /** VpnGatewaysScopedList vpnGateways */
                    vpnGateways?: (google.cloud.compute.v1.IVpnGateway[]|null);

                    /** VpnGatewaysScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VpnGatewaysScopedList. */
                class VpnGatewaysScopedList implements IVpnGatewaysScopedList {

                    /**
                     * Constructs a new VpnGatewaysScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnGatewaysScopedList);

                    /** VpnGatewaysScopedList vpnGateways. */
                    public vpnGateways: google.cloud.compute.v1.IVpnGateway[];

                    /** VpnGatewaysScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VpnGatewaysScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VpnGatewaysScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnGatewaysScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnGatewaysScopedList): google.cloud.compute.v1.VpnGatewaysScopedList;

                    /**
                     * Encodes the specified VpnGatewaysScopedList message. Does not implicitly {@link google.cloud.compute.v1.VpnGatewaysScopedList.verify|verify} messages.
                     * @param message VpnGatewaysScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnGatewaysScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnGatewaysScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnGatewaysScopedList.verify|verify} messages.
                     * @param message VpnGatewaysScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnGatewaysScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnGatewaysScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnGatewaysScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnGatewaysScopedList;

                    /**
                     * Decodes a VpnGatewaysScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnGatewaysScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnGatewaysScopedList;

                    /**
                     * Verifies a VpnGatewaysScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnGatewaysScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnGatewaysScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnGatewaysScopedList;

                    /**
                     * Creates a plain object from a VpnGatewaysScopedList message. Also converts values to other types if specified.
                     * @param message VpnGatewaysScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnGatewaysScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnGatewaysScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnGatewaysScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnTunnel. */
                interface IVpnTunnel {

                    /** VpnTunnel creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** VpnTunnel description */
                    description?: (string|null);

                    /** VpnTunnel detailedStatus */
                    detailedStatus?: (string|null);

                    /** VpnTunnel id */
                    id?: (number|Long|string|null);

                    /** VpnTunnel ikeVersion */
                    ikeVersion?: (number|null);

                    /** VpnTunnel kind */
                    kind?: (string|null);

                    /** VpnTunnel localTrafficSelector */
                    localTrafficSelector?: (string[]|null);

                    /** VpnTunnel name */
                    name?: (string|null);

                    /** VpnTunnel peerExternalGateway */
                    peerExternalGateway?: (string|null);

                    /** VpnTunnel peerExternalGatewayInterface */
                    peerExternalGatewayInterface?: (number|null);

                    /** VpnTunnel peerGcpGateway */
                    peerGcpGateway?: (string|null);

                    /** VpnTunnel peerIp */
                    peerIp?: (string|null);

                    /** VpnTunnel region */
                    region?: (string|null);

                    /** VpnTunnel remoteTrafficSelector */
                    remoteTrafficSelector?: (string[]|null);

                    /** VpnTunnel router */
                    router?: (string|null);

                    /** VpnTunnel selfLink */
                    selfLink?: (string|null);

                    /** VpnTunnel sharedSecret */
                    sharedSecret?: (string|null);

                    /** VpnTunnel sharedSecretHash */
                    sharedSecretHash?: (string|null);

                    /** VpnTunnel status */
                    status?: (string|null);

                    /** VpnTunnel targetVpnGateway */
                    targetVpnGateway?: (string|null);

                    /** VpnTunnel vpnGateway */
                    vpnGateway?: (string|null);

                    /** VpnTunnel vpnGatewayInterface */
                    vpnGatewayInterface?: (number|null);
                }

                /** Represents a VpnTunnel. */
                class VpnTunnel implements IVpnTunnel {

                    /**
                     * Constructs a new VpnTunnel.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnTunnel);

                    /** VpnTunnel creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** VpnTunnel description. */
                    public description?: (string|null);

                    /** VpnTunnel detailedStatus. */
                    public detailedStatus?: (string|null);

                    /** VpnTunnel id. */
                    public id?: (number|Long|string|null);

                    /** VpnTunnel ikeVersion. */
                    public ikeVersion?: (number|null);

                    /** VpnTunnel kind. */
                    public kind?: (string|null);

                    /** VpnTunnel localTrafficSelector. */
                    public localTrafficSelector: string[];

                    /** VpnTunnel name. */
                    public name?: (string|null);

                    /** VpnTunnel peerExternalGateway. */
                    public peerExternalGateway?: (string|null);

                    /** VpnTunnel peerExternalGatewayInterface. */
                    public peerExternalGatewayInterface?: (number|null);

                    /** VpnTunnel peerGcpGateway. */
                    public peerGcpGateway?: (string|null);

                    /** VpnTunnel peerIp. */
                    public peerIp?: (string|null);

                    /** VpnTunnel region. */
                    public region?: (string|null);

                    /** VpnTunnel remoteTrafficSelector. */
                    public remoteTrafficSelector: string[];

                    /** VpnTunnel router. */
                    public router?: (string|null);

                    /** VpnTunnel selfLink. */
                    public selfLink?: (string|null);

                    /** VpnTunnel sharedSecret. */
                    public sharedSecret?: (string|null);

                    /** VpnTunnel sharedSecretHash. */
                    public sharedSecretHash?: (string|null);

                    /** VpnTunnel status. */
                    public status?: (string|null);

                    /** VpnTunnel targetVpnGateway. */
                    public targetVpnGateway?: (string|null);

                    /** VpnTunnel vpnGateway. */
                    public vpnGateway?: (string|null);

                    /** VpnTunnel vpnGatewayInterface. */
                    public vpnGatewayInterface?: (number|null);

                    /** VpnTunnel _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** VpnTunnel _description. */
                    public _description?: "description";

                    /** VpnTunnel _detailedStatus. */
                    public _detailedStatus?: "detailedStatus";

                    /** VpnTunnel _id. */
                    public _id?: "id";

                    /** VpnTunnel _ikeVersion. */
                    public _ikeVersion?: "ikeVersion";

                    /** VpnTunnel _kind. */
                    public _kind?: "kind";

                    /** VpnTunnel _name. */
                    public _name?: "name";

                    /** VpnTunnel _peerExternalGateway. */
                    public _peerExternalGateway?: "peerExternalGateway";

                    /** VpnTunnel _peerExternalGatewayInterface. */
                    public _peerExternalGatewayInterface?: "peerExternalGatewayInterface";

                    /** VpnTunnel _peerGcpGateway. */
                    public _peerGcpGateway?: "peerGcpGateway";

                    /** VpnTunnel _peerIp. */
                    public _peerIp?: "peerIp";

                    /** VpnTunnel _region. */
                    public _region?: "region";

                    /** VpnTunnel _router. */
                    public _router?: "router";

                    /** VpnTunnel _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VpnTunnel _sharedSecret. */
                    public _sharedSecret?: "sharedSecret";

                    /** VpnTunnel _sharedSecretHash. */
                    public _sharedSecretHash?: "sharedSecretHash";

                    /** VpnTunnel _status. */
                    public _status?: "status";

                    /** VpnTunnel _targetVpnGateway. */
                    public _targetVpnGateway?: "targetVpnGateway";

                    /** VpnTunnel _vpnGateway. */
                    public _vpnGateway?: "vpnGateway";

                    /** VpnTunnel _vpnGatewayInterface. */
                    public _vpnGatewayInterface?: "vpnGatewayInterface";

                    /**
                     * Creates a new VpnTunnel instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnTunnel instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnTunnel): google.cloud.compute.v1.VpnTunnel;

                    /**
                     * Encodes the specified VpnTunnel message. Does not implicitly {@link google.cloud.compute.v1.VpnTunnel.verify|verify} messages.
                     * @param message VpnTunnel message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnTunnel, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnTunnel message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnTunnel.verify|verify} messages.
                     * @param message VpnTunnel message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnTunnel, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnTunnel message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnTunnel
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnTunnel;

                    /**
                     * Decodes a VpnTunnel message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnTunnel
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnTunnel;

                    /**
                     * Verifies a VpnTunnel message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnTunnel message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnTunnel
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnTunnel;

                    /**
                     * Creates a plain object from a VpnTunnel message. Also converts values to other types if specified.
                     * @param message VpnTunnel
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnTunnel, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnTunnel to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnTunnel
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace VpnTunnel {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        ALLOCATING_RESOURCES = 320922816,
                        AUTHORIZATION_ERROR = 23580290,
                        DEPROVISIONING = 428935662,
                        ESTABLISHED = 88852344,
                        FAILED = 455706685,
                        FIRST_HANDSHAKE = 191393000,
                        NEGOTIATION_FAILURE = 360325868,
                        NETWORK_ERROR = 193912951,
                        NO_INCOMING_PACKETS = 119983216,
                        PROVISIONING = 290896621,
                        REJECTED = 174130302,
                        STOPPED = 444276141,
                        WAITING_FOR_FULL_CONFIG = 41640522
                    }
                }

                /** Properties of a VpnTunnelAggregatedList. */
                interface IVpnTunnelAggregatedList {

                    /** VpnTunnelAggregatedList id */
                    id?: (string|null);

                    /** VpnTunnelAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1.IVpnTunnelsScopedList }|null);

                    /** VpnTunnelAggregatedList kind */
                    kind?: (string|null);

                    /** VpnTunnelAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** VpnTunnelAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** VpnTunnelAggregatedList unreachables */
                    unreachables?: (string[]|null);

                    /** VpnTunnelAggregatedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VpnTunnelAggregatedList. */
                class VpnTunnelAggregatedList implements IVpnTunnelAggregatedList {

                    /**
                     * Constructs a new VpnTunnelAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnTunnelAggregatedList);

                    /** VpnTunnelAggregatedList id. */
                    public id?: (string|null);

                    /** VpnTunnelAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1.IVpnTunnelsScopedList };

                    /** VpnTunnelAggregatedList kind. */
                    public kind?: (string|null);

                    /** VpnTunnelAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** VpnTunnelAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** VpnTunnelAggregatedList unreachables. */
                    public unreachables: string[];

                    /** VpnTunnelAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VpnTunnelAggregatedList _id. */
                    public _id?: "id";

                    /** VpnTunnelAggregatedList _kind. */
                    public _kind?: "kind";

                    /** VpnTunnelAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** VpnTunnelAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VpnTunnelAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VpnTunnelAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnTunnelAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnTunnelAggregatedList): google.cloud.compute.v1.VpnTunnelAggregatedList;

                    /**
                     * Encodes the specified VpnTunnelAggregatedList message. Does not implicitly {@link google.cloud.compute.v1.VpnTunnelAggregatedList.verify|verify} messages.
                     * @param message VpnTunnelAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnTunnelAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnTunnelAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnTunnelAggregatedList.verify|verify} messages.
                     * @param message VpnTunnelAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnTunnelAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnTunnelAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnTunnelAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnTunnelAggregatedList;

                    /**
                     * Decodes a VpnTunnelAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnTunnelAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnTunnelAggregatedList;

                    /**
                     * Verifies a VpnTunnelAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnTunnelAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnTunnelAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnTunnelAggregatedList;

                    /**
                     * Creates a plain object from a VpnTunnelAggregatedList message. Also converts values to other types if specified.
                     * @param message VpnTunnelAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnTunnelAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnTunnelAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnTunnelAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnTunnelList. */
                interface IVpnTunnelList {

                    /** VpnTunnelList id */
                    id?: (string|null);

                    /** VpnTunnelList items */
                    items?: (google.cloud.compute.v1.IVpnTunnel[]|null);

                    /** VpnTunnelList kind */
                    kind?: (string|null);

                    /** VpnTunnelList nextPageToken */
                    nextPageToken?: (string|null);

                    /** VpnTunnelList selfLink */
                    selfLink?: (string|null);

                    /** VpnTunnelList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VpnTunnelList. */
                class VpnTunnelList implements IVpnTunnelList {

                    /**
                     * Constructs a new VpnTunnelList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnTunnelList);

                    /** VpnTunnelList id. */
                    public id?: (string|null);

                    /** VpnTunnelList items. */
                    public items: google.cloud.compute.v1.IVpnTunnel[];

                    /** VpnTunnelList kind. */
                    public kind?: (string|null);

                    /** VpnTunnelList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** VpnTunnelList selfLink. */
                    public selfLink?: (string|null);

                    /** VpnTunnelList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VpnTunnelList _id. */
                    public _id?: "id";

                    /** VpnTunnelList _kind. */
                    public _kind?: "kind";

                    /** VpnTunnelList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** VpnTunnelList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** VpnTunnelList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VpnTunnelList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnTunnelList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnTunnelList): google.cloud.compute.v1.VpnTunnelList;

                    /**
                     * Encodes the specified VpnTunnelList message. Does not implicitly {@link google.cloud.compute.v1.VpnTunnelList.verify|verify} messages.
                     * @param message VpnTunnelList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnTunnelList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnTunnelList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnTunnelList.verify|verify} messages.
                     * @param message VpnTunnelList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnTunnelList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnTunnelList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnTunnelList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnTunnelList;

                    /**
                     * Decodes a VpnTunnelList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnTunnelList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnTunnelList;

                    /**
                     * Verifies a VpnTunnelList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnTunnelList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnTunnelList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnTunnelList;

                    /**
                     * Creates a plain object from a VpnTunnelList message. Also converts values to other types if specified.
                     * @param message VpnTunnelList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnTunnelList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnTunnelList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnTunnelList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a VpnTunnelsScopedList. */
                interface IVpnTunnelsScopedList {

                    /** VpnTunnelsScopedList vpnTunnels */
                    vpnTunnels?: (google.cloud.compute.v1.IVpnTunnel[]|null);

                    /** VpnTunnelsScopedList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a VpnTunnelsScopedList. */
                class VpnTunnelsScopedList implements IVpnTunnelsScopedList {

                    /**
                     * Constructs a new VpnTunnelsScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IVpnTunnelsScopedList);

                    /** VpnTunnelsScopedList vpnTunnels. */
                    public vpnTunnels: google.cloud.compute.v1.IVpnTunnel[];

                    /** VpnTunnelsScopedList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** VpnTunnelsScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new VpnTunnelsScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns VpnTunnelsScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IVpnTunnelsScopedList): google.cloud.compute.v1.VpnTunnelsScopedList;

                    /**
                     * Encodes the specified VpnTunnelsScopedList message. Does not implicitly {@link google.cloud.compute.v1.VpnTunnelsScopedList.verify|verify} messages.
                     * @param message VpnTunnelsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IVpnTunnelsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified VpnTunnelsScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.VpnTunnelsScopedList.verify|verify} messages.
                     * @param message VpnTunnelsScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IVpnTunnelsScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a VpnTunnelsScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns VpnTunnelsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.VpnTunnelsScopedList;

                    /**
                     * Decodes a VpnTunnelsScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns VpnTunnelsScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.VpnTunnelsScopedList;

                    /**
                     * Verifies a VpnTunnelsScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a VpnTunnelsScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns VpnTunnelsScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.VpnTunnelsScopedList;

                    /**
                     * Creates a plain object from a VpnTunnelsScopedList message. Also converts values to other types if specified.
                     * @param message VpnTunnelsScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.VpnTunnelsScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this VpnTunnelsScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for VpnTunnelsScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a WafExpressionSet. */
                interface IWafExpressionSet {

                    /** WafExpressionSet aliases */
                    aliases?: (string[]|null);

                    /** WafExpressionSet expressions */
                    expressions?: (google.cloud.compute.v1.IWafExpressionSetExpression[]|null);

                    /** WafExpressionSet id */
                    id?: (string|null);
                }

                /** Represents a WafExpressionSet. */
                class WafExpressionSet implements IWafExpressionSet {

                    /**
                     * Constructs a new WafExpressionSet.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWafExpressionSet);

                    /** WafExpressionSet aliases. */
                    public aliases: string[];

                    /** WafExpressionSet expressions. */
                    public expressions: google.cloud.compute.v1.IWafExpressionSetExpression[];

                    /** WafExpressionSet id. */
                    public id?: (string|null);

                    /** WafExpressionSet _id. */
                    public _id?: "id";

                    /**
                     * Creates a new WafExpressionSet instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WafExpressionSet instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWafExpressionSet): google.cloud.compute.v1.WafExpressionSet;

                    /**
                     * Encodes the specified WafExpressionSet message. Does not implicitly {@link google.cloud.compute.v1.WafExpressionSet.verify|verify} messages.
                     * @param message WafExpressionSet message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWafExpressionSet, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WafExpressionSet message, length delimited. Does not implicitly {@link google.cloud.compute.v1.WafExpressionSet.verify|verify} messages.
                     * @param message WafExpressionSet message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWafExpressionSet, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WafExpressionSet message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WafExpressionSet
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.WafExpressionSet;

                    /**
                     * Decodes a WafExpressionSet message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WafExpressionSet
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.WafExpressionSet;

                    /**
                     * Verifies a WafExpressionSet message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WafExpressionSet message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WafExpressionSet
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.WafExpressionSet;

                    /**
                     * Creates a plain object from a WafExpressionSet message. Also converts values to other types if specified.
                     * @param message WafExpressionSet
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.WafExpressionSet, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WafExpressionSet to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WafExpressionSet
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a WafExpressionSetExpression. */
                interface IWafExpressionSetExpression {

                    /** WafExpressionSetExpression id */
                    id?: (string|null);
                }

                /** Represents a WafExpressionSetExpression. */
                class WafExpressionSetExpression implements IWafExpressionSetExpression {

                    /**
                     * Constructs a new WafExpressionSetExpression.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWafExpressionSetExpression);

                    /** WafExpressionSetExpression id. */
                    public id?: (string|null);

                    /** WafExpressionSetExpression _id. */
                    public _id?: "id";

                    /**
                     * Creates a new WafExpressionSetExpression instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WafExpressionSetExpression instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWafExpressionSetExpression): google.cloud.compute.v1.WafExpressionSetExpression;

                    /**
                     * Encodes the specified WafExpressionSetExpression message. Does not implicitly {@link google.cloud.compute.v1.WafExpressionSetExpression.verify|verify} messages.
                     * @param message WafExpressionSetExpression message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWafExpressionSetExpression, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WafExpressionSetExpression message, length delimited. Does not implicitly {@link google.cloud.compute.v1.WafExpressionSetExpression.verify|verify} messages.
                     * @param message WafExpressionSetExpression message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWafExpressionSetExpression, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WafExpressionSetExpression message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WafExpressionSetExpression
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.WafExpressionSetExpression;

                    /**
                     * Decodes a WafExpressionSetExpression message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WafExpressionSetExpression
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.WafExpressionSetExpression;

                    /**
                     * Verifies a WafExpressionSetExpression message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WafExpressionSetExpression message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WafExpressionSetExpression
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.WafExpressionSetExpression;

                    /**
                     * Creates a plain object from a WafExpressionSetExpression message. Also converts values to other types if specified.
                     * @param message WafExpressionSetExpression
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.WafExpressionSetExpression, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WafExpressionSetExpression to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WafExpressionSetExpression
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a WaitGlobalOperationRequest. */
                interface IWaitGlobalOperationRequest {

                    /** WaitGlobalOperationRequest operation */
                    operation?: (string|null);

                    /** WaitGlobalOperationRequest project */
                    project?: (string|null);
                }

                /** Represents a WaitGlobalOperationRequest. */
                class WaitGlobalOperationRequest implements IWaitGlobalOperationRequest {

                    /**
                     * Constructs a new WaitGlobalOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWaitGlobalOperationRequest);

                    /** WaitGlobalOperationRequest operation. */
                    public operation: string;

                    /** WaitGlobalOperationRequest project. */
                    public project: string;

                    /**
                     * Creates a new WaitGlobalOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WaitGlobalOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWaitGlobalOperationRequest): google.cloud.compute.v1.WaitGlobalOperationRequest;

                    /**
                     * Encodes the specified WaitGlobalOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.WaitGlobalOperationRequest.verify|verify} messages.
                     * @param message WaitGlobalOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWaitGlobalOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WaitGlobalOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.WaitGlobalOperationRequest.verify|verify} messages.
                     * @param message WaitGlobalOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWaitGlobalOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WaitGlobalOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WaitGlobalOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.WaitGlobalOperationRequest;

                    /**
                     * Decodes a WaitGlobalOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WaitGlobalOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.WaitGlobalOperationRequest;

                    /**
                     * Verifies a WaitGlobalOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WaitGlobalOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WaitGlobalOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.WaitGlobalOperationRequest;

                    /**
                     * Creates a plain object from a WaitGlobalOperationRequest message. Also converts values to other types if specified.
                     * @param message WaitGlobalOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.WaitGlobalOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WaitGlobalOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WaitGlobalOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a WaitRegionOperationRequest. */
                interface IWaitRegionOperationRequest {

                    /** WaitRegionOperationRequest operation */
                    operation?: (string|null);

                    /** WaitRegionOperationRequest project */
                    project?: (string|null);

                    /** WaitRegionOperationRequest region */
                    region?: (string|null);
                }

                /** Represents a WaitRegionOperationRequest. */
                class WaitRegionOperationRequest implements IWaitRegionOperationRequest {

                    /**
                     * Constructs a new WaitRegionOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWaitRegionOperationRequest);

                    /** WaitRegionOperationRequest operation. */
                    public operation: string;

                    /** WaitRegionOperationRequest project. */
                    public project: string;

                    /** WaitRegionOperationRequest region. */
                    public region: string;

                    /**
                     * Creates a new WaitRegionOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WaitRegionOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWaitRegionOperationRequest): google.cloud.compute.v1.WaitRegionOperationRequest;

                    /**
                     * Encodes the specified WaitRegionOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.WaitRegionOperationRequest.verify|verify} messages.
                     * @param message WaitRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWaitRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WaitRegionOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.WaitRegionOperationRequest.verify|verify} messages.
                     * @param message WaitRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWaitRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WaitRegionOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WaitRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.WaitRegionOperationRequest;

                    /**
                     * Decodes a WaitRegionOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WaitRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.WaitRegionOperationRequest;

                    /**
                     * Verifies a WaitRegionOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WaitRegionOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WaitRegionOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.WaitRegionOperationRequest;

                    /**
                     * Creates a plain object from a WaitRegionOperationRequest message. Also converts values to other types if specified.
                     * @param message WaitRegionOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.WaitRegionOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WaitRegionOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WaitRegionOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a WaitZoneOperationRequest. */
                interface IWaitZoneOperationRequest {

                    /** WaitZoneOperationRequest operation */
                    operation?: (string|null);

                    /** WaitZoneOperationRequest project */
                    project?: (string|null);

                    /** WaitZoneOperationRequest zone */
                    zone?: (string|null);
                }

                /** Represents a WaitZoneOperationRequest. */
                class WaitZoneOperationRequest implements IWaitZoneOperationRequest {

                    /**
                     * Constructs a new WaitZoneOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWaitZoneOperationRequest);

                    /** WaitZoneOperationRequest operation. */
                    public operation: string;

                    /** WaitZoneOperationRequest project. */
                    public project: string;

                    /** WaitZoneOperationRequest zone. */
                    public zone: string;

                    /**
                     * Creates a new WaitZoneOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WaitZoneOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWaitZoneOperationRequest): google.cloud.compute.v1.WaitZoneOperationRequest;

                    /**
                     * Encodes the specified WaitZoneOperationRequest message. Does not implicitly {@link google.cloud.compute.v1.WaitZoneOperationRequest.verify|verify} messages.
                     * @param message WaitZoneOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWaitZoneOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WaitZoneOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.WaitZoneOperationRequest.verify|verify} messages.
                     * @param message WaitZoneOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWaitZoneOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WaitZoneOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WaitZoneOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.WaitZoneOperationRequest;

                    /**
                     * Decodes a WaitZoneOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WaitZoneOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.WaitZoneOperationRequest;

                    /**
                     * Verifies a WaitZoneOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WaitZoneOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WaitZoneOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.WaitZoneOperationRequest;

                    /**
                     * Creates a plain object from a WaitZoneOperationRequest message. Also converts values to other types if specified.
                     * @param message WaitZoneOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.WaitZoneOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WaitZoneOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WaitZoneOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Warning. */
                interface IWarning {

                    /** Warning code */
                    code?: (string|null);

                    /** Warning data */
                    data?: (google.cloud.compute.v1.IData[]|null);

                    /** Warning message */
                    message?: (string|null);
                }

                /** Represents a Warning. */
                class Warning implements IWarning {

                    /**
                     * Constructs a new Warning.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWarning);

                    /** Warning code. */
                    public code?: (string|null);

                    /** Warning data. */
                    public data: google.cloud.compute.v1.IData[];

                    /** Warning message. */
                    public message?: (string|null);

                    /** Warning _code. */
                    public _code?: "code";

                    /** Warning _message. */
                    public _message?: "message";

                    /**
                     * Creates a new Warning instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Warning instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWarning): google.cloud.compute.v1.Warning;

                    /**
                     * Encodes the specified Warning message. Does not implicitly {@link google.cloud.compute.v1.Warning.verify|verify} messages.
                     * @param message Warning message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWarning, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Warning message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Warning.verify|verify} messages.
                     * @param message Warning message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWarning, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Warning message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Warning
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Warning;

                    /**
                     * Decodes a Warning message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Warning
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Warning;

                    /**
                     * Verifies a Warning message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Warning message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Warning
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Warning;

                    /**
                     * Creates a plain object from a Warning message. Also converts values to other types if specified.
                     * @param message Warning
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Warning, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Warning to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Warning
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Warning {

                    /** Code enum. */
                    enum Code {
                        UNDEFINED_CODE = 0,
                        CLEANUP_FAILED = 150308440,
                        DEPRECATED_RESOURCE_USED = 391835586,
                        DEPRECATED_TYPE_USED = 346526230,
                        DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369442967,
                        EXPERIMENTAL_TYPE_USED = 451954443,
                        EXTERNAL_API_WARNING = 175546307,
                        FIELD_VALUE_OVERRIDEN = 329669423,
                        INJECTED_KERNELS_DEPRECATED = 417377419,
                        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401542606,
                        LARGE_DEPLOYMENT_WARNING = 481440678,
                        MISSING_TYPE_DEPENDENCY = 344505463,
                        NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324964999,
                        NEXT_HOP_CANNOT_IP_FORWARD = 383382887,
                        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146748434,
                        NEXT_HOP_INSTANCE_NOT_FOUND = 464250446,
                        NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243758146,
                        NEXT_HOP_NOT_RUNNING = 417081265,
                        NOT_CRITICAL_ERROR = 105763924,
                        NO_RESULTS_ON_PAGE = 30036744,
                        PARTIAL_SUCCESS = 39966469,
                        REQUIRED_TOS_AGREEMENT = 3745539,
                        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496728641,
                        RESOURCE_NOT_DELETED = 168598460,
                        SCHEMA_VALIDATION_IGNORED = 275245642,
                        SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268305617,
                        UNDECLARED_PROPERTIES = 390513439,
                        UNREACHABLE = 13328052
                    }
                }

                /** Properties of a Warnings. */
                interface IWarnings {

                    /** Warnings code */
                    code?: (string|null);

                    /** Warnings data */
                    data?: (google.cloud.compute.v1.IData[]|null);

                    /** Warnings message */
                    message?: (string|null);
                }

                /** Represents a Warnings. */
                class Warnings implements IWarnings {

                    /**
                     * Constructs a new Warnings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWarnings);

                    /** Warnings code. */
                    public code?: (string|null);

                    /** Warnings data. */
                    public data: google.cloud.compute.v1.IData[];

                    /** Warnings message. */
                    public message?: (string|null);

                    /** Warnings _code. */
                    public _code?: "code";

                    /** Warnings _message. */
                    public _message?: "message";

                    /**
                     * Creates a new Warnings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Warnings instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWarnings): google.cloud.compute.v1.Warnings;

                    /**
                     * Encodes the specified Warnings message. Does not implicitly {@link google.cloud.compute.v1.Warnings.verify|verify} messages.
                     * @param message Warnings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWarnings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Warnings message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Warnings.verify|verify} messages.
                     * @param message Warnings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWarnings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Warnings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Warnings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Warnings;

                    /**
                     * Decodes a Warnings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Warnings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Warnings;

                    /**
                     * Verifies a Warnings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Warnings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Warnings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Warnings;

                    /**
                     * Creates a plain object from a Warnings message. Also converts values to other types if specified.
                     * @param message Warnings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Warnings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Warnings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Warnings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Warnings {

                    /** Code enum. */
                    enum Code {
                        UNDEFINED_CODE = 0,
                        CLEANUP_FAILED = 150308440,
                        DEPRECATED_RESOURCE_USED = 391835586,
                        DEPRECATED_TYPE_USED = 346526230,
                        DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369442967,
                        EXPERIMENTAL_TYPE_USED = 451954443,
                        EXTERNAL_API_WARNING = 175546307,
                        FIELD_VALUE_OVERRIDEN = 329669423,
                        INJECTED_KERNELS_DEPRECATED = 417377419,
                        INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401542606,
                        LARGE_DEPLOYMENT_WARNING = 481440678,
                        MISSING_TYPE_DEPENDENCY = 344505463,
                        NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324964999,
                        NEXT_HOP_CANNOT_IP_FORWARD = 383382887,
                        NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146748434,
                        NEXT_HOP_INSTANCE_NOT_FOUND = 464250446,
                        NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243758146,
                        NEXT_HOP_NOT_RUNNING = 417081265,
                        NOT_CRITICAL_ERROR = 105763924,
                        NO_RESULTS_ON_PAGE = 30036744,
                        PARTIAL_SUCCESS = 39966469,
                        REQUIRED_TOS_AGREEMENT = 3745539,
                        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496728641,
                        RESOURCE_NOT_DELETED = 168598460,
                        SCHEMA_VALIDATION_IGNORED = 275245642,
                        SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268305617,
                        UNDECLARED_PROPERTIES = 390513439,
                        UNREACHABLE = 13328052
                    }
                }

                /** Properties of a WeightedBackendService. */
                interface IWeightedBackendService {

                    /** WeightedBackendService backendService */
                    backendService?: (string|null);

                    /** WeightedBackendService headerAction */
                    headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** WeightedBackendService weight */
                    weight?: (number|null);
                }

                /** Represents a WeightedBackendService. */
                class WeightedBackendService implements IWeightedBackendService {

                    /**
                     * Constructs a new WeightedBackendService.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IWeightedBackendService);

                    /** WeightedBackendService backendService. */
                    public backendService?: (string|null);

                    /** WeightedBackendService headerAction. */
                    public headerAction?: (google.cloud.compute.v1.IHttpHeaderAction|null);

                    /** WeightedBackendService weight. */
                    public weight?: (number|null);

                    /** WeightedBackendService _backendService. */
                    public _backendService?: "backendService";

                    /** WeightedBackendService _headerAction. */
                    public _headerAction?: "headerAction";

                    /** WeightedBackendService _weight. */
                    public _weight?: "weight";

                    /**
                     * Creates a new WeightedBackendService instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WeightedBackendService instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IWeightedBackendService): google.cloud.compute.v1.WeightedBackendService;

                    /**
                     * Encodes the specified WeightedBackendService message. Does not implicitly {@link google.cloud.compute.v1.WeightedBackendService.verify|verify} messages.
                     * @param message WeightedBackendService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IWeightedBackendService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WeightedBackendService message, length delimited. Does not implicitly {@link google.cloud.compute.v1.WeightedBackendService.verify|verify} messages.
                     * @param message WeightedBackendService message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IWeightedBackendService, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WeightedBackendService message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WeightedBackendService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.WeightedBackendService;

                    /**
                     * Decodes a WeightedBackendService message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WeightedBackendService
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.WeightedBackendService;

                    /**
                     * Verifies a WeightedBackendService message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WeightedBackendService message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WeightedBackendService
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.WeightedBackendService;

                    /**
                     * Creates a plain object from a WeightedBackendService message. Also converts values to other types if specified.
                     * @param message WeightedBackendService
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.WeightedBackendService, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WeightedBackendService to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WeightedBackendService
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a XpnHostList. */
                interface IXpnHostList {

                    /** XpnHostList id */
                    id?: (string|null);

                    /** XpnHostList items */
                    items?: (google.cloud.compute.v1.IProject[]|null);

                    /** XpnHostList kind */
                    kind?: (string|null);

                    /** XpnHostList nextPageToken */
                    nextPageToken?: (string|null);

                    /** XpnHostList selfLink */
                    selfLink?: (string|null);

                    /** XpnHostList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a XpnHostList. */
                class XpnHostList implements IXpnHostList {

                    /**
                     * Constructs a new XpnHostList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IXpnHostList);

                    /** XpnHostList id. */
                    public id?: (string|null);

                    /** XpnHostList items. */
                    public items: google.cloud.compute.v1.IProject[];

                    /** XpnHostList kind. */
                    public kind?: (string|null);

                    /** XpnHostList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** XpnHostList selfLink. */
                    public selfLink?: (string|null);

                    /** XpnHostList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** XpnHostList _id. */
                    public _id?: "id";

                    /** XpnHostList _kind. */
                    public _kind?: "kind";

                    /** XpnHostList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** XpnHostList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** XpnHostList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new XpnHostList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns XpnHostList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IXpnHostList): google.cloud.compute.v1.XpnHostList;

                    /**
                     * Encodes the specified XpnHostList message. Does not implicitly {@link google.cloud.compute.v1.XpnHostList.verify|verify} messages.
                     * @param message XpnHostList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IXpnHostList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified XpnHostList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.XpnHostList.verify|verify} messages.
                     * @param message XpnHostList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IXpnHostList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a XpnHostList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns XpnHostList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.XpnHostList;

                    /**
                     * Decodes a XpnHostList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns XpnHostList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.XpnHostList;

                    /**
                     * Verifies a XpnHostList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a XpnHostList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns XpnHostList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.XpnHostList;

                    /**
                     * Creates a plain object from a XpnHostList message. Also converts values to other types if specified.
                     * @param message XpnHostList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.XpnHostList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this XpnHostList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for XpnHostList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a XpnResourceId. */
                interface IXpnResourceId {

                    /** XpnResourceId id */
                    id?: (string|null);

                    /** XpnResourceId type */
                    type?: (string|null);
                }

                /** Represents a XpnResourceId. */
                class XpnResourceId implements IXpnResourceId {

                    /**
                     * Constructs a new XpnResourceId.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IXpnResourceId);

                    /** XpnResourceId id. */
                    public id?: (string|null);

                    /** XpnResourceId type. */
                    public type?: (string|null);

                    /** XpnResourceId _id. */
                    public _id?: "id";

                    /** XpnResourceId _type. */
                    public _type?: "type";

                    /**
                     * Creates a new XpnResourceId instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns XpnResourceId instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IXpnResourceId): google.cloud.compute.v1.XpnResourceId;

                    /**
                     * Encodes the specified XpnResourceId message. Does not implicitly {@link google.cloud.compute.v1.XpnResourceId.verify|verify} messages.
                     * @param message XpnResourceId message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IXpnResourceId, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified XpnResourceId message, length delimited. Does not implicitly {@link google.cloud.compute.v1.XpnResourceId.verify|verify} messages.
                     * @param message XpnResourceId message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IXpnResourceId, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a XpnResourceId message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns XpnResourceId
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.XpnResourceId;

                    /**
                     * Decodes a XpnResourceId message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns XpnResourceId
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.XpnResourceId;

                    /**
                     * Verifies a XpnResourceId message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a XpnResourceId message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns XpnResourceId
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.XpnResourceId;

                    /**
                     * Creates a plain object from a XpnResourceId message. Also converts values to other types if specified.
                     * @param message XpnResourceId
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.XpnResourceId, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this XpnResourceId to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for XpnResourceId
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace XpnResourceId {

                    /** Type enum. */
                    enum Type {
                        UNDEFINED_TYPE = 0,
                        PROJECT = 408671993,
                        XPN_RESOURCE_TYPE_UNSPECIFIED = 151607034
                    }
                }

                /** Properties of a Zone. */
                interface IZone {

                    /** Zone availableCpuPlatforms */
                    availableCpuPlatforms?: (string[]|null);

                    /** Zone creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Zone deprecated */
                    deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** Zone description */
                    description?: (string|null);

                    /** Zone id */
                    id?: (number|Long|string|null);

                    /** Zone kind */
                    kind?: (string|null);

                    /** Zone name */
                    name?: (string|null);

                    /** Zone region */
                    region?: (string|null);

                    /** Zone selfLink */
                    selfLink?: (string|null);

                    /** Zone status */
                    status?: (string|null);

                    /** Zone supportsPzs */
                    supportsPzs?: (boolean|null);
                }

                /** Represents a Zone. */
                class Zone implements IZone {

                    /**
                     * Constructs a new Zone.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IZone);

                    /** Zone availableCpuPlatforms. */
                    public availableCpuPlatforms: string[];

                    /** Zone creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Zone deprecated. */
                    public deprecated?: (google.cloud.compute.v1.IDeprecationStatus|null);

                    /** Zone description. */
                    public description?: (string|null);

                    /** Zone id. */
                    public id?: (number|Long|string|null);

                    /** Zone kind. */
                    public kind?: (string|null);

                    /** Zone name. */
                    public name?: (string|null);

                    /** Zone region. */
                    public region?: (string|null);

                    /** Zone selfLink. */
                    public selfLink?: (string|null);

                    /** Zone status. */
                    public status?: (string|null);

                    /** Zone supportsPzs. */
                    public supportsPzs?: (boolean|null);

                    /** Zone _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Zone _deprecated. */
                    public _deprecated?: "deprecated";

                    /** Zone _description. */
                    public _description?: "description";

                    /** Zone _id. */
                    public _id?: "id";

                    /** Zone _kind. */
                    public _kind?: "kind";

                    /** Zone _name. */
                    public _name?: "name";

                    /** Zone _region. */
                    public _region?: "region";

                    /** Zone _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Zone _status. */
                    public _status?: "status";

                    /** Zone _supportsPzs. */
                    public _supportsPzs?: "supportsPzs";

                    /**
                     * Creates a new Zone instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Zone instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IZone): google.cloud.compute.v1.Zone;

                    /**
                     * Encodes the specified Zone message. Does not implicitly {@link google.cloud.compute.v1.Zone.verify|verify} messages.
                     * @param message Zone message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IZone, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Zone message, length delimited. Does not implicitly {@link google.cloud.compute.v1.Zone.verify|verify} messages.
                     * @param message Zone message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IZone, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Zone message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Zone
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.Zone;

                    /**
                     * Decodes a Zone message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Zone
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.Zone;

                    /**
                     * Verifies a Zone message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Zone message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Zone
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.Zone;

                    /**
                     * Creates a plain object from a Zone message. Also converts values to other types if specified.
                     * @param message Zone
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.Zone, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Zone to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Zone
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Zone {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DOWN = 2104482,
                        UP = 2715
                    }
                }

                /** Properties of a ZoneList. */
                interface IZoneList {

                    /** ZoneList id */
                    id?: (string|null);

                    /** ZoneList items */
                    items?: (google.cloud.compute.v1.IZone[]|null);

                    /** ZoneList kind */
                    kind?: (string|null);

                    /** ZoneList nextPageToken */
                    nextPageToken?: (string|null);

                    /** ZoneList selfLink */
                    selfLink?: (string|null);

                    /** ZoneList warning */
                    warning?: (google.cloud.compute.v1.IWarning|null);
                }

                /** Represents a ZoneList. */
                class ZoneList implements IZoneList {

                    /**
                     * Constructs a new ZoneList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IZoneList);

                    /** ZoneList id. */
                    public id?: (string|null);

                    /** ZoneList items. */
                    public items: google.cloud.compute.v1.IZone[];

                    /** ZoneList kind. */
                    public kind?: (string|null);

                    /** ZoneList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** ZoneList selfLink. */
                    public selfLink?: (string|null);

                    /** ZoneList warning. */
                    public warning?: (google.cloud.compute.v1.IWarning|null);

                    /** ZoneList _id. */
                    public _id?: "id";

                    /** ZoneList _kind. */
                    public _kind?: "kind";

                    /** ZoneList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** ZoneList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** ZoneList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new ZoneList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ZoneList instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IZoneList): google.cloud.compute.v1.ZoneList;

                    /**
                     * Encodes the specified ZoneList message. Does not implicitly {@link google.cloud.compute.v1.ZoneList.verify|verify} messages.
                     * @param message ZoneList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IZoneList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ZoneList message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ZoneList.verify|verify} messages.
                     * @param message ZoneList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IZoneList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ZoneList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ZoneList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ZoneList;

                    /**
                     * Decodes a ZoneList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ZoneList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ZoneList;

                    /**
                     * Verifies a ZoneList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ZoneList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ZoneList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ZoneList;

                    /**
                     * Creates a plain object from a ZoneList message. Also converts values to other types if specified.
                     * @param message ZoneList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ZoneList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ZoneList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ZoneList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ZoneSetLabelsRequest. */
                interface IZoneSetLabelsRequest {

                    /** ZoneSetLabelsRequest labelFingerprint */
                    labelFingerprint?: (string|null);

                    /** ZoneSetLabelsRequest labels */
                    labels?: ({ [k: string]: string }|null);
                }

                /** Represents a ZoneSetLabelsRequest. */
                class ZoneSetLabelsRequest implements IZoneSetLabelsRequest {

                    /**
                     * Constructs a new ZoneSetLabelsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IZoneSetLabelsRequest);

                    /** ZoneSetLabelsRequest labelFingerprint. */
                    public labelFingerprint?: (string|null);

                    /** ZoneSetLabelsRequest labels. */
                    public labels: { [k: string]: string };

                    /** ZoneSetLabelsRequest _labelFingerprint. */
                    public _labelFingerprint?: "labelFingerprint";

                    /**
                     * Creates a new ZoneSetLabelsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ZoneSetLabelsRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IZoneSetLabelsRequest): google.cloud.compute.v1.ZoneSetLabelsRequest;

                    /**
                     * Encodes the specified ZoneSetLabelsRequest message. Does not implicitly {@link google.cloud.compute.v1.ZoneSetLabelsRequest.verify|verify} messages.
                     * @param message ZoneSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IZoneSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ZoneSetLabelsRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ZoneSetLabelsRequest.verify|verify} messages.
                     * @param message ZoneSetLabelsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IZoneSetLabelsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ZoneSetLabelsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ZoneSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ZoneSetLabelsRequest;

                    /**
                     * Decodes a ZoneSetLabelsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ZoneSetLabelsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ZoneSetLabelsRequest;

                    /**
                     * Verifies a ZoneSetLabelsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ZoneSetLabelsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ZoneSetLabelsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ZoneSetLabelsRequest;

                    /**
                     * Creates a plain object from a ZoneSetLabelsRequest message. Also converts values to other types if specified.
                     * @param message ZoneSetLabelsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ZoneSetLabelsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ZoneSetLabelsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ZoneSetLabelsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ZoneSetPolicyRequest. */
                interface IZoneSetPolicyRequest {

                    /** ZoneSetPolicyRequest bindings */
                    bindings?: (google.cloud.compute.v1.IBinding[]|null);

                    /** ZoneSetPolicyRequest etag */
                    etag?: (string|null);

                    /** ZoneSetPolicyRequest policy */
                    policy?: (google.cloud.compute.v1.IPolicy|null);
                }

                /** Represents a ZoneSetPolicyRequest. */
                class ZoneSetPolicyRequest implements IZoneSetPolicyRequest {

                    /**
                     * Constructs a new ZoneSetPolicyRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1.IZoneSetPolicyRequest);

                    /** ZoneSetPolicyRequest bindings. */
                    public bindings: google.cloud.compute.v1.IBinding[];

                    /** ZoneSetPolicyRequest etag. */
                    public etag?: (string|null);

                    /** ZoneSetPolicyRequest policy. */
                    public policy?: (google.cloud.compute.v1.IPolicy|null);

                    /** ZoneSetPolicyRequest _etag. */
                    public _etag?: "etag";

                    /** ZoneSetPolicyRequest _policy. */
                    public _policy?: "policy";

                    /**
                     * Creates a new ZoneSetPolicyRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ZoneSetPolicyRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1.IZoneSetPolicyRequest): google.cloud.compute.v1.ZoneSetPolicyRequest;

                    /**
                     * Encodes the specified ZoneSetPolicyRequest message. Does not implicitly {@link google.cloud.compute.v1.ZoneSetPolicyRequest.verify|verify} messages.
                     * @param message ZoneSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1.IZoneSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ZoneSetPolicyRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1.ZoneSetPolicyRequest.verify|verify} messages.
                     * @param message ZoneSetPolicyRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1.IZoneSetPolicyRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ZoneSetPolicyRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ZoneSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1.ZoneSetPolicyRequest;

                    /**
                     * Decodes a ZoneSetPolicyRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ZoneSetPolicyRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1.ZoneSetPolicyRequest;

                    /**
                     * Verifies a ZoneSetPolicyRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ZoneSetPolicyRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ZoneSetPolicyRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1.ZoneSetPolicyRequest;

                    /**
                     * Creates a plain object from a ZoneSetPolicyRequest message. Also converts values to other types if specified.
                     * @param message ZoneSetPolicyRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1.ZoneSetPolicyRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ZoneSetPolicyRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ZoneSetPolicyRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Represents an AcceleratorTypes */
                class AcceleratorTypes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new AcceleratorTypes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new AcceleratorTypes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): AcceleratorTypes;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAcceleratorTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AcceleratorTypeAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListAcceleratorTypesRequest, callback: google.cloud.compute.v1.AcceleratorTypes.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAcceleratorTypesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListAcceleratorTypesRequest): Promise<google.cloud.compute.v1.AcceleratorTypeAggregatedList>;

                    /**
                     * Calls Get.
                     * @param request GetAcceleratorTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AcceleratorType
                     */
                    public get(request: google.cloud.compute.v1.IGetAcceleratorTypeRequest, callback: google.cloud.compute.v1.AcceleratorTypes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetAcceleratorTypeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetAcceleratorTypeRequest): Promise<google.cloud.compute.v1.AcceleratorType>;

                    /**
                     * Calls List.
                     * @param request ListAcceleratorTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AcceleratorTypeList
                     */
                    public list(request: google.cloud.compute.v1.IListAcceleratorTypesRequest, callback: google.cloud.compute.v1.AcceleratorTypes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListAcceleratorTypesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListAcceleratorTypesRequest): Promise<google.cloud.compute.v1.AcceleratorTypeList>;
                }

                namespace AcceleratorTypes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.AcceleratorTypes|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] AcceleratorTypeAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AcceleratorTypeAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.AcceleratorTypes|get}.
                     * @param error Error, if any
                     * @param [response] AcceleratorType
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.AcceleratorType) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.AcceleratorTypes|list}.
                     * @param error Error, if any
                     * @param [response] AcceleratorTypeList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AcceleratorTypeList) => void;
                }

                /** Represents an Addresses */
                class Addresses extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Addresses service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Addresses service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Addresses;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAddressesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AddressAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListAddressesRequest, callback: google.cloud.compute.v1.Addresses.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAddressesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListAddressesRequest): Promise<google.cloud.compute.v1.AddressAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteAddressRequest, callback: google.cloud.compute.v1.Addresses.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteAddressRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteAddressRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Address
                     */
                    public get(request: google.cloud.compute.v1.IGetAddressRequest, callback: google.cloud.compute.v1.Addresses.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetAddressRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetAddressRequest): Promise<google.cloud.compute.v1.Address>;

                    /**
                     * Calls Insert.
                     * @param request InsertAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertAddressRequest, callback: google.cloud.compute.v1.Addresses.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertAddressRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertAddressRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListAddressesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AddressList
                     */
                    public list(request: google.cloud.compute.v1.IListAddressesRequest, callback: google.cloud.compute.v1.Addresses.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListAddressesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListAddressesRequest): Promise<google.cloud.compute.v1.AddressList>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsAddressRequest, callback: google.cloud.compute.v1.Addresses.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsAddressRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsAddressRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Addresses {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Addresses|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] AddressAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AddressAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Addresses|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Addresses|get}.
                     * @param error Error, if any
                     * @param [response] Address
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Address) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Addresses|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Addresses|list}.
                     * @param error Error, if any
                     * @param [response] AddressList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AddressList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Addresses|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an Autoscalers */
                class Autoscalers extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Autoscalers service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Autoscalers service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Autoscalers;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAutoscalersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AutoscalerAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListAutoscalersRequest, callback: google.cloud.compute.v1.Autoscalers.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAutoscalersRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListAutoscalersRequest): Promise<google.cloud.compute.v1.AutoscalerAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteAutoscalerRequest, callback: google.cloud.compute.v1.Autoscalers.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Autoscaler
                     */
                    public get(request: google.cloud.compute.v1.IGetAutoscalerRequest, callback: google.cloud.compute.v1.Autoscalers.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetAutoscalerRequest): Promise<google.cloud.compute.v1.Autoscaler>;

                    /**
                     * Calls Insert.
                     * @param request InsertAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertAutoscalerRequest, callback: google.cloud.compute.v1.Autoscalers.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListAutoscalersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AutoscalerList
                     */
                    public list(request: google.cloud.compute.v1.IListAutoscalersRequest, callback: google.cloud.compute.v1.Autoscalers.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListAutoscalersRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListAutoscalersRequest): Promise<google.cloud.compute.v1.AutoscalerList>;

                    /**
                     * Calls Patch.
                     * @param request PatchAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchAutoscalerRequest, callback: google.cloud.compute.v1.Autoscalers.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateAutoscalerRequest, callback: google.cloud.compute.v1.Autoscalers.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Autoscalers {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] AutoscalerAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AutoscalerAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|get}.
                     * @param error Error, if any
                     * @param [response] Autoscaler
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Autoscaler) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|list}.
                     * @param error Error, if any
                     * @param [response] AutoscalerList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AutoscalerList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Autoscalers|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a BackendBuckets */
                class BackendBuckets extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new BackendBuckets service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new BackendBuckets service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): BackendBuckets;

                    /**
                     * Calls AddSignedUrlKey.
                     * @param request AddSignedUrlKeyBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addSignedUrlKey(request: google.cloud.compute.v1.IAddSignedUrlKeyBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.AddSignedUrlKeyCallback): void;

                    /**
                     * Calls AddSignedUrlKey.
                     * @param request AddSignedUrlKeyBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public addSignedUrlKey(request: google.cloud.compute.v1.IAddSignedUrlKeyBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeleteSignedUrlKey.
                     * @param request DeleteSignedUrlKeyBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteSignedUrlKey(request: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.DeleteSignedUrlKeyCallback): void;

                    /**
                     * Calls DeleteSignedUrlKey.
                     * @param request DeleteSignedUrlKeyBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public deleteSignedUrlKey(request: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendBucket
                     */
                    public get(request: google.cloud.compute.v1.IGetBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetBackendBucketRequest): Promise<google.cloud.compute.v1.BackendBucket>;

                    /**
                     * Calls Insert.
                     * @param request InsertBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListBackendBucketsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendBucketList
                     */
                    public list(request: google.cloud.compute.v1.IListBackendBucketsRequest, callback: google.cloud.compute.v1.BackendBuckets.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListBackendBucketsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListBackendBucketsRequest): Promise<google.cloud.compute.v1.BackendBucketList>;

                    /**
                     * Calls Patch.
                     * @param request PatchBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetEdgeSecurityPolicy.
                     * @param request SetEdgeSecurityPolicyBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setEdgeSecurityPolicy(request: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.SetEdgeSecurityPolicyCallback): void;

                    /**
                     * Calls SetEdgeSecurityPolicy.
                     * @param request SetEdgeSecurityPolicyBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public setEdgeSecurityPolicy(request: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateBackendBucketRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateBackendBucketRequest, callback: google.cloud.compute.v1.BackendBuckets.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateBackendBucketRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateBackendBucketRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace BackendBuckets {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|addSignedUrlKey}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddSignedUrlKeyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|deleteSignedUrlKey}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteSignedUrlKeyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|get}.
                     * @param error Error, if any
                     * @param [response] BackendBucket
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendBucket) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|list}.
                     * @param error Error, if any
                     * @param [response] BackendBucketList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendBucketList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|setEdgeSecurityPolicy}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetEdgeSecurityPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendBuckets|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a BackendServices */
                class BackendServices extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new BackendServices service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new BackendServices service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): BackendServices;

                    /**
                     * Calls AddSignedUrlKey.
                     * @param request AddSignedUrlKeyBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addSignedUrlKey(request: google.cloud.compute.v1.IAddSignedUrlKeyBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.AddSignedUrlKeyCallback): void;

                    /**
                     * Calls AddSignedUrlKey.
                     * @param request AddSignedUrlKeyBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public addSignedUrlKey(request: google.cloud.compute.v1.IAddSignedUrlKeyBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListBackendServicesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendServiceAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListBackendServicesRequest, callback: google.cloud.compute.v1.BackendServices.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListBackendServicesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListBackendServicesRequest): Promise<google.cloud.compute.v1.BackendServiceAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeleteSignedUrlKey.
                     * @param request DeleteSignedUrlKeyBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteSignedUrlKey(request: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.DeleteSignedUrlKeyCallback): void;

                    /**
                     * Calls DeleteSignedUrlKey.
                     * @param request DeleteSignedUrlKeyBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public deleteSignedUrlKey(request: google.cloud.compute.v1.IDeleteSignedUrlKeyBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendService
                     */
                    public get(request: google.cloud.compute.v1.IGetBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetBackendServiceRequest): Promise<google.cloud.compute.v1.BackendService>;

                    /**
                     * Calls GetHealth.
                     * @param request GetHealthBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendServiceGroupHealth
                     */
                    public getHealth(request: google.cloud.compute.v1.IGetHealthBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.GetHealthCallback): void;

                    /**
                     * Calls GetHealth.
                     * @param request GetHealthBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public getHealth(request: google.cloud.compute.v1.IGetHealthBackendServiceRequest): Promise<google.cloud.compute.v1.BackendServiceGroupHealth>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyBackendServiceRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListBackendServicesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendServiceList
                     */
                    public list(request: google.cloud.compute.v1.IListBackendServicesRequest, callback: google.cloud.compute.v1.BackendServices.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListBackendServicesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListBackendServicesRequest): Promise<google.cloud.compute.v1.BackendServiceList>;

                    /**
                     * Calls Patch.
                     * @param request PatchBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetEdgeSecurityPolicy.
                     * @param request SetEdgeSecurityPolicyBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setEdgeSecurityPolicy(request: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.SetEdgeSecurityPolicyCallback): void;

                    /**
                     * Calls SetEdgeSecurityPolicy.
                     * @param request SetEdgeSecurityPolicyBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public setEdgeSecurityPolicy(request: google.cloud.compute.v1.ISetEdgeSecurityPolicyBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyBackendServiceRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetSecurityPolicy.
                     * @param request SetSecurityPolicyBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setSecurityPolicy(request: google.cloud.compute.v1.ISetSecurityPolicyBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.SetSecurityPolicyCallback): void;

                    /**
                     * Calls SetSecurityPolicy.
                     * @param request SetSecurityPolicyBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public setSecurityPolicy(request: google.cloud.compute.v1.ISetSecurityPolicyBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateBackendServiceRequest, callback: google.cloud.compute.v1.BackendServices.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace BackendServices {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|addSignedUrlKey}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddSignedUrlKeyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] BackendServiceAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendServiceAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|deleteSignedUrlKey}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteSignedUrlKeyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|get}.
                     * @param error Error, if any
                     * @param [response] BackendService
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendService) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|getHealth}.
                     * @param error Error, if any
                     * @param [response] BackendServiceGroupHealth
                     */
                    type GetHealthCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendServiceGroupHealth) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|list}.
                     * @param error Error, if any
                     * @param [response] BackendServiceList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendServiceList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|setEdgeSecurityPolicy}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetEdgeSecurityPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|setSecurityPolicy}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSecurityPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.BackendServices|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a DiskTypes */
                class DiskTypes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new DiskTypes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new DiskTypes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): DiskTypes;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListDiskTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskTypeAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListDiskTypesRequest, callback: google.cloud.compute.v1.DiskTypes.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListDiskTypesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListDiskTypesRequest): Promise<google.cloud.compute.v1.DiskTypeAggregatedList>;

                    /**
                     * Calls Get.
                     * @param request GetDiskTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskType
                     */
                    public get(request: google.cloud.compute.v1.IGetDiskTypeRequest, callback: google.cloud.compute.v1.DiskTypes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetDiskTypeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetDiskTypeRequest): Promise<google.cloud.compute.v1.DiskType>;

                    /**
                     * Calls List.
                     * @param request ListDiskTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskTypeList
                     */
                    public list(request: google.cloud.compute.v1.IListDiskTypesRequest, callback: google.cloud.compute.v1.DiskTypes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListDiskTypesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListDiskTypesRequest): Promise<google.cloud.compute.v1.DiskTypeList>;
                }

                namespace DiskTypes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.DiskTypes|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] DiskTypeAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskTypeAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.DiskTypes|get}.
                     * @param error Error, if any
                     * @param [response] DiskType
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskType) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.DiskTypes|list}.
                     * @param error Error, if any
                     * @param [response] DiskTypeList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskTypeList) => void;
                }

                /** Represents a Disks */
                class Disks extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Disks service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Disks service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Disks;

                    /**
                     * Calls AddResourcePolicies.
                     * @param request AddResourcePoliciesDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addResourcePolicies(request: google.cloud.compute.v1.IAddResourcePoliciesDiskRequest, callback: google.cloud.compute.v1.Disks.AddResourcePoliciesCallback): void;

                    /**
                     * Calls AddResourcePolicies.
                     * @param request AddResourcePoliciesDiskRequest message or plain object
                     * @returns Promise
                     */
                    public addResourcePolicies(request: google.cloud.compute.v1.IAddResourcePoliciesDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListDisksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListDisksRequest, callback: google.cloud.compute.v1.Disks.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListDisksRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListDisksRequest): Promise<google.cloud.compute.v1.DiskAggregatedList>;

                    /**
                     * Calls CreateSnapshot.
                     * @param request CreateSnapshotDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public createSnapshot(request: google.cloud.compute.v1.ICreateSnapshotDiskRequest, callback: google.cloud.compute.v1.Disks.CreateSnapshotCallback): void;

                    /**
                     * Calls CreateSnapshot.
                     * @param request CreateSnapshotDiskRequest message or plain object
                     * @returns Promise
                     */
                    public createSnapshot(request: google.cloud.compute.v1.ICreateSnapshotDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteDiskRequest, callback: google.cloud.compute.v1.Disks.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteDiskRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Disk
                     */
                    public get(request: google.cloud.compute.v1.IGetDiskRequest, callback: google.cloud.compute.v1.Disks.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetDiskRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetDiskRequest): Promise<google.cloud.compute.v1.Disk>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyDiskRequest, callback: google.cloud.compute.v1.Disks.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyDiskRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyDiskRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertDiskRequest, callback: google.cloud.compute.v1.Disks.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertDiskRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListDisksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskList
                     */
                    public list(request: google.cloud.compute.v1.IListDisksRequest, callback: google.cloud.compute.v1.Disks.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListDisksRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListDisksRequest): Promise<google.cloud.compute.v1.DiskList>;

                    /**
                     * Calls RemoveResourcePolicies.
                     * @param request RemoveResourcePoliciesDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeResourcePolicies(request: google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest, callback: google.cloud.compute.v1.Disks.RemoveResourcePoliciesCallback): void;

                    /**
                     * Calls RemoveResourcePolicies.
                     * @param request RemoveResourcePoliciesDiskRequest message or plain object
                     * @returns Promise
                     */
                    public removeResourcePolicies(request: google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Resize.
                     * @param request ResizeDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public resize(request: google.cloud.compute.v1.IResizeDiskRequest, callback: google.cloud.compute.v1.Disks.ResizeCallback): void;

                    /**
                     * Calls Resize.
                     * @param request ResizeDiskRequest message or plain object
                     * @returns Promise
                     */
                    public resize(request: google.cloud.compute.v1.IResizeDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyDiskRequest, callback: google.cloud.compute.v1.Disks.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyDiskRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyDiskRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsDiskRequest, callback: google.cloud.compute.v1.Disks.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsDiskRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsDiskRequest, callback: google.cloud.compute.v1.Disks.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsDiskRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsDiskRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace Disks {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|addResourcePolicies}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddResourcePoliciesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] DiskAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|createSnapshot}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CreateSnapshotCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|get}.
                     * @param error Error, if any
                     * @param [response] Disk
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Disk) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|list}.
                     * @param error Error, if any
                     * @param [response] DiskList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|removeResourcePolicies}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveResourcePoliciesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|resize}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResizeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Disks|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents an ExternalVpnGateways */
                class ExternalVpnGateways extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new ExternalVpnGateways service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new ExternalVpnGateways service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): ExternalVpnGateways;

                    /**
                     * Calls Delete.
                     * @param request DeleteExternalVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteExternalVpnGatewayRequest, callback: google.cloud.compute.v1.ExternalVpnGateways.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteExternalVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteExternalVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetExternalVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ExternalVpnGateway
                     */
                    public get(request: google.cloud.compute.v1.IGetExternalVpnGatewayRequest, callback: google.cloud.compute.v1.ExternalVpnGateways.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetExternalVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetExternalVpnGatewayRequest): Promise<google.cloud.compute.v1.ExternalVpnGateway>;

                    /**
                     * Calls Insert.
                     * @param request InsertExternalVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertExternalVpnGatewayRequest, callback: google.cloud.compute.v1.ExternalVpnGateways.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertExternalVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertExternalVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListExternalVpnGatewaysRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ExternalVpnGatewayList
                     */
                    public list(request: google.cloud.compute.v1.IListExternalVpnGatewaysRequest, callback: google.cloud.compute.v1.ExternalVpnGateways.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListExternalVpnGatewaysRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListExternalVpnGatewaysRequest): Promise<google.cloud.compute.v1.ExternalVpnGatewayList>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsExternalVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsExternalVpnGatewayRequest, callback: google.cloud.compute.v1.ExternalVpnGateways.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsExternalVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsExternalVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsExternalVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsExternalVpnGatewayRequest, callback: google.cloud.compute.v1.ExternalVpnGateways.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsExternalVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsExternalVpnGatewayRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace ExternalVpnGateways {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ExternalVpnGateways|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ExternalVpnGateways|get}.
                     * @param error Error, if any
                     * @param [response] ExternalVpnGateway
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.ExternalVpnGateway) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ExternalVpnGateways|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ExternalVpnGateways|list}.
                     * @param error Error, if any
                     * @param [response] ExternalVpnGatewayList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ExternalVpnGatewayList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ExternalVpnGateways|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ExternalVpnGateways|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a FirewallPolicies */
                class FirewallPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new FirewallPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new FirewallPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): FirewallPolicies;

                    /**
                     * Calls AddAssociation.
                     * @param request AddAssociationFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addAssociation(request: google.cloud.compute.v1.IAddAssociationFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.AddAssociationCallback): void;

                    /**
                     * Calls AddAssociation.
                     * @param request AddAssociationFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addAssociation(request: google.cloud.compute.v1.IAddAssociationFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.AddRuleCallback): void;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls CloneRules.
                     * @param request CloneRulesFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public cloneRules(request: google.cloud.compute.v1.ICloneRulesFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.CloneRulesCallback): void;

                    /**
                     * Calls CloneRules.
                     * @param request CloneRulesFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public cloneRules(request: google.cloud.compute.v1.ICloneRulesFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicy>;

                    /**
                     * Calls GetAssociation.
                     * @param request GetAssociationFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyAssociation
                     */
                    public getAssociation(request: google.cloud.compute.v1.IGetAssociationFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.GetAssociationCallback): void;

                    /**
                     * Calls GetAssociation.
                     * @param request GetAssociationFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getAssociation(request: google.cloud.compute.v1.IGetAssociationFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicyAssociation>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyFirewallPolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyRule
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.GetRuleCallback): void;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicyRule>;

                    /**
                     * Calls Insert.
                     * @param request InsertFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListFirewallPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyList
                     */
                    public list(request: google.cloud.compute.v1.IListFirewallPoliciesRequest, callback: google.cloud.compute.v1.FirewallPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListFirewallPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListFirewallPoliciesRequest): Promise<google.cloud.compute.v1.FirewallPolicyList>;

                    /**
                     * Calls ListAssociations.
                     * @param request ListAssociationsFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPoliciesListAssociationsResponse
                     */
                    public listAssociations(request: google.cloud.compute.v1.IListAssociationsFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.ListAssociationsCallback): void;

                    /**
                     * Calls ListAssociations.
                     * @param request ListAssociationsFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public listAssociations(request: google.cloud.compute.v1.IListAssociationsFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse>;

                    /**
                     * Calls Move.
                     * @param request MoveFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public move(request: google.cloud.compute.v1.IMoveFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.MoveCallback): void;

                    /**
                     * Calls Move.
                     * @param request MoveFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public move(request: google.cloud.compute.v1.IMoveFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Patch.
                     * @param request PatchFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.PatchRuleCallback): void;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveAssociation.
                     * @param request RemoveAssociationFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeAssociation(request: google.cloud.compute.v1.IRemoveAssociationFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.RemoveAssociationCallback): void;

                    /**
                     * Calls RemoveAssociation.
                     * @param request RemoveAssociationFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeAssociation(request: google.cloud.compute.v1.IRemoveAssociationFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.RemoveRuleCallback): void;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyFirewallPolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsFirewallPolicyRequest, callback: google.cloud.compute.v1.FirewallPolicies.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsFirewallPolicyRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace FirewallPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|addAssociation}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|addRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|cloneRules}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CloneRulesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|get}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|getAssociation}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyAssociation
                     */
                    type GetAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyAssociation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|getRule}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyRule
                     */
                    type GetRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyRule) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|list}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|listAssociations}.
                     * @param error Error, if any
                     * @param [response] FirewallPoliciesListAssociationsResponse
                     */
                    type ListAssociationsCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPoliciesListAssociationsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|move}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type MoveCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|patchRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|removeAssociation}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|removeRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.FirewallPolicies|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a Firewalls */
                class Firewalls extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Firewalls service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Firewalls service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Firewalls;

                    /**
                     * Calls Delete.
                     * @param request DeleteFirewallRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteFirewallRequest, callback: google.cloud.compute.v1.Firewalls.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteFirewallRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteFirewallRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetFirewallRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Firewall
                     */
                    public get(request: google.cloud.compute.v1.IGetFirewallRequest, callback: google.cloud.compute.v1.Firewalls.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetFirewallRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetFirewallRequest): Promise<google.cloud.compute.v1.Firewall>;

                    /**
                     * Calls Insert.
                     * @param request InsertFirewallRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertFirewallRequest, callback: google.cloud.compute.v1.Firewalls.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertFirewallRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertFirewallRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListFirewallsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallList
                     */
                    public list(request: google.cloud.compute.v1.IListFirewallsRequest, callback: google.cloud.compute.v1.Firewalls.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListFirewallsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListFirewallsRequest): Promise<google.cloud.compute.v1.FirewallList>;

                    /**
                     * Calls Patch.
                     * @param request PatchFirewallRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchFirewallRequest, callback: google.cloud.compute.v1.Firewalls.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchFirewallRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchFirewallRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateFirewallRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateFirewallRequest, callback: google.cloud.compute.v1.Firewalls.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateFirewallRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateFirewallRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Firewalls {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Firewalls|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Firewalls|get}.
                     * @param error Error, if any
                     * @param [response] Firewall
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Firewall) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Firewalls|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Firewalls|list}.
                     * @param error Error, if any
                     * @param [response] FirewallList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Firewalls|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Firewalls|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a ForwardingRules */
                class ForwardingRules extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new ForwardingRules service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new ForwardingRules service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): ForwardingRules;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListForwardingRulesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ForwardingRuleAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListForwardingRulesRequest, callback: google.cloud.compute.v1.ForwardingRules.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListForwardingRulesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListForwardingRulesRequest): Promise<google.cloud.compute.v1.ForwardingRuleAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteForwardingRuleRequest, callback: google.cloud.compute.v1.ForwardingRules.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ForwardingRule
                     */
                    public get(request: google.cloud.compute.v1.IGetForwardingRuleRequest, callback: google.cloud.compute.v1.ForwardingRules.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetForwardingRuleRequest): Promise<google.cloud.compute.v1.ForwardingRule>;

                    /**
                     * Calls Insert.
                     * @param request InsertForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertForwardingRuleRequest, callback: google.cloud.compute.v1.ForwardingRules.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListForwardingRulesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ForwardingRuleList
                     */
                    public list(request: google.cloud.compute.v1.IListForwardingRulesRequest, callback: google.cloud.compute.v1.ForwardingRules.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListForwardingRulesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListForwardingRulesRequest): Promise<google.cloud.compute.v1.ForwardingRuleList>;

                    /**
                     * Calls Patch.
                     * @param request PatchForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchForwardingRuleRequest, callback: google.cloud.compute.v1.ForwardingRules.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsForwardingRuleRequest, callback: google.cloud.compute.v1.ForwardingRules.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetTarget.
                     * @param request SetTargetForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setTarget(request: google.cloud.compute.v1.ISetTargetForwardingRuleRequest, callback: google.cloud.compute.v1.ForwardingRules.SetTargetCallback): void;

                    /**
                     * Calls SetTarget.
                     * @param request SetTargetForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public setTarget(request: google.cloud.compute.v1.ISetTargetForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace ForwardingRules {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] ForwardingRuleAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ForwardingRuleAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|get}.
                     * @param error Error, if any
                     * @param [response] ForwardingRule
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.ForwardingRule) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|list}.
                     * @param error Error, if any
                     * @param [response] ForwardingRuleList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ForwardingRuleList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ForwardingRules|setTarget}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetTargetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a GlobalAddresses */
                class GlobalAddresses extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new GlobalAddresses service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new GlobalAddresses service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): GlobalAddresses;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalAddressRequest, callback: google.cloud.compute.v1.GlobalAddresses.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalAddressRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalAddressRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetGlobalAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Address
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalAddressRequest, callback: google.cloud.compute.v1.GlobalAddresses.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetGlobalAddressRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalAddressRequest): Promise<google.cloud.compute.v1.Address>;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalAddressRequest, callback: google.cloud.compute.v1.GlobalAddresses.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalAddressRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalAddressRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListGlobalAddressesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AddressList
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalAddressesRequest, callback: google.cloud.compute.v1.GlobalAddresses.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListGlobalAddressesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalAddressesRequest): Promise<google.cloud.compute.v1.AddressList>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsGlobalAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsGlobalAddressRequest, callback: google.cloud.compute.v1.GlobalAddresses.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsGlobalAddressRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsGlobalAddressRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace GlobalAddresses {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalAddresses|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalAddresses|get}.
                     * @param error Error, if any
                     * @param [response] Address
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Address) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalAddresses|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalAddresses|list}.
                     * @param error Error, if any
                     * @param [response] AddressList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.AddressList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalAddresses|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a GlobalForwardingRules */
                class GlobalForwardingRules extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new GlobalForwardingRules service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new GlobalForwardingRules service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): GlobalForwardingRules;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalForwardingRuleRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetGlobalForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ForwardingRule
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalForwardingRuleRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetGlobalForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalForwardingRuleRequest): Promise<google.cloud.compute.v1.ForwardingRule>;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalForwardingRuleRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListGlobalForwardingRulesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ForwardingRuleList
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalForwardingRulesRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListGlobalForwardingRulesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalForwardingRulesRequest): Promise<google.cloud.compute.v1.ForwardingRuleList>;

                    /**
                     * Calls Patch.
                     * @param request PatchGlobalForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchGlobalForwardingRuleRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchGlobalForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchGlobalForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsGlobalForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsGlobalForwardingRuleRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsGlobalForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsGlobalForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetTarget.
                     * @param request SetTargetGlobalForwardingRuleRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setTarget(request: google.cloud.compute.v1.ISetTargetGlobalForwardingRuleRequest, callback: google.cloud.compute.v1.GlobalForwardingRules.SetTargetCallback): void;

                    /**
                     * Calls SetTarget.
                     * @param request SetTargetGlobalForwardingRuleRequest message or plain object
                     * @returns Promise
                     */
                    public setTarget(request: google.cloud.compute.v1.ISetTargetGlobalForwardingRuleRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace GlobalForwardingRules {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|get}.
                     * @param error Error, if any
                     * @param [response] ForwardingRule
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.ForwardingRule) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|list}.
                     * @param error Error, if any
                     * @param [response] ForwardingRuleList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ForwardingRuleList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalForwardingRules|setTarget}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetTargetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a GlobalNetworkEndpointGroups */
                class GlobalNetworkEndpointGroups extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new GlobalNetworkEndpointGroups service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new GlobalNetworkEndpointGroups service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): GlobalNetworkEndpointGroups;

                    /**
                     * Calls AttachNetworkEndpoints.
                     * @param request AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public attachNetworkEndpoints(request: google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.AttachNetworkEndpointsCallback): void;

                    /**
                     * Calls AttachNetworkEndpoints.
                     * @param request AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public attachNetworkEndpoints(request: google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DetachNetworkEndpoints.
                     * @param request DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public detachNetworkEndpoints(request: google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.DetachNetworkEndpointsCallback): void;

                    /**
                     * Calls DetachNetworkEndpoints.
                     * @param request DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public detachNetworkEndpoints(request: google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetGlobalNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroup
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetGlobalNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroup>;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListGlobalNetworkEndpointGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroupList
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListGlobalNetworkEndpointGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroupList>;

                    /**
                     * Calls ListNetworkEndpoints.
                     * @param request ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroupsListNetworkEndpoints
                     */
                    public listNetworkEndpoints(request: google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, callback: google.cloud.compute.v1.GlobalNetworkEndpointGroups.ListNetworkEndpointsCallback): void;

                    /**
                     * Calls ListNetworkEndpoints.
                     * @param request ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public listNetworkEndpoints(request: google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints>;
                }

                namespace GlobalNetworkEndpointGroups {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|attachNetworkEndpoints}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AttachNetworkEndpointsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|detachNetworkEndpoints}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DetachNetworkEndpointsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|get}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroup
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroup) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|list}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroupList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroupList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalNetworkEndpointGroups|listNetworkEndpoints}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroupsListNetworkEndpoints
                     */
                    type ListNetworkEndpointsCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints) => void;
                }

                /** Represents a GlobalOperations */
                class GlobalOperations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new GlobalOperations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new GlobalOperations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): GlobalOperations;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListGlobalOperationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and OperationAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListGlobalOperationsRequest, callback: google.cloud.compute.v1.GlobalOperations.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListGlobalOperationsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListGlobalOperationsRequest): Promise<google.cloud.compute.v1.OperationAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DeleteGlobalOperationResponse
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalOperationRequest, callback: google.cloud.compute.v1.GlobalOperations.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalOperationRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalOperationRequest): Promise<google.cloud.compute.v1.DeleteGlobalOperationResponse>;

                    /**
                     * Calls Get.
                     * @param request GetGlobalOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalOperationRequest, callback: google.cloud.compute.v1.GlobalOperations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetGlobalOperationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalOperationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListGlobalOperationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and OperationList
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalOperationsRequest, callback: google.cloud.compute.v1.GlobalOperations.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListGlobalOperationsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalOperationsRequest): Promise<google.cloud.compute.v1.OperationList>;

                    /**
                     * Calls Wait.
                     * @param request WaitGlobalOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public wait(request: google.cloud.compute.v1.IWaitGlobalOperationRequest, callback: google.cloud.compute.v1.GlobalOperations.WaitCallback): void;

                    /**
                     * Calls Wait.
                     * @param request WaitGlobalOperationRequest message or plain object
                     * @returns Promise
                     */
                    public wait(request: google.cloud.compute.v1.IWaitGlobalOperationRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace GlobalOperations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOperations|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] OperationAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.OperationAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOperations|delete_}.
                     * @param error Error, if any
                     * @param [response] DeleteGlobalOperationResponse
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.DeleteGlobalOperationResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOperations|get}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOperations|list}.
                     * @param error Error, if any
                     * @param [response] OperationList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.OperationList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOperations|wait}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type WaitCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a GlobalOrganizationOperations */
                class GlobalOrganizationOperations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new GlobalOrganizationOperations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new GlobalOrganizationOperations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): GlobalOrganizationOperations;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalOrganizationOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DeleteGlobalOrganizationOperationResponse
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationRequest, callback: google.cloud.compute.v1.GlobalOrganizationOperations.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalOrganizationOperationRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalOrganizationOperationRequest): Promise<google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse>;

                    /**
                     * Calls Get.
                     * @param request GetGlobalOrganizationOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalOrganizationOperationRequest, callback: google.cloud.compute.v1.GlobalOrganizationOperations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetGlobalOrganizationOperationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalOrganizationOperationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListGlobalOrganizationOperationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and OperationList
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalOrganizationOperationsRequest, callback: google.cloud.compute.v1.GlobalOrganizationOperations.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListGlobalOrganizationOperationsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalOrganizationOperationsRequest): Promise<google.cloud.compute.v1.OperationList>;
                }

                namespace GlobalOrganizationOperations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOrganizationOperations|delete_}.
                     * @param error Error, if any
                     * @param [response] DeleteGlobalOrganizationOperationResponse
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.DeleteGlobalOrganizationOperationResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOrganizationOperations|get}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalOrganizationOperations|list}.
                     * @param error Error, if any
                     * @param [response] OperationList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.OperationList) => void;
                }

                /** Represents a GlobalPublicDelegatedPrefixes */
                class GlobalPublicDelegatedPrefixes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new GlobalPublicDelegatedPrefixes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new GlobalPublicDelegatedPrefixes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): GlobalPublicDelegatedPrefixes;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.GlobalPublicDelegatedPrefixes.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteGlobalPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicDelegatedPrefix
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.GlobalPublicDelegatedPrefixes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetGlobalPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.PublicDelegatedPrefix>;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.GlobalPublicDelegatedPrefixes.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertGlobalPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListGlobalPublicDelegatedPrefixesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicDelegatedPrefixList
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalPublicDelegatedPrefixesRequest, callback: google.cloud.compute.v1.GlobalPublicDelegatedPrefixes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListGlobalPublicDelegatedPrefixesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListGlobalPublicDelegatedPrefixesRequest): Promise<google.cloud.compute.v1.PublicDelegatedPrefixList>;

                    /**
                     * Calls Patch.
                     * @param request PatchGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchGlobalPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.GlobalPublicDelegatedPrefixes.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchGlobalPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchGlobalPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace GlobalPublicDelegatedPrefixes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalPublicDelegatedPrefixes|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalPublicDelegatedPrefixes|get}.
                     * @param error Error, if any
                     * @param [response] PublicDelegatedPrefix
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicDelegatedPrefix) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalPublicDelegatedPrefixes|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalPublicDelegatedPrefixes|list}.
                     * @param error Error, if any
                     * @param [response] PublicDelegatedPrefixList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicDelegatedPrefixList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.GlobalPublicDelegatedPrefixes|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a HealthChecks */
                class HealthChecks extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new HealthChecks service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new HealthChecks service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): HealthChecks;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListHealthChecksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthChecksAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListHealthChecksRequest, callback: google.cloud.compute.v1.HealthChecks.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListHealthChecksRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListHealthChecksRequest): Promise<google.cloud.compute.v1.HealthChecksAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteHealthCheckRequest, callback: google.cloud.compute.v1.HealthChecks.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthCheck
                     */
                    public get(request: google.cloud.compute.v1.IGetHealthCheckRequest, callback: google.cloud.compute.v1.HealthChecks.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetHealthCheckRequest): Promise<google.cloud.compute.v1.HealthCheck>;

                    /**
                     * Calls Insert.
                     * @param request InsertHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertHealthCheckRequest, callback: google.cloud.compute.v1.HealthChecks.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListHealthChecksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthCheckList
                     */
                    public list(request: google.cloud.compute.v1.IListHealthChecksRequest, callback: google.cloud.compute.v1.HealthChecks.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListHealthChecksRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListHealthChecksRequest): Promise<google.cloud.compute.v1.HealthCheckList>;

                    /**
                     * Calls Patch.
                     * @param request PatchHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchHealthCheckRequest, callback: google.cloud.compute.v1.HealthChecks.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateHealthCheckRequest, callback: google.cloud.compute.v1.HealthChecks.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace HealthChecks {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] HealthChecksAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthChecksAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|get}.
                     * @param error Error, if any
                     * @param [response] HealthCheck
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthCheck) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|list}.
                     * @param error Error, if any
                     * @param [response] HealthCheckList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthCheckList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.HealthChecks|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an ImageFamilyViews */
                class ImageFamilyViews extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new ImageFamilyViews service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new ImageFamilyViews service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): ImageFamilyViews;

                    /**
                     * Calls Get.
                     * @param request GetImageFamilyViewRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ImageFamilyView
                     */
                    public get(request: google.cloud.compute.v1.IGetImageFamilyViewRequest, callback: google.cloud.compute.v1.ImageFamilyViews.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetImageFamilyViewRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetImageFamilyViewRequest): Promise<google.cloud.compute.v1.ImageFamilyView>;
                }

                namespace ImageFamilyViews {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ImageFamilyViews|get}.
                     * @param error Error, if any
                     * @param [response] ImageFamilyView
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.ImageFamilyView) => void;
                }

                /** Represents an Images */
                class Images extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Images service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Images service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Images;

                    /**
                     * Calls Delete.
                     * @param request DeleteImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteImageRequest, callback: google.cloud.compute.v1.Images.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteImageRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Deprecate.
                     * @param request DeprecateImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deprecate(request: google.cloud.compute.v1.IDeprecateImageRequest, callback: google.cloud.compute.v1.Images.DeprecateCallback): void;

                    /**
                     * Calls Deprecate.
                     * @param request DeprecateImageRequest message or plain object
                     * @returns Promise
                     */
                    public deprecate(request: google.cloud.compute.v1.IDeprecateImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Image
                     */
                    public get(request: google.cloud.compute.v1.IGetImageRequest, callback: google.cloud.compute.v1.Images.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetImageRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetImageRequest): Promise<google.cloud.compute.v1.Image>;

                    /**
                     * Calls GetFromFamily.
                     * @param request GetFromFamilyImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Image
                     */
                    public getFromFamily(request: google.cloud.compute.v1.IGetFromFamilyImageRequest, callback: google.cloud.compute.v1.Images.GetFromFamilyCallback): void;

                    /**
                     * Calls GetFromFamily.
                     * @param request GetFromFamilyImageRequest message or plain object
                     * @returns Promise
                     */
                    public getFromFamily(request: google.cloud.compute.v1.IGetFromFamilyImageRequest): Promise<google.cloud.compute.v1.Image>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyImageRequest, callback: google.cloud.compute.v1.Images.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyImageRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyImageRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertImageRequest, callback: google.cloud.compute.v1.Images.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertImageRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListImagesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ImageList
                     */
                    public list(request: google.cloud.compute.v1.IListImagesRequest, callback: google.cloud.compute.v1.Images.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListImagesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListImagesRequest): Promise<google.cloud.compute.v1.ImageList>;

                    /**
                     * Calls Patch.
                     * @param request PatchImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchImageRequest, callback: google.cloud.compute.v1.Images.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchImageRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyImageRequest, callback: google.cloud.compute.v1.Images.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyImageRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyImageRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsImageRequest, callback: google.cloud.compute.v1.Images.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsImageRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsImageRequest, callback: google.cloud.compute.v1.Images.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsImageRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsImageRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace Images {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|deprecate}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeprecateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|get}.
                     * @param error Error, if any
                     * @param [response] Image
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Image) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|getFromFamily}.
                     * @param error Error, if any
                     * @param [response] Image
                     */
                    type GetFromFamilyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Image) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|list}.
                     * @param error Error, if any
                     * @param [response] ImageList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ImageList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Images|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents an InstanceGroupManagers */
                class InstanceGroupManagers extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new InstanceGroupManagers service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new InstanceGroupManagers service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): InstanceGroupManagers;

                    /**
                     * Calls AbandonInstances.
                     * @param request AbandonInstancesInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public abandonInstances(request: google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.AbandonInstancesCallback): void;

                    /**
                     * Calls AbandonInstances.
                     * @param request AbandonInstancesInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public abandonInstances(request: google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManagerAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.InstanceGroupManagerAggregatedList>;

                    /**
                     * Calls ApplyUpdatesToInstances.
                     * @param request ApplyUpdatesToInstancesInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public applyUpdatesToInstances(request: google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.ApplyUpdatesToInstancesCallback): void;

                    /**
                     * Calls ApplyUpdatesToInstances.
                     * @param request ApplyUpdatesToInstancesInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public applyUpdatesToInstances(request: google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls CreateInstances.
                     * @param request CreateInstancesInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public createInstances(request: google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.CreateInstancesCallback): void;

                    /**
                     * Calls CreateInstances.
                     * @param request CreateInstancesInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public createInstances(request: google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeleteInstances.
                     * @param request DeleteInstancesInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteInstances(request: google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.DeleteInstancesCallback): void;

                    /**
                     * Calls DeleteInstances.
                     * @param request DeleteInstancesInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public deleteInstances(request: google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeletePerInstanceConfigs.
                     * @param request DeletePerInstanceConfigsInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deletePerInstanceConfigs(request: google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.DeletePerInstanceConfigsCallback): void;

                    /**
                     * Calls DeletePerInstanceConfigs.
                     * @param request DeletePerInstanceConfigsInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public deletePerInstanceConfigs(request: google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManager
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.InstanceGroupManager>;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManagerList
                     */
                    public list(request: google.cloud.compute.v1.IListInstanceGroupManagersRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.InstanceGroupManagerList>;

                    /**
                     * Calls ListErrors.
                     * @param request ListErrorsInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManagersListErrorsResponse
                     */
                    public listErrors(request: google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.ListErrorsCallback): void;

                    /**
                     * Calls ListErrors.
                     * @param request ListErrorsInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public listErrors(request: google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse>;

                    /**
                     * Calls ListManagedInstances.
                     * @param request ListManagedInstancesInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManagersListManagedInstancesResponse
                     */
                    public listManagedInstances(request: google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.ListManagedInstancesCallback): void;

                    /**
                     * Calls ListManagedInstances.
                     * @param request ListManagedInstancesInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public listManagedInstances(request: google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse>;

                    /**
                     * Calls ListPerInstanceConfigs.
                     * @param request ListPerInstanceConfigsInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManagersListPerInstanceConfigsResp
                     */
                    public listPerInstanceConfigs(request: google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.ListPerInstanceConfigsCallback): void;

                    /**
                     * Calls ListPerInstanceConfigs.
                     * @param request ListPerInstanceConfigsInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public listPerInstanceConfigs(request: google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp>;

                    /**
                     * Calls Patch.
                     * @param request PatchInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls PatchPerInstanceConfigs.
                     * @param request PatchPerInstanceConfigsInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patchPerInstanceConfigs(request: google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.PatchPerInstanceConfigsCallback): void;

                    /**
                     * Calls PatchPerInstanceConfigs.
                     * @param request PatchPerInstanceConfigsInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public patchPerInstanceConfigs(request: google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RecreateInstances.
                     * @param request RecreateInstancesInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public recreateInstances(request: google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.RecreateInstancesCallback): void;

                    /**
                     * Calls RecreateInstances.
                     * @param request RecreateInstancesInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public recreateInstances(request: google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Resize.
                     * @param request ResizeInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public resize(request: google.cloud.compute.v1.IResizeInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.ResizeCallback): void;

                    /**
                     * Calls Resize.
                     * @param request ResizeInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public resize(request: google.cloud.compute.v1.IResizeInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetInstanceTemplate.
                     * @param request SetInstanceTemplateInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setInstanceTemplate(request: google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.SetInstanceTemplateCallback): void;

                    /**
                     * Calls SetInstanceTemplate.
                     * @param request SetInstanceTemplateInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public setInstanceTemplate(request: google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetTargetPools.
                     * @param request SetTargetPoolsInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setTargetPools(request: google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.SetTargetPoolsCallback): void;

                    /**
                     * Calls SetTargetPools.
                     * @param request SetTargetPoolsInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public setTargetPools(request: google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdatePerInstanceConfigs.
                     * @param request UpdatePerInstanceConfigsInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updatePerInstanceConfigs(request: google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest, callback: google.cloud.compute.v1.InstanceGroupManagers.UpdatePerInstanceConfigsCallback): void;

                    /**
                     * Calls UpdatePerInstanceConfigs.
                     * @param request UpdatePerInstanceConfigsInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public updatePerInstanceConfigs(request: google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace InstanceGroupManagers {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|abandonInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AbandonInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManagerAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManagerAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|applyUpdatesToInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ApplyUpdatesToInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|createInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CreateInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|deleteInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|deletePerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeletePerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|get}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManager
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManager) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|list}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManagerList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManagerList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|listErrors}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManagersListErrorsResponse
                     */
                    type ListErrorsCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManagersListErrorsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|listManagedInstances}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManagersListManagedInstancesResponse
                     */
                    type ListManagedInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManagersListManagedInstancesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|listPerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManagersListPerInstanceConfigsResp
                     */
                    type ListPerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManagersListPerInstanceConfigsResp) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|patchPerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchPerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|recreateInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RecreateInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|resize}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResizeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|setInstanceTemplate}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetInstanceTemplateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|setTargetPools}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetTargetPoolsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroupManagers|updatePerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdatePerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an InstanceGroups */
                class InstanceGroups extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new InstanceGroups service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new InstanceGroups service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): InstanceGroups;

                    /**
                     * Calls AddInstances.
                     * @param request AddInstancesInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addInstances(request: google.cloud.compute.v1.IAddInstancesInstanceGroupRequest, callback: google.cloud.compute.v1.InstanceGroups.AddInstancesCallback): void;

                    /**
                     * Calls AddInstances.
                     * @param request AddInstancesInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public addInstances(request: google.cloud.compute.v1.IAddInstancesInstanceGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInstanceGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInstanceGroupsRequest, callback: google.cloud.compute.v1.InstanceGroups.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInstanceGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInstanceGroupsRequest): Promise<google.cloud.compute.v1.InstanceGroupAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceGroupRequest, callback: google.cloud.compute.v1.InstanceGroups.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroup
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceGroupRequest, callback: google.cloud.compute.v1.InstanceGroups.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceGroupRequest): Promise<google.cloud.compute.v1.InstanceGroup>;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceGroupRequest, callback: google.cloud.compute.v1.InstanceGroups.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListInstanceGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupList
                     */
                    public list(request: google.cloud.compute.v1.IListInstanceGroupsRequest, callback: google.cloud.compute.v1.InstanceGroups.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInstanceGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInstanceGroupsRequest): Promise<google.cloud.compute.v1.InstanceGroupList>;

                    /**
                     * Calls ListInstances.
                     * @param request ListInstancesInstanceGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupsListInstances
                     */
                    public listInstances(request: google.cloud.compute.v1.IListInstancesInstanceGroupsRequest, callback: google.cloud.compute.v1.InstanceGroups.ListInstancesCallback): void;

                    /**
                     * Calls ListInstances.
                     * @param request ListInstancesInstanceGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public listInstances(request: google.cloud.compute.v1.IListInstancesInstanceGroupsRequest): Promise<google.cloud.compute.v1.InstanceGroupsListInstances>;

                    /**
                     * Calls RemoveInstances.
                     * @param request RemoveInstancesInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeInstances(request: google.cloud.compute.v1.IRemoveInstancesInstanceGroupRequest, callback: google.cloud.compute.v1.InstanceGroups.RemoveInstancesCallback): void;

                    /**
                     * Calls RemoveInstances.
                     * @param request RemoveInstancesInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public removeInstances(request: google.cloud.compute.v1.IRemoveInstancesInstanceGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetNamedPorts.
                     * @param request SetNamedPortsInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setNamedPorts(request: google.cloud.compute.v1.ISetNamedPortsInstanceGroupRequest, callback: google.cloud.compute.v1.InstanceGroups.SetNamedPortsCallback): void;

                    /**
                     * Calls SetNamedPorts.
                     * @param request SetNamedPortsInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public setNamedPorts(request: google.cloud.compute.v1.ISetNamedPortsInstanceGroupRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace InstanceGroups {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|addInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|get}.
                     * @param error Error, if any
                     * @param [response] InstanceGroup
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroup) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|list}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|listInstances}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupsListInstances
                     */
                    type ListInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupsListInstances) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|removeInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceGroups|setNamedPorts}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetNamedPortsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an InstanceTemplates */
                class InstanceTemplates extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new InstanceTemplates service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new InstanceTemplates service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): InstanceTemplates;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceTemplateRequest, callback: google.cloud.compute.v1.InstanceTemplates.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceTemplateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetInstanceTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceTemplate
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceTemplateRequest, callback: google.cloud.compute.v1.InstanceTemplates.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInstanceTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceTemplateRequest): Promise<google.cloud.compute.v1.InstanceTemplate>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyInstanceTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyInstanceTemplateRequest, callback: google.cloud.compute.v1.InstanceTemplates.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyInstanceTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyInstanceTemplateRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceTemplateRequest, callback: google.cloud.compute.v1.InstanceTemplates.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceTemplateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListInstanceTemplatesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceTemplateList
                     */
                    public list(request: google.cloud.compute.v1.IListInstanceTemplatesRequest, callback: google.cloud.compute.v1.InstanceTemplates.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInstanceTemplatesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInstanceTemplatesRequest): Promise<google.cloud.compute.v1.InstanceTemplateList>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyInstanceTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyInstanceTemplateRequest, callback: google.cloud.compute.v1.InstanceTemplates.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyInstanceTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyInstanceTemplateRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsInstanceTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsInstanceTemplateRequest, callback: google.cloud.compute.v1.InstanceTemplates.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsInstanceTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsInstanceTemplateRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace InstanceTemplates {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|get}.
                     * @param error Error, if any
                     * @param [response] InstanceTemplate
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceTemplate) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|list}.
                     * @param error Error, if any
                     * @param [response] InstanceTemplateList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceTemplateList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InstanceTemplates|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents an Instances */
                class Instances extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Instances service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Instances service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Instances;

                    /**
                     * Calls AddAccessConfig.
                     * @param request AddAccessConfigInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addAccessConfig(request: google.cloud.compute.v1.IAddAccessConfigInstanceRequest, callback: google.cloud.compute.v1.Instances.AddAccessConfigCallback): void;

                    /**
                     * Calls AddAccessConfig.
                     * @param request AddAccessConfigInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public addAccessConfig(request: google.cloud.compute.v1.IAddAccessConfigInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AddResourcePolicies.
                     * @param request AddResourcePoliciesInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addResourcePolicies(request: google.cloud.compute.v1.IAddResourcePoliciesInstanceRequest, callback: google.cloud.compute.v1.Instances.AddResourcePoliciesCallback): void;

                    /**
                     * Calls AddResourcePolicies.
                     * @param request AddResourcePoliciesInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public addResourcePolicies(request: google.cloud.compute.v1.IAddResourcePoliciesInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInstancesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInstancesRequest, callback: google.cloud.compute.v1.Instances.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInstancesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInstancesRequest): Promise<google.cloud.compute.v1.InstanceAggregatedList>;

                    /**
                     * Calls AttachDisk.
                     * @param request AttachDiskInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public attachDisk(request: google.cloud.compute.v1.IAttachDiskInstanceRequest, callback: google.cloud.compute.v1.Instances.AttachDiskCallback): void;

                    /**
                     * Calls AttachDisk.
                     * @param request AttachDiskInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public attachDisk(request: google.cloud.compute.v1.IAttachDiskInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls BulkInsert.
                     * @param request BulkInsertInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public bulkInsert(request: google.cloud.compute.v1.IBulkInsertInstanceRequest, callback: google.cloud.compute.v1.Instances.BulkInsertCallback): void;

                    /**
                     * Calls BulkInsert.
                     * @param request BulkInsertInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public bulkInsert(request: google.cloud.compute.v1.IBulkInsertInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceRequest, callback: google.cloud.compute.v1.Instances.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeleteAccessConfig.
                     * @param request DeleteAccessConfigInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteAccessConfig(request: google.cloud.compute.v1.IDeleteAccessConfigInstanceRequest, callback: google.cloud.compute.v1.Instances.DeleteAccessConfigCallback): void;

                    /**
                     * Calls DeleteAccessConfig.
                     * @param request DeleteAccessConfigInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public deleteAccessConfig(request: google.cloud.compute.v1.IDeleteAccessConfigInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DetachDisk.
                     * @param request DetachDiskInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public detachDisk(request: google.cloud.compute.v1.IDetachDiskInstanceRequest, callback: google.cloud.compute.v1.Instances.DetachDiskCallback): void;

                    /**
                     * Calls DetachDisk.
                     * @param request DetachDiskInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public detachDisk(request: google.cloud.compute.v1.IDetachDiskInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Instance
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceRequest, callback: google.cloud.compute.v1.Instances.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInstanceRequest): Promise<google.cloud.compute.v1.Instance>;

                    /**
                     * Calls GetEffectiveFirewalls.
                     * @param request GetEffectiveFirewallsInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstancesGetEffectiveFirewallsResponse
                     */
                    public getEffectiveFirewalls(request: google.cloud.compute.v1.IGetEffectiveFirewallsInstanceRequest, callback: google.cloud.compute.v1.Instances.GetEffectiveFirewallsCallback): void;

                    /**
                     * Calls GetEffectiveFirewalls.
                     * @param request GetEffectiveFirewallsInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public getEffectiveFirewalls(request: google.cloud.compute.v1.IGetEffectiveFirewallsInstanceRequest): Promise<google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse>;

                    /**
                     * Calls GetGuestAttributes.
                     * @param request GetGuestAttributesInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and GuestAttributes
                     */
                    public getGuestAttributes(request: google.cloud.compute.v1.IGetGuestAttributesInstanceRequest, callback: google.cloud.compute.v1.Instances.GetGuestAttributesCallback): void;

                    /**
                     * Calls GetGuestAttributes.
                     * @param request GetGuestAttributesInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public getGuestAttributes(request: google.cloud.compute.v1.IGetGuestAttributesInstanceRequest): Promise<google.cloud.compute.v1.GuestAttributes>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyInstanceRequest, callback: google.cloud.compute.v1.Instances.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyInstanceRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls GetScreenshot.
                     * @param request GetScreenshotInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Screenshot
                     */
                    public getScreenshot(request: google.cloud.compute.v1.IGetScreenshotInstanceRequest, callback: google.cloud.compute.v1.Instances.GetScreenshotCallback): void;

                    /**
                     * Calls GetScreenshot.
                     * @param request GetScreenshotInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public getScreenshot(request: google.cloud.compute.v1.IGetScreenshotInstanceRequest): Promise<google.cloud.compute.v1.Screenshot>;

                    /**
                     * Calls GetSerialPortOutput.
                     * @param request GetSerialPortOutputInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SerialPortOutput
                     */
                    public getSerialPortOutput(request: google.cloud.compute.v1.IGetSerialPortOutputInstanceRequest, callback: google.cloud.compute.v1.Instances.GetSerialPortOutputCallback): void;

                    /**
                     * Calls GetSerialPortOutput.
                     * @param request GetSerialPortOutputInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public getSerialPortOutput(request: google.cloud.compute.v1.IGetSerialPortOutputInstanceRequest): Promise<google.cloud.compute.v1.SerialPortOutput>;

                    /**
                     * Calls GetShieldedInstanceIdentity.
                     * @param request GetShieldedInstanceIdentityInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ShieldedInstanceIdentity
                     */
                    public getShieldedInstanceIdentity(request: google.cloud.compute.v1.IGetShieldedInstanceIdentityInstanceRequest, callback: google.cloud.compute.v1.Instances.GetShieldedInstanceIdentityCallback): void;

                    /**
                     * Calls GetShieldedInstanceIdentity.
                     * @param request GetShieldedInstanceIdentityInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public getShieldedInstanceIdentity(request: google.cloud.compute.v1.IGetShieldedInstanceIdentityInstanceRequest): Promise<google.cloud.compute.v1.ShieldedInstanceIdentity>;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceRequest, callback: google.cloud.compute.v1.Instances.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListInstancesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceList
                     */
                    public list(request: google.cloud.compute.v1.IListInstancesRequest, callback: google.cloud.compute.v1.Instances.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInstancesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInstancesRequest): Promise<google.cloud.compute.v1.InstanceList>;

                    /**
                     * Calls ListReferrers.
                     * @param request ListReferrersInstancesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceListReferrers
                     */
                    public listReferrers(request: google.cloud.compute.v1.IListReferrersInstancesRequest, callback: google.cloud.compute.v1.Instances.ListReferrersCallback): void;

                    /**
                     * Calls ListReferrers.
                     * @param request ListReferrersInstancesRequest message or plain object
                     * @returns Promise
                     */
                    public listReferrers(request: google.cloud.compute.v1.IListReferrersInstancesRequest): Promise<google.cloud.compute.v1.InstanceListReferrers>;

                    /**
                     * Calls RemoveResourcePolicies.
                     * @param request RemoveResourcePoliciesInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeResourcePolicies(request: google.cloud.compute.v1.IRemoveResourcePoliciesInstanceRequest, callback: google.cloud.compute.v1.Instances.RemoveResourcePoliciesCallback): void;

                    /**
                     * Calls RemoveResourcePolicies.
                     * @param request RemoveResourcePoliciesInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public removeResourcePolicies(request: google.cloud.compute.v1.IRemoveResourcePoliciesInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Reset.
                     * @param request ResetInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public reset(request: google.cloud.compute.v1.IResetInstanceRequest, callback: google.cloud.compute.v1.Instances.ResetCallback): void;

                    /**
                     * Calls Reset.
                     * @param request ResetInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public reset(request: google.cloud.compute.v1.IResetInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Resume.
                     * @param request ResumeInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public resume(request: google.cloud.compute.v1.IResumeInstanceRequest, callback: google.cloud.compute.v1.Instances.ResumeCallback): void;

                    /**
                     * Calls Resume.
                     * @param request ResumeInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public resume(request: google.cloud.compute.v1.IResumeInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SendDiagnosticInterrupt.
                     * @param request SendDiagnosticInterruptInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SendDiagnosticInterruptInstanceResponse
                     */
                    public sendDiagnosticInterrupt(request: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceRequest, callback: google.cloud.compute.v1.Instances.SendDiagnosticInterruptCallback): void;

                    /**
                     * Calls SendDiagnosticInterrupt.
                     * @param request SendDiagnosticInterruptInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public sendDiagnosticInterrupt(request: google.cloud.compute.v1.ISendDiagnosticInterruptInstanceRequest): Promise<google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse>;

                    /**
                     * Calls SetDeletionProtection.
                     * @param request SetDeletionProtectionInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setDeletionProtection(request: google.cloud.compute.v1.ISetDeletionProtectionInstanceRequest, callback: google.cloud.compute.v1.Instances.SetDeletionProtectionCallback): void;

                    /**
                     * Calls SetDeletionProtection.
                     * @param request SetDeletionProtectionInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setDeletionProtection(request: google.cloud.compute.v1.ISetDeletionProtectionInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetDiskAutoDelete.
                     * @param request SetDiskAutoDeleteInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setDiskAutoDelete(request: google.cloud.compute.v1.ISetDiskAutoDeleteInstanceRequest, callback: google.cloud.compute.v1.Instances.SetDiskAutoDeleteCallback): void;

                    /**
                     * Calls SetDiskAutoDelete.
                     * @param request SetDiskAutoDeleteInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setDiskAutoDelete(request: google.cloud.compute.v1.ISetDiskAutoDeleteInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyInstanceRequest, callback: google.cloud.compute.v1.Instances.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyInstanceRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsInstanceRequest, callback: google.cloud.compute.v1.Instances.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetMachineResources.
                     * @param request SetMachineResourcesInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setMachineResources(request: google.cloud.compute.v1.ISetMachineResourcesInstanceRequest, callback: google.cloud.compute.v1.Instances.SetMachineResourcesCallback): void;

                    /**
                     * Calls SetMachineResources.
                     * @param request SetMachineResourcesInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setMachineResources(request: google.cloud.compute.v1.ISetMachineResourcesInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetMachineType.
                     * @param request SetMachineTypeInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setMachineType(request: google.cloud.compute.v1.ISetMachineTypeInstanceRequest, callback: google.cloud.compute.v1.Instances.SetMachineTypeCallback): void;

                    /**
                     * Calls SetMachineType.
                     * @param request SetMachineTypeInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setMachineType(request: google.cloud.compute.v1.ISetMachineTypeInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetMetadata.
                     * @param request SetMetadataInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setMetadata(request: google.cloud.compute.v1.ISetMetadataInstanceRequest, callback: google.cloud.compute.v1.Instances.SetMetadataCallback): void;

                    /**
                     * Calls SetMetadata.
                     * @param request SetMetadataInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setMetadata(request: google.cloud.compute.v1.ISetMetadataInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetMinCpuPlatform.
                     * @param request SetMinCpuPlatformInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setMinCpuPlatform(request: google.cloud.compute.v1.ISetMinCpuPlatformInstanceRequest, callback: google.cloud.compute.v1.Instances.SetMinCpuPlatformCallback): void;

                    /**
                     * Calls SetMinCpuPlatform.
                     * @param request SetMinCpuPlatformInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setMinCpuPlatform(request: google.cloud.compute.v1.ISetMinCpuPlatformInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetScheduling.
                     * @param request SetSchedulingInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setScheduling(request: google.cloud.compute.v1.ISetSchedulingInstanceRequest, callback: google.cloud.compute.v1.Instances.SetSchedulingCallback): void;

                    /**
                     * Calls SetScheduling.
                     * @param request SetSchedulingInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setScheduling(request: google.cloud.compute.v1.ISetSchedulingInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetServiceAccount.
                     * @param request SetServiceAccountInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setServiceAccount(request: google.cloud.compute.v1.ISetServiceAccountInstanceRequest, callback: google.cloud.compute.v1.Instances.SetServiceAccountCallback): void;

                    /**
                     * Calls SetServiceAccount.
                     * @param request SetServiceAccountInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setServiceAccount(request: google.cloud.compute.v1.ISetServiceAccountInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetShieldedInstanceIntegrityPolicy.
                     * @param request SetShieldedInstanceIntegrityPolicyInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setShieldedInstanceIntegrityPolicy(request: google.cloud.compute.v1.ISetShieldedInstanceIntegrityPolicyInstanceRequest, callback: google.cloud.compute.v1.Instances.SetShieldedInstanceIntegrityPolicyCallback): void;

                    /**
                     * Calls SetShieldedInstanceIntegrityPolicy.
                     * @param request SetShieldedInstanceIntegrityPolicyInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setShieldedInstanceIntegrityPolicy(request: google.cloud.compute.v1.ISetShieldedInstanceIntegrityPolicyInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetTags.
                     * @param request SetTagsInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setTags(request: google.cloud.compute.v1.ISetTagsInstanceRequest, callback: google.cloud.compute.v1.Instances.SetTagsCallback): void;

                    /**
                     * Calls SetTags.
                     * @param request SetTagsInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public setTags(request: google.cloud.compute.v1.ISetTagsInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SimulateMaintenanceEvent.
                     * @param request SimulateMaintenanceEventInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public simulateMaintenanceEvent(request: google.cloud.compute.v1.ISimulateMaintenanceEventInstanceRequest, callback: google.cloud.compute.v1.Instances.SimulateMaintenanceEventCallback): void;

                    /**
                     * Calls SimulateMaintenanceEvent.
                     * @param request SimulateMaintenanceEventInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public simulateMaintenanceEvent(request: google.cloud.compute.v1.ISimulateMaintenanceEventInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Start.
                     * @param request StartInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public start(request: google.cloud.compute.v1.IStartInstanceRequest, callback: google.cloud.compute.v1.Instances.StartCallback): void;

                    /**
                     * Calls Start.
                     * @param request StartInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public start(request: google.cloud.compute.v1.IStartInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls StartWithEncryptionKey.
                     * @param request StartWithEncryptionKeyInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public startWithEncryptionKey(request: google.cloud.compute.v1.IStartWithEncryptionKeyInstanceRequest, callback: google.cloud.compute.v1.Instances.StartWithEncryptionKeyCallback): void;

                    /**
                     * Calls StartWithEncryptionKey.
                     * @param request StartWithEncryptionKeyInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public startWithEncryptionKey(request: google.cloud.compute.v1.IStartWithEncryptionKeyInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Stop.
                     * @param request StopInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public stop(request: google.cloud.compute.v1.IStopInstanceRequest, callback: google.cloud.compute.v1.Instances.StopCallback): void;

                    /**
                     * Calls Stop.
                     * @param request StopInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public stop(request: google.cloud.compute.v1.IStopInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Suspend.
                     * @param request SuspendInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public suspend(request: google.cloud.compute.v1.ISuspendInstanceRequest, callback: google.cloud.compute.v1.Instances.SuspendCallback): void;

                    /**
                     * Calls Suspend.
                     * @param request SuspendInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public suspend(request: google.cloud.compute.v1.ISuspendInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsInstanceRequest, callback: google.cloud.compute.v1.Instances.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsInstanceRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;

                    /**
                     * Calls Update.
                     * @param request UpdateInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateInstanceRequest, callback: google.cloud.compute.v1.Instances.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdateAccessConfig.
                     * @param request UpdateAccessConfigInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updateAccessConfig(request: google.cloud.compute.v1.IUpdateAccessConfigInstanceRequest, callback: google.cloud.compute.v1.Instances.UpdateAccessConfigCallback): void;

                    /**
                     * Calls UpdateAccessConfig.
                     * @param request UpdateAccessConfigInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public updateAccessConfig(request: google.cloud.compute.v1.IUpdateAccessConfigInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdateDisplayDevice.
                     * @param request UpdateDisplayDeviceInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updateDisplayDevice(request: google.cloud.compute.v1.IUpdateDisplayDeviceInstanceRequest, callback: google.cloud.compute.v1.Instances.UpdateDisplayDeviceCallback): void;

                    /**
                     * Calls UpdateDisplayDevice.
                     * @param request UpdateDisplayDeviceInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public updateDisplayDevice(request: google.cloud.compute.v1.IUpdateDisplayDeviceInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdateNetworkInterface.
                     * @param request UpdateNetworkInterfaceInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updateNetworkInterface(request: google.cloud.compute.v1.IUpdateNetworkInterfaceInstanceRequest, callback: google.cloud.compute.v1.Instances.UpdateNetworkInterfaceCallback): void;

                    /**
                     * Calls UpdateNetworkInterface.
                     * @param request UpdateNetworkInterfaceInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public updateNetworkInterface(request: google.cloud.compute.v1.IUpdateNetworkInterfaceInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdateShieldedInstanceConfig.
                     * @param request UpdateShieldedInstanceConfigInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updateShieldedInstanceConfig(request: google.cloud.compute.v1.IUpdateShieldedInstanceConfigInstanceRequest, callback: google.cloud.compute.v1.Instances.UpdateShieldedInstanceConfigCallback): void;

                    /**
                     * Calls UpdateShieldedInstanceConfig.
                     * @param request UpdateShieldedInstanceConfigInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public updateShieldedInstanceConfig(request: google.cloud.compute.v1.IUpdateShieldedInstanceConfigInstanceRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Instances {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|addAccessConfig}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddAccessConfigCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|addResourcePolicies}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddResourcePoliciesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] InstanceAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|attachDisk}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AttachDiskCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|bulkInsert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BulkInsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|deleteAccessConfig}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteAccessConfigCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|detachDisk}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DetachDiskCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|get}.
                     * @param error Error, if any
                     * @param [response] Instance
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Instance) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|getEffectiveFirewalls}.
                     * @param error Error, if any
                     * @param [response] InstancesGetEffectiveFirewallsResponse
                     */
                    type GetEffectiveFirewallsCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstancesGetEffectiveFirewallsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|getGuestAttributes}.
                     * @param error Error, if any
                     * @param [response] GuestAttributes
                     */
                    type GetGuestAttributesCallback = (error: (Error|null), response?: google.cloud.compute.v1.GuestAttributes) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|getScreenshot}.
                     * @param error Error, if any
                     * @param [response] Screenshot
                     */
                    type GetScreenshotCallback = (error: (Error|null), response?: google.cloud.compute.v1.Screenshot) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|getSerialPortOutput}.
                     * @param error Error, if any
                     * @param [response] SerialPortOutput
                     */
                    type GetSerialPortOutputCallback = (error: (Error|null), response?: google.cloud.compute.v1.SerialPortOutput) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|getShieldedInstanceIdentity}.
                     * @param error Error, if any
                     * @param [response] ShieldedInstanceIdentity
                     */
                    type GetShieldedInstanceIdentityCallback = (error: (Error|null), response?: google.cloud.compute.v1.ShieldedInstanceIdentity) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|list}.
                     * @param error Error, if any
                     * @param [response] InstanceList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|listReferrers}.
                     * @param error Error, if any
                     * @param [response] InstanceListReferrers
                     */
                    type ListReferrersCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceListReferrers) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|removeResourcePolicies}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveResourcePoliciesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|reset}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|resume}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResumeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|sendDiagnosticInterrupt}.
                     * @param error Error, if any
                     * @param [response] SendDiagnosticInterruptInstanceResponse
                     */
                    type SendDiagnosticInterruptCallback = (error: (Error|null), response?: google.cloud.compute.v1.SendDiagnosticInterruptInstanceResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setDeletionProtection}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetDeletionProtectionCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setDiskAutoDelete}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetDiskAutoDeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setMachineResources}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetMachineResourcesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setMachineType}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetMachineTypeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setMetadata}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetMetadataCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setMinCpuPlatform}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetMinCpuPlatformCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setScheduling}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSchedulingCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setServiceAccount}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetServiceAccountCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setShieldedInstanceIntegrityPolicy}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetShieldedInstanceIntegrityPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|setTags}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetTagsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|simulateMaintenanceEvent}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SimulateMaintenanceEventCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|start}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type StartCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|startWithEncryptionKey}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type StartWithEncryptionKeyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|stop}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type StopCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|suspend}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SuspendCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|updateAccessConfig}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateAccessConfigCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|updateDisplayDevice}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateDisplayDeviceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|updateNetworkInterface}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateNetworkInterfaceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Instances|updateShieldedInstanceConfig}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateShieldedInstanceConfigCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an InterconnectAttachments */
                class InterconnectAttachments extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new InterconnectAttachments service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new InterconnectAttachments service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): InterconnectAttachments;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInterconnectAttachmentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectAttachmentAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInterconnectAttachmentsRequest, callback: google.cloud.compute.v1.InterconnectAttachments.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListInterconnectAttachmentsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListInterconnectAttachmentsRequest): Promise<google.cloud.compute.v1.InterconnectAttachmentAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteInterconnectAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInterconnectAttachmentRequest, callback: google.cloud.compute.v1.InterconnectAttachments.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteInterconnectAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInterconnectAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetInterconnectAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectAttachment
                     */
                    public get(request: google.cloud.compute.v1.IGetInterconnectAttachmentRequest, callback: google.cloud.compute.v1.InterconnectAttachments.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInterconnectAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInterconnectAttachmentRequest): Promise<google.cloud.compute.v1.InterconnectAttachment>;

                    /**
                     * Calls Insert.
                     * @param request InsertInterconnectAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInterconnectAttachmentRequest, callback: google.cloud.compute.v1.InterconnectAttachments.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertInterconnectAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInterconnectAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListInterconnectAttachmentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectAttachmentList
                     */
                    public list(request: google.cloud.compute.v1.IListInterconnectAttachmentsRequest, callback: google.cloud.compute.v1.InterconnectAttachments.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInterconnectAttachmentsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInterconnectAttachmentsRequest): Promise<google.cloud.compute.v1.InterconnectAttachmentList>;

                    /**
                     * Calls Patch.
                     * @param request PatchInterconnectAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchInterconnectAttachmentRequest, callback: google.cloud.compute.v1.InterconnectAttachments.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchInterconnectAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchInterconnectAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsInterconnectAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsInterconnectAttachmentRequest, callback: google.cloud.compute.v1.InterconnectAttachments.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsInterconnectAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsInterconnectAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace InterconnectAttachments {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] InterconnectAttachmentAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectAttachmentAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|get}.
                     * @param error Error, if any
                     * @param [response] InterconnectAttachment
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectAttachment) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|list}.
                     * @param error Error, if any
                     * @param [response] InterconnectAttachmentList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectAttachmentList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectAttachments|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an InterconnectLocations */
                class InterconnectLocations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new InterconnectLocations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new InterconnectLocations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): InterconnectLocations;

                    /**
                     * Calls Get.
                     * @param request GetInterconnectLocationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectLocation
                     */
                    public get(request: google.cloud.compute.v1.IGetInterconnectLocationRequest, callback: google.cloud.compute.v1.InterconnectLocations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInterconnectLocationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInterconnectLocationRequest): Promise<google.cloud.compute.v1.InterconnectLocation>;

                    /**
                     * Calls List.
                     * @param request ListInterconnectLocationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectLocationList
                     */
                    public list(request: google.cloud.compute.v1.IListInterconnectLocationsRequest, callback: google.cloud.compute.v1.InterconnectLocations.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInterconnectLocationsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInterconnectLocationsRequest): Promise<google.cloud.compute.v1.InterconnectLocationList>;
                }

                namespace InterconnectLocations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectLocations|get}.
                     * @param error Error, if any
                     * @param [response] InterconnectLocation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectLocation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.InterconnectLocations|list}.
                     * @param error Error, if any
                     * @param [response] InterconnectLocationList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectLocationList) => void;
                }

                /** Represents an Interconnects */
                class Interconnects extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Interconnects service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Interconnects service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Interconnects;

                    /**
                     * Calls Delete.
                     * @param request DeleteInterconnectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInterconnectRequest, callback: google.cloud.compute.v1.Interconnects.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteInterconnectRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteInterconnectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetInterconnectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Interconnect
                     */
                    public get(request: google.cloud.compute.v1.IGetInterconnectRequest, callback: google.cloud.compute.v1.Interconnects.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetInterconnectRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetInterconnectRequest): Promise<google.cloud.compute.v1.Interconnect>;

                    /**
                     * Calls GetDiagnostics.
                     * @param request GetDiagnosticsInterconnectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectsGetDiagnosticsResponse
                     */
                    public getDiagnostics(request: google.cloud.compute.v1.IGetDiagnosticsInterconnectRequest, callback: google.cloud.compute.v1.Interconnects.GetDiagnosticsCallback): void;

                    /**
                     * Calls GetDiagnostics.
                     * @param request GetDiagnosticsInterconnectRequest message or plain object
                     * @returns Promise
                     */
                    public getDiagnostics(request: google.cloud.compute.v1.IGetDiagnosticsInterconnectRequest): Promise<google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse>;

                    /**
                     * Calls Insert.
                     * @param request InsertInterconnectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInterconnectRequest, callback: google.cloud.compute.v1.Interconnects.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertInterconnectRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertInterconnectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListInterconnectsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InterconnectList
                     */
                    public list(request: google.cloud.compute.v1.IListInterconnectsRequest, callback: google.cloud.compute.v1.Interconnects.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListInterconnectsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListInterconnectsRequest): Promise<google.cloud.compute.v1.InterconnectList>;

                    /**
                     * Calls Patch.
                     * @param request PatchInterconnectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchInterconnectRequest, callback: google.cloud.compute.v1.Interconnects.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchInterconnectRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchInterconnectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsInterconnectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsInterconnectRequest, callback: google.cloud.compute.v1.Interconnects.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsInterconnectRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsInterconnectRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Interconnects {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|get}.
                     * @param error Error, if any
                     * @param [response] Interconnect
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Interconnect) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|getDiagnostics}.
                     * @param error Error, if any
                     * @param [response] InterconnectsGetDiagnosticsResponse
                     */
                    type GetDiagnosticsCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectsGetDiagnosticsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|list}.
                     * @param error Error, if any
                     * @param [response] InterconnectList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.InterconnectList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Interconnects|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a LicenseCodes */
                class LicenseCodes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new LicenseCodes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new LicenseCodes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): LicenseCodes;

                    /**
                     * Calls Get.
                     * @param request GetLicenseCodeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and LicenseCode
                     */
                    public get(request: google.cloud.compute.v1.IGetLicenseCodeRequest, callback: google.cloud.compute.v1.LicenseCodes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetLicenseCodeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetLicenseCodeRequest): Promise<google.cloud.compute.v1.LicenseCode>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsLicenseCodeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsLicenseCodeRequest, callback: google.cloud.compute.v1.LicenseCodes.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsLicenseCodeRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsLicenseCodeRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace LicenseCodes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.LicenseCodes|get}.
                     * @param error Error, if any
                     * @param [response] LicenseCode
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.LicenseCode) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.LicenseCodes|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a Licenses */
                class Licenses extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Licenses service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Licenses service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Licenses;

                    /**
                     * Calls Delete.
                     * @param request DeleteLicenseRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteLicenseRequest, callback: google.cloud.compute.v1.Licenses.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteLicenseRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteLicenseRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetLicenseRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and License
                     */
                    public get(request: google.cloud.compute.v1.IGetLicenseRequest, callback: google.cloud.compute.v1.Licenses.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetLicenseRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetLicenseRequest): Promise<google.cloud.compute.v1.License>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyLicenseRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyLicenseRequest, callback: google.cloud.compute.v1.Licenses.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyLicenseRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyLicenseRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertLicenseRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertLicenseRequest, callback: google.cloud.compute.v1.Licenses.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertLicenseRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertLicenseRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListLicensesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and LicensesListResponse
                     */
                    public list(request: google.cloud.compute.v1.IListLicensesRequest, callback: google.cloud.compute.v1.Licenses.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListLicensesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListLicensesRequest): Promise<google.cloud.compute.v1.LicensesListResponse>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyLicenseRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyLicenseRequest, callback: google.cloud.compute.v1.Licenses.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyLicenseRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyLicenseRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsLicenseRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsLicenseRequest, callback: google.cloud.compute.v1.Licenses.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsLicenseRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsLicenseRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace Licenses {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|get}.
                     * @param error Error, if any
                     * @param [response] License
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.License) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|list}.
                     * @param error Error, if any
                     * @param [response] LicensesListResponse
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.LicensesListResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Licenses|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a MachineImages */
                class MachineImages extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new MachineImages service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new MachineImages service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): MachineImages;

                    /**
                     * Calls Delete.
                     * @param request DeleteMachineImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteMachineImageRequest, callback: google.cloud.compute.v1.MachineImages.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteMachineImageRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteMachineImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetMachineImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and MachineImage
                     */
                    public get(request: google.cloud.compute.v1.IGetMachineImageRequest, callback: google.cloud.compute.v1.MachineImages.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetMachineImageRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetMachineImageRequest): Promise<google.cloud.compute.v1.MachineImage>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyMachineImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyMachineImageRequest, callback: google.cloud.compute.v1.MachineImages.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyMachineImageRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyMachineImageRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertMachineImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertMachineImageRequest, callback: google.cloud.compute.v1.MachineImages.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertMachineImageRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertMachineImageRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListMachineImagesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and MachineImageList
                     */
                    public list(request: google.cloud.compute.v1.IListMachineImagesRequest, callback: google.cloud.compute.v1.MachineImages.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListMachineImagesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListMachineImagesRequest): Promise<google.cloud.compute.v1.MachineImageList>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyMachineImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyMachineImageRequest, callback: google.cloud.compute.v1.MachineImages.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyMachineImageRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyMachineImageRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsMachineImageRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsMachineImageRequest, callback: google.cloud.compute.v1.MachineImages.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsMachineImageRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsMachineImageRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace MachineImages {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|get}.
                     * @param error Error, if any
                     * @param [response] MachineImage
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.MachineImage) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|list}.
                     * @param error Error, if any
                     * @param [response] MachineImageList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.MachineImageList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineImages|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a MachineTypes */
                class MachineTypes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new MachineTypes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new MachineTypes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): MachineTypes;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListMachineTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and MachineTypeAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListMachineTypesRequest, callback: google.cloud.compute.v1.MachineTypes.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListMachineTypesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListMachineTypesRequest): Promise<google.cloud.compute.v1.MachineTypeAggregatedList>;

                    /**
                     * Calls Get.
                     * @param request GetMachineTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and MachineType
                     */
                    public get(request: google.cloud.compute.v1.IGetMachineTypeRequest, callback: google.cloud.compute.v1.MachineTypes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetMachineTypeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetMachineTypeRequest): Promise<google.cloud.compute.v1.MachineType>;

                    /**
                     * Calls List.
                     * @param request ListMachineTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and MachineTypeList
                     */
                    public list(request: google.cloud.compute.v1.IListMachineTypesRequest, callback: google.cloud.compute.v1.MachineTypes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListMachineTypesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListMachineTypesRequest): Promise<google.cloud.compute.v1.MachineTypeList>;
                }

                namespace MachineTypes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineTypes|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] MachineTypeAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.MachineTypeAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineTypes|get}.
                     * @param error Error, if any
                     * @param [response] MachineType
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.MachineType) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.MachineTypes|list}.
                     * @param error Error, if any
                     * @param [response] MachineTypeList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.MachineTypeList) => void;
                }

                /** Represents a NetworkEdgeSecurityServices */
                class NetworkEdgeSecurityServices extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new NetworkEdgeSecurityServices service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new NetworkEdgeSecurityServices service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): NetworkEdgeSecurityServices;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNetworkEdgeSecurityServicesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEdgeSecurityServiceAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNetworkEdgeSecurityServicesRequest, callback: google.cloud.compute.v1.NetworkEdgeSecurityServices.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNetworkEdgeSecurityServicesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNetworkEdgeSecurityServicesRequest): Promise<google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkEdgeSecurityServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkEdgeSecurityServiceRequest, callback: google.cloud.compute.v1.NetworkEdgeSecurityServices.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkEdgeSecurityServiceRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkEdgeSecurityServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetNetworkEdgeSecurityServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEdgeSecurityService
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkEdgeSecurityServiceRequest, callback: google.cloud.compute.v1.NetworkEdgeSecurityServices.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNetworkEdgeSecurityServiceRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkEdgeSecurityServiceRequest): Promise<google.cloud.compute.v1.NetworkEdgeSecurityService>;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkEdgeSecurityServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkEdgeSecurityServiceRequest, callback: google.cloud.compute.v1.NetworkEdgeSecurityServices.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkEdgeSecurityServiceRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkEdgeSecurityServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Patch.
                     * @param request PatchNetworkEdgeSecurityServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNetworkEdgeSecurityServiceRequest, callback: google.cloud.compute.v1.NetworkEdgeSecurityServices.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchNetworkEdgeSecurityServiceRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNetworkEdgeSecurityServiceRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace NetworkEdgeSecurityServices {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEdgeSecurityServices|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] NetworkEdgeSecurityServiceAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEdgeSecurityServiceAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEdgeSecurityServices|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEdgeSecurityServices|get}.
                     * @param error Error, if any
                     * @param [response] NetworkEdgeSecurityService
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEdgeSecurityService) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEdgeSecurityServices|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEdgeSecurityServices|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a NetworkEndpointGroups */
                class NetworkEndpointGroups extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new NetworkEndpointGroups service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new NetworkEndpointGroups service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): NetworkEndpointGroups;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNetworkEndpointGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroupAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNetworkEndpointGroupsRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNetworkEndpointGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNetworkEndpointGroupsRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroupAggregatedList>;

                    /**
                     * Calls AttachNetworkEndpoints.
                     * @param request AttachNetworkEndpointsNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public attachNetworkEndpoints(request: google.cloud.compute.v1.IAttachNetworkEndpointsNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.AttachNetworkEndpointsCallback): void;

                    /**
                     * Calls AttachNetworkEndpoints.
                     * @param request AttachNetworkEndpointsNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public attachNetworkEndpoints(request: google.cloud.compute.v1.IAttachNetworkEndpointsNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DetachNetworkEndpoints.
                     * @param request DetachNetworkEndpointsNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public detachNetworkEndpoints(request: google.cloud.compute.v1.IDetachNetworkEndpointsNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.DetachNetworkEndpointsCallback): void;

                    /**
                     * Calls DetachNetworkEndpoints.
                     * @param request DetachNetworkEndpointsNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public detachNetworkEndpoints(request: google.cloud.compute.v1.IDetachNetworkEndpointsNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroup
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroup>;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListNetworkEndpointGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroupList
                     */
                    public list(request: google.cloud.compute.v1.IListNetworkEndpointGroupsRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListNetworkEndpointGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListNetworkEndpointGroupsRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroupList>;

                    /**
                     * Calls ListNetworkEndpoints.
                     * @param request ListNetworkEndpointsNetworkEndpointGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroupsListNetworkEndpoints
                     */
                    public listNetworkEndpoints(request: google.cloud.compute.v1.IListNetworkEndpointsNetworkEndpointGroupsRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.ListNetworkEndpointsCallback): void;

                    /**
                     * Calls ListNetworkEndpoints.
                     * @param request ListNetworkEndpointsNetworkEndpointGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public listNetworkEndpoints(request: google.cloud.compute.v1.IListNetworkEndpointsNetworkEndpointGroupsRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.NetworkEndpointGroups.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace NetworkEndpointGroups {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroupAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroupAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|attachNetworkEndpoints}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AttachNetworkEndpointsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|detachNetworkEndpoints}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DetachNetworkEndpointsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|get}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroup
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroup) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|list}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroupList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroupList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|listNetworkEndpoints}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroupsListNetworkEndpoints
                     */
                    type ListNetworkEndpointsCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroupsListNetworkEndpoints) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkEndpointGroups|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a NetworkFirewallPolicies */
                class NetworkFirewallPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new NetworkFirewallPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new NetworkFirewallPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): NetworkFirewallPolicies;

                    /**
                     * Calls AddAssociation.
                     * @param request AddAssociationNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addAssociation(request: google.cloud.compute.v1.IAddAssociationNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.AddAssociationCallback): void;

                    /**
                     * Calls AddAssociation.
                     * @param request AddAssociationNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addAssociation(request: google.cloud.compute.v1.IAddAssociationNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.AddRuleCallback): void;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls CloneRules.
                     * @param request CloneRulesNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public cloneRules(request: google.cloud.compute.v1.ICloneRulesNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.CloneRulesCallback): void;

                    /**
                     * Calls CloneRules.
                     * @param request CloneRulesNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public cloneRules(request: google.cloud.compute.v1.ICloneRulesNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicy>;

                    /**
                     * Calls GetAssociation.
                     * @param request GetAssociationNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyAssociation
                     */
                    public getAssociation(request: google.cloud.compute.v1.IGetAssociationNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.GetAssociationCallback): void;

                    /**
                     * Calls GetAssociation.
                     * @param request GetAssociationNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getAssociation(request: google.cloud.compute.v1.IGetAssociationNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicyAssociation>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyRule
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.GetRuleCallback): void;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicyRule>;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListNetworkFirewallPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyList
                     */
                    public list(request: google.cloud.compute.v1.IListNetworkFirewallPoliciesRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListNetworkFirewallPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListNetworkFirewallPoliciesRequest): Promise<google.cloud.compute.v1.FirewallPolicyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.PatchRuleCallback): void;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveAssociation.
                     * @param request RemoveAssociationNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeAssociation(request: google.cloud.compute.v1.IRemoveAssociationNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.RemoveAssociationCallback): void;

                    /**
                     * Calls RemoveAssociation.
                     * @param request RemoveAssociationNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeAssociation(request: google.cloud.compute.v1.IRemoveAssociationNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.RemoveRuleCallback): void;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.NetworkFirewallPolicies.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace NetworkFirewallPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|addAssociation}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|addRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|cloneRules}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CloneRulesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|get}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|getAssociation}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyAssociation
                     */
                    type GetAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyAssociation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|getRule}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyRule
                     */
                    type GetRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyRule) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|list}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|patchRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|removeAssociation}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|removeRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NetworkFirewallPolicies|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a Networks */
                class Networks extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Networks service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Networks service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Networks;

                    /**
                     * Calls AddPeering.
                     * @param request AddPeeringNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addPeering(request: google.cloud.compute.v1.IAddPeeringNetworkRequest, callback: google.cloud.compute.v1.Networks.AddPeeringCallback): void;

                    /**
                     * Calls AddPeering.
                     * @param request AddPeeringNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public addPeering(request: google.cloud.compute.v1.IAddPeeringNetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkRequest, callback: google.cloud.compute.v1.Networks.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Network
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkRequest, callback: google.cloud.compute.v1.Networks.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNetworkRequest): Promise<google.cloud.compute.v1.Network>;

                    /**
                     * Calls GetEffectiveFirewalls.
                     * @param request GetEffectiveFirewallsNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworksGetEffectiveFirewallsResponse
                     */
                    public getEffectiveFirewalls(request: google.cloud.compute.v1.IGetEffectiveFirewallsNetworkRequest, callback: google.cloud.compute.v1.Networks.GetEffectiveFirewallsCallback): void;

                    /**
                     * Calls GetEffectiveFirewalls.
                     * @param request GetEffectiveFirewallsNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public getEffectiveFirewalls(request: google.cloud.compute.v1.IGetEffectiveFirewallsNetworkRequest): Promise<google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse>;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkRequest, callback: google.cloud.compute.v1.Networks.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListNetworksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkList
                     */
                    public list(request: google.cloud.compute.v1.IListNetworksRequest, callback: google.cloud.compute.v1.Networks.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListNetworksRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListNetworksRequest): Promise<google.cloud.compute.v1.NetworkList>;

                    /**
                     * Calls ListPeeringRoutes.
                     * @param request ListPeeringRoutesNetworksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ExchangedPeeringRoutesList
                     */
                    public listPeeringRoutes(request: google.cloud.compute.v1.IListPeeringRoutesNetworksRequest, callback: google.cloud.compute.v1.Networks.ListPeeringRoutesCallback): void;

                    /**
                     * Calls ListPeeringRoutes.
                     * @param request ListPeeringRoutesNetworksRequest message or plain object
                     * @returns Promise
                     */
                    public listPeeringRoutes(request: google.cloud.compute.v1.IListPeeringRoutesNetworksRequest): Promise<google.cloud.compute.v1.ExchangedPeeringRoutesList>;

                    /**
                     * Calls Patch.
                     * @param request PatchNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNetworkRequest, callback: google.cloud.compute.v1.Networks.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemovePeering.
                     * @param request RemovePeeringNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removePeering(request: google.cloud.compute.v1.IRemovePeeringNetworkRequest, callback: google.cloud.compute.v1.Networks.RemovePeeringCallback): void;

                    /**
                     * Calls RemovePeering.
                     * @param request RemovePeeringNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public removePeering(request: google.cloud.compute.v1.IRemovePeeringNetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SwitchToCustomMode.
                     * @param request SwitchToCustomModeNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public switchToCustomMode(request: google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest, callback: google.cloud.compute.v1.Networks.SwitchToCustomModeCallback): void;

                    /**
                     * Calls SwitchToCustomMode.
                     * @param request SwitchToCustomModeNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public switchToCustomMode(request: google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdatePeering.
                     * @param request UpdatePeeringNetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updatePeering(request: google.cloud.compute.v1.IUpdatePeeringNetworkRequest, callback: google.cloud.compute.v1.Networks.UpdatePeeringCallback): void;

                    /**
                     * Calls UpdatePeering.
                     * @param request UpdatePeeringNetworkRequest message or plain object
                     * @returns Promise
                     */
                    public updatePeering(request: google.cloud.compute.v1.IUpdatePeeringNetworkRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Networks {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|addPeering}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddPeeringCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|get}.
                     * @param error Error, if any
                     * @param [response] Network
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Network) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|getEffectiveFirewalls}.
                     * @param error Error, if any
                     * @param [response] NetworksGetEffectiveFirewallsResponse
                     */
                    type GetEffectiveFirewallsCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworksGetEffectiveFirewallsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|list}.
                     * @param error Error, if any
                     * @param [response] NetworkList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|listPeeringRoutes}.
                     * @param error Error, if any
                     * @param [response] ExchangedPeeringRoutesList
                     */
                    type ListPeeringRoutesCallback = (error: (Error|null), response?: google.cloud.compute.v1.ExchangedPeeringRoutesList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|removePeering}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemovePeeringCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|switchToCustomMode}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SwitchToCustomModeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Networks|updatePeering}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdatePeeringCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a NodeGroups */
                class NodeGroups extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new NodeGroups service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new NodeGroups service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): NodeGroups;

                    /**
                     * Calls AddNodes.
                     * @param request AddNodesNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addNodes(request: google.cloud.compute.v1.IAddNodesNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.AddNodesCallback): void;

                    /**
                     * Calls AddNodes.
                     * @param request AddNodesNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public addNodes(request: google.cloud.compute.v1.IAddNodesNodeGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNodeGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeGroupAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNodeGroupsRequest, callback: google.cloud.compute.v1.NodeGroups.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNodeGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNodeGroupsRequest): Promise<google.cloud.compute.v1.NodeGroupAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNodeGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeleteNodes.
                     * @param request DeleteNodesNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteNodes(request: google.cloud.compute.v1.IDeleteNodesNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.DeleteNodesCallback): void;

                    /**
                     * Calls DeleteNodes.
                     * @param request DeleteNodesNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public deleteNodes(request: google.cloud.compute.v1.IDeleteNodesNodeGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeGroup
                     */
                    public get(request: google.cloud.compute.v1.IGetNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNodeGroupRequest): Promise<google.cloud.compute.v1.NodeGroup>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNodeGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListNodeGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeGroupList
                     */
                    public list(request: google.cloud.compute.v1.IListNodeGroupsRequest, callback: google.cloud.compute.v1.NodeGroups.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListNodeGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListNodeGroupsRequest): Promise<google.cloud.compute.v1.NodeGroupList>;

                    /**
                     * Calls ListNodes.
                     * @param request ListNodesNodeGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeGroupsListNodes
                     */
                    public listNodes(request: google.cloud.compute.v1.IListNodesNodeGroupsRequest, callback: google.cloud.compute.v1.NodeGroups.ListNodesCallback): void;

                    /**
                     * Calls ListNodes.
                     * @param request ListNodesNodeGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public listNodes(request: google.cloud.compute.v1.IListNodesNodeGroupsRequest): Promise<google.cloud.compute.v1.NodeGroupsListNodes>;

                    /**
                     * Calls Patch.
                     * @param request PatchNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchNodeGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetNodeTemplate.
                     * @param request SetNodeTemplateNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setNodeTemplate(request: google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.SetNodeTemplateCallback): void;

                    /**
                     * Calls SetNodeTemplate.
                     * @param request SetNodeTemplateNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public setNodeTemplate(request: google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNodeGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest, callback: google.cloud.compute.v1.NodeGroups.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNodeGroupRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace NodeGroups {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|addNodes}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddNodesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] NodeGroupAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeGroupAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|deleteNodes}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteNodesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|get}.
                     * @param error Error, if any
                     * @param [response] NodeGroup
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeGroup) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|list}.
                     * @param error Error, if any
                     * @param [response] NodeGroupList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeGroupList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|listNodes}.
                     * @param error Error, if any
                     * @param [response] NodeGroupsListNodes
                     */
                    type ListNodesCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeGroupsListNodes) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|setNodeTemplate}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetNodeTemplateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeGroups|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a NodeTemplates */
                class NodeTemplates extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new NodeTemplates service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new NodeTemplates service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): NodeTemplates;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNodeTemplatesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeTemplateAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNodeTemplatesRequest, callback: google.cloud.compute.v1.NodeTemplates.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNodeTemplatesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNodeTemplatesRequest): Promise<google.cloud.compute.v1.NodeTemplateAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteNodeTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNodeTemplateRequest, callback: google.cloud.compute.v1.NodeTemplates.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteNodeTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteNodeTemplateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetNodeTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeTemplate
                     */
                    public get(request: google.cloud.compute.v1.IGetNodeTemplateRequest, callback: google.cloud.compute.v1.NodeTemplates.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNodeTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNodeTemplateRequest): Promise<google.cloud.compute.v1.NodeTemplate>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyNodeTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyNodeTemplateRequest, callback: google.cloud.compute.v1.NodeTemplates.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyNodeTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyNodeTemplateRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertNodeTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNodeTemplateRequest, callback: google.cloud.compute.v1.NodeTemplates.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertNodeTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertNodeTemplateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListNodeTemplatesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeTemplateList
                     */
                    public list(request: google.cloud.compute.v1.IListNodeTemplatesRequest, callback: google.cloud.compute.v1.NodeTemplates.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListNodeTemplatesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListNodeTemplatesRequest): Promise<google.cloud.compute.v1.NodeTemplateList>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyNodeTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyNodeTemplateRequest, callback: google.cloud.compute.v1.NodeTemplates.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyNodeTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyNodeTemplateRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNodeTemplateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNodeTemplateRequest, callback: google.cloud.compute.v1.NodeTemplates.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsNodeTemplateRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsNodeTemplateRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace NodeTemplates {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] NodeTemplateAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeTemplateAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|get}.
                     * @param error Error, if any
                     * @param [response] NodeTemplate
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeTemplate) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|list}.
                     * @param error Error, if any
                     * @param [response] NodeTemplateList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeTemplateList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTemplates|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a NodeTypes */
                class NodeTypes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new NodeTypes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new NodeTypes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): NodeTypes;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNodeTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeTypeAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNodeTypesRequest, callback: google.cloud.compute.v1.NodeTypes.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListNodeTypesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListNodeTypesRequest): Promise<google.cloud.compute.v1.NodeTypeAggregatedList>;

                    /**
                     * Calls Get.
                     * @param request GetNodeTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeType
                     */
                    public get(request: google.cloud.compute.v1.IGetNodeTypeRequest, callback: google.cloud.compute.v1.NodeTypes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetNodeTypeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetNodeTypeRequest): Promise<google.cloud.compute.v1.NodeType>;

                    /**
                     * Calls List.
                     * @param request ListNodeTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NodeTypeList
                     */
                    public list(request: google.cloud.compute.v1.IListNodeTypesRequest, callback: google.cloud.compute.v1.NodeTypes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListNodeTypesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListNodeTypesRequest): Promise<google.cloud.compute.v1.NodeTypeList>;
                }

                namespace NodeTypes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTypes|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] NodeTypeAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeTypeAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTypes|get}.
                     * @param error Error, if any
                     * @param [response] NodeType
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeType) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.NodeTypes|list}.
                     * @param error Error, if any
                     * @param [response] NodeTypeList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NodeTypeList) => void;
                }

                /** Represents a PacketMirrorings */
                class PacketMirrorings extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new PacketMirrorings service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new PacketMirrorings service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): PacketMirrorings;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListPacketMirroringsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PacketMirroringAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListPacketMirroringsRequest, callback: google.cloud.compute.v1.PacketMirrorings.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListPacketMirroringsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListPacketMirroringsRequest): Promise<google.cloud.compute.v1.PacketMirroringAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeletePacketMirroringRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeletePacketMirroringRequest, callback: google.cloud.compute.v1.PacketMirrorings.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeletePacketMirroringRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeletePacketMirroringRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetPacketMirroringRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PacketMirroring
                     */
                    public get(request: google.cloud.compute.v1.IGetPacketMirroringRequest, callback: google.cloud.compute.v1.PacketMirrorings.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetPacketMirroringRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetPacketMirroringRequest): Promise<google.cloud.compute.v1.PacketMirroring>;

                    /**
                     * Calls Insert.
                     * @param request InsertPacketMirroringRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertPacketMirroringRequest, callback: google.cloud.compute.v1.PacketMirrorings.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertPacketMirroringRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertPacketMirroringRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListPacketMirroringsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PacketMirroringList
                     */
                    public list(request: google.cloud.compute.v1.IListPacketMirroringsRequest, callback: google.cloud.compute.v1.PacketMirrorings.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListPacketMirroringsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListPacketMirroringsRequest): Promise<google.cloud.compute.v1.PacketMirroringList>;

                    /**
                     * Calls Patch.
                     * @param request PatchPacketMirroringRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchPacketMirroringRequest, callback: google.cloud.compute.v1.PacketMirrorings.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchPacketMirroringRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchPacketMirroringRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsPacketMirroringRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsPacketMirroringRequest, callback: google.cloud.compute.v1.PacketMirrorings.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsPacketMirroringRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsPacketMirroringRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace PacketMirrorings {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] PacketMirroringAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.PacketMirroringAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|get}.
                     * @param error Error, if any
                     * @param [response] PacketMirroring
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.PacketMirroring) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|list}.
                     * @param error Error, if any
                     * @param [response] PacketMirroringList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.PacketMirroringList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PacketMirrorings|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a Projects */
                class Projects extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Projects service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Projects service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Projects;

                    /**
                     * Calls DisableXpnHost.
                     * @param request DisableXpnHostProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public disableXpnHost(request: google.cloud.compute.v1.IDisableXpnHostProjectRequest, callback: google.cloud.compute.v1.Projects.DisableXpnHostCallback): void;

                    /**
                     * Calls DisableXpnHost.
                     * @param request DisableXpnHostProjectRequest message or plain object
                     * @returns Promise
                     */
                    public disableXpnHost(request: google.cloud.compute.v1.IDisableXpnHostProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DisableXpnResource.
                     * @param request DisableXpnResourceProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public disableXpnResource(request: google.cloud.compute.v1.IDisableXpnResourceProjectRequest, callback: google.cloud.compute.v1.Projects.DisableXpnResourceCallback): void;

                    /**
                     * Calls DisableXpnResource.
                     * @param request DisableXpnResourceProjectRequest message or plain object
                     * @returns Promise
                     */
                    public disableXpnResource(request: google.cloud.compute.v1.IDisableXpnResourceProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls EnableXpnHost.
                     * @param request EnableXpnHostProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public enableXpnHost(request: google.cloud.compute.v1.IEnableXpnHostProjectRequest, callback: google.cloud.compute.v1.Projects.EnableXpnHostCallback): void;

                    /**
                     * Calls EnableXpnHost.
                     * @param request EnableXpnHostProjectRequest message or plain object
                     * @returns Promise
                     */
                    public enableXpnHost(request: google.cloud.compute.v1.IEnableXpnHostProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls EnableXpnResource.
                     * @param request EnableXpnResourceProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public enableXpnResource(request: google.cloud.compute.v1.IEnableXpnResourceProjectRequest, callback: google.cloud.compute.v1.Projects.EnableXpnResourceCallback): void;

                    /**
                     * Calls EnableXpnResource.
                     * @param request EnableXpnResourceProjectRequest message or plain object
                     * @returns Promise
                     */
                    public enableXpnResource(request: google.cloud.compute.v1.IEnableXpnResourceProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Project
                     */
                    public get(request: google.cloud.compute.v1.IGetProjectRequest, callback: google.cloud.compute.v1.Projects.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetProjectRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetProjectRequest): Promise<google.cloud.compute.v1.Project>;

                    /**
                     * Calls GetXpnHost.
                     * @param request GetXpnHostProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Project
                     */
                    public getXpnHost(request: google.cloud.compute.v1.IGetXpnHostProjectRequest, callback: google.cloud.compute.v1.Projects.GetXpnHostCallback): void;

                    /**
                     * Calls GetXpnHost.
                     * @param request GetXpnHostProjectRequest message or plain object
                     * @returns Promise
                     */
                    public getXpnHost(request: google.cloud.compute.v1.IGetXpnHostProjectRequest): Promise<google.cloud.compute.v1.Project>;

                    /**
                     * Calls GetXpnResources.
                     * @param request GetXpnResourcesProjectsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProjectsGetXpnResources
                     */
                    public getXpnResources(request: google.cloud.compute.v1.IGetXpnResourcesProjectsRequest, callback: google.cloud.compute.v1.Projects.GetXpnResourcesCallback): void;

                    /**
                     * Calls GetXpnResources.
                     * @param request GetXpnResourcesProjectsRequest message or plain object
                     * @returns Promise
                     */
                    public getXpnResources(request: google.cloud.compute.v1.IGetXpnResourcesProjectsRequest): Promise<google.cloud.compute.v1.ProjectsGetXpnResources>;

                    /**
                     * Calls ListXpnHosts.
                     * @param request ListXpnHostsProjectsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and XpnHostList
                     */
                    public listXpnHosts(request: google.cloud.compute.v1.IListXpnHostsProjectsRequest, callback: google.cloud.compute.v1.Projects.ListXpnHostsCallback): void;

                    /**
                     * Calls ListXpnHosts.
                     * @param request ListXpnHostsProjectsRequest message or plain object
                     * @returns Promise
                     */
                    public listXpnHosts(request: google.cloud.compute.v1.IListXpnHostsProjectsRequest): Promise<google.cloud.compute.v1.XpnHostList>;

                    /**
                     * Calls MoveDisk.
                     * @param request MoveDiskProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public moveDisk(request: google.cloud.compute.v1.IMoveDiskProjectRequest, callback: google.cloud.compute.v1.Projects.MoveDiskCallback): void;

                    /**
                     * Calls MoveDisk.
                     * @param request MoveDiskProjectRequest message or plain object
                     * @returns Promise
                     */
                    public moveDisk(request: google.cloud.compute.v1.IMoveDiskProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls MoveInstance.
                     * @param request MoveInstanceProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public moveInstance(request: google.cloud.compute.v1.IMoveInstanceProjectRequest, callback: google.cloud.compute.v1.Projects.MoveInstanceCallback): void;

                    /**
                     * Calls MoveInstance.
                     * @param request MoveInstanceProjectRequest message or plain object
                     * @returns Promise
                     */
                    public moveInstance(request: google.cloud.compute.v1.IMoveInstanceProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetCommonInstanceMetadata.
                     * @param request SetCommonInstanceMetadataProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setCommonInstanceMetadata(request: google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest, callback: google.cloud.compute.v1.Projects.SetCommonInstanceMetadataCallback): void;

                    /**
                     * Calls SetCommonInstanceMetadata.
                     * @param request SetCommonInstanceMetadataProjectRequest message or plain object
                     * @returns Promise
                     */
                    public setCommonInstanceMetadata(request: google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetDefaultNetworkTier.
                     * @param request SetDefaultNetworkTierProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setDefaultNetworkTier(request: google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest, callback: google.cloud.compute.v1.Projects.SetDefaultNetworkTierCallback): void;

                    /**
                     * Calls SetDefaultNetworkTier.
                     * @param request SetDefaultNetworkTierProjectRequest message or plain object
                     * @returns Promise
                     */
                    public setDefaultNetworkTier(request: google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetUsageExportBucket.
                     * @param request SetUsageExportBucketProjectRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setUsageExportBucket(request: google.cloud.compute.v1.ISetUsageExportBucketProjectRequest, callback: google.cloud.compute.v1.Projects.SetUsageExportBucketCallback): void;

                    /**
                     * Calls SetUsageExportBucket.
                     * @param request SetUsageExportBucketProjectRequest message or plain object
                     * @returns Promise
                     */
                    public setUsageExportBucket(request: google.cloud.compute.v1.ISetUsageExportBucketProjectRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Projects {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|disableXpnHost}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DisableXpnHostCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|disableXpnResource}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DisableXpnResourceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|enableXpnHost}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type EnableXpnHostCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|enableXpnResource}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type EnableXpnResourceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|get}.
                     * @param error Error, if any
                     * @param [response] Project
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Project) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|getXpnHost}.
                     * @param error Error, if any
                     * @param [response] Project
                     */
                    type GetXpnHostCallback = (error: (Error|null), response?: google.cloud.compute.v1.Project) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|getXpnResources}.
                     * @param error Error, if any
                     * @param [response] ProjectsGetXpnResources
                     */
                    type GetXpnResourcesCallback = (error: (Error|null), response?: google.cloud.compute.v1.ProjectsGetXpnResources) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|listXpnHosts}.
                     * @param error Error, if any
                     * @param [response] XpnHostList
                     */
                    type ListXpnHostsCallback = (error: (Error|null), response?: google.cloud.compute.v1.XpnHostList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|moveDisk}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type MoveDiskCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|moveInstance}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type MoveInstanceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|setCommonInstanceMetadata}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetCommonInstanceMetadataCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|setDefaultNetworkTier}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetDefaultNetworkTierCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Projects|setUsageExportBucket}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetUsageExportBucketCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a PublicAdvertisedPrefixes */
                class PublicAdvertisedPrefixes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new PublicAdvertisedPrefixes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new PublicAdvertisedPrefixes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): PublicAdvertisedPrefixes;

                    /**
                     * Calls Delete.
                     * @param request DeletePublicAdvertisedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeletePublicAdvertisedPrefixeRequest, callback: google.cloud.compute.v1.PublicAdvertisedPrefixes.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeletePublicAdvertisedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeletePublicAdvertisedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetPublicAdvertisedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicAdvertisedPrefix
                     */
                    public get(request: google.cloud.compute.v1.IGetPublicAdvertisedPrefixeRequest, callback: google.cloud.compute.v1.PublicAdvertisedPrefixes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetPublicAdvertisedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetPublicAdvertisedPrefixeRequest): Promise<google.cloud.compute.v1.PublicAdvertisedPrefix>;

                    /**
                     * Calls Insert.
                     * @param request InsertPublicAdvertisedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertPublicAdvertisedPrefixeRequest, callback: google.cloud.compute.v1.PublicAdvertisedPrefixes.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertPublicAdvertisedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertPublicAdvertisedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListPublicAdvertisedPrefixesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicAdvertisedPrefixList
                     */
                    public list(request: google.cloud.compute.v1.IListPublicAdvertisedPrefixesRequest, callback: google.cloud.compute.v1.PublicAdvertisedPrefixes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListPublicAdvertisedPrefixesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListPublicAdvertisedPrefixesRequest): Promise<google.cloud.compute.v1.PublicAdvertisedPrefixList>;

                    /**
                     * Calls Patch.
                     * @param request PatchPublicAdvertisedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchPublicAdvertisedPrefixeRequest, callback: google.cloud.compute.v1.PublicAdvertisedPrefixes.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchPublicAdvertisedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchPublicAdvertisedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace PublicAdvertisedPrefixes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicAdvertisedPrefixes|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicAdvertisedPrefixes|get}.
                     * @param error Error, if any
                     * @param [response] PublicAdvertisedPrefix
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicAdvertisedPrefix) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicAdvertisedPrefixes|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicAdvertisedPrefixes|list}.
                     * @param error Error, if any
                     * @param [response] PublicAdvertisedPrefixList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicAdvertisedPrefixList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicAdvertisedPrefixes|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a PublicDelegatedPrefixes */
                class PublicDelegatedPrefixes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new PublicDelegatedPrefixes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new PublicDelegatedPrefixes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): PublicDelegatedPrefixes;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListPublicDelegatedPrefixesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicDelegatedPrefixAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListPublicDelegatedPrefixesRequest, callback: google.cloud.compute.v1.PublicDelegatedPrefixes.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListPublicDelegatedPrefixesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListPublicDelegatedPrefixesRequest): Promise<google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeletePublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeletePublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.PublicDelegatedPrefixes.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeletePublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeletePublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicDelegatedPrefix
                     */
                    public get(request: google.cloud.compute.v1.IGetPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.PublicDelegatedPrefixes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.PublicDelegatedPrefix>;

                    /**
                     * Calls Insert.
                     * @param request InsertPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.PublicDelegatedPrefixes.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListPublicDelegatedPrefixesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and PublicDelegatedPrefixList
                     */
                    public list(request: google.cloud.compute.v1.IListPublicDelegatedPrefixesRequest, callback: google.cloud.compute.v1.PublicDelegatedPrefixes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListPublicDelegatedPrefixesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListPublicDelegatedPrefixesRequest): Promise<google.cloud.compute.v1.PublicDelegatedPrefixList>;

                    /**
                     * Calls Patch.
                     * @param request PatchPublicDelegatedPrefixeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchPublicDelegatedPrefixeRequest, callback: google.cloud.compute.v1.PublicDelegatedPrefixes.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchPublicDelegatedPrefixeRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchPublicDelegatedPrefixeRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace PublicDelegatedPrefixes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicDelegatedPrefixes|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] PublicDelegatedPrefixAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicDelegatedPrefixAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicDelegatedPrefixes|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicDelegatedPrefixes|get}.
                     * @param error Error, if any
                     * @param [response] PublicDelegatedPrefix
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicDelegatedPrefix) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicDelegatedPrefixes|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicDelegatedPrefixes|list}.
                     * @param error Error, if any
                     * @param [response] PublicDelegatedPrefixList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.PublicDelegatedPrefixList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.PublicDelegatedPrefixes|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionAutoscalers */
                class RegionAutoscalers extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionAutoscalers service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionAutoscalers service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionAutoscalers;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionAutoscalerRequest, callback: google.cloud.compute.v1.RegionAutoscalers.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Autoscaler
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionAutoscalerRequest, callback: google.cloud.compute.v1.RegionAutoscalers.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionAutoscalerRequest): Promise<google.cloud.compute.v1.Autoscaler>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionAutoscalerRequest, callback: google.cloud.compute.v1.RegionAutoscalers.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionAutoscalersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionAutoscalerList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionAutoscalersRequest, callback: google.cloud.compute.v1.RegionAutoscalers.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionAutoscalersRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionAutoscalersRequest): Promise<google.cloud.compute.v1.RegionAutoscalerList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionAutoscalerRequest, callback: google.cloud.compute.v1.RegionAutoscalers.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionAutoscalerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionAutoscalerRequest, callback: google.cloud.compute.v1.RegionAutoscalers.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionAutoscalerRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionAutoscalerRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionAutoscalers {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionAutoscalers|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionAutoscalers|get}.
                     * @param error Error, if any
                     * @param [response] Autoscaler
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Autoscaler) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionAutoscalers|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionAutoscalers|list}.
                     * @param error Error, if any
                     * @param [response] RegionAutoscalerList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionAutoscalerList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionAutoscalers|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionAutoscalers|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionBackendServices */
                class RegionBackendServices extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionBackendServices service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionBackendServices service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionBackendServices;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendService
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionBackendServiceRequest): Promise<google.cloud.compute.v1.BackendService>;

                    /**
                     * Calls GetHealth.
                     * @param request GetHealthRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendServiceGroupHealth
                     */
                    public getHealth(request: google.cloud.compute.v1.IGetHealthRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.GetHealthCallback): void;

                    /**
                     * Calls GetHealth.
                     * @param request GetHealthRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public getHealth(request: google.cloud.compute.v1.IGetHealthRegionBackendServiceRequest): Promise<google.cloud.compute.v1.BackendServiceGroupHealth>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyRegionBackendServiceRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionBackendServicesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and BackendServiceList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionBackendServicesRequest, callback: google.cloud.compute.v1.RegionBackendServices.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionBackendServicesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionBackendServicesRequest): Promise<google.cloud.compute.v1.BackendServiceList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyRegionBackendServiceRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionBackendServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionBackendServiceRequest, callback: google.cloud.compute.v1.RegionBackendServices.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionBackendServiceRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionBackendServiceRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionBackendServices {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|get}.
                     * @param error Error, if any
                     * @param [response] BackendService
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendService) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|getHealth}.
                     * @param error Error, if any
                     * @param [response] BackendServiceGroupHealth
                     */
                    type GetHealthCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendServiceGroupHealth) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|list}.
                     * @param error Error, if any
                     * @param [response] BackendServiceList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.BackendServiceList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionBackendServices|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionCommitments */
                class RegionCommitments extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionCommitments service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionCommitments service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionCommitments;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListRegionCommitmentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and CommitmentAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListRegionCommitmentsRequest, callback: google.cloud.compute.v1.RegionCommitments.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListRegionCommitmentsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListRegionCommitmentsRequest): Promise<google.cloud.compute.v1.CommitmentAggregatedList>;

                    /**
                     * Calls Get.
                     * @param request GetRegionCommitmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Commitment
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionCommitmentRequest, callback: google.cloud.compute.v1.RegionCommitments.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionCommitmentRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionCommitmentRequest): Promise<google.cloud.compute.v1.Commitment>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionCommitmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionCommitmentRequest, callback: google.cloud.compute.v1.RegionCommitments.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionCommitmentRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionCommitmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionCommitmentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and CommitmentList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionCommitmentsRequest, callback: google.cloud.compute.v1.RegionCommitments.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionCommitmentsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionCommitmentsRequest): Promise<google.cloud.compute.v1.CommitmentList>;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionCommitmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionCommitmentRequest, callback: google.cloud.compute.v1.RegionCommitments.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionCommitmentRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionCommitmentRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionCommitments {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionCommitments|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] CommitmentAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.CommitmentAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionCommitments|get}.
                     * @param error Error, if any
                     * @param [response] Commitment
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Commitment) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionCommitments|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionCommitments|list}.
                     * @param error Error, if any
                     * @param [response] CommitmentList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.CommitmentList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionCommitments|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionDiskTypes */
                class RegionDiskTypes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionDiskTypes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionDiskTypes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionDiskTypes;

                    /**
                     * Calls Get.
                     * @param request GetRegionDiskTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskType
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionDiskTypeRequest, callback: google.cloud.compute.v1.RegionDiskTypes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionDiskTypeRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionDiskTypeRequest): Promise<google.cloud.compute.v1.DiskType>;

                    /**
                     * Calls List.
                     * @param request ListRegionDiskTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionDiskTypeList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionDiskTypesRequest, callback: google.cloud.compute.v1.RegionDiskTypes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionDiskTypesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionDiskTypesRequest): Promise<google.cloud.compute.v1.RegionDiskTypeList>;
                }

                namespace RegionDiskTypes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDiskTypes|get}.
                     * @param error Error, if any
                     * @param [response] DiskType
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskType) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDiskTypes|list}.
                     * @param error Error, if any
                     * @param [response] RegionDiskTypeList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionDiskTypeList) => void;
                }

                /** Represents a RegionDisks */
                class RegionDisks extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionDisks service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionDisks service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionDisks;

                    /**
                     * Calls AddResourcePolicies.
                     * @param request AddResourcePoliciesRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addResourcePolicies(request: google.cloud.compute.v1.IAddResourcePoliciesRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.AddResourcePoliciesCallback): void;

                    /**
                     * Calls AddResourcePolicies.
                     * @param request AddResourcePoliciesRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public addResourcePolicies(request: google.cloud.compute.v1.IAddResourcePoliciesRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls CreateSnapshot.
                     * @param request CreateSnapshotRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public createSnapshot(request: google.cloud.compute.v1.ICreateSnapshotRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.CreateSnapshotCallback): void;

                    /**
                     * Calls CreateSnapshot.
                     * @param request CreateSnapshotRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public createSnapshot(request: google.cloud.compute.v1.ICreateSnapshotRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Disk
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionDiskRequest): Promise<google.cloud.compute.v1.Disk>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyRegionDiskRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionDisksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DiskList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionDisksRequest, callback: google.cloud.compute.v1.RegionDisks.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionDisksRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionDisksRequest): Promise<google.cloud.compute.v1.DiskList>;

                    /**
                     * Calls RemoveResourcePolicies.
                     * @param request RemoveResourcePoliciesRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeResourcePolicies(request: google.cloud.compute.v1.IRemoveResourcePoliciesRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.RemoveResourcePoliciesCallback): void;

                    /**
                     * Calls RemoveResourcePolicies.
                     * @param request RemoveResourcePoliciesRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public removeResourcePolicies(request: google.cloud.compute.v1.IRemoveResourcePoliciesRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Resize.
                     * @param request ResizeRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public resize(request: google.cloud.compute.v1.IResizeRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.ResizeCallback): void;

                    /**
                     * Calls Resize.
                     * @param request ResizeRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public resize(request: google.cloud.compute.v1.IResizeRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyRegionDiskRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsRegionDiskRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsRegionDiskRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsRegionDiskRequest, callback: google.cloud.compute.v1.RegionDisks.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsRegionDiskRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsRegionDiskRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace RegionDisks {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|addResourcePolicies}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddResourcePoliciesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|createSnapshot}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CreateSnapshotCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|get}.
                     * @param error Error, if any
                     * @param [response] Disk
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Disk) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|list}.
                     * @param error Error, if any
                     * @param [response] DiskList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.DiskList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|removeResourcePolicies}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveResourcePoliciesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|resize}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResizeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionDisks|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a RegionHealthCheckServices */
                class RegionHealthCheckServices extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionHealthCheckServices service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionHealthCheckServices service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionHealthCheckServices;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionHealthCheckServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionHealthCheckServiceRequest, callback: google.cloud.compute.v1.RegionHealthCheckServices.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionHealthCheckServiceRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionHealthCheckServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionHealthCheckServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthCheckService
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionHealthCheckServiceRequest, callback: google.cloud.compute.v1.RegionHealthCheckServices.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionHealthCheckServiceRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionHealthCheckServiceRequest): Promise<google.cloud.compute.v1.HealthCheckService>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionHealthCheckServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionHealthCheckServiceRequest, callback: google.cloud.compute.v1.RegionHealthCheckServices.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionHealthCheckServiceRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionHealthCheckServiceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionHealthCheckServicesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthCheckServicesList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionHealthCheckServicesRequest, callback: google.cloud.compute.v1.RegionHealthCheckServices.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionHealthCheckServicesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionHealthCheckServicesRequest): Promise<google.cloud.compute.v1.HealthCheckServicesList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionHealthCheckServiceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionHealthCheckServiceRequest, callback: google.cloud.compute.v1.RegionHealthCheckServices.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionHealthCheckServiceRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionHealthCheckServiceRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionHealthCheckServices {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthCheckServices|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthCheckServices|get}.
                     * @param error Error, if any
                     * @param [response] HealthCheckService
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthCheckService) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthCheckServices|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthCheckServices|list}.
                     * @param error Error, if any
                     * @param [response] HealthCheckServicesList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthCheckServicesList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthCheckServices|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionHealthChecks */
                class RegionHealthChecks extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionHealthChecks service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionHealthChecks service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionHealthChecks;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionHealthCheckRequest, callback: google.cloud.compute.v1.RegionHealthChecks.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthCheck
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionHealthCheckRequest, callback: google.cloud.compute.v1.RegionHealthChecks.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionHealthCheckRequest): Promise<google.cloud.compute.v1.HealthCheck>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionHealthCheckRequest, callback: google.cloud.compute.v1.RegionHealthChecks.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionHealthChecksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and HealthCheckList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionHealthChecksRequest, callback: google.cloud.compute.v1.RegionHealthChecks.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionHealthChecksRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionHealthChecksRequest): Promise<google.cloud.compute.v1.HealthCheckList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionHealthCheckRequest, callback: google.cloud.compute.v1.RegionHealthChecks.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionHealthCheckRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionHealthCheckRequest, callback: google.cloud.compute.v1.RegionHealthChecks.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionHealthCheckRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionHealthCheckRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionHealthChecks {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthChecks|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthChecks|get}.
                     * @param error Error, if any
                     * @param [response] HealthCheck
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthCheck) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthChecks|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthChecks|list}.
                     * @param error Error, if any
                     * @param [response] HealthCheckList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.HealthCheckList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthChecks|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionHealthChecks|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionInstanceGroupManagers */
                class RegionInstanceGroupManagers extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionInstanceGroupManagers service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionInstanceGroupManagers service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionInstanceGroupManagers;

                    /**
                     * Calls AbandonInstances.
                     * @param request AbandonInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public abandonInstances(request: google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.AbandonInstancesCallback): void;

                    /**
                     * Calls AbandonInstances.
                     * @param request AbandonInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public abandonInstances(request: google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls ApplyUpdatesToInstances.
                     * @param request ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public applyUpdatesToInstances(request: google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.ApplyUpdatesToInstancesCallback): void;

                    /**
                     * Calls ApplyUpdatesToInstances.
                     * @param request ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public applyUpdatesToInstances(request: google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls CreateInstances.
                     * @param request CreateInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public createInstances(request: google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.CreateInstancesCallback): void;

                    /**
                     * Calls CreateInstances.
                     * @param request CreateInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public createInstances(request: google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeleteInstances.
                     * @param request DeleteInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteInstances(request: google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.DeleteInstancesCallback): void;

                    /**
                     * Calls DeleteInstances.
                     * @param request DeleteInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public deleteInstances(request: google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls DeletePerInstanceConfigs.
                     * @param request DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deletePerInstanceConfigs(request: google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.DeletePerInstanceConfigsCallback): void;

                    /**
                     * Calls DeletePerInstanceConfigs.
                     * @param request DeletePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public deletePerInstanceConfigs(request: google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroupManager
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.InstanceGroupManager>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionInstanceGroupManagerList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.RegionInstanceGroupManagerList>;

                    /**
                     * Calls ListErrors.
                     * @param request ListErrorsRegionInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionInstanceGroupManagersListErrorsResponse
                     */
                    public listErrors(request: google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.ListErrorsCallback): void;

                    /**
                     * Calls ListErrors.
                     * @param request ListErrorsRegionInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public listErrors(request: google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse>;

                    /**
                     * Calls ListManagedInstances.
                     * @param request ListManagedInstancesRegionInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionInstanceGroupManagersListInstancesResponse
                     */
                    public listManagedInstances(request: google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.ListManagedInstancesCallback): void;

                    /**
                     * Calls ListManagedInstances.
                     * @param request ListManagedInstancesRegionInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public listManagedInstances(request: google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse>;

                    /**
                     * Calls ListPerInstanceConfigs.
                     * @param request ListPerInstanceConfigsRegionInstanceGroupManagersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionInstanceGroupManagersListInstanceConfigsResp
                     */
                    public listPerInstanceConfigs(request: google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.ListPerInstanceConfigsCallback): void;

                    /**
                     * Calls ListPerInstanceConfigs.
                     * @param request ListPerInstanceConfigsRegionInstanceGroupManagersRequest message or plain object
                     * @returns Promise
                     */
                    public listPerInstanceConfigs(request: google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest): Promise<google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls PatchPerInstanceConfigs.
                     * @param request PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patchPerInstanceConfigs(request: google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.PatchPerInstanceConfigsCallback): void;

                    /**
                     * Calls PatchPerInstanceConfigs.
                     * @param request PatchPerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public patchPerInstanceConfigs(request: google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RecreateInstances.
                     * @param request RecreateInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public recreateInstances(request: google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.RecreateInstancesCallback): void;

                    /**
                     * Calls RecreateInstances.
                     * @param request RecreateInstancesRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public recreateInstances(request: google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Resize.
                     * @param request ResizeRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public resize(request: google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.ResizeCallback): void;

                    /**
                     * Calls Resize.
                     * @param request ResizeRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public resize(request: google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetInstanceTemplate.
                     * @param request SetInstanceTemplateRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setInstanceTemplate(request: google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.SetInstanceTemplateCallback): void;

                    /**
                     * Calls SetInstanceTemplate.
                     * @param request SetInstanceTemplateRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public setInstanceTemplate(request: google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetTargetPools.
                     * @param request SetTargetPoolsRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setTargetPools(request: google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.SetTargetPoolsCallback): void;

                    /**
                     * Calls SetTargetPools.
                     * @param request SetTargetPoolsRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public setTargetPools(request: google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls UpdatePerInstanceConfigs.
                     * @param request UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updatePerInstanceConfigs(request: google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, callback: google.cloud.compute.v1.RegionInstanceGroupManagers.UpdatePerInstanceConfigsCallback): void;

                    /**
                     * Calls UpdatePerInstanceConfigs.
                     * @param request UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest message or plain object
                     * @returns Promise
                     */
                    public updatePerInstanceConfigs(request: google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionInstanceGroupManagers {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|abandonInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AbandonInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|applyUpdatesToInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ApplyUpdatesToInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|createInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CreateInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|deleteInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|deletePerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeletePerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|get}.
                     * @param error Error, if any
                     * @param [response] InstanceGroupManager
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroupManager) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|list}.
                     * @param error Error, if any
                     * @param [response] RegionInstanceGroupManagerList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionInstanceGroupManagerList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|listErrors}.
                     * @param error Error, if any
                     * @param [response] RegionInstanceGroupManagersListErrorsResponse
                     */
                    type ListErrorsCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionInstanceGroupManagersListErrorsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|listManagedInstances}.
                     * @param error Error, if any
                     * @param [response] RegionInstanceGroupManagersListInstancesResponse
                     */
                    type ListManagedInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionInstanceGroupManagersListInstancesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|listPerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] RegionInstanceGroupManagersListInstanceConfigsResp
                     */
                    type ListPerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionInstanceGroupManagersListInstanceConfigsResp) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|patchPerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchPerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|recreateInstances}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RecreateInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|resize}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResizeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|setInstanceTemplate}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetInstanceTemplateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|setTargetPools}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetTargetPoolsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroupManagers|updatePerInstanceConfigs}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdatePerInstanceConfigsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionInstanceGroups */
                class RegionInstanceGroups extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionInstanceGroups service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionInstanceGroups service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionInstanceGroups;

                    /**
                     * Calls Get.
                     * @param request GetRegionInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and InstanceGroup
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionInstanceGroupRequest, callback: google.cloud.compute.v1.RegionInstanceGroups.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionInstanceGroupRequest): Promise<google.cloud.compute.v1.InstanceGroup>;

                    /**
                     * Calls List.
                     * @param request ListRegionInstanceGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionInstanceGroupList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionInstanceGroupsRequest, callback: google.cloud.compute.v1.RegionInstanceGroups.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionInstanceGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionInstanceGroupsRequest): Promise<google.cloud.compute.v1.RegionInstanceGroupList>;

                    /**
                     * Calls ListInstances.
                     * @param request ListInstancesRegionInstanceGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionInstanceGroupsListInstances
                     */
                    public listInstances(request: google.cloud.compute.v1.IListInstancesRegionInstanceGroupsRequest, callback: google.cloud.compute.v1.RegionInstanceGroups.ListInstancesCallback): void;

                    /**
                     * Calls ListInstances.
                     * @param request ListInstancesRegionInstanceGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public listInstances(request: google.cloud.compute.v1.IListInstancesRegionInstanceGroupsRequest): Promise<google.cloud.compute.v1.RegionInstanceGroupsListInstances>;

                    /**
                     * Calls SetNamedPorts.
                     * @param request SetNamedPortsRegionInstanceGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setNamedPorts(request: google.cloud.compute.v1.ISetNamedPortsRegionInstanceGroupRequest, callback: google.cloud.compute.v1.RegionInstanceGroups.SetNamedPortsCallback): void;

                    /**
                     * Calls SetNamedPorts.
                     * @param request SetNamedPortsRegionInstanceGroupRequest message or plain object
                     * @returns Promise
                     */
                    public setNamedPorts(request: google.cloud.compute.v1.ISetNamedPortsRegionInstanceGroupRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionInstanceGroups {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroups|get}.
                     * @param error Error, if any
                     * @param [response] InstanceGroup
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.InstanceGroup) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroups|list}.
                     * @param error Error, if any
                     * @param [response] RegionInstanceGroupList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionInstanceGroupList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroups|listInstances}.
                     * @param error Error, if any
                     * @param [response] RegionInstanceGroupsListInstances
                     */
                    type ListInstancesCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionInstanceGroupsListInstances) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstanceGroups|setNamedPorts}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetNamedPortsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionInstances */
                class RegionInstances extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionInstances service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionInstances service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionInstances;

                    /**
                     * Calls BulkInsert.
                     * @param request BulkInsertRegionInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public bulkInsert(request: google.cloud.compute.v1.IBulkInsertRegionInstanceRequest, callback: google.cloud.compute.v1.RegionInstances.BulkInsertCallback): void;

                    /**
                     * Calls BulkInsert.
                     * @param request BulkInsertRegionInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public bulkInsert(request: google.cloud.compute.v1.IBulkInsertRegionInstanceRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionInstances {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionInstances|bulkInsert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BulkInsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionNetworkEndpointGroups */
                class RegionNetworkEndpointGroups extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionNetworkEndpointGroups service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionNetworkEndpointGroups service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionNetworkEndpointGroups;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.RegionNetworkEndpointGroups.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroup
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.RegionNetworkEndpointGroups.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroup>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionNetworkEndpointGroupRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionNetworkEndpointGroupRequest, callback: google.cloud.compute.v1.RegionNetworkEndpointGroups.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionNetworkEndpointGroupRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionNetworkEndpointGroupRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionNetworkEndpointGroupsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NetworkEndpointGroupList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionNetworkEndpointGroupsRequest, callback: google.cloud.compute.v1.RegionNetworkEndpointGroups.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionNetworkEndpointGroupsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionNetworkEndpointGroupsRequest): Promise<google.cloud.compute.v1.NetworkEndpointGroupList>;
                }

                namespace RegionNetworkEndpointGroups {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkEndpointGroups|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkEndpointGroups|get}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroup
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroup) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkEndpointGroups|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkEndpointGroups|list}.
                     * @param error Error, if any
                     * @param [response] NetworkEndpointGroupList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NetworkEndpointGroupList) => void;
                }

                /** Represents a RegionNetworkFirewallPolicies */
                class RegionNetworkFirewallPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionNetworkFirewallPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionNetworkFirewallPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionNetworkFirewallPolicies;

                    /**
                     * Calls AddAssociation.
                     * @param request AddAssociationRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addAssociation(request: google.cloud.compute.v1.IAddAssociationRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.AddAssociationCallback): void;

                    /**
                     * Calls AddAssociation.
                     * @param request AddAssociationRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addAssociation(request: google.cloud.compute.v1.IAddAssociationRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.AddRuleCallback): void;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls CloneRules.
                     * @param request CloneRulesRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public cloneRules(request: google.cloud.compute.v1.ICloneRulesRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.CloneRulesCallback): void;

                    /**
                     * Calls CloneRules.
                     * @param request CloneRulesRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public cloneRules(request: google.cloud.compute.v1.ICloneRulesRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicy>;

                    /**
                     * Calls GetAssociation.
                     * @param request GetAssociationRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyAssociation
                     */
                    public getAssociation(request: google.cloud.compute.v1.IGetAssociationRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.GetAssociationCallback): void;

                    /**
                     * Calls GetAssociation.
                     * @param request GetAssociationRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getAssociation(request: google.cloud.compute.v1.IGetAssociationRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicyAssociation>;

                    /**
                     * Calls GetEffectiveFirewalls.
                     * @param request GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     */
                    public getEffectiveFirewalls(request: google.cloud.compute.v1.IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.GetEffectiveFirewallsCallback): void;

                    /**
                     * Calls GetEffectiveFirewalls.
                     * @param request GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getEffectiveFirewalls(request: google.cloud.compute.v1.IGetEffectiveFirewallsRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyRule
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.GetRuleCallback): void;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.FirewallPolicyRule>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionNetworkFirewallPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FirewallPolicyList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionNetworkFirewallPoliciesRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionNetworkFirewallPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionNetworkFirewallPoliciesRequest): Promise<google.cloud.compute.v1.FirewallPolicyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.PatchRuleCallback): void;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveAssociation.
                     * @param request RemoveAssociationRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeAssociation(request: google.cloud.compute.v1.IRemoveAssociationRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.RemoveAssociationCallback): void;

                    /**
                     * Calls RemoveAssociation.
                     * @param request RemoveAssociationRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeAssociation(request: google.cloud.compute.v1.IRemoveAssociationRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.RemoveRuleCallback): void;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsRegionNetworkFirewallPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsRegionNetworkFirewallPolicyRequest, callback: google.cloud.compute.v1.RegionNetworkFirewallPolicies.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsRegionNetworkFirewallPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsRegionNetworkFirewallPolicyRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace RegionNetworkFirewallPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|addAssociation}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|addRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|cloneRules}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type CloneRulesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|get}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|getAssociation}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyAssociation
                     */
                    type GetAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyAssociation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|getEffectiveFirewalls}.
                     * @param error Error, if any
                     * @param [response] RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
                     */
                    type GetEffectiveFirewallsCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|getRule}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyRule
                     */
                    type GetRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyRule) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|list}.
                     * @param error Error, if any
                     * @param [response] FirewallPolicyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.FirewallPolicyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|patchRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|removeAssociation}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveAssociationCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|removeRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNetworkFirewallPolicies|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a RegionNotificationEndpoints */
                class RegionNotificationEndpoints extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionNotificationEndpoints service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionNotificationEndpoints service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionNotificationEndpoints;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionNotificationEndpointRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionNotificationEndpointRequest, callback: google.cloud.compute.v1.RegionNotificationEndpoints.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionNotificationEndpointRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionNotificationEndpointRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionNotificationEndpointRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NotificationEndpoint
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionNotificationEndpointRequest, callback: google.cloud.compute.v1.RegionNotificationEndpoints.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionNotificationEndpointRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionNotificationEndpointRequest): Promise<google.cloud.compute.v1.NotificationEndpoint>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionNotificationEndpointRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionNotificationEndpointRequest, callback: google.cloud.compute.v1.RegionNotificationEndpoints.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionNotificationEndpointRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionNotificationEndpointRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionNotificationEndpointsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and NotificationEndpointList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionNotificationEndpointsRequest, callback: google.cloud.compute.v1.RegionNotificationEndpoints.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionNotificationEndpointsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionNotificationEndpointsRequest): Promise<google.cloud.compute.v1.NotificationEndpointList>;
                }

                namespace RegionNotificationEndpoints {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNotificationEndpoints|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNotificationEndpoints|get}.
                     * @param error Error, if any
                     * @param [response] NotificationEndpoint
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.NotificationEndpoint) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNotificationEndpoints|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionNotificationEndpoints|list}.
                     * @param error Error, if any
                     * @param [response] NotificationEndpointList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.NotificationEndpointList) => void;
                }

                /** Represents a RegionOperations */
                class RegionOperations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionOperations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionOperations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionOperations;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DeleteRegionOperationResponse
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionOperationRequest, callback: google.cloud.compute.v1.RegionOperations.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionOperationRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionOperationRequest): Promise<google.cloud.compute.v1.DeleteRegionOperationResponse>;

                    /**
                     * Calls Get.
                     * @param request GetRegionOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionOperationRequest, callback: google.cloud.compute.v1.RegionOperations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionOperationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionOperationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionOperationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and OperationList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionOperationsRequest, callback: google.cloud.compute.v1.RegionOperations.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionOperationsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionOperationsRequest): Promise<google.cloud.compute.v1.OperationList>;

                    /**
                     * Calls Wait.
                     * @param request WaitRegionOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public wait(request: google.cloud.compute.v1.IWaitRegionOperationRequest, callback: google.cloud.compute.v1.RegionOperations.WaitCallback): void;

                    /**
                     * Calls Wait.
                     * @param request WaitRegionOperationRequest message or plain object
                     * @returns Promise
                     */
                    public wait(request: google.cloud.compute.v1.IWaitRegionOperationRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionOperations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionOperations|delete_}.
                     * @param error Error, if any
                     * @param [response] DeleteRegionOperationResponse
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.DeleteRegionOperationResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionOperations|get}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionOperations|list}.
                     * @param error Error, if any
                     * @param [response] OperationList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.OperationList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionOperations|wait}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type WaitCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionSecurityPolicies */
                class RegionSecurityPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionSecurityPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionSecurityPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionSecurityPolicies;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionSecurityPolicyRequest, callback: google.cloud.compute.v1.RegionSecurityPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionSecurityPolicyRequest, callback: google.cloud.compute.v1.RegionSecurityPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionSecurityPolicyRequest): Promise<google.cloud.compute.v1.SecurityPolicy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionSecurityPolicyRequest, callback: google.cloud.compute.v1.RegionSecurityPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionSecurityPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPolicyList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionSecurityPoliciesRequest, callback: google.cloud.compute.v1.RegionSecurityPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionSecurityPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionSecurityPoliciesRequest): Promise<google.cloud.compute.v1.SecurityPolicyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionSecurityPolicyRequest, callback: google.cloud.compute.v1.RegionSecurityPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionSecurityPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSecurityPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSecurityPolicies|get}.
                     * @param error Error, if any
                     * @param [response] SecurityPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSecurityPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSecurityPolicies|list}.
                     * @param error Error, if any
                     * @param [response] SecurityPolicyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPolicyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSecurityPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionSslCertificates */
                class RegionSslCertificates extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionSslCertificates service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionSslCertificates service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionSslCertificates;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionSslCertificateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionSslCertificateRequest, callback: google.cloud.compute.v1.RegionSslCertificates.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionSslCertificateRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionSslCertificateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionSslCertificateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslCertificate
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionSslCertificateRequest, callback: google.cloud.compute.v1.RegionSslCertificates.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionSslCertificateRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionSslCertificateRequest): Promise<google.cloud.compute.v1.SslCertificate>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionSslCertificateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionSslCertificateRequest, callback: google.cloud.compute.v1.RegionSslCertificates.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionSslCertificateRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionSslCertificateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionSslCertificatesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslCertificateList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionSslCertificatesRequest, callback: google.cloud.compute.v1.RegionSslCertificates.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionSslCertificatesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionSslCertificatesRequest): Promise<google.cloud.compute.v1.SslCertificateList>;
                }

                namespace RegionSslCertificates {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslCertificates|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslCertificates|get}.
                     * @param error Error, if any
                     * @param [response] SslCertificate
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslCertificate) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslCertificates|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslCertificates|list}.
                     * @param error Error, if any
                     * @param [response] SslCertificateList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslCertificateList) => void;
                }

                /** Represents a RegionSslPolicies */
                class RegionSslPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionSslPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionSslPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionSslPolicies;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionSslPolicyRequest, callback: google.cloud.compute.v1.RegionSslPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionSslPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionSslPolicyRequest, callback: google.cloud.compute.v1.RegionSslPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionSslPolicyRequest): Promise<google.cloud.compute.v1.SslPolicy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionSslPolicyRequest, callback: google.cloud.compute.v1.RegionSslPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionSslPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionSslPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPoliciesList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionSslPoliciesRequest, callback: google.cloud.compute.v1.RegionSslPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionSslPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionSslPoliciesRequest): Promise<google.cloud.compute.v1.SslPoliciesList>;

                    /**
                     * Calls ListAvailableFeatures.
                     * @param request ListAvailableFeaturesRegionSslPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPoliciesListAvailableFeaturesResponse
                     */
                    public listAvailableFeatures(request: google.cloud.compute.v1.IListAvailableFeaturesRegionSslPoliciesRequest, callback: google.cloud.compute.v1.RegionSslPolicies.ListAvailableFeaturesCallback): void;

                    /**
                     * Calls ListAvailableFeatures.
                     * @param request ListAvailableFeaturesRegionSslPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public listAvailableFeatures(request: google.cloud.compute.v1.IListAvailableFeaturesRegionSslPoliciesRequest): Promise<google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionSslPolicyRequest, callback: google.cloud.compute.v1.RegionSslPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionSslPolicyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionSslPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslPolicies|get}.
                     * @param error Error, if any
                     * @param [response] SslPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslPolicies|list}.
                     * @param error Error, if any
                     * @param [response] SslPoliciesList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPoliciesList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslPolicies|listAvailableFeatures}.
                     * @param error Error, if any
                     * @param [response] SslPoliciesListAvailableFeaturesResponse
                     */
                    type ListAvailableFeaturesCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionSslPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionTargetHttpProxies */
                class RegionTargetHttpProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionTargetHttpProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionTargetHttpProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionTargetHttpProxies;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionTargetHttpProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionTargetHttpProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionTargetHttpProxyRequest): Promise<google.cloud.compute.v1.TargetHttpProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionTargetHttpProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionTargetHttpProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionTargetHttpProxiesRequest, callback: google.cloud.compute.v1.RegionTargetHttpProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionTargetHttpProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionTargetHttpProxiesRequest): Promise<google.cloud.compute.v1.TargetHttpProxyList>;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapRegionTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpProxies.SetUrlMapCallback): void;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapRegionTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionTargetHttpProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetHttpProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetHttpProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpProxies|setUrlMap}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetUrlMapCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionTargetHttpsProxies */
                class RegionTargetHttpsProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionTargetHttpsProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionTargetHttpsProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionTargetHttpsProxies;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionTargetHttpsProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpsProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionTargetHttpsProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.TargetHttpsProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionTargetHttpsProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionTargetHttpsProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpsProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionTargetHttpsProxiesRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionTargetHttpsProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionTargetHttpsProxiesRequest): Promise<google.cloud.compute.v1.TargetHttpsProxyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionTargetHttpsProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetSslCertificates.
                     * @param request SetSslCertificatesRegionTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setSslCertificates(request: google.cloud.compute.v1.ISetSslCertificatesRegionTargetHttpsProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.SetSslCertificatesCallback): void;

                    /**
                     * Calls SetSslCertificates.
                     * @param request SetSslCertificatesRegionTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setSslCertificates(request: google.cloud.compute.v1.ISetSslCertificatesRegionTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapRegionTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpsProxyRequest, callback: google.cloud.compute.v1.RegionTargetHttpsProxies.SetUrlMapCallback): void;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapRegionTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapRegionTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace RegionTargetHttpsProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetHttpsProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpsProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetHttpsProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpsProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|setSslCertificates}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSslCertificatesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetHttpsProxies|setUrlMap}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetUrlMapCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a RegionTargetTcpProxies */
                class RegionTargetTcpProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionTargetTcpProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionTargetTcpProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionTargetTcpProxies;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionTargetTcpProxyRequest, callback: google.cloud.compute.v1.RegionTargetTcpProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionTargetTcpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetTcpProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionTargetTcpProxyRequest, callback: google.cloud.compute.v1.RegionTargetTcpProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionTargetTcpProxyRequest): Promise<google.cloud.compute.v1.TargetTcpProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionTargetTcpProxyRequest, callback: google.cloud.compute.v1.RegionTargetTcpProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionTargetTcpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionTargetTcpProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetTcpProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionTargetTcpProxiesRequest, callback: google.cloud.compute.v1.RegionTargetTcpProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionTargetTcpProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionTargetTcpProxiesRequest): Promise<google.cloud.compute.v1.TargetTcpProxyList>;
                }

                namespace RegionTargetTcpProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetTcpProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetTcpProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetTcpProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetTcpProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetTcpProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionTargetTcpProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetTcpProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetTcpProxyList) => void;
                }

                /** Represents a RegionUrlMaps */
                class RegionUrlMaps extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionUrlMaps service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionUrlMaps service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionUrlMaps;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionUrlMapRequest, callback: google.cloud.compute.v1.RegionUrlMaps.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRegionUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRegionUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRegionUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMap
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionUrlMapRequest, callback: google.cloud.compute.v1.RegionUrlMaps.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionUrlMapRequest): Promise<google.cloud.compute.v1.UrlMap>;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionUrlMapRequest, callback: google.cloud.compute.v1.RegionUrlMaps.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRegionUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRegionUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRegionUrlMapsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMapList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionUrlMapsRequest, callback: google.cloud.compute.v1.RegionUrlMaps.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionUrlMapsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionUrlMapsRequest): Promise<google.cloud.compute.v1.UrlMapList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionUrlMapRequest, callback: google.cloud.compute.v1.RegionUrlMaps.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRegionUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRegionUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionUrlMapRequest, callback: google.cloud.compute.v1.RegionUrlMaps.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateRegionUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRegionUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Validate.
                     * @param request ValidateRegionUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMapsValidateResponse
                     */
                    public validate(request: google.cloud.compute.v1.IValidateRegionUrlMapRequest, callback: google.cloud.compute.v1.RegionUrlMaps.ValidateCallback): void;

                    /**
                     * Calls Validate.
                     * @param request ValidateRegionUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public validate(request: google.cloud.compute.v1.IValidateRegionUrlMapRequest): Promise<google.cloud.compute.v1.UrlMapsValidateResponse>;
                }

                namespace RegionUrlMaps {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|get}.
                     * @param error Error, if any
                     * @param [response] UrlMap
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMap) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|list}.
                     * @param error Error, if any
                     * @param [response] UrlMapList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMapList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.RegionUrlMaps|validate}.
                     * @param error Error, if any
                     * @param [response] UrlMapsValidateResponse
                     */
                    type ValidateCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMapsValidateResponse) => void;
                }

                /** Represents a Regions */
                class Regions extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Regions service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Regions service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Regions;

                    /**
                     * Calls Get.
                     * @param request GetRegionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Region
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionRequest, callback: google.cloud.compute.v1.Regions.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRegionRequest): Promise<google.cloud.compute.v1.Region>;

                    /**
                     * Calls List.
                     * @param request ListRegionsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RegionList
                     */
                    public list(request: google.cloud.compute.v1.IListRegionsRequest, callback: google.cloud.compute.v1.Regions.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRegionsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRegionsRequest): Promise<google.cloud.compute.v1.RegionList>;
                }

                namespace Regions {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Regions|get}.
                     * @param error Error, if any
                     * @param [response] Region
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Region) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Regions|list}.
                     * @param error Error, if any
                     * @param [response] RegionList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RegionList) => void;
                }

                /** Represents a Reservations */
                class Reservations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Reservations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Reservations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Reservations;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListReservationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ReservationAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListReservationsRequest, callback: google.cloud.compute.v1.Reservations.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListReservationsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListReservationsRequest): Promise<google.cloud.compute.v1.ReservationAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteReservationRequest, callback: google.cloud.compute.v1.Reservations.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteReservationRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteReservationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Reservation
                     */
                    public get(request: google.cloud.compute.v1.IGetReservationRequest, callback: google.cloud.compute.v1.Reservations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetReservationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetReservationRequest): Promise<google.cloud.compute.v1.Reservation>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyReservationRequest, callback: google.cloud.compute.v1.Reservations.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyReservationRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyReservationRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertReservationRequest, callback: google.cloud.compute.v1.Reservations.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertReservationRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertReservationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListReservationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ReservationList
                     */
                    public list(request: google.cloud.compute.v1.IListReservationsRequest, callback: google.cloud.compute.v1.Reservations.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListReservationsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListReservationsRequest): Promise<google.cloud.compute.v1.ReservationList>;

                    /**
                     * Calls Resize.
                     * @param request ResizeReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public resize(request: google.cloud.compute.v1.IResizeReservationRequest, callback: google.cloud.compute.v1.Reservations.ResizeCallback): void;

                    /**
                     * Calls Resize.
                     * @param request ResizeReservationRequest message or plain object
                     * @returns Promise
                     */
                    public resize(request: google.cloud.compute.v1.IResizeReservationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyReservationRequest, callback: google.cloud.compute.v1.Reservations.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyReservationRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyReservationRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsReservationRequest, callback: google.cloud.compute.v1.Reservations.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsReservationRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsReservationRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;

                    /**
                     * Calls Update.
                     * @param request UpdateReservationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateReservationRequest, callback: google.cloud.compute.v1.Reservations.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateReservationRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateReservationRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Reservations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] ReservationAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ReservationAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|get}.
                     * @param error Error, if any
                     * @param [response] Reservation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Reservation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|list}.
                     * @param error Error, if any
                     * @param [response] ReservationList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ReservationList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|resize}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ResizeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Reservations|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a ResourcePolicies */
                class ResourcePolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new ResourcePolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new ResourcePolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): ResourcePolicies;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListResourcePoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ResourcePolicyAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListResourcePoliciesRequest, callback: google.cloud.compute.v1.ResourcePolicies.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListResourcePoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListResourcePoliciesRequest): Promise<google.cloud.compute.v1.ResourcePolicyAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteResourcePolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteResourcePolicyRequest, callback: google.cloud.compute.v1.ResourcePolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteResourcePolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteResourcePolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetResourcePolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ResourcePolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetResourcePolicyRequest, callback: google.cloud.compute.v1.ResourcePolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetResourcePolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetResourcePolicyRequest): Promise<google.cloud.compute.v1.ResourcePolicy>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyResourcePolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyResourcePolicyRequest, callback: google.cloud.compute.v1.ResourcePolicies.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyResourcePolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyResourcePolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertResourcePolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertResourcePolicyRequest, callback: google.cloud.compute.v1.ResourcePolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertResourcePolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertResourcePolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListResourcePoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ResourcePolicyList
                     */
                    public list(request: google.cloud.compute.v1.IListResourcePoliciesRequest, callback: google.cloud.compute.v1.ResourcePolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListResourcePoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListResourcePoliciesRequest): Promise<google.cloud.compute.v1.ResourcePolicyList>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyResourcePolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyResourcePolicyRequest, callback: google.cloud.compute.v1.ResourcePolicies.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyResourcePolicyRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyResourcePolicyRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsResourcePolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsResourcePolicyRequest, callback: google.cloud.compute.v1.ResourcePolicies.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsResourcePolicyRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsResourcePolicyRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace ResourcePolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] ResourcePolicyAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ResourcePolicyAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|get}.
                     * @param error Error, if any
                     * @param [response] ResourcePolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.ResourcePolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|list}.
                     * @param error Error, if any
                     * @param [response] ResourcePolicyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ResourcePolicyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ResourcePolicies|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a Routers */
                class Routers extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Routers service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Routers service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Routers;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListRoutersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RouterAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListRoutersRequest, callback: google.cloud.compute.v1.Routers.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListRoutersRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListRoutersRequest): Promise<google.cloud.compute.v1.RouterAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRouterRequest, callback: google.cloud.compute.v1.Routers.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRouterRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRouterRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Router
                     */
                    public get(request: google.cloud.compute.v1.IGetRouterRequest, callback: google.cloud.compute.v1.Routers.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRouterRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRouterRequest): Promise<google.cloud.compute.v1.Router>;

                    /**
                     * Calls GetNatMappingInfo.
                     * @param request GetNatMappingInfoRoutersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VmEndpointNatMappingsList
                     */
                    public getNatMappingInfo(request: google.cloud.compute.v1.IGetNatMappingInfoRoutersRequest, callback: google.cloud.compute.v1.Routers.GetNatMappingInfoCallback): void;

                    /**
                     * Calls GetNatMappingInfo.
                     * @param request GetNatMappingInfoRoutersRequest message or plain object
                     * @returns Promise
                     */
                    public getNatMappingInfo(request: google.cloud.compute.v1.IGetNatMappingInfoRoutersRequest): Promise<google.cloud.compute.v1.VmEndpointNatMappingsList>;

                    /**
                     * Calls GetRouterStatus.
                     * @param request GetRouterStatusRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RouterStatusResponse
                     */
                    public getRouterStatus(request: google.cloud.compute.v1.IGetRouterStatusRouterRequest, callback: google.cloud.compute.v1.Routers.GetRouterStatusCallback): void;

                    /**
                     * Calls GetRouterStatus.
                     * @param request GetRouterStatusRouterRequest message or plain object
                     * @returns Promise
                     */
                    public getRouterStatus(request: google.cloud.compute.v1.IGetRouterStatusRouterRequest): Promise<google.cloud.compute.v1.RouterStatusResponse>;

                    /**
                     * Calls Insert.
                     * @param request InsertRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRouterRequest, callback: google.cloud.compute.v1.Routers.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRouterRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRouterRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRoutersRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RouterList
                     */
                    public list(request: google.cloud.compute.v1.IListRoutersRequest, callback: google.cloud.compute.v1.Routers.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRoutersRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRoutersRequest): Promise<google.cloud.compute.v1.RouterList>;

                    /**
                     * Calls Patch.
                     * @param request PatchRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRouterRequest, callback: google.cloud.compute.v1.Routers.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchRouterRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchRouterRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Preview.
                     * @param request PreviewRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RoutersPreviewResponse
                     */
                    public preview(request: google.cloud.compute.v1.IPreviewRouterRequest, callback: google.cloud.compute.v1.Routers.PreviewCallback): void;

                    /**
                     * Calls Preview.
                     * @param request PreviewRouterRequest message or plain object
                     * @returns Promise
                     */
                    public preview(request: google.cloud.compute.v1.IPreviewRouterRequest): Promise<google.cloud.compute.v1.RoutersPreviewResponse>;

                    /**
                     * Calls Update.
                     * @param request UpdateRouterRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRouterRequest, callback: google.cloud.compute.v1.Routers.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateRouterRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateRouterRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace Routers {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] RouterAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RouterAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|get}.
                     * @param error Error, if any
                     * @param [response] Router
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Router) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|getNatMappingInfo}.
                     * @param error Error, if any
                     * @param [response] VmEndpointNatMappingsList
                     */
                    type GetNatMappingInfoCallback = (error: (Error|null), response?: google.cloud.compute.v1.VmEndpointNatMappingsList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|getRouterStatus}.
                     * @param error Error, if any
                     * @param [response] RouterStatusResponse
                     */
                    type GetRouterStatusCallback = (error: (Error|null), response?: google.cloud.compute.v1.RouterStatusResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|list}.
                     * @param error Error, if any
                     * @param [response] RouterList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RouterList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|preview}.
                     * @param error Error, if any
                     * @param [response] RoutersPreviewResponse
                     */
                    type PreviewCallback = (error: (Error|null), response?: google.cloud.compute.v1.RoutersPreviewResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routers|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a Routes */
                class Routes extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Routes service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Routes service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Routes;

                    /**
                     * Calls Delete.
                     * @param request DeleteRouteRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRouteRequest, callback: google.cloud.compute.v1.Routes.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteRouteRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteRouteRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetRouteRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Route
                     */
                    public get(request: google.cloud.compute.v1.IGetRouteRequest, callback: google.cloud.compute.v1.Routes.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRouteRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetRouteRequest): Promise<google.cloud.compute.v1.Route>;

                    /**
                     * Calls Insert.
                     * @param request InsertRouteRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRouteRequest, callback: google.cloud.compute.v1.Routes.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertRouteRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertRouteRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListRoutesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and RouteList
                     */
                    public list(request: google.cloud.compute.v1.IListRoutesRequest, callback: google.cloud.compute.v1.Routes.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListRoutesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListRoutesRequest): Promise<google.cloud.compute.v1.RouteList>;
                }

                namespace Routes {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routes|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routes|get}.
                     * @param error Error, if any
                     * @param [response] Route
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Route) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routes|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Routes|list}.
                     * @param error Error, if any
                     * @param [response] RouteList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.RouteList) => void;
                }

                /** Represents a SecurityPolicies */
                class SecurityPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new SecurityPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new SecurityPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): SecurityPolicies;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.AddRuleCallback): void;

                    /**
                     * Calls AddRule.
                     * @param request AddRuleSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public addRule(request: google.cloud.compute.v1.IAddRuleSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSecurityPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPoliciesAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSecurityPoliciesRequest, callback: google.cloud.compute.v1.SecurityPolicies.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSecurityPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSecurityPoliciesRequest): Promise<google.cloud.compute.v1.SecurityPoliciesAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetSecurityPolicyRequest): Promise<google.cloud.compute.v1.SecurityPolicy>;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPolicyRule
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.GetRuleCallback): void;

                    /**
                     * Calls GetRule.
                     * @param request GetRuleSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public getRule(request: google.cloud.compute.v1.IGetRuleSecurityPolicyRequest): Promise<google.cloud.compute.v1.SecurityPolicyRule>;

                    /**
                     * Calls Insert.
                     * @param request InsertSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListSecurityPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPolicyList
                     */
                    public list(request: google.cloud.compute.v1.IListSecurityPoliciesRequest, callback: google.cloud.compute.v1.SecurityPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListSecurityPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListSecurityPoliciesRequest): Promise<google.cloud.compute.v1.SecurityPolicyList>;

                    /**
                     * Calls ListPreconfiguredExpressionSets.
                     * @param request ListPreconfiguredExpressionSetsSecurityPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     */
                    public listPreconfiguredExpressionSets(request: google.cloud.compute.v1.IListPreconfiguredExpressionSetsSecurityPoliciesRequest, callback: google.cloud.compute.v1.SecurityPolicies.ListPreconfiguredExpressionSetsCallback): void;

                    /**
                     * Calls ListPreconfiguredExpressionSets.
                     * @param request ListPreconfiguredExpressionSetsSecurityPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public listPreconfiguredExpressionSets(request: google.cloud.compute.v1.IListPreconfiguredExpressionSetsSecurityPoliciesRequest): Promise<google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse>;

                    /**
                     * Calls Patch.
                     * @param request PatchSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.PatchRuleCallback): void;

                    /**
                     * Calls PatchRule.
                     * @param request PatchRuleSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patchRule(request: google.cloud.compute.v1.IPatchRuleSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.RemoveRuleCallback): void;

                    /**
                     * Calls RemoveRule.
                     * @param request RemoveRuleSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public removeRule(request: google.cloud.compute.v1.IRemoveRuleSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsSecurityPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsSecurityPolicyRequest, callback: google.cloud.compute.v1.SecurityPolicies.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsSecurityPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsSecurityPolicyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace SecurityPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|addRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] SecurityPoliciesAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPoliciesAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|get}.
                     * @param error Error, if any
                     * @param [response] SecurityPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|getRule}.
                     * @param error Error, if any
                     * @param [response] SecurityPolicyRule
                     */
                    type GetRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPolicyRule) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|list}.
                     * @param error Error, if any
                     * @param [response] SecurityPolicyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPolicyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|listPreconfiguredExpressionSets}.
                     * @param error Error, if any
                     * @param [response] SecurityPoliciesListPreconfiguredExpressionSetsResponse
                     */
                    type ListPreconfiguredExpressionSetsCallback = (error: (Error|null), response?: google.cloud.compute.v1.SecurityPoliciesListPreconfiguredExpressionSetsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|patchRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|removeRule}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveRuleCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SecurityPolicies|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a ServiceAttachments */
                class ServiceAttachments extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new ServiceAttachments service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new ServiceAttachments service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): ServiceAttachments;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListServiceAttachmentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ServiceAttachmentAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListServiceAttachmentsRequest, callback: google.cloud.compute.v1.ServiceAttachments.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListServiceAttachmentsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListServiceAttachmentsRequest): Promise<google.cloud.compute.v1.ServiceAttachmentAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteServiceAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ServiceAttachment
                     */
                    public get(request: google.cloud.compute.v1.IGetServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetServiceAttachmentRequest): Promise<google.cloud.compute.v1.ServiceAttachment>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicyServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicyServiceAttachmentRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertServiceAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListServiceAttachmentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ServiceAttachmentList
                     */
                    public list(request: google.cloud.compute.v1.IListServiceAttachmentsRequest, callback: google.cloud.compute.v1.ServiceAttachments.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListServiceAttachmentsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListServiceAttachmentsRequest): Promise<google.cloud.compute.v1.ServiceAttachmentList>;

                    /**
                     * Calls Patch.
                     * @param request PatchServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchServiceAttachmentRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicyServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicyServiceAttachmentRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsServiceAttachmentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsServiceAttachmentRequest, callback: google.cloud.compute.v1.ServiceAttachments.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsServiceAttachmentRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsServiceAttachmentRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace ServiceAttachments {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] ServiceAttachmentAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ServiceAttachmentAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|get}.
                     * @param error Error, if any
                     * @param [response] ServiceAttachment
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.ServiceAttachment) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|list}.
                     * @param error Error, if any
                     * @param [response] ServiceAttachmentList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ServiceAttachmentList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ServiceAttachments|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a Snapshots */
                class Snapshots extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Snapshots service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Snapshots service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Snapshots;

                    /**
                     * Calls Delete.
                     * @param request DeleteSnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSnapshotRequest, callback: google.cloud.compute.v1.Snapshots.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteSnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSnapshotRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetSnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Snapshot
                     */
                    public get(request: google.cloud.compute.v1.IGetSnapshotRequest, callback: google.cloud.compute.v1.Snapshots.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetSnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetSnapshotRequest): Promise<google.cloud.compute.v1.Snapshot>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicySnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicySnapshotRequest, callback: google.cloud.compute.v1.Snapshots.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicySnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicySnapshotRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertSnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSnapshotRequest, callback: google.cloud.compute.v1.Snapshots.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertSnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSnapshotRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListSnapshotsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SnapshotList
                     */
                    public list(request: google.cloud.compute.v1.IListSnapshotsRequest, callback: google.cloud.compute.v1.Snapshots.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListSnapshotsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListSnapshotsRequest): Promise<google.cloud.compute.v1.SnapshotList>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicySnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicySnapshotRequest, callback: google.cloud.compute.v1.Snapshots.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicySnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicySnapshotRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsSnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsSnapshotRequest, callback: google.cloud.compute.v1.Snapshots.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsSnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsSnapshotRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsSnapshotRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsSnapshotRequest, callback: google.cloud.compute.v1.Snapshots.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsSnapshotRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsSnapshotRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace Snapshots {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|get}.
                     * @param error Error, if any
                     * @param [response] Snapshot
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Snapshot) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|list}.
                     * @param error Error, if any
                     * @param [response] SnapshotList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SnapshotList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Snapshots|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a SslCertificates */
                class SslCertificates extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new SslCertificates service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new SslCertificates service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): SslCertificates;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSslCertificatesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslCertificateAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSslCertificatesRequest, callback: google.cloud.compute.v1.SslCertificates.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSslCertificatesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSslCertificatesRequest): Promise<google.cloud.compute.v1.SslCertificateAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteSslCertificateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSslCertificateRequest, callback: google.cloud.compute.v1.SslCertificates.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteSslCertificateRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSslCertificateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetSslCertificateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslCertificate
                     */
                    public get(request: google.cloud.compute.v1.IGetSslCertificateRequest, callback: google.cloud.compute.v1.SslCertificates.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetSslCertificateRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetSslCertificateRequest): Promise<google.cloud.compute.v1.SslCertificate>;

                    /**
                     * Calls Insert.
                     * @param request InsertSslCertificateRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSslCertificateRequest, callback: google.cloud.compute.v1.SslCertificates.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertSslCertificateRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSslCertificateRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListSslCertificatesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslCertificateList
                     */
                    public list(request: google.cloud.compute.v1.IListSslCertificatesRequest, callback: google.cloud.compute.v1.SslCertificates.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListSslCertificatesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListSslCertificatesRequest): Promise<google.cloud.compute.v1.SslCertificateList>;
                }

                namespace SslCertificates {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslCertificates|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] SslCertificateAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslCertificateAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslCertificates|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslCertificates|get}.
                     * @param error Error, if any
                     * @param [response] SslCertificate
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslCertificate) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslCertificates|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslCertificates|list}.
                     * @param error Error, if any
                     * @param [response] SslCertificateList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslCertificateList) => void;
                }

                /** Represents a SslPolicies */
                class SslPolicies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new SslPolicies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new SslPolicies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): SslPolicies;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSslPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPoliciesAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSslPoliciesRequest, callback: google.cloud.compute.v1.SslPolicies.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSslPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSslPoliciesRequest): Promise<google.cloud.compute.v1.SslPoliciesAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSslPolicyRequest, callback: google.cloud.compute.v1.SslPolicies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSslPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPolicy
                     */
                    public get(request: google.cloud.compute.v1.IGetSslPolicyRequest, callback: google.cloud.compute.v1.SslPolicies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetSslPolicyRequest): Promise<google.cloud.compute.v1.SslPolicy>;

                    /**
                     * Calls Insert.
                     * @param request InsertSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSslPolicyRequest, callback: google.cloud.compute.v1.SslPolicies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSslPolicyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListSslPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPoliciesList
                     */
                    public list(request: google.cloud.compute.v1.IListSslPoliciesRequest, callback: google.cloud.compute.v1.SslPolicies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListSslPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListSslPoliciesRequest): Promise<google.cloud.compute.v1.SslPoliciesList>;

                    /**
                     * Calls ListAvailableFeatures.
                     * @param request ListAvailableFeaturesSslPoliciesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SslPoliciesListAvailableFeaturesResponse
                     */
                    public listAvailableFeatures(request: google.cloud.compute.v1.IListAvailableFeaturesSslPoliciesRequest, callback: google.cloud.compute.v1.SslPolicies.ListAvailableFeaturesCallback): void;

                    /**
                     * Calls ListAvailableFeatures.
                     * @param request ListAvailableFeaturesSslPoliciesRequest message or plain object
                     * @returns Promise
                     */
                    public listAvailableFeatures(request: google.cloud.compute.v1.IListAvailableFeaturesSslPoliciesRequest): Promise<google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse>;

                    /**
                     * Calls Patch.
                     * @param request PatchSslPolicyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchSslPolicyRequest, callback: google.cloud.compute.v1.SslPolicies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchSslPolicyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchSslPolicyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace SslPolicies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] SslPoliciesAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPoliciesAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|get}.
                     * @param error Error, if any
                     * @param [response] SslPolicy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPolicy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|list}.
                     * @param error Error, if any
                     * @param [response] SslPoliciesList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPoliciesList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|listAvailableFeatures}.
                     * @param error Error, if any
                     * @param [response] SslPoliciesListAvailableFeaturesResponse
                     */
                    type ListAvailableFeaturesCallback = (error: (Error|null), response?: google.cloud.compute.v1.SslPoliciesListAvailableFeaturesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.SslPolicies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a Subnetworks */
                class Subnetworks extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Subnetworks service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Subnetworks service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Subnetworks;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSubnetworksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SubnetworkAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSubnetworksRequest, callback: google.cloud.compute.v1.Subnetworks.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListSubnetworksRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListSubnetworksRequest): Promise<google.cloud.compute.v1.SubnetworkAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteSubnetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls ExpandIpCidrRange.
                     * @param request ExpandIpCidrRangeSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public expandIpCidrRange(request: google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.ExpandIpCidrRangeCallback): void;

                    /**
                     * Calls ExpandIpCidrRange.
                     * @param request ExpandIpCidrRangeSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public expandIpCidrRange(request: google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Subnetwork
                     */
                    public get(request: google.cloud.compute.v1.IGetSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetSubnetworkRequest): Promise<google.cloud.compute.v1.Subnetwork>;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicySubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicySubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.GetIamPolicyCallback): void;

                    /**
                     * Calls GetIamPolicy.
                     * @param request GetIamPolicySubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public getIamPolicy(request: google.cloud.compute.v1.IGetIamPolicySubnetworkRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls Insert.
                     * @param request InsertSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertSubnetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListSubnetworksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and SubnetworkList
                     */
                    public list(request: google.cloud.compute.v1.IListSubnetworksRequest, callback: google.cloud.compute.v1.Subnetworks.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListSubnetworksRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListSubnetworksRequest): Promise<google.cloud.compute.v1.SubnetworkList>;

                    /**
                     * Calls ListUsable.
                     * @param request ListUsableSubnetworksRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UsableSubnetworksAggregatedList
                     */
                    public listUsable(request: google.cloud.compute.v1.IListUsableSubnetworksRequest, callback: google.cloud.compute.v1.Subnetworks.ListUsableCallback): void;

                    /**
                     * Calls ListUsable.
                     * @param request ListUsableSubnetworksRequest message or plain object
                     * @returns Promise
                     */
                    public listUsable(request: google.cloud.compute.v1.IListUsableSubnetworksRequest): Promise<google.cloud.compute.v1.UsableSubnetworksAggregatedList>;

                    /**
                     * Calls Patch.
                     * @param request PatchSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchSubnetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicySubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Policy
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicySubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.SetIamPolicyCallback): void;

                    /**
                     * Calls SetIamPolicy.
                     * @param request SetIamPolicySubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public setIamPolicy(request: google.cloud.compute.v1.ISetIamPolicySubnetworkRequest): Promise<google.cloud.compute.v1.Policy>;

                    /**
                     * Calls SetPrivateIpGoogleAccess.
                     * @param request SetPrivateIpGoogleAccessSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setPrivateIpGoogleAccess(request: google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.SetPrivateIpGoogleAccessCallback): void;

                    /**
                     * Calls SetPrivateIpGoogleAccess.
                     * @param request SetPrivateIpGoogleAccessSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public setPrivateIpGoogleAccess(request: google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsSubnetworkRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest, callback: google.cloud.compute.v1.Subnetworks.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsSubnetworkRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace Subnetworks {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] SubnetworkAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SubnetworkAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|expandIpCidrRange}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ExpandIpCidrRangeCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|get}.
                     * @param error Error, if any
                     * @param [response] Subnetwork
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Subnetwork) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|getIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type GetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|list}.
                     * @param error Error, if any
                     * @param [response] SubnetworkList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.SubnetworkList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|listUsable}.
                     * @param error Error, if any
                     * @param [response] UsableSubnetworksAggregatedList
                     */
                    type ListUsableCallback = (error: (Error|null), response?: google.cloud.compute.v1.UsableSubnetworksAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|setIamPolicy}.
                     * @param error Error, if any
                     * @param [response] Policy
                     */
                    type SetIamPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Policy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|setPrivateIpGoogleAccess}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetPrivateIpGoogleAccessCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Subnetworks|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a TargetGrpcProxies */
                class TargetGrpcProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetGrpcProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetGrpcProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetGrpcProxies;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetGrpcProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetGrpcProxyRequest, callback: google.cloud.compute.v1.TargetGrpcProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetGrpcProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetGrpcProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetGrpcProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetGrpcProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetGrpcProxyRequest, callback: google.cloud.compute.v1.TargetGrpcProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetGrpcProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetGrpcProxyRequest): Promise<google.cloud.compute.v1.TargetGrpcProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetGrpcProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetGrpcProxyRequest, callback: google.cloud.compute.v1.TargetGrpcProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetGrpcProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetGrpcProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetGrpcProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetGrpcProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetGrpcProxiesRequest, callback: google.cloud.compute.v1.TargetGrpcProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetGrpcProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetGrpcProxiesRequest): Promise<google.cloud.compute.v1.TargetGrpcProxyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchTargetGrpcProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchTargetGrpcProxyRequest, callback: google.cloud.compute.v1.TargetGrpcProxies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchTargetGrpcProxyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchTargetGrpcProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetGrpcProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetGrpcProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetGrpcProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetGrpcProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetGrpcProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetGrpcProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetGrpcProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetGrpcProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetGrpcProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetGrpcProxies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a TargetHttpProxies */
                class TargetHttpProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetHttpProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetHttpProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetHttpProxies;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetHttpProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpProxyAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetHttpProxiesRequest, callback: google.cloud.compute.v1.TargetHttpProxies.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetHttpProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetHttpProxiesRequest): Promise<google.cloud.compute.v1.TargetHttpProxyAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetHttpProxyRequest, callback: google.cloud.compute.v1.TargetHttpProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetHttpProxyRequest, callback: google.cloud.compute.v1.TargetHttpProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetHttpProxyRequest): Promise<google.cloud.compute.v1.TargetHttpProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetHttpProxyRequest, callback: google.cloud.compute.v1.TargetHttpProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetHttpProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetHttpProxiesRequest, callback: google.cloud.compute.v1.TargetHttpProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetHttpProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetHttpProxiesRequest): Promise<google.cloud.compute.v1.TargetHttpProxyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchTargetHttpProxyRequest, callback: google.cloud.compute.v1.TargetHttpProxies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapTargetHttpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapTargetHttpProxyRequest, callback: google.cloud.compute.v1.TargetHttpProxies.SetUrlMapCallback): void;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapTargetHttpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapTargetHttpProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetHttpProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] TargetHttpProxyAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpProxyAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetHttpProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetHttpProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpProxies|setUrlMap}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetUrlMapCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a TargetHttpsProxies */
                class TargetHttpsProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetHttpsProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetHttpsProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetHttpsProxies;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetHttpsProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpsProxyAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetHttpsProxiesRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetHttpsProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetHttpsProxiesRequest): Promise<google.cloud.compute.v1.TargetHttpsProxyAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpsProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.TargetHttpsProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetHttpsProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetHttpsProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetHttpsProxiesRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetHttpsProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetHttpsProxiesRequest): Promise<google.cloud.compute.v1.TargetHttpsProxyList>;

                    /**
                     * Calls Patch.
                     * @param request PatchTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetCertificateMap.
                     * @param request SetCertificateMapTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setCertificateMap(request: google.cloud.compute.v1.ISetCertificateMapTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.SetCertificateMapCallback): void;

                    /**
                     * Calls SetCertificateMap.
                     * @param request SetCertificateMapTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setCertificateMap(request: google.cloud.compute.v1.ISetCertificateMapTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetQuicOverride.
                     * @param request SetQuicOverrideTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setQuicOverride(request: google.cloud.compute.v1.ISetQuicOverrideTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.SetQuicOverrideCallback): void;

                    /**
                     * Calls SetQuicOverride.
                     * @param request SetQuicOverrideTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setQuicOverride(request: google.cloud.compute.v1.ISetQuicOverrideTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetSslCertificates.
                     * @param request SetSslCertificatesTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setSslCertificates(request: google.cloud.compute.v1.ISetSslCertificatesTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.SetSslCertificatesCallback): void;

                    /**
                     * Calls SetSslCertificates.
                     * @param request SetSslCertificatesTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setSslCertificates(request: google.cloud.compute.v1.ISetSslCertificatesTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetSslPolicy.
                     * @param request SetSslPolicyTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setSslPolicy(request: google.cloud.compute.v1.ISetSslPolicyTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.SetSslPolicyCallback): void;

                    /**
                     * Calls SetSslPolicy.
                     * @param request SetSslPolicyTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setSslPolicy(request: google.cloud.compute.v1.ISetSslPolicyTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapTargetHttpsProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapTargetHttpsProxyRequest, callback: google.cloud.compute.v1.TargetHttpsProxies.SetUrlMapCallback): void;

                    /**
                     * Calls SetUrlMap.
                     * @param request SetUrlMapTargetHttpsProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setUrlMap(request: google.cloud.compute.v1.ISetUrlMapTargetHttpsProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetHttpsProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] TargetHttpsProxyAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpsProxyAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetHttpsProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpsProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetHttpsProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetHttpsProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|setCertificateMap}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetCertificateMapCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|setQuicOverride}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetQuicOverrideCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|setSslCertificates}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSslCertificatesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|setSslPolicy}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSslPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetHttpsProxies|setUrlMap}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetUrlMapCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a TargetInstances */
                class TargetInstances extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetInstances service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetInstances service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetInstances;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetInstancesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetInstanceAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetInstancesRequest, callback: google.cloud.compute.v1.TargetInstances.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetInstancesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetInstancesRequest): Promise<google.cloud.compute.v1.TargetInstanceAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetInstanceRequest, callback: google.cloud.compute.v1.TargetInstances.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetInstance
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetInstanceRequest, callback: google.cloud.compute.v1.TargetInstances.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetInstanceRequest): Promise<google.cloud.compute.v1.TargetInstance>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetInstanceRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetInstanceRequest, callback: google.cloud.compute.v1.TargetInstances.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetInstanceRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetInstanceRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetInstancesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetInstanceList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetInstancesRequest, callback: google.cloud.compute.v1.TargetInstances.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetInstancesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetInstancesRequest): Promise<google.cloud.compute.v1.TargetInstanceList>;
                }

                namespace TargetInstances {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetInstances|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] TargetInstanceAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetInstanceAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetInstances|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetInstances|get}.
                     * @param error Error, if any
                     * @param [response] TargetInstance
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetInstance) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetInstances|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetInstances|list}.
                     * @param error Error, if any
                     * @param [response] TargetInstanceList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetInstanceList) => void;
                }

                /** Represents a TargetPools */
                class TargetPools extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetPools service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetPools service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetPools;

                    /**
                     * Calls AddHealthCheck.
                     * @param request AddHealthCheckTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addHealthCheck(request: google.cloud.compute.v1.IAddHealthCheckTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.AddHealthCheckCallback): void;

                    /**
                     * Calls AddHealthCheck.
                     * @param request AddHealthCheckTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public addHealthCheck(request: google.cloud.compute.v1.IAddHealthCheckTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AddInstance.
                     * @param request AddInstanceTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public addInstance(request: google.cloud.compute.v1.IAddInstanceTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.AddInstanceCallback): void;

                    /**
                     * Calls AddInstance.
                     * @param request AddInstanceTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public addInstance(request: google.cloud.compute.v1.IAddInstanceTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetPoolsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetPoolAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetPoolsRequest, callback: google.cloud.compute.v1.TargetPools.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetPoolsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetPoolsRequest): Promise<google.cloud.compute.v1.TargetPoolAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetPool
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetPoolRequest): Promise<google.cloud.compute.v1.TargetPool>;

                    /**
                     * Calls GetHealth.
                     * @param request GetHealthTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetPoolInstanceHealth
                     */
                    public getHealth(request: google.cloud.compute.v1.IGetHealthTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.GetHealthCallback): void;

                    /**
                     * Calls GetHealth.
                     * @param request GetHealthTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public getHealth(request: google.cloud.compute.v1.IGetHealthTargetPoolRequest): Promise<google.cloud.compute.v1.TargetPoolInstanceHealth>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetPoolsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetPoolList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetPoolsRequest, callback: google.cloud.compute.v1.TargetPools.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetPoolsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetPoolsRequest): Promise<google.cloud.compute.v1.TargetPoolList>;

                    /**
                     * Calls RemoveHealthCheck.
                     * @param request RemoveHealthCheckTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeHealthCheck(request: google.cloud.compute.v1.IRemoveHealthCheckTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.RemoveHealthCheckCallback): void;

                    /**
                     * Calls RemoveHealthCheck.
                     * @param request RemoveHealthCheckTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public removeHealthCheck(request: google.cloud.compute.v1.IRemoveHealthCheckTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls RemoveInstance.
                     * @param request RemoveInstanceTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public removeInstance(request: google.cloud.compute.v1.IRemoveInstanceTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.RemoveInstanceCallback): void;

                    /**
                     * Calls RemoveInstance.
                     * @param request RemoveInstanceTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public removeInstance(request: google.cloud.compute.v1.IRemoveInstanceTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetBackup.
                     * @param request SetBackupTargetPoolRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setBackup(request: google.cloud.compute.v1.ISetBackupTargetPoolRequest, callback: google.cloud.compute.v1.TargetPools.SetBackupCallback): void;

                    /**
                     * Calls SetBackup.
                     * @param request SetBackupTargetPoolRequest message or plain object
                     * @returns Promise
                     */
                    public setBackup(request: google.cloud.compute.v1.ISetBackupTargetPoolRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetPools {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|addHealthCheck}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddHealthCheckCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|addInstance}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type AddInstanceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] TargetPoolAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetPoolAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|get}.
                     * @param error Error, if any
                     * @param [response] TargetPool
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetPool) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|getHealth}.
                     * @param error Error, if any
                     * @param [response] TargetPoolInstanceHealth
                     */
                    type GetHealthCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetPoolInstanceHealth) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|list}.
                     * @param error Error, if any
                     * @param [response] TargetPoolList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetPoolList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|removeHealthCheck}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveHealthCheckCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|removeInstance}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type RemoveInstanceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetPools|setBackup}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetBackupCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a TargetSslProxies */
                class TargetSslProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetSslProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetSslProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetSslProxies;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetSslProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetSslProxyRequest): Promise<google.cloud.compute.v1.TargetSslProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetSslProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetSslProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetSslProxiesRequest, callback: google.cloud.compute.v1.TargetSslProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetSslProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetSslProxiesRequest): Promise<google.cloud.compute.v1.TargetSslProxyList>;

                    /**
                     * Calls SetBackendService.
                     * @param request SetBackendServiceTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setBackendService(request: google.cloud.compute.v1.ISetBackendServiceTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.SetBackendServiceCallback): void;

                    /**
                     * Calls SetBackendService.
                     * @param request SetBackendServiceTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setBackendService(request: google.cloud.compute.v1.ISetBackendServiceTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetCertificateMap.
                     * @param request SetCertificateMapTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setCertificateMap(request: google.cloud.compute.v1.ISetCertificateMapTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.SetCertificateMapCallback): void;

                    /**
                     * Calls SetCertificateMap.
                     * @param request SetCertificateMapTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setCertificateMap(request: google.cloud.compute.v1.ISetCertificateMapTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetProxyHeader.
                     * @param request SetProxyHeaderTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setProxyHeader(request: google.cloud.compute.v1.ISetProxyHeaderTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.SetProxyHeaderCallback): void;

                    /**
                     * Calls SetProxyHeader.
                     * @param request SetProxyHeaderTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setProxyHeader(request: google.cloud.compute.v1.ISetProxyHeaderTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetSslCertificates.
                     * @param request SetSslCertificatesTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setSslCertificates(request: google.cloud.compute.v1.ISetSslCertificatesTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.SetSslCertificatesCallback): void;

                    /**
                     * Calls SetSslCertificates.
                     * @param request SetSslCertificatesTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setSslCertificates(request: google.cloud.compute.v1.ISetSslCertificatesTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetSslPolicy.
                     * @param request SetSslPolicyTargetSslProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setSslPolicy(request: google.cloud.compute.v1.ISetSslPolicyTargetSslProxyRequest, callback: google.cloud.compute.v1.TargetSslProxies.SetSslPolicyCallback): void;

                    /**
                     * Calls SetSslPolicy.
                     * @param request SetSslPolicyTargetSslProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setSslPolicy(request: google.cloud.compute.v1.ISetSslPolicyTargetSslProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetSslProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetSslProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetSslProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetSslProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetSslProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|setBackendService}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetBackendServiceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|setCertificateMap}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetCertificateMapCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|setProxyHeader}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetProxyHeaderCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|setSslCertificates}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSslCertificatesCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetSslProxies|setSslPolicy}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetSslPolicyCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a TargetTcpProxies */
                class TargetTcpProxies extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetTcpProxies service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetTcpProxies service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetTcpProxies;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetTcpProxyRequest, callback: google.cloud.compute.v1.TargetTcpProxies.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetTcpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetTcpProxy
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetTcpProxyRequest, callback: google.cloud.compute.v1.TargetTcpProxies.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetTcpProxyRequest): Promise<google.cloud.compute.v1.TargetTcpProxy>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetTcpProxyRequest, callback: google.cloud.compute.v1.TargetTcpProxies.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetTcpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetTcpProxiesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetTcpProxyList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetTcpProxiesRequest, callback: google.cloud.compute.v1.TargetTcpProxies.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetTcpProxiesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetTcpProxiesRequest): Promise<google.cloud.compute.v1.TargetTcpProxyList>;

                    /**
                     * Calls SetBackendService.
                     * @param request SetBackendServiceTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setBackendService(request: google.cloud.compute.v1.ISetBackendServiceTargetTcpProxyRequest, callback: google.cloud.compute.v1.TargetTcpProxies.SetBackendServiceCallback): void;

                    /**
                     * Calls SetBackendService.
                     * @param request SetBackendServiceTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setBackendService(request: google.cloud.compute.v1.ISetBackendServiceTargetTcpProxyRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls SetProxyHeader.
                     * @param request SetProxyHeaderTargetTcpProxyRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setProxyHeader(request: google.cloud.compute.v1.ISetProxyHeaderTargetTcpProxyRequest, callback: google.cloud.compute.v1.TargetTcpProxies.SetProxyHeaderCallback): void;

                    /**
                     * Calls SetProxyHeader.
                     * @param request SetProxyHeaderTargetTcpProxyRequest message or plain object
                     * @returns Promise
                     */
                    public setProxyHeader(request: google.cloud.compute.v1.ISetProxyHeaderTargetTcpProxyRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetTcpProxies {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetTcpProxies|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetTcpProxies|get}.
                     * @param error Error, if any
                     * @param [response] TargetTcpProxy
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetTcpProxy) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetTcpProxies|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetTcpProxies|list}.
                     * @param error Error, if any
                     * @param [response] TargetTcpProxyList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetTcpProxyList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetTcpProxies|setBackendService}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetBackendServiceCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetTcpProxies|setProxyHeader}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetProxyHeaderCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a TargetVpnGateways */
                class TargetVpnGateways extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new TargetVpnGateways service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new TargetVpnGateways service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): TargetVpnGateways;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetVpnGatewaysRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetVpnGatewayAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetVpnGatewaysRequest, callback: google.cloud.compute.v1.TargetVpnGateways.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListTargetVpnGatewaysRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListTargetVpnGatewaysRequest): Promise<google.cloud.compute.v1.TargetVpnGatewayAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetVpnGatewayRequest, callback: google.cloud.compute.v1.TargetVpnGateways.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteTargetVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteTargetVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetTargetVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetVpnGateway
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetVpnGatewayRequest, callback: google.cloud.compute.v1.TargetVpnGateways.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetTargetVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetTargetVpnGatewayRequest): Promise<google.cloud.compute.v1.TargetVpnGateway>;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetVpnGatewayRequest, callback: google.cloud.compute.v1.TargetVpnGateways.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertTargetVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertTargetVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListTargetVpnGatewaysRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TargetVpnGatewayList
                     */
                    public list(request: google.cloud.compute.v1.IListTargetVpnGatewaysRequest, callback: google.cloud.compute.v1.TargetVpnGateways.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListTargetVpnGatewaysRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListTargetVpnGatewaysRequest): Promise<google.cloud.compute.v1.TargetVpnGatewayList>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsTargetVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsTargetVpnGatewayRequest, callback: google.cloud.compute.v1.TargetVpnGateways.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsTargetVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsTargetVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace TargetVpnGateways {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetVpnGateways|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] TargetVpnGatewayAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetVpnGatewayAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetVpnGateways|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetVpnGateways|get}.
                     * @param error Error, if any
                     * @param [response] TargetVpnGateway
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetVpnGateway) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetVpnGateways|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetVpnGateways|list}.
                     * @param error Error, if any
                     * @param [response] TargetVpnGatewayList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.TargetVpnGatewayList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.TargetVpnGateways|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents an UrlMaps */
                class UrlMaps extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new UrlMaps service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new UrlMaps service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): UrlMaps;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListUrlMapsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMapsAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListUrlMapsRequest, callback: google.cloud.compute.v1.UrlMaps.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListUrlMapsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListUrlMapsRequest): Promise<google.cloud.compute.v1.UrlMapsAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMap
                     */
                    public get(request: google.cloud.compute.v1.IGetUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetUrlMapRequest): Promise<google.cloud.compute.v1.UrlMap>;

                    /**
                     * Calls Insert.
                     * @param request InsertUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls InvalidateCache.
                     * @param request InvalidateCacheUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public invalidateCache(request: google.cloud.compute.v1.IInvalidateCacheUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.InvalidateCacheCallback): void;

                    /**
                     * Calls InvalidateCache.
                     * @param request InvalidateCacheUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public invalidateCache(request: google.cloud.compute.v1.IInvalidateCacheUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListUrlMapsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMapList
                     */
                    public list(request: google.cloud.compute.v1.IListUrlMapsRequest, callback: google.cloud.compute.v1.UrlMaps.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListUrlMapsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListUrlMapsRequest): Promise<google.cloud.compute.v1.UrlMapList>;

                    /**
                     * Calls Patch.
                     * @param request PatchUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public patch(request: google.cloud.compute.v1.IPatchUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.PatchCallback): void;

                    /**
                     * Calls Patch.
                     * @param request PatchUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public patch(request: google.cloud.compute.v1.IPatchUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Update.
                     * @param request UpdateUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public update(request: google.cloud.compute.v1.IUpdateUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.UpdateCallback): void;

                    /**
                     * Calls Update.
                     * @param request UpdateUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public update(request: google.cloud.compute.v1.IUpdateUrlMapRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Validate.
                     * @param request ValidateUrlMapRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and UrlMapsValidateResponse
                     */
                    public validate(request: google.cloud.compute.v1.IValidateUrlMapRequest, callback: google.cloud.compute.v1.UrlMaps.ValidateCallback): void;

                    /**
                     * Calls Validate.
                     * @param request ValidateUrlMapRequest message or plain object
                     * @returns Promise
                     */
                    public validate(request: google.cloud.compute.v1.IValidateUrlMapRequest): Promise<google.cloud.compute.v1.UrlMapsValidateResponse>;
                }

                namespace UrlMaps {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] UrlMapsAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMapsAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|get}.
                     * @param error Error, if any
                     * @param [response] UrlMap
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMap) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|invalidateCache}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InvalidateCacheCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|list}.
                     * @param error Error, if any
                     * @param [response] UrlMapList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMapList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|patch}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type PatchCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|update}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.UrlMaps|validate}.
                     * @param error Error, if any
                     * @param [response] UrlMapsValidateResponse
                     */
                    type ValidateCallback = (error: (Error|null), response?: google.cloud.compute.v1.UrlMapsValidateResponse) => void;
                }

                /** Represents a VpnGateways */
                class VpnGateways extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new VpnGateways service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new VpnGateways service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): VpnGateways;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListVpnGatewaysRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnGatewayAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListVpnGatewaysRequest, callback: google.cloud.compute.v1.VpnGateways.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListVpnGatewaysRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListVpnGatewaysRequest): Promise<google.cloud.compute.v1.VpnGatewayAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteVpnGatewayRequest, callback: google.cloud.compute.v1.VpnGateways.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnGateway
                     */
                    public get(request: google.cloud.compute.v1.IGetVpnGatewayRequest, callback: google.cloud.compute.v1.VpnGateways.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetVpnGatewayRequest): Promise<google.cloud.compute.v1.VpnGateway>;

                    /**
                     * Calls GetStatus.
                     * @param request GetStatusVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnGatewaysGetStatusResponse
                     */
                    public getStatus(request: google.cloud.compute.v1.IGetStatusVpnGatewayRequest, callback: google.cloud.compute.v1.VpnGateways.GetStatusCallback): void;

                    /**
                     * Calls GetStatus.
                     * @param request GetStatusVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public getStatus(request: google.cloud.compute.v1.IGetStatusVpnGatewayRequest): Promise<google.cloud.compute.v1.VpnGatewaysGetStatusResponse>;

                    /**
                     * Calls Insert.
                     * @param request InsertVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertVpnGatewayRequest, callback: google.cloud.compute.v1.VpnGateways.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListVpnGatewaysRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnGatewayList
                     */
                    public list(request: google.cloud.compute.v1.IListVpnGatewaysRequest, callback: google.cloud.compute.v1.VpnGateways.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListVpnGatewaysRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListVpnGatewaysRequest): Promise<google.cloud.compute.v1.VpnGatewayList>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsVpnGatewayRequest, callback: google.cloud.compute.v1.VpnGateways.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsVpnGatewayRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsVpnGatewayRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and TestPermissionsResponse
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsVpnGatewayRequest, callback: google.cloud.compute.v1.VpnGateways.TestIamPermissionsCallback): void;

                    /**
                     * Calls TestIamPermissions.
                     * @param request TestIamPermissionsVpnGatewayRequest message or plain object
                     * @returns Promise
                     */
                    public testIamPermissions(request: google.cloud.compute.v1.ITestIamPermissionsVpnGatewayRequest): Promise<google.cloud.compute.v1.TestPermissionsResponse>;
                }

                namespace VpnGateways {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] VpnGatewayAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnGatewayAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|get}.
                     * @param error Error, if any
                     * @param [response] VpnGateway
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnGateway) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|getStatus}.
                     * @param error Error, if any
                     * @param [response] VpnGatewaysGetStatusResponse
                     */
                    type GetStatusCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnGatewaysGetStatusResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|list}.
                     * @param error Error, if any
                     * @param [response] VpnGatewayList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnGatewayList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnGateways|testIamPermissions}.
                     * @param error Error, if any
                     * @param [response] TestPermissionsResponse
                     */
                    type TestIamPermissionsCallback = (error: (Error|null), response?: google.cloud.compute.v1.TestPermissionsResponse) => void;
                }

                /** Represents a VpnTunnels */
                class VpnTunnels extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new VpnTunnels service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new VpnTunnels service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): VpnTunnels;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListVpnTunnelsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnTunnelAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListVpnTunnelsRequest, callback: google.cloud.compute.v1.VpnTunnels.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListVpnTunnelsRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1.IAggregatedListVpnTunnelsRequest): Promise<google.cloud.compute.v1.VpnTunnelAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteVpnTunnelRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteVpnTunnelRequest, callback: google.cloud.compute.v1.VpnTunnels.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteVpnTunnelRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteVpnTunnelRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls Get.
                     * @param request GetVpnTunnelRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnTunnel
                     */
                    public get(request: google.cloud.compute.v1.IGetVpnTunnelRequest, callback: google.cloud.compute.v1.VpnTunnels.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetVpnTunnelRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetVpnTunnelRequest): Promise<google.cloud.compute.v1.VpnTunnel>;

                    /**
                     * Calls Insert.
                     * @param request InsertVpnTunnelRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1.IInsertVpnTunnelRequest, callback: google.cloud.compute.v1.VpnTunnels.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertVpnTunnelRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1.IInsertVpnTunnelRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListVpnTunnelsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and VpnTunnelList
                     */
                    public list(request: google.cloud.compute.v1.IListVpnTunnelsRequest, callback: google.cloud.compute.v1.VpnTunnels.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListVpnTunnelsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListVpnTunnelsRequest): Promise<google.cloud.compute.v1.VpnTunnelList>;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsVpnTunnelRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsVpnTunnelRequest, callback: google.cloud.compute.v1.VpnTunnels.SetLabelsCallback): void;

                    /**
                     * Calls SetLabels.
                     * @param request SetLabelsVpnTunnelRequest message or plain object
                     * @returns Promise
                     */
                    public setLabels(request: google.cloud.compute.v1.ISetLabelsVpnTunnelRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace VpnTunnels {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnTunnels|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] VpnTunnelAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnTunnelAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnTunnels|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnTunnels|get}.
                     * @param error Error, if any
                     * @param [response] VpnTunnel
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnTunnel) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnTunnels|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnTunnels|list}.
                     * @param error Error, if any
                     * @param [response] VpnTunnelList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.VpnTunnelList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.VpnTunnels|setLabels}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetLabelsCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a ZoneOperations */
                class ZoneOperations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new ZoneOperations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new ZoneOperations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): ZoneOperations;

                    /**
                     * Calls Delete.
                     * @param request DeleteZoneOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DeleteZoneOperationResponse
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteZoneOperationRequest, callback: google.cloud.compute.v1.ZoneOperations.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteZoneOperationRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1.IDeleteZoneOperationRequest): Promise<google.cloud.compute.v1.DeleteZoneOperationResponse>;

                    /**
                     * Calls Get.
                     * @param request GetZoneOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public get(request: google.cloud.compute.v1.IGetZoneOperationRequest, callback: google.cloud.compute.v1.ZoneOperations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetZoneOperationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetZoneOperationRequest): Promise<google.cloud.compute.v1.Operation>;

                    /**
                     * Calls List.
                     * @param request ListZoneOperationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and OperationList
                     */
                    public list(request: google.cloud.compute.v1.IListZoneOperationsRequest, callback: google.cloud.compute.v1.ZoneOperations.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListZoneOperationsRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListZoneOperationsRequest): Promise<google.cloud.compute.v1.OperationList>;

                    /**
                     * Calls Wait.
                     * @param request WaitZoneOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public wait(request: google.cloud.compute.v1.IWaitZoneOperationRequest, callback: google.cloud.compute.v1.ZoneOperations.WaitCallback): void;

                    /**
                     * Calls Wait.
                     * @param request WaitZoneOperationRequest message or plain object
                     * @returns Promise
                     */
                    public wait(request: google.cloud.compute.v1.IWaitZoneOperationRequest): Promise<google.cloud.compute.v1.Operation>;
                }

                namespace ZoneOperations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ZoneOperations|delete_}.
                     * @param error Error, if any
                     * @param [response] DeleteZoneOperationResponse
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1.DeleteZoneOperationResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ZoneOperations|get}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ZoneOperations|list}.
                     * @param error Error, if any
                     * @param [response] OperationList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.OperationList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.ZoneOperations|wait}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type WaitCallback = (error: (Error|null), response?: google.cloud.compute.v1.Operation) => void;
                }

                /** Represents a Zones */
                class Zones extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Zones service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Zones service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Zones;

                    /**
                     * Calls Get.
                     * @param request GetZoneRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Zone
                     */
                    public get(request: google.cloud.compute.v1.IGetZoneRequest, callback: google.cloud.compute.v1.Zones.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetZoneRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1.IGetZoneRequest): Promise<google.cloud.compute.v1.Zone>;

                    /**
                     * Calls List.
                     * @param request ListZonesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ZoneList
                     */
                    public list(request: google.cloud.compute.v1.IListZonesRequest, callback: google.cloud.compute.v1.Zones.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListZonesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1.IListZonesRequest): Promise<google.cloud.compute.v1.ZoneList>;
                }

                namespace Zones {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Zones|get}.
                     * @param error Error, if any
                     * @param [response] Zone
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1.Zone) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1.Zones|list}.
                     * @param error Error, if any
                     * @param [response] ZoneList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1.ZoneList) => void;
                }
            }

            /** Namespace v1small. */
            namespace v1small {

                /** Properties of an Address. */
                interface IAddress {

                    /** Address address */
                    address?: (string|null);

                    /** Address addressType */
                    addressType?: (string|null);

                    /** Address creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Address description */
                    description?: (string|null);

                    /** Address id */
                    id?: (number|Long|string|null);

                    /** Address ipVersion */
                    ipVersion?: (string|null);

                    /** Address kind */
                    kind?: (string|null);

                    /** Address name */
                    name?: (string|null);

                    /** Address network */
                    network?: (string|null);

                    /** Address networkTier */
                    networkTier?: (string|null);

                    /** Address prefixLength */
                    prefixLength?: (number|null);

                    /** Address purpose */
                    purpose?: (string|null);

                    /** Address region */
                    region?: (string|null);

                    /** Address selfLink */
                    selfLink?: (string|null);

                    /** Address status */
                    status?: (string|null);

                    /** Address subnetwork */
                    subnetwork?: (string|null);

                    /** Address users */
                    users?: (string[]|null);
                }

                /** Represents an Address. */
                class Address implements IAddress {

                    /**
                     * Constructs a new Address.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IAddress);

                    /** Address address. */
                    public address?: (string|null);

                    /** Address addressType. */
                    public addressType?: (string|null);

                    /** Address creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Address description. */
                    public description?: (string|null);

                    /** Address id. */
                    public id?: (number|Long|string|null);

                    /** Address ipVersion. */
                    public ipVersion?: (string|null);

                    /** Address kind. */
                    public kind?: (string|null);

                    /** Address name. */
                    public name?: (string|null);

                    /** Address network. */
                    public network?: (string|null);

                    /** Address networkTier. */
                    public networkTier?: (string|null);

                    /** Address prefixLength. */
                    public prefixLength?: (number|null);

                    /** Address purpose. */
                    public purpose?: (string|null);

                    /** Address region. */
                    public region?: (string|null);

                    /** Address selfLink. */
                    public selfLink?: (string|null);

                    /** Address status. */
                    public status?: (string|null);

                    /** Address subnetwork. */
                    public subnetwork?: (string|null);

                    /** Address users. */
                    public users: string[];

                    /** Address _address. */
                    public _address?: "address";

                    /** Address _addressType. */
                    public _addressType?: "addressType";

                    /** Address _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Address _description. */
                    public _description?: "description";

                    /** Address _id. */
                    public _id?: "id";

                    /** Address _ipVersion. */
                    public _ipVersion?: "ipVersion";

                    /** Address _kind. */
                    public _kind?: "kind";

                    /** Address _name. */
                    public _name?: "name";

                    /** Address _network. */
                    public _network?: "network";

                    /** Address _networkTier. */
                    public _networkTier?: "networkTier";

                    /** Address _prefixLength. */
                    public _prefixLength?: "prefixLength";

                    /** Address _purpose. */
                    public _purpose?: "purpose";

                    /** Address _region. */
                    public _region?: "region";

                    /** Address _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Address _status. */
                    public _status?: "status";

                    /** Address _subnetwork. */
                    public _subnetwork?: "subnetwork";

                    /**
                     * Creates a new Address instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Address instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IAddress): google.cloud.compute.v1small.Address;

                    /**
                     * Encodes the specified Address message. Does not implicitly {@link google.cloud.compute.v1small.Address.verify|verify} messages.
                     * @param message Address message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IAddress, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Address message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Address.verify|verify} messages.
                     * @param message Address message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IAddress, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Address message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Address
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Address;

                    /**
                     * Decodes an Address message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Address
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Address;

                    /**
                     * Verifies an Address message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Address message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Address
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Address;

                    /**
                     * Creates a plain object from an Address message. Also converts values to other types if specified.
                     * @param message Address
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Address, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Address to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Address
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Address {

                    /** AddressType enum. */
                    enum AddressType {
                        UNDEFINED_ADDRESS_TYPE = 0,
                        EXTERNAL = 35607499,
                        INTERNAL = 279295677,
                        UNSPECIFIED_TYPE = 53933922
                    }

                    /** IpVersion enum. */
                    enum IpVersion {
                        UNDEFINED_IP_VERSION = 0,
                        IPV4 = 2254341,
                        IPV6 = 2254343,
                        UNSPECIFIED_VERSION = 21850000
                    }

                    /** NetworkTier enum. */
                    enum NetworkTier {
                        UNDEFINED_NETWORK_TIER = 0,
                        PREMIUM = 399530551,
                        STANDARD = 484642493
                    }

                    /** Purpose enum. */
                    enum Purpose {
                        UNDEFINED_PURPOSE = 0,
                        DNS_RESOLVER = 476114556,
                        GCE_ENDPOINT = 230515243,
                        NAT_AUTO = 163666477,
                        VPC_PEERING = 400800170
                    }

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        IN_USE = 17393485,
                        RESERVED = 432241448,
                        RESERVING = 514587225
                    }
                }

                /** Properties of an AddressAggregatedList. */
                interface IAddressAggregatedList {

                    /** AddressAggregatedList id */
                    id?: (string|null);

                    /** AddressAggregatedList items */
                    items?: ({ [k: string]: google.cloud.compute.v1small.IAddressesScopedList }|null);

                    /** AddressAggregatedList kind */
                    kind?: (string|null);

                    /** AddressAggregatedList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AddressAggregatedList selfLink */
                    selfLink?: (string|null);

                    /** AddressAggregatedList warning */
                    warning?: (google.cloud.compute.v1small.IWarning|null);
                }

                /** Represents an AddressAggregatedList. */
                class AddressAggregatedList implements IAddressAggregatedList {

                    /**
                     * Constructs a new AddressAggregatedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IAddressAggregatedList);

                    /** AddressAggregatedList id. */
                    public id?: (string|null);

                    /** AddressAggregatedList items. */
                    public items: { [k: string]: google.cloud.compute.v1small.IAddressesScopedList };

                    /** AddressAggregatedList kind. */
                    public kind?: (string|null);

                    /** AddressAggregatedList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AddressAggregatedList selfLink. */
                    public selfLink?: (string|null);

                    /** AddressAggregatedList warning. */
                    public warning?: (google.cloud.compute.v1small.IWarning|null);

                    /** AddressAggregatedList _id. */
                    public _id?: "id";

                    /** AddressAggregatedList _kind. */
                    public _kind?: "kind";

                    /** AddressAggregatedList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AddressAggregatedList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AddressAggregatedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AddressAggregatedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddressAggregatedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IAddressAggregatedList): google.cloud.compute.v1small.AddressAggregatedList;

                    /**
                     * Encodes the specified AddressAggregatedList message. Does not implicitly {@link google.cloud.compute.v1small.AddressAggregatedList.verify|verify} messages.
                     * @param message AddressAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IAddressAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddressAggregatedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.AddressAggregatedList.verify|verify} messages.
                     * @param message AddressAggregatedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IAddressAggregatedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddressAggregatedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddressAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.AddressAggregatedList;

                    /**
                     * Decodes an AddressAggregatedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddressAggregatedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.AddressAggregatedList;

                    /**
                     * Verifies an AddressAggregatedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddressAggregatedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddressAggregatedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.AddressAggregatedList;

                    /**
                     * Creates a plain object from an AddressAggregatedList message. Also converts values to other types if specified.
                     * @param message AddressAggregatedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.AddressAggregatedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddressAggregatedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddressAggregatedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddressList. */
                interface IAddressList {

                    /** AddressList id */
                    id?: (string|null);

                    /** AddressList items */
                    items?: (google.cloud.compute.v1small.IAddress[]|null);

                    /** AddressList kind */
                    kind?: (string|null);

                    /** AddressList nextPageToken */
                    nextPageToken?: (string|null);

                    /** AddressList selfLink */
                    selfLink?: (string|null);

                    /** AddressList warning */
                    warning?: (google.cloud.compute.v1small.IWarning|null);
                }

                /** Represents an AddressList. */
                class AddressList implements IAddressList {

                    /**
                     * Constructs a new AddressList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IAddressList);

                    /** AddressList id. */
                    public id?: (string|null);

                    /** AddressList items. */
                    public items: google.cloud.compute.v1small.IAddress[];

                    /** AddressList kind. */
                    public kind?: (string|null);

                    /** AddressList nextPageToken. */
                    public nextPageToken?: (string|null);

                    /** AddressList selfLink. */
                    public selfLink?: (string|null);

                    /** AddressList warning. */
                    public warning?: (google.cloud.compute.v1small.IWarning|null);

                    /** AddressList _id. */
                    public _id?: "id";

                    /** AddressList _kind. */
                    public _kind?: "kind";

                    /** AddressList _nextPageToken. */
                    public _nextPageToken?: "nextPageToken";

                    /** AddressList _selfLink. */
                    public _selfLink?: "selfLink";

                    /** AddressList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AddressList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddressList instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IAddressList): google.cloud.compute.v1small.AddressList;

                    /**
                     * Encodes the specified AddressList message. Does not implicitly {@link google.cloud.compute.v1small.AddressList.verify|verify} messages.
                     * @param message AddressList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IAddressList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddressList message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.AddressList.verify|verify} messages.
                     * @param message AddressList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IAddressList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddressList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddressList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.AddressList;

                    /**
                     * Decodes an AddressList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddressList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.AddressList;

                    /**
                     * Verifies an AddressList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddressList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddressList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.AddressList;

                    /**
                     * Creates a plain object from an AddressList message. Also converts values to other types if specified.
                     * @param message AddressList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.AddressList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddressList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddressList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AddressesScopedList. */
                interface IAddressesScopedList {

                    /** AddressesScopedList addresses */
                    addresses?: (google.cloud.compute.v1small.IAddress[]|null);

                    /** AddressesScopedList warning */
                    warning?: (google.cloud.compute.v1small.IWarning|null);
                }

                /** Represents an AddressesScopedList. */
                class AddressesScopedList implements IAddressesScopedList {

                    /**
                     * Constructs a new AddressesScopedList.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IAddressesScopedList);

                    /** AddressesScopedList addresses. */
                    public addresses: google.cloud.compute.v1small.IAddress[];

                    /** AddressesScopedList warning. */
                    public warning?: (google.cloud.compute.v1small.IWarning|null);

                    /** AddressesScopedList _warning. */
                    public _warning?: "warning";

                    /**
                     * Creates a new AddressesScopedList instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AddressesScopedList instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IAddressesScopedList): google.cloud.compute.v1small.AddressesScopedList;

                    /**
                     * Encodes the specified AddressesScopedList message. Does not implicitly {@link google.cloud.compute.v1small.AddressesScopedList.verify|verify} messages.
                     * @param message AddressesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IAddressesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AddressesScopedList message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.AddressesScopedList.verify|verify} messages.
                     * @param message AddressesScopedList message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IAddressesScopedList, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AddressesScopedList message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AddressesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.AddressesScopedList;

                    /**
                     * Decodes an AddressesScopedList message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AddressesScopedList
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.AddressesScopedList;

                    /**
                     * Verifies an AddressesScopedList message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AddressesScopedList message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AddressesScopedList
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.AddressesScopedList;

                    /**
                     * Creates a plain object from an AddressesScopedList message. Also converts values to other types if specified.
                     * @param message AddressesScopedList
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.AddressesScopedList, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AddressesScopedList to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AddressesScopedList
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AggregatedListAddressesRequest. */
                interface IAggregatedListAddressesRequest {

                    /** AggregatedListAddressesRequest filter */
                    filter?: (string|null);

                    /** AggregatedListAddressesRequest includeAllScopes */
                    includeAllScopes?: (boolean|null);

                    /** AggregatedListAddressesRequest maxResults */
                    maxResults?: (number|null);

                    /** AggregatedListAddressesRequest orderBy */
                    orderBy?: (string|null);

                    /** AggregatedListAddressesRequest pageToken */
                    pageToken?: (string|null);

                    /** AggregatedListAddressesRequest project */
                    project?: (string|null);
                }

                /** Represents an AggregatedListAddressesRequest. */
                class AggregatedListAddressesRequest implements IAggregatedListAddressesRequest {

                    /**
                     * Constructs a new AggregatedListAddressesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IAggregatedListAddressesRequest);

                    /** AggregatedListAddressesRequest filter. */
                    public filter?: (string|null);

                    /** AggregatedListAddressesRequest includeAllScopes. */
                    public includeAllScopes?: (boolean|null);

                    /** AggregatedListAddressesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** AggregatedListAddressesRequest orderBy. */
                    public orderBy?: (string|null);

                    /** AggregatedListAddressesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** AggregatedListAddressesRequest project. */
                    public project: string;

                    /** AggregatedListAddressesRequest _filter. */
                    public _filter?: "filter";

                    /** AggregatedListAddressesRequest _includeAllScopes. */
                    public _includeAllScopes?: "includeAllScopes";

                    /** AggregatedListAddressesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** AggregatedListAddressesRequest _orderBy. */
                    public _orderBy?: "orderBy";

                    /** AggregatedListAddressesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /**
                     * Creates a new AggregatedListAddressesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AggregatedListAddressesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IAggregatedListAddressesRequest): google.cloud.compute.v1small.AggregatedListAddressesRequest;

                    /**
                     * Encodes the specified AggregatedListAddressesRequest message. Does not implicitly {@link google.cloud.compute.v1small.AggregatedListAddressesRequest.verify|verify} messages.
                     * @param message AggregatedListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IAggregatedListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AggregatedListAddressesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.AggregatedListAddressesRequest.verify|verify} messages.
                     * @param message AggregatedListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IAggregatedListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AggregatedListAddressesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AggregatedListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.AggregatedListAddressesRequest;

                    /**
                     * Decodes an AggregatedListAddressesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AggregatedListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.AggregatedListAddressesRequest;

                    /**
                     * Verifies an AggregatedListAddressesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AggregatedListAddressesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AggregatedListAddressesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.AggregatedListAddressesRequest;

                    /**
                     * Creates a plain object from an AggregatedListAddressesRequest message. Also converts values to other types if specified.
                     * @param message AggregatedListAddressesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.AggregatedListAddressesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AggregatedListAddressesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AggregatedListAddressesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Data. */
                interface IData {

                    /** Data key */
                    key?: (string|null);

                    /** Data value */
                    value?: (string|null);
                }

                /** Represents a Data. */
                class Data implements IData {

                    /**
                     * Constructs a new Data.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IData);

                    /** Data key. */
                    public key?: (string|null);

                    /** Data value. */
                    public value?: (string|null);

                    /** Data _key. */
                    public _key?: "key";

                    /** Data _value. */
                    public _value?: "value";

                    /**
                     * Creates a new Data instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Data instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IData): google.cloud.compute.v1small.Data;

                    /**
                     * Encodes the specified Data message. Does not implicitly {@link google.cloud.compute.v1small.Data.verify|verify} messages.
                     * @param message Data message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Data message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Data.verify|verify} messages.
                     * @param message Data message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IData, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Data message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Data
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Data;

                    /**
                     * Decodes a Data message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Data
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Data;

                    /**
                     * Verifies a Data message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Data message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Data
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Data;

                    /**
                     * Creates a plain object from a Data message. Also converts values to other types if specified.
                     * @param message Data
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Data, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Data to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Data
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteAddressRequest. */
                interface IDeleteAddressRequest {

                    /** DeleteAddressRequest address */
                    address?: (string|null);

                    /** DeleteAddressRequest project */
                    project?: (string|null);

                    /** DeleteAddressRequest region */
                    region?: (string|null);

                    /** DeleteAddressRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents a DeleteAddressRequest. */
                class DeleteAddressRequest implements IDeleteAddressRequest {

                    /**
                     * Constructs a new DeleteAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IDeleteAddressRequest);

                    /** DeleteAddressRequest address. */
                    public address: string;

                    /** DeleteAddressRequest project. */
                    public project: string;

                    /** DeleteAddressRequest region. */
                    public region: string;

                    /** DeleteAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** DeleteAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new DeleteAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IDeleteAddressRequest): google.cloud.compute.v1small.DeleteAddressRequest;

                    /**
                     * Encodes the specified DeleteAddressRequest message. Does not implicitly {@link google.cloud.compute.v1small.DeleteAddressRequest.verify|verify} messages.
                     * @param message DeleteAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IDeleteAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.DeleteAddressRequest.verify|verify} messages.
                     * @param message DeleteAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IDeleteAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.DeleteAddressRequest;

                    /**
                     * Decodes a DeleteAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.DeleteAddressRequest;

                    /**
                     * Verifies a DeleteAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.DeleteAddressRequest;

                    /**
                     * Creates a plain object from a DeleteAddressRequest message. Also converts values to other types if specified.
                     * @param message DeleteAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.DeleteAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Error. */
                interface IError {

                    /** Error errors */
                    errors?: (google.cloud.compute.v1small.IErrors[]|null);
                }

                /** Represents an Error. */
                class Error implements IError {

                    /**
                     * Constructs a new Error.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IError);

                    /** Error errors. */
                    public errors: google.cloud.compute.v1small.IErrors[];

                    /**
                     * Creates a new Error instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Error instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IError): google.cloud.compute.v1small.Error;

                    /**
                     * Encodes the specified Error message. Does not implicitly {@link google.cloud.compute.v1small.Error.verify|verify} messages.
                     * @param message Error message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Error message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Error.verify|verify} messages.
                     * @param message Error message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IError, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Error message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Error
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Error;

                    /**
                     * Decodes an Error message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Error
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Error;

                    /**
                     * Verifies an Error message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Error message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Error
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Error;

                    /**
                     * Creates a plain object from an Error message. Also converts values to other types if specified.
                     * @param message Error
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Error, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Error to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Error
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Errors. */
                interface IErrors {

                    /** Errors code */
                    code?: (string|null);

                    /** Errors location */
                    location?: (string|null);

                    /** Errors message */
                    message?: (string|null);
                }

                /** Represents an Errors. */
                class Errors implements IErrors {

                    /**
                     * Constructs a new Errors.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IErrors);

                    /** Errors code. */
                    public code?: (string|null);

                    /** Errors location. */
                    public location?: (string|null);

                    /** Errors message. */
                    public message?: (string|null);

                    /** Errors _code. */
                    public _code?: "code";

                    /** Errors _location. */
                    public _location?: "location";

                    /** Errors _message. */
                    public _message?: "message";

                    /**
                     * Creates a new Errors instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Errors instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IErrors): google.cloud.compute.v1small.Errors;

                    /**
                     * Encodes the specified Errors message. Does not implicitly {@link google.cloud.compute.v1small.Errors.verify|verify} messages.
                     * @param message Errors message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IErrors, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Errors message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Errors.verify|verify} messages.
                     * @param message Errors message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IErrors, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Errors message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Errors
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Errors;

                    /**
                     * Decodes an Errors message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Errors
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Errors;

                    /**
                     * Verifies an Errors message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Errors message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Errors
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Errors;

                    /**
                     * Creates a plain object from an Errors message. Also converts values to other types if specified.
                     * @param message Errors
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Errors, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Errors to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Errors
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetRegionOperationRequest. */
                interface IGetRegionOperationRequest {

                    /** GetRegionOperationRequest operation */
                    operation?: (string|null);

                    /** GetRegionOperationRequest project */
                    project?: (string|null);

                    /** GetRegionOperationRequest region */
                    region?: (string|null);
                }

                /** Represents a GetRegionOperationRequest. */
                class GetRegionOperationRequest implements IGetRegionOperationRequest {

                    /**
                     * Constructs a new GetRegionOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IGetRegionOperationRequest);

                    /** GetRegionOperationRequest operation. */
                    public operation: string;

                    /** GetRegionOperationRequest project. */
                    public project: string;

                    /** GetRegionOperationRequest region. */
                    public region: string;

                    /**
                     * Creates a new GetRegionOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetRegionOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IGetRegionOperationRequest): google.cloud.compute.v1small.GetRegionOperationRequest;

                    /**
                     * Encodes the specified GetRegionOperationRequest message. Does not implicitly {@link google.cloud.compute.v1small.GetRegionOperationRequest.verify|verify} messages.
                     * @param message GetRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IGetRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetRegionOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.GetRegionOperationRequest.verify|verify} messages.
                     * @param message GetRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IGetRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetRegionOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.GetRegionOperationRequest;

                    /**
                     * Decodes a GetRegionOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.GetRegionOperationRequest;

                    /**
                     * Verifies a GetRegionOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetRegionOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetRegionOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.GetRegionOperationRequest;

                    /**
                     * Creates a plain object from a GetRegionOperationRequest message. Also converts values to other types if specified.
                     * @param message GetRegionOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.GetRegionOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetRegionOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetRegionOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InsertAddressRequest. */
                interface IInsertAddressRequest {

                    /** InsertAddressRequest addressResource */
                    addressResource?: (google.cloud.compute.v1small.IAddress|null);

                    /** InsertAddressRequest project */
                    project?: (string|null);

                    /** InsertAddressRequest region */
                    region?: (string|null);

                    /** InsertAddressRequest requestId */
                    requestId?: (string|null);
                }

                /** Represents an InsertAddressRequest. */
                class InsertAddressRequest implements IInsertAddressRequest {

                    /**
                     * Constructs a new InsertAddressRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IInsertAddressRequest);

                    /** InsertAddressRequest addressResource. */
                    public addressResource?: (google.cloud.compute.v1small.IAddress|null);

                    /** InsertAddressRequest project. */
                    public project: string;

                    /** InsertAddressRequest region. */
                    public region: string;

                    /** InsertAddressRequest requestId. */
                    public requestId?: (string|null);

                    /** InsertAddressRequest _requestId. */
                    public _requestId?: "requestId";

                    /**
                     * Creates a new InsertAddressRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InsertAddressRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IInsertAddressRequest): google.cloud.compute.v1small.InsertAddressRequest;

                    /**
                     * Encodes the specified InsertAddressRequest message. Does not implicitly {@link google.cloud.compute.v1small.InsertAddressRequest.verify|verify} messages.
                     * @param message InsertAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IInsertAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InsertAddressRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.InsertAddressRequest.verify|verify} messages.
                     * @param message InsertAddressRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IInsertAddressRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InsertAddressRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InsertAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.InsertAddressRequest;

                    /**
                     * Decodes an InsertAddressRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InsertAddressRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.InsertAddressRequest;

                    /**
                     * Verifies an InsertAddressRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InsertAddressRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InsertAddressRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.InsertAddressRequest;

                    /**
                     * Creates a plain object from an InsertAddressRequest message. Also converts values to other types if specified.
                     * @param message InsertAddressRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.InsertAddressRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InsertAddressRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InsertAddressRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListAddressesRequest. */
                interface IListAddressesRequest {

                    /** ListAddressesRequest filter */
                    filter?: (string|null);

                    /** ListAddressesRequest maxResults */
                    maxResults?: (number|null);

                    /** ListAddressesRequest orderBy */
                    orderBy?: (string|null);

                    /** ListAddressesRequest pageToken */
                    pageToken?: (string|null);

                    /** ListAddressesRequest project */
                    project?: (string|null);

                    /** ListAddressesRequest region */
                    region?: (string|null);
                }

                /** Represents a ListAddressesRequest. */
                class ListAddressesRequest implements IListAddressesRequest {

                    /**
                     * Constructs a new ListAddressesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IListAddressesRequest);

                    /** ListAddressesRequest filter. */
                    public filter?: (string|null);

                    /** ListAddressesRequest maxResults. */
                    public maxResults?: (number|null);

                    /** ListAddressesRequest orderBy. */
                    public orderBy: string;

                    /** ListAddressesRequest pageToken. */
                    public pageToken?: (string|null);

                    /** ListAddressesRequest project. */
                    public project: string;

                    /** ListAddressesRequest region. */
                    public region: string;

                    /** ListAddressesRequest _filter. */
                    public _filter?: "filter";

                    /** ListAddressesRequest _maxResults. */
                    public _maxResults?: "maxResults";

                    /** ListAddressesRequest _pageToken. */
                    public _pageToken?: "pageToken";

                    /**
                     * Creates a new ListAddressesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListAddressesRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IListAddressesRequest): google.cloud.compute.v1small.ListAddressesRequest;

                    /**
                     * Encodes the specified ListAddressesRequest message. Does not implicitly {@link google.cloud.compute.v1small.ListAddressesRequest.verify|verify} messages.
                     * @param message ListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListAddressesRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.ListAddressesRequest.verify|verify} messages.
                     * @param message ListAddressesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IListAddressesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListAddressesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.ListAddressesRequest;

                    /**
                     * Decodes a ListAddressesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListAddressesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.ListAddressesRequest;

                    /**
                     * Verifies a ListAddressesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListAddressesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListAddressesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.ListAddressesRequest;

                    /**
                     * Creates a plain object from a ListAddressesRequest message. Also converts values to other types if specified.
                     * @param message ListAddressesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.ListAddressesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListAddressesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListAddressesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Operation. */
                interface IOperation {

                    /** Operation clientOperationId */
                    clientOperationId?: (string|null);

                    /** Operation creationTimestamp */
                    creationTimestamp?: (string|null);

                    /** Operation description */
                    description?: (string|null);

                    /** Operation endTime */
                    endTime?: (string|null);

                    /** Operation error */
                    error?: (google.cloud.compute.v1small.IError|null);

                    /** Operation httpErrorMessage */
                    httpErrorMessage?: (string|null);

                    /** Operation httpErrorStatusCode */
                    httpErrorStatusCode?: (number|null);

                    /** Operation id */
                    id?: (number|Long|string|null);

                    /** Operation insertTime */
                    insertTime?: (string|null);

                    /** Operation kind */
                    kind?: (string|null);

                    /** Operation name */
                    name?: (string|null);

                    /** Operation operationType */
                    operationType?: (string|null);

                    /** Operation progress */
                    progress?: (number|null);

                    /** Operation region */
                    region?: (string|null);

                    /** Operation selfLink */
                    selfLink?: (string|null);

                    /** Operation startTime */
                    startTime?: (string|null);

                    /** Operation status */
                    status?: (google.cloud.compute.v1small.Operation.Status|keyof typeof google.cloud.compute.v1small.Operation.Status|null);

                    /** Operation statusMessage */
                    statusMessage?: (string|null);

                    /** Operation targetId */
                    targetId?: (number|Long|string|null);

                    /** Operation targetLink */
                    targetLink?: (string|null);

                    /** Operation user */
                    user?: (string|null);

                    /** Operation warnings */
                    warnings?: (google.cloud.compute.v1small.IWarnings[]|null);

                    /** Operation zone */
                    zone?: (string|null);
                }

                /** Represents an Operation. */
                class Operation implements IOperation {

                    /**
                     * Constructs a new Operation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IOperation);

                    /** Operation clientOperationId. */
                    public clientOperationId?: (string|null);

                    /** Operation creationTimestamp. */
                    public creationTimestamp?: (string|null);

                    /** Operation description. */
                    public description?: (string|null);

                    /** Operation endTime. */
                    public endTime?: (string|null);

                    /** Operation error. */
                    public error?: (google.cloud.compute.v1small.IError|null);

                    /** Operation httpErrorMessage. */
                    public httpErrorMessage?: (string|null);

                    /** Operation httpErrorStatusCode. */
                    public httpErrorStatusCode?: (number|null);

                    /** Operation id. */
                    public id?: (number|Long|string|null);

                    /** Operation insertTime. */
                    public insertTime?: (string|null);

                    /** Operation kind. */
                    public kind?: (string|null);

                    /** Operation name. */
                    public name?: (string|null);

                    /** Operation operationType. */
                    public operationType?: (string|null);

                    /** Operation progress. */
                    public progress?: (number|null);

                    /** Operation region. */
                    public region?: (string|null);

                    /** Operation selfLink. */
                    public selfLink?: (string|null);

                    /** Operation startTime. */
                    public startTime?: (string|null);

                    /** Operation status. */
                    public status?: (google.cloud.compute.v1small.Operation.Status|keyof typeof google.cloud.compute.v1small.Operation.Status|null);

                    /** Operation statusMessage. */
                    public statusMessage?: (string|null);

                    /** Operation targetId. */
                    public targetId?: (number|Long|string|null);

                    /** Operation targetLink. */
                    public targetLink?: (string|null);

                    /** Operation user. */
                    public user?: (string|null);

                    /** Operation warnings. */
                    public warnings: google.cloud.compute.v1small.IWarnings[];

                    /** Operation zone. */
                    public zone?: (string|null);

                    /** Operation _clientOperationId. */
                    public _clientOperationId?: "clientOperationId";

                    /** Operation _creationTimestamp. */
                    public _creationTimestamp?: "creationTimestamp";

                    /** Operation _description. */
                    public _description?: "description";

                    /** Operation _endTime. */
                    public _endTime?: "endTime";

                    /** Operation _error. */
                    public _error?: "error";

                    /** Operation _httpErrorMessage. */
                    public _httpErrorMessage?: "httpErrorMessage";

                    /** Operation _httpErrorStatusCode. */
                    public _httpErrorStatusCode?: "httpErrorStatusCode";

                    /** Operation _id. */
                    public _id?: "id";

                    /** Operation _insertTime. */
                    public _insertTime?: "insertTime";

                    /** Operation _kind. */
                    public _kind?: "kind";

                    /** Operation _name. */
                    public _name?: "name";

                    /** Operation _operationType. */
                    public _operationType?: "operationType";

                    /** Operation _progress. */
                    public _progress?: "progress";

                    /** Operation _region. */
                    public _region?: "region";

                    /** Operation _selfLink. */
                    public _selfLink?: "selfLink";

                    /** Operation _startTime. */
                    public _startTime?: "startTime";

                    /** Operation _status. */
                    public _status?: "status";

                    /** Operation _statusMessage. */
                    public _statusMessage?: "statusMessage";

                    /** Operation _targetId. */
                    public _targetId?: "targetId";

                    /** Operation _targetLink. */
                    public _targetLink?: "targetLink";

                    /** Operation _user. */
                    public _user?: "user";

                    /** Operation _zone. */
                    public _zone?: "zone";

                    /**
                     * Creates a new Operation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Operation instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IOperation): google.cloud.compute.v1small.Operation;

                    /**
                     * Encodes the specified Operation message. Does not implicitly {@link google.cloud.compute.v1small.Operation.verify|verify} messages.
                     * @param message Operation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IOperation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Operation message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Operation.verify|verify} messages.
                     * @param message Operation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IOperation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Operation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Operation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Operation;

                    /**
                     * Decodes an Operation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Operation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Operation;

                    /**
                     * Verifies an Operation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Operation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Operation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Operation;

                    /**
                     * Creates a plain object from an Operation message. Also converts values to other types if specified.
                     * @param message Operation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Operation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Operation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Operation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Operation {

                    /** Status enum. */
                    enum Status {
                        UNDEFINED_STATUS = 0,
                        DONE = 2104194,
                        PENDING = 35394935,
                        RUNNING = 121282975
                    }
                }

                /** Properties of a WaitRegionOperationRequest. */
                interface IWaitRegionOperationRequest {

                    /** WaitRegionOperationRequest operation */
                    operation?: (string|null);

                    /** WaitRegionOperationRequest project */
                    project?: (string|null);

                    /** WaitRegionOperationRequest region */
                    region?: (string|null);
                }

                /** Represents a WaitRegionOperationRequest. */
                class WaitRegionOperationRequest implements IWaitRegionOperationRequest {

                    /**
                     * Constructs a new WaitRegionOperationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IWaitRegionOperationRequest);

                    /** WaitRegionOperationRequest operation. */
                    public operation: string;

                    /** WaitRegionOperationRequest project. */
                    public project: string;

                    /** WaitRegionOperationRequest region. */
                    public region: string;

                    /**
                     * Creates a new WaitRegionOperationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns WaitRegionOperationRequest instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IWaitRegionOperationRequest): google.cloud.compute.v1small.WaitRegionOperationRequest;

                    /**
                     * Encodes the specified WaitRegionOperationRequest message. Does not implicitly {@link google.cloud.compute.v1small.WaitRegionOperationRequest.verify|verify} messages.
                     * @param message WaitRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IWaitRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified WaitRegionOperationRequest message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.WaitRegionOperationRequest.verify|verify} messages.
                     * @param message WaitRegionOperationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IWaitRegionOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a WaitRegionOperationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns WaitRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.WaitRegionOperationRequest;

                    /**
                     * Decodes a WaitRegionOperationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns WaitRegionOperationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.WaitRegionOperationRequest;

                    /**
                     * Verifies a WaitRegionOperationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a WaitRegionOperationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns WaitRegionOperationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.WaitRegionOperationRequest;

                    /**
                     * Creates a plain object from a WaitRegionOperationRequest message. Also converts values to other types if specified.
                     * @param message WaitRegionOperationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.WaitRegionOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this WaitRegionOperationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for WaitRegionOperationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Warning. */
                interface IWarning {

                    /** Warning code */
                    code?: (string|null);

                    /** Warning data */
                    data?: (google.cloud.compute.v1small.IData[]|null);

                    /** Warning message */
                    message?: (string|null);
                }

                /** Represents a Warning. */
                class Warning implements IWarning {

                    /**
                     * Constructs a new Warning.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IWarning);

                    /** Warning code. */
                    public code?: (string|null);

                    /** Warning data. */
                    public data: google.cloud.compute.v1small.IData[];

                    /** Warning message. */
                    public message?: (string|null);

                    /** Warning _code. */
                    public _code?: "code";

                    /** Warning _message. */
                    public _message?: "message";

                    /**
                     * Creates a new Warning instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Warning instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IWarning): google.cloud.compute.v1small.Warning;

                    /**
                     * Encodes the specified Warning message. Does not implicitly {@link google.cloud.compute.v1small.Warning.verify|verify} messages.
                     * @param message Warning message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IWarning, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Warning message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Warning.verify|verify} messages.
                     * @param message Warning message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IWarning, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Warning message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Warning
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Warning;

                    /**
                     * Decodes a Warning message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Warning
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Warning;

                    /**
                     * Verifies a Warning message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Warning message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Warning
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Warning;

                    /**
                     * Creates a plain object from a Warning message. Also converts values to other types if specified.
                     * @param message Warning
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Warning, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Warning to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Warning
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Warning {

                    /** Code enum. */
                    enum Code {
                        UNDEFINED_CODE = 0,
                        CLEANUP_FAILED = 150308440,
                        DEPRECATED_RESOURCE_USED = 391835586,
                        DEPRECATED_TYPE_USED = 346526230,
                        DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369442967,
                        EXPERIMENTAL_TYPE_USED = 451954443,
                        EXTERNAL_API_WARNING = 175546307,
                        FIELD_VALUE_OVERRIDEN = 329669423,
                        INJECTED_KERNELS_DEPRECATED = 417377419,
                        MISSING_TYPE_DEPENDENCY = 344505463,
                        NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324964999,
                        NEXT_HOP_CANNOT_IP_FORWARD = 383382887,
                        NEXT_HOP_INSTANCE_NOT_FOUND = 464250446,
                        NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243758146,
                        NEXT_HOP_NOT_RUNNING = 417081265,
                        NOT_CRITICAL_ERROR = 105763924,
                        NO_RESULTS_ON_PAGE = 30036744,
                        REQUIRED_TOS_AGREEMENT = 3745539,
                        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496728641,
                        RESOURCE_NOT_DELETED = 168598460,
                        SCHEMA_VALIDATION_IGNORED = 275245642,
                        SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268305617,
                        UNDECLARED_PROPERTIES = 390513439,
                        UNREACHABLE = 13328052
                    }
                }

                /** Properties of a Warnings. */
                interface IWarnings {

                    /** Warnings code */
                    code?: (string|null);

                    /** Warnings data */
                    data?: (google.cloud.compute.v1small.IData[]|null);

                    /** Warnings message */
                    message?: (string|null);
                }

                /** Represents a Warnings. */
                class Warnings implements IWarnings {

                    /**
                     * Constructs a new Warnings.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.compute.v1small.IWarnings);

                    /** Warnings code. */
                    public code?: (string|null);

                    /** Warnings data. */
                    public data: google.cloud.compute.v1small.IData[];

                    /** Warnings message. */
                    public message?: (string|null);

                    /** Warnings _code. */
                    public _code?: "code";

                    /** Warnings _message. */
                    public _message?: "message";

                    /**
                     * Creates a new Warnings instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Warnings instance
                     */
                    public static create(properties?: google.cloud.compute.v1small.IWarnings): google.cloud.compute.v1small.Warnings;

                    /**
                     * Encodes the specified Warnings message. Does not implicitly {@link google.cloud.compute.v1small.Warnings.verify|verify} messages.
                     * @param message Warnings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.compute.v1small.IWarnings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Warnings message, length delimited. Does not implicitly {@link google.cloud.compute.v1small.Warnings.verify|verify} messages.
                     * @param message Warnings message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.compute.v1small.IWarnings, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Warnings message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Warnings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.compute.v1small.Warnings;

                    /**
                     * Decodes a Warnings message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Warnings
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.compute.v1small.Warnings;

                    /**
                     * Verifies a Warnings message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Warnings message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Warnings
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.compute.v1small.Warnings;

                    /**
                     * Creates a plain object from a Warnings message. Also converts values to other types if specified.
                     * @param message Warnings
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.compute.v1small.Warnings, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Warnings to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Warnings
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Warnings {

                    /** Code enum. */
                    enum Code {
                        UNDEFINED_CODE = 0,
                        CLEANUP_FAILED = 150308440,
                        DEPRECATED_RESOURCE_USED = 391835586,
                        DEPRECATED_TYPE_USED = 346526230,
                        DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369442967,
                        EXPERIMENTAL_TYPE_USED = 451954443,
                        EXTERNAL_API_WARNING = 175546307,
                        FIELD_VALUE_OVERRIDEN = 329669423,
                        INJECTED_KERNELS_DEPRECATED = 417377419,
                        MISSING_TYPE_DEPENDENCY = 344505463,
                        NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324964999,
                        NEXT_HOP_CANNOT_IP_FORWARD = 383382887,
                        NEXT_HOP_INSTANCE_NOT_FOUND = 464250446,
                        NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243758146,
                        NEXT_HOP_NOT_RUNNING = 417081265,
                        NOT_CRITICAL_ERROR = 105763924,
                        NO_RESULTS_ON_PAGE = 30036744,
                        REQUIRED_TOS_AGREEMENT = 3745539,
                        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496728641,
                        RESOURCE_NOT_DELETED = 168598460,
                        SCHEMA_VALIDATION_IGNORED = 275245642,
                        SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268305617,
                        UNDECLARED_PROPERTIES = 390513439,
                        UNREACHABLE = 13328052
                    }
                }

                /** Represents an Addresses */
                class Addresses extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new Addresses service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new Addresses service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Addresses;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAddressesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AddressAggregatedList
                     */
                    public aggregatedList(request: google.cloud.compute.v1small.IAggregatedListAddressesRequest, callback: google.cloud.compute.v1small.Addresses.AggregatedListCallback): void;

                    /**
                     * Calls AggregatedList.
                     * @param request AggregatedListAddressesRequest message or plain object
                     * @returns Promise
                     */
                    public aggregatedList(request: google.cloud.compute.v1small.IAggregatedListAddressesRequest): Promise<google.cloud.compute.v1small.AddressAggregatedList>;

                    /**
                     * Calls Delete.
                     * @param request DeleteAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public delete(request: google.cloud.compute.v1small.IDeleteAddressRequest, callback: google.cloud.compute.v1small.Addresses.DeleteCallback): void;

                    /**
                     * Calls Delete.
                     * @param request DeleteAddressRequest message or plain object
                     * @returns Promise
                     */
                    public delete(request: google.cloud.compute.v1small.IDeleteAddressRequest): Promise<google.cloud.compute.v1small.Operation>;

                    /**
                     * Calls Insert.
                     * @param request InsertAddressRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public insert(request: google.cloud.compute.v1small.IInsertAddressRequest, callback: google.cloud.compute.v1small.Addresses.InsertCallback): void;

                    /**
                     * Calls Insert.
                     * @param request InsertAddressRequest message or plain object
                     * @returns Promise
                     */
                    public insert(request: google.cloud.compute.v1small.IInsertAddressRequest): Promise<google.cloud.compute.v1small.Operation>;

                    /**
                     * Calls List.
                     * @param request ListAddressesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and AddressList
                     */
                    public list(request: google.cloud.compute.v1small.IListAddressesRequest, callback: google.cloud.compute.v1small.Addresses.ListCallback): void;

                    /**
                     * Calls List.
                     * @param request ListAddressesRequest message or plain object
                     * @returns Promise
                     */
                    public list(request: google.cloud.compute.v1small.IListAddressesRequest): Promise<google.cloud.compute.v1small.AddressList>;
                }

                namespace Addresses {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1small.Addresses|aggregatedList}.
                     * @param error Error, if any
                     * @param [response] AddressAggregatedList
                     */
                    type AggregatedListCallback = (error: (Error|null), response?: google.cloud.compute.v1small.AddressAggregatedList) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1small.Addresses|delete_}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteCallback = (error: (Error|null), response?: google.cloud.compute.v1small.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1small.Addresses|insert}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type InsertCallback = (error: (Error|null), response?: google.cloud.compute.v1small.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1small.Addresses|list}.
                     * @param error Error, if any
                     * @param [response] AddressList
                     */
                    type ListCallback = (error: (Error|null), response?: google.cloud.compute.v1small.AddressList) => void;
                }

                /** Represents a RegionOperations */
                class RegionOperations extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new RegionOperations service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new RegionOperations service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): RegionOperations;

                    /**
                     * Calls Get.
                     * @param request GetRegionOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public get(request: google.cloud.compute.v1small.IGetRegionOperationRequest, callback: google.cloud.compute.v1small.RegionOperations.GetCallback): void;

                    /**
                     * Calls Get.
                     * @param request GetRegionOperationRequest message or plain object
                     * @returns Promise
                     */
                    public get(request: google.cloud.compute.v1small.IGetRegionOperationRequest): Promise<google.cloud.compute.v1small.Operation>;

                    /**
                     * Calls Wait.
                     * @param request WaitRegionOperationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public wait(request: google.cloud.compute.v1small.IWaitRegionOperationRequest, callback: google.cloud.compute.v1small.RegionOperations.WaitCallback): void;

                    /**
                     * Calls Wait.
                     * @param request WaitRegionOperationRequest message or plain object
                     * @returns Promise
                     */
                    public wait(request: google.cloud.compute.v1small.IWaitRegionOperationRequest): Promise<google.cloud.compute.v1small.Operation>;
                }

                namespace RegionOperations {

                    /**
                     * Callback as used by {@link google.cloud.compute.v1small.RegionOperations|get}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type GetCallback = (error: (Error|null), response?: google.cloud.compute.v1small.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.compute.v1small.RegionOperations|wait}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type WaitCallback = (error: (Error|null), response?: google.cloud.compute.v1small.Operation) => void;
                }
            }
        }
    }

    /** Namespace api. */
    namespace api {

        /** Properties of a Http. */
        interface IHttp {

            /** Http rules */
            rules?: (google.api.IHttpRule[]|null);

            /** Http fullyDecodeReservedExpansion */
            fullyDecodeReservedExpansion?: (boolean|null);
        }

        /** Represents a Http. */
        class Http implements IHttp {

            /**
             * Constructs a new Http.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IHttp);

            /** Http rules. */
            public rules: google.api.IHttpRule[];

            /** Http fullyDecodeReservedExpansion. */
            public fullyDecodeReservedExpansion: boolean;

            /**
             * Creates a new Http instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Http instance
             */
            public static create(properties?: google.api.IHttp): google.api.Http;

            /**
             * Encodes the specified Http message. Does not implicitly {@link google.api.Http.verify|verify} messages.
             * @param message Http message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IHttp, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Http message, length delimited. Does not implicitly {@link google.api.Http.verify|verify} messages.
             * @param message Http message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IHttp, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Http message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Http
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.Http;

            /**
             * Decodes a Http message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Http
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.Http;

            /**
             * Verifies a Http message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Http message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Http
             */
            public static fromObject(object: { [k: string]: any }): google.api.Http;

            /**
             * Creates a plain object from a Http message. Also converts values to other types if specified.
             * @param message Http
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.Http, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Http to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Http
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a HttpRule. */
        interface IHttpRule {

            /** HttpRule selector */
            selector?: (string|null);

            /** HttpRule get */
            get?: (string|null);

            /** HttpRule put */
            put?: (string|null);

            /** HttpRule post */
            post?: (string|null);

            /** HttpRule delete */
            "delete"?: (string|null);

            /** HttpRule patch */
            patch?: (string|null);

            /** HttpRule custom */
            custom?: (google.api.ICustomHttpPattern|null);

            /** HttpRule body */
            body?: (string|null);

            /** HttpRule responseBody */
            responseBody?: (string|null);

            /** HttpRule additionalBindings */
            additionalBindings?: (google.api.IHttpRule[]|null);
        }

        /** Represents a HttpRule. */
        class HttpRule implements IHttpRule {

            /**
             * Constructs a new HttpRule.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IHttpRule);

            /** HttpRule selector. */
            public selector: string;

            /** HttpRule get. */
            public get?: (string|null);

            /** HttpRule put. */
            public put?: (string|null);

            /** HttpRule post. */
            public post?: (string|null);

            /** HttpRule delete. */
            public delete?: (string|null);

            /** HttpRule patch. */
            public patch?: (string|null);

            /** HttpRule custom. */
            public custom?: (google.api.ICustomHttpPattern|null);

            /** HttpRule body. */
            public body: string;

            /** HttpRule responseBody. */
            public responseBody: string;

            /** HttpRule additionalBindings. */
            public additionalBindings: google.api.IHttpRule[];

            /** HttpRule pattern. */
            public pattern?: ("get"|"put"|"post"|"delete"|"patch"|"custom");

            /**
             * Creates a new HttpRule instance using the specified properties.
             * @param [properties] Properties to set
             * @returns HttpRule instance
             */
            public static create(properties?: google.api.IHttpRule): google.api.HttpRule;

            /**
             * Encodes the specified HttpRule message. Does not implicitly {@link google.api.HttpRule.verify|verify} messages.
             * @param message HttpRule message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IHttpRule, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified HttpRule message, length delimited. Does not implicitly {@link google.api.HttpRule.verify|verify} messages.
             * @param message HttpRule message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IHttpRule, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a HttpRule message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns HttpRule
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.HttpRule;

            /**
             * Decodes a HttpRule message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns HttpRule
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.HttpRule;

            /**
             * Verifies a HttpRule message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a HttpRule message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns HttpRule
             */
            public static fromObject(object: { [k: string]: any }): google.api.HttpRule;

            /**
             * Creates a plain object from a HttpRule message. Also converts values to other types if specified.
             * @param message HttpRule
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.HttpRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this HttpRule to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for HttpRule
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a CustomHttpPattern. */
        interface ICustomHttpPattern {

            /** CustomHttpPattern kind */
            kind?: (string|null);

            /** CustomHttpPattern path */
            path?: (string|null);
        }

        /** Represents a CustomHttpPattern. */
        class CustomHttpPattern implements ICustomHttpPattern {

            /**
             * Constructs a new CustomHttpPattern.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.ICustomHttpPattern);

            /** CustomHttpPattern kind. */
            public kind: string;

            /** CustomHttpPattern path. */
            public path: string;

            /**
             * Creates a new CustomHttpPattern instance using the specified properties.
             * @param [properties] Properties to set
             * @returns CustomHttpPattern instance
             */
            public static create(properties?: google.api.ICustomHttpPattern): google.api.CustomHttpPattern;

            /**
             * Encodes the specified CustomHttpPattern message. Does not implicitly {@link google.api.CustomHttpPattern.verify|verify} messages.
             * @param message CustomHttpPattern message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.ICustomHttpPattern, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified CustomHttpPattern message, length delimited. Does not implicitly {@link google.api.CustomHttpPattern.verify|verify} messages.
             * @param message CustomHttpPattern message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.ICustomHttpPattern, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a CustomHttpPattern message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns CustomHttpPattern
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.CustomHttpPattern;

            /**
             * Decodes a CustomHttpPattern message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns CustomHttpPattern
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.CustomHttpPattern;

            /**
             * Verifies a CustomHttpPattern message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a CustomHttpPattern message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns CustomHttpPattern
             */
            public static fromObject(object: { [k: string]: any }): google.api.CustomHttpPattern;

            /**
             * Creates a plain object from a CustomHttpPattern message. Also converts values to other types if specified.
             * @param message CustomHttpPattern
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.CustomHttpPattern, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this CustomHttpPattern to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for CustomHttpPattern
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** FieldBehavior enum. */
        enum FieldBehavior {
            FIELD_BEHAVIOR_UNSPECIFIED = 0,
            OPTIONAL = 1,
            REQUIRED = 2,
            OUTPUT_ONLY = 3,
            INPUT_ONLY = 4,
            IMMUTABLE = 5,
            UNORDERED_LIST = 6,
            NON_EMPTY_DEFAULT = 7
        }

        /** Properties of a ResourceDescriptor. */
        interface IResourceDescriptor {

            /** ResourceDescriptor type */
            type?: (string|null);

            /** ResourceDescriptor pattern */
            pattern?: (string[]|null);

            /** ResourceDescriptor nameField */
            nameField?: (string|null);

            /** ResourceDescriptor history */
            history?: (google.api.ResourceDescriptor.History|keyof typeof google.api.ResourceDescriptor.History|null);

            /** ResourceDescriptor plural */
            plural?: (string|null);

            /** ResourceDescriptor singular */
            singular?: (string|null);

            /** ResourceDescriptor style */
            style?: (google.api.ResourceDescriptor.Style[]|null);
        }

        /** Represents a ResourceDescriptor. */
        class ResourceDescriptor implements IResourceDescriptor {

            /**
             * Constructs a new ResourceDescriptor.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IResourceDescriptor);

            /** ResourceDescriptor type. */
            public type: string;

            /** ResourceDescriptor pattern. */
            public pattern: string[];

            /** ResourceDescriptor nameField. */
            public nameField: string;

            /** ResourceDescriptor history. */
            public history: (google.api.ResourceDescriptor.History|keyof typeof google.api.ResourceDescriptor.History);

            /** ResourceDescriptor plural. */
            public plural: string;

            /** ResourceDescriptor singular. */
            public singular: string;

            /** ResourceDescriptor style. */
            public style: google.api.ResourceDescriptor.Style[];

            /**
             * Creates a new ResourceDescriptor instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ResourceDescriptor instance
             */
            public static create(properties?: google.api.IResourceDescriptor): google.api.ResourceDescriptor;

            /**
             * Encodes the specified ResourceDescriptor message. Does not implicitly {@link google.api.ResourceDescriptor.verify|verify} messages.
             * @param message ResourceDescriptor message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IResourceDescriptor, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ResourceDescriptor message, length delimited. Does not implicitly {@link google.api.ResourceDescriptor.verify|verify} messages.
             * @param message ResourceDescriptor message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IResourceDescriptor, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ResourceDescriptor message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ResourceDescriptor
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.ResourceDescriptor;

            /**
             * Decodes a ResourceDescriptor message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ResourceDescriptor
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.ResourceDescriptor;

            /**
             * Verifies a ResourceDescriptor message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ResourceDescriptor message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ResourceDescriptor
             */
            public static fromObject(object: { [k: string]: any }): google.api.ResourceDescriptor;

            /**
             * Creates a plain object from a ResourceDescriptor message. Also converts values to other types if specified.
             * @param message ResourceDescriptor
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.ResourceDescriptor, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ResourceDescriptor to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ResourceDescriptor
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace ResourceDescriptor {

            /** History enum. */
            enum History {
                HISTORY_UNSPECIFIED = 0,
                ORIGINALLY_SINGLE_PATTERN = 1,
                FUTURE_MULTI_PATTERN = 2
            }

            /** Style enum. */
            enum Style {
                STYLE_UNSPECIFIED = 0,
                DECLARATIVE_FRIENDLY = 1
            }
        }

        /** Properties of a ResourceReference. */
        interface IResourceReference {

            /** ResourceReference type */
            type?: (string|null);

            /** ResourceReference childType */
            childType?: (string|null);
        }

        /** Represents a ResourceReference. */
        class ResourceReference implements IResourceReference {

            /**
             * Constructs a new ResourceReference.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IResourceReference);

            /** ResourceReference type. */
            public type: string;

            /** ResourceReference childType. */
            public childType: string;

            /**
             * Creates a new ResourceReference instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ResourceReference instance
             */
            public static create(properties?: google.api.IResourceReference): google.api.ResourceReference;

            /**
             * Encodes the specified ResourceReference message. Does not implicitly {@link google.api.ResourceReference.verify|verify} messages.
             * @param message ResourceReference message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IResourceReference, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ResourceReference message, length delimited. Does not implicitly {@link google.api.ResourceReference.verify|verify} messages.
             * @param message ResourceReference message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IResourceReference, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ResourceReference message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ResourceReference
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.ResourceReference;

            /**
             * Decodes a ResourceReference message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ResourceReference
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.ResourceReference;

            /**
             * Verifies a ResourceReference message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ResourceReference message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ResourceReference
             */
            public static fromObject(object: { [k: string]: any }): google.api.ResourceReference;

            /**
             * Creates a plain object from a ResourceReference message. Also converts values to other types if specified.
             * @param message ResourceReference
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.ResourceReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ResourceReference to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ResourceReference
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }
    }

    /** Namespace protobuf. */
    namespace protobuf {

        /** Properties of a FileDescriptorSet. */
        interface IFileDescriptorSet {

            /** FileDescriptorSet file */
            file?: (google.protobuf.IFileDescriptorProto[]|null);
        }

        /** Represents a FileDescriptorSet. */
        class FileDescriptorSet implements IFileDescriptorSet {

            /**
             * Constructs a new FileDescriptorSet.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFileDescriptorSet);

            /** FileDescriptorSet file. */
            public file: google.protobuf.IFileDescriptorProto[];

            /**
             * Creates a new FileDescriptorSet instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FileDescriptorSet instance
             */
            public static create(properties?: google.protobuf.IFileDescriptorSet): google.protobuf.FileDescriptorSet;

            /**
             * Encodes the specified FileDescriptorSet message. Does not implicitly {@link google.protobuf.FileDescriptorSet.verify|verify} messages.
             * @param message FileDescriptorSet message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFileDescriptorSet, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FileDescriptorSet message, length delimited. Does not implicitly {@link google.protobuf.FileDescriptorSet.verify|verify} messages.
             * @param message FileDescriptorSet message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFileDescriptorSet, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FileDescriptorSet message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FileDescriptorSet
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FileDescriptorSet;

            /**
             * Decodes a FileDescriptorSet message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FileDescriptorSet
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FileDescriptorSet;

            /**
             * Verifies a FileDescriptorSet message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FileDescriptorSet message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FileDescriptorSet
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FileDescriptorSet;

            /**
             * Creates a plain object from a FileDescriptorSet message. Also converts values to other types if specified.
             * @param message FileDescriptorSet
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FileDescriptorSet, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FileDescriptorSet to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FileDescriptorSet
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FileDescriptorProto. */
        interface IFileDescriptorProto {

            /** FileDescriptorProto name */
            name?: (string|null);

            /** FileDescriptorProto package */
            "package"?: (string|null);

            /** FileDescriptorProto dependency */
            dependency?: (string[]|null);

            /** FileDescriptorProto publicDependency */
            publicDependency?: (number[]|null);

            /** FileDescriptorProto weakDependency */
            weakDependency?: (number[]|null);

            /** FileDescriptorProto messageType */
            messageType?: (google.protobuf.IDescriptorProto[]|null);

            /** FileDescriptorProto enumType */
            enumType?: (google.protobuf.IEnumDescriptorProto[]|null);

            /** FileDescriptorProto service */
            service?: (google.protobuf.IServiceDescriptorProto[]|null);

            /** FileDescriptorProto extension */
            extension?: (google.protobuf.IFieldDescriptorProto[]|null);

            /** FileDescriptorProto options */
            options?: (google.protobuf.IFileOptions|null);

            /** FileDescriptorProto sourceCodeInfo */
            sourceCodeInfo?: (google.protobuf.ISourceCodeInfo|null);

            /** FileDescriptorProto syntax */
            syntax?: (string|null);

            /** FileDescriptorProto edition */
            edition?: (string|null);
        }

        /** Represents a FileDescriptorProto. */
        class FileDescriptorProto implements IFileDescriptorProto {

            /**
             * Constructs a new FileDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFileDescriptorProto);

            /** FileDescriptorProto name. */
            public name: string;

            /** FileDescriptorProto package. */
            public package: string;

            /** FileDescriptorProto dependency. */
            public dependency: string[];

            /** FileDescriptorProto publicDependency. */
            public publicDependency: number[];

            /** FileDescriptorProto weakDependency. */
            public weakDependency: number[];

            /** FileDescriptorProto messageType. */
            public messageType: google.protobuf.IDescriptorProto[];

            /** FileDescriptorProto enumType. */
            public enumType: google.protobuf.IEnumDescriptorProto[];

            /** FileDescriptorProto service. */
            public service: google.protobuf.IServiceDescriptorProto[];

            /** FileDescriptorProto extension. */
            public extension: google.protobuf.IFieldDescriptorProto[];

            /** FileDescriptorProto options. */
            public options?: (google.protobuf.IFileOptions|null);

            /** FileDescriptorProto sourceCodeInfo. */
            public sourceCodeInfo?: (google.protobuf.ISourceCodeInfo|null);

            /** FileDescriptorProto syntax. */
            public syntax: string;

            /** FileDescriptorProto edition. */
            public edition: string;

            /**
             * Creates a new FileDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FileDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IFileDescriptorProto): google.protobuf.FileDescriptorProto;

            /**
             * Encodes the specified FileDescriptorProto message. Does not implicitly {@link google.protobuf.FileDescriptorProto.verify|verify} messages.
             * @param message FileDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFileDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FileDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.FileDescriptorProto.verify|verify} messages.
             * @param message FileDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFileDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FileDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FileDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FileDescriptorProto;

            /**
             * Decodes a FileDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FileDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FileDescriptorProto;

            /**
             * Verifies a FileDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FileDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FileDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FileDescriptorProto;

            /**
             * Creates a plain object from a FileDescriptorProto message. Also converts values to other types if specified.
             * @param message FileDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FileDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FileDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FileDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a DescriptorProto. */
        interface IDescriptorProto {

            /** DescriptorProto name */
            name?: (string|null);

            /** DescriptorProto field */
            field?: (google.protobuf.IFieldDescriptorProto[]|null);

            /** DescriptorProto extension */
            extension?: (google.protobuf.IFieldDescriptorProto[]|null);

            /** DescriptorProto nestedType */
            nestedType?: (google.protobuf.IDescriptorProto[]|null);

            /** DescriptorProto enumType */
            enumType?: (google.protobuf.IEnumDescriptorProto[]|null);

            /** DescriptorProto extensionRange */
            extensionRange?: (google.protobuf.DescriptorProto.IExtensionRange[]|null);

            /** DescriptorProto oneofDecl */
            oneofDecl?: (google.protobuf.IOneofDescriptorProto[]|null);

            /** DescriptorProto options */
            options?: (google.protobuf.IMessageOptions|null);

            /** DescriptorProto reservedRange */
            reservedRange?: (google.protobuf.DescriptorProto.IReservedRange[]|null);

            /** DescriptorProto reservedName */
            reservedName?: (string[]|null);
        }

        /** Represents a DescriptorProto. */
        class DescriptorProto implements IDescriptorProto {

            /**
             * Constructs a new DescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IDescriptorProto);

            /** DescriptorProto name. */
            public name: string;

            /** DescriptorProto field. */
            public field: google.protobuf.IFieldDescriptorProto[];

            /** DescriptorProto extension. */
            public extension: google.protobuf.IFieldDescriptorProto[];

            /** DescriptorProto nestedType. */
            public nestedType: google.protobuf.IDescriptorProto[];

            /** DescriptorProto enumType. */
            public enumType: google.protobuf.IEnumDescriptorProto[];

            /** DescriptorProto extensionRange. */
            public extensionRange: google.protobuf.DescriptorProto.IExtensionRange[];

            /** DescriptorProto oneofDecl. */
            public oneofDecl: google.protobuf.IOneofDescriptorProto[];

            /** DescriptorProto options. */
            public options?: (google.protobuf.IMessageOptions|null);

            /** DescriptorProto reservedRange. */
            public reservedRange: google.protobuf.DescriptorProto.IReservedRange[];

            /** DescriptorProto reservedName. */
            public reservedName: string[];

            /**
             * Creates a new DescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns DescriptorProto instance
             */
            public static create(properties?: google.protobuf.IDescriptorProto): google.protobuf.DescriptorProto;

            /**
             * Encodes the specified DescriptorProto message. Does not implicitly {@link google.protobuf.DescriptorProto.verify|verify} messages.
             * @param message DescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified DescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.verify|verify} messages.
             * @param message DescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a DescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns DescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DescriptorProto;

            /**
             * Decodes a DescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns DescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DescriptorProto;

            /**
             * Verifies a DescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a DescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns DescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.DescriptorProto;

            /**
             * Creates a plain object from a DescriptorProto message. Also converts values to other types if specified.
             * @param message DescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.DescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this DescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for DescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace DescriptorProto {

            /** Properties of an ExtensionRange. */
            interface IExtensionRange {

                /** ExtensionRange start */
                start?: (number|null);

                /** ExtensionRange end */
                end?: (number|null);

                /** ExtensionRange options */
                options?: (google.protobuf.IExtensionRangeOptions|null);
            }

            /** Represents an ExtensionRange. */
            class ExtensionRange implements IExtensionRange {

                /**
                 * Constructs a new ExtensionRange.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.DescriptorProto.IExtensionRange);

                /** ExtensionRange start. */
                public start: number;

                /** ExtensionRange end. */
                public end: number;

                /** ExtensionRange options. */
                public options?: (google.protobuf.IExtensionRangeOptions|null);

                /**
                 * Creates a new ExtensionRange instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns ExtensionRange instance
                 */
                public static create(properties?: google.protobuf.DescriptorProto.IExtensionRange): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Encodes the specified ExtensionRange message. Does not implicitly {@link google.protobuf.DescriptorProto.ExtensionRange.verify|verify} messages.
                 * @param message ExtensionRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.DescriptorProto.IExtensionRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified ExtensionRange message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.ExtensionRange.verify|verify} messages.
                 * @param message ExtensionRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.DescriptorProto.IExtensionRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an ExtensionRange message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns ExtensionRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Decodes an ExtensionRange message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns ExtensionRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Verifies an ExtensionRange message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an ExtensionRange message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns ExtensionRange
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Creates a plain object from an ExtensionRange message. Also converts values to other types if specified.
                 * @param message ExtensionRange
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.DescriptorProto.ExtensionRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this ExtensionRange to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for ExtensionRange
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }

            /** Properties of a ReservedRange. */
            interface IReservedRange {

                /** ReservedRange start */
                start?: (number|null);

                /** ReservedRange end */
                end?: (number|null);
            }

            /** Represents a ReservedRange. */
            class ReservedRange implements IReservedRange {

                /**
                 * Constructs a new ReservedRange.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.DescriptorProto.IReservedRange);

                /** ReservedRange start. */
                public start: number;

                /** ReservedRange end. */
                public end: number;

                /**
                 * Creates a new ReservedRange instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns ReservedRange instance
                 */
                public static create(properties?: google.protobuf.DescriptorProto.IReservedRange): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Encodes the specified ReservedRange message. Does not implicitly {@link google.protobuf.DescriptorProto.ReservedRange.verify|verify} messages.
                 * @param message ReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.DescriptorProto.IReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified ReservedRange message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.ReservedRange.verify|verify} messages.
                 * @param message ReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.DescriptorProto.IReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a ReservedRange message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns ReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Decodes a ReservedRange message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns ReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Verifies a ReservedRange message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a ReservedRange message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns ReservedRange
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Creates a plain object from a ReservedRange message. Also converts values to other types if specified.
                 * @param message ReservedRange
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.DescriptorProto.ReservedRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this ReservedRange to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for ReservedRange
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of an ExtensionRangeOptions. */
        interface IExtensionRangeOptions {

            /** ExtensionRangeOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an ExtensionRangeOptions. */
        class ExtensionRangeOptions implements IExtensionRangeOptions {

            /**
             * Constructs a new ExtensionRangeOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IExtensionRangeOptions);

            /** ExtensionRangeOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new ExtensionRangeOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ExtensionRangeOptions instance
             */
            public static create(properties?: google.protobuf.IExtensionRangeOptions): google.protobuf.ExtensionRangeOptions;

            /**
             * Encodes the specified ExtensionRangeOptions message. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.verify|verify} messages.
             * @param message ExtensionRangeOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IExtensionRangeOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ExtensionRangeOptions message, length delimited. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.verify|verify} messages.
             * @param message ExtensionRangeOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IExtensionRangeOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an ExtensionRangeOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ExtensionRangeOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ExtensionRangeOptions;

            /**
             * Decodes an ExtensionRangeOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ExtensionRangeOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ExtensionRangeOptions;

            /**
             * Verifies an ExtensionRangeOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an ExtensionRangeOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ExtensionRangeOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.ExtensionRangeOptions;

            /**
             * Creates a plain object from an ExtensionRangeOptions message. Also converts values to other types if specified.
             * @param message ExtensionRangeOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.ExtensionRangeOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ExtensionRangeOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ExtensionRangeOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FieldDescriptorProto. */
        interface IFieldDescriptorProto {

            /** FieldDescriptorProto name */
            name?: (string|null);

            /** FieldDescriptorProto number */
            number?: (number|null);

            /** FieldDescriptorProto label */
            label?: (google.protobuf.FieldDescriptorProto.Label|keyof typeof google.protobuf.FieldDescriptorProto.Label|null);

            /** FieldDescriptorProto type */
            type?: (google.protobuf.FieldDescriptorProto.Type|keyof typeof google.protobuf.FieldDescriptorProto.Type|null);

            /** FieldDescriptorProto typeName */
            typeName?: (string|null);

            /** FieldDescriptorProto extendee */
            extendee?: (string|null);

            /** FieldDescriptorProto defaultValue */
            defaultValue?: (string|null);

            /** FieldDescriptorProto oneofIndex */
            oneofIndex?: (number|null);

            /** FieldDescriptorProto jsonName */
            jsonName?: (string|null);

            /** FieldDescriptorProto options */
            options?: (google.protobuf.IFieldOptions|null);

            /** FieldDescriptorProto proto3Optional */
            proto3Optional?: (boolean|null);
        }

        /** Represents a FieldDescriptorProto. */
        class FieldDescriptorProto implements IFieldDescriptorProto {

            /**
             * Constructs a new FieldDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFieldDescriptorProto);

            /** FieldDescriptorProto name. */
            public name: string;

            /** FieldDescriptorProto number. */
            public number: number;

            /** FieldDescriptorProto label. */
            public label: (google.protobuf.FieldDescriptorProto.Label|keyof typeof google.protobuf.FieldDescriptorProto.Label);

            /** FieldDescriptorProto type. */
            public type: (google.protobuf.FieldDescriptorProto.Type|keyof typeof google.protobuf.FieldDescriptorProto.Type);

            /** FieldDescriptorProto typeName. */
            public typeName: string;

            /** FieldDescriptorProto extendee. */
            public extendee: string;

            /** FieldDescriptorProto defaultValue. */
            public defaultValue: string;

            /** FieldDescriptorProto oneofIndex. */
            public oneofIndex: number;

            /** FieldDescriptorProto jsonName. */
            public jsonName: string;

            /** FieldDescriptorProto options. */
            public options?: (google.protobuf.IFieldOptions|null);

            /** FieldDescriptorProto proto3Optional. */
            public proto3Optional: boolean;

            /**
             * Creates a new FieldDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FieldDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IFieldDescriptorProto): google.protobuf.FieldDescriptorProto;

            /**
             * Encodes the specified FieldDescriptorProto message. Does not implicitly {@link google.protobuf.FieldDescriptorProto.verify|verify} messages.
             * @param message FieldDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFieldDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FieldDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.FieldDescriptorProto.verify|verify} messages.
             * @param message FieldDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFieldDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FieldDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FieldDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FieldDescriptorProto;

            /**
             * Decodes a FieldDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FieldDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FieldDescriptorProto;

            /**
             * Verifies a FieldDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FieldDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FieldDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FieldDescriptorProto;

            /**
             * Creates a plain object from a FieldDescriptorProto message. Also converts values to other types if specified.
             * @param message FieldDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FieldDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FieldDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FieldDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FieldDescriptorProto {

            /** Type enum. */
            enum Type {
                TYPE_DOUBLE = 1,
                TYPE_FLOAT = 2,
                TYPE_INT64 = 3,
                TYPE_UINT64 = 4,
                TYPE_INT32 = 5,
                TYPE_FIXED64 = 6,
                TYPE_FIXED32 = 7,
                TYPE_BOOL = 8,
                TYPE_STRING = 9,
                TYPE_GROUP = 10,
                TYPE_MESSAGE = 11,
                TYPE_BYTES = 12,
                TYPE_UINT32 = 13,
                TYPE_ENUM = 14,
                TYPE_SFIXED32 = 15,
                TYPE_SFIXED64 = 16,
                TYPE_SINT32 = 17,
                TYPE_SINT64 = 18
            }

            /** Label enum. */
            enum Label {
                LABEL_OPTIONAL = 1,
                LABEL_REQUIRED = 2,
                LABEL_REPEATED = 3
            }
        }

        /** Properties of an OneofDescriptorProto. */
        interface IOneofDescriptorProto {

            /** OneofDescriptorProto name */
            name?: (string|null);

            /** OneofDescriptorProto options */
            options?: (google.protobuf.IOneofOptions|null);
        }

        /** Represents an OneofDescriptorProto. */
        class OneofDescriptorProto implements IOneofDescriptorProto {

            /**
             * Constructs a new OneofDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IOneofDescriptorProto);

            /** OneofDescriptorProto name. */
            public name: string;

            /** OneofDescriptorProto options. */
            public options?: (google.protobuf.IOneofOptions|null);

            /**
             * Creates a new OneofDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns OneofDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IOneofDescriptorProto): google.protobuf.OneofDescriptorProto;

            /**
             * Encodes the specified OneofDescriptorProto message. Does not implicitly {@link google.protobuf.OneofDescriptorProto.verify|verify} messages.
             * @param message OneofDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IOneofDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified OneofDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.OneofDescriptorProto.verify|verify} messages.
             * @param message OneofDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IOneofDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an OneofDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns OneofDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.OneofDescriptorProto;

            /**
             * Decodes an OneofDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns OneofDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.OneofDescriptorProto;

            /**
             * Verifies an OneofDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an OneofDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns OneofDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.OneofDescriptorProto;

            /**
             * Creates a plain object from an OneofDescriptorProto message. Also converts values to other types if specified.
             * @param message OneofDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.OneofDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this OneofDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for OneofDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an EnumDescriptorProto. */
        interface IEnumDescriptorProto {

            /** EnumDescriptorProto name */
            name?: (string|null);

            /** EnumDescriptorProto value */
            value?: (google.protobuf.IEnumValueDescriptorProto[]|null);

            /** EnumDescriptorProto options */
            options?: (google.protobuf.IEnumOptions|null);

            /** EnumDescriptorProto reservedRange */
            reservedRange?: (google.protobuf.EnumDescriptorProto.IEnumReservedRange[]|null);

            /** EnumDescriptorProto reservedName */
            reservedName?: (string[]|null);
        }

        /** Represents an EnumDescriptorProto. */
        class EnumDescriptorProto implements IEnumDescriptorProto {

            /**
             * Constructs a new EnumDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumDescriptorProto);

            /** EnumDescriptorProto name. */
            public name: string;

            /** EnumDescriptorProto value. */
            public value: google.protobuf.IEnumValueDescriptorProto[];

            /** EnumDescriptorProto options. */
            public options?: (google.protobuf.IEnumOptions|null);

            /** EnumDescriptorProto reservedRange. */
            public reservedRange: google.protobuf.EnumDescriptorProto.IEnumReservedRange[];

            /** EnumDescriptorProto reservedName. */
            public reservedName: string[];

            /**
             * Creates a new EnumDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IEnumDescriptorProto): google.protobuf.EnumDescriptorProto;

            /**
             * Encodes the specified EnumDescriptorProto message. Does not implicitly {@link google.protobuf.EnumDescriptorProto.verify|verify} messages.
             * @param message EnumDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.EnumDescriptorProto.verify|verify} messages.
             * @param message EnumDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumDescriptorProto;

            /**
             * Decodes an EnumDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumDescriptorProto;

            /**
             * Verifies an EnumDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumDescriptorProto;

            /**
             * Creates a plain object from an EnumDescriptorProto message. Also converts values to other types if specified.
             * @param message EnumDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace EnumDescriptorProto {

            /** Properties of an EnumReservedRange. */
            interface IEnumReservedRange {

                /** EnumReservedRange start */
                start?: (number|null);

                /** EnumReservedRange end */
                end?: (number|null);
            }

            /** Represents an EnumReservedRange. */
            class EnumReservedRange implements IEnumReservedRange {

                /**
                 * Constructs a new EnumReservedRange.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.EnumDescriptorProto.IEnumReservedRange);

                /** EnumReservedRange start. */
                public start: number;

                /** EnumReservedRange end. */
                public end: number;

                /**
                 * Creates a new EnumReservedRange instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns EnumReservedRange instance
                 */
                public static create(properties?: google.protobuf.EnumDescriptorProto.IEnumReservedRange): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Encodes the specified EnumReservedRange message. Does not implicitly {@link google.protobuf.EnumDescriptorProto.EnumReservedRange.verify|verify} messages.
                 * @param message EnumReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.EnumDescriptorProto.IEnumReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified EnumReservedRange message, length delimited. Does not implicitly {@link google.protobuf.EnumDescriptorProto.EnumReservedRange.verify|verify} messages.
                 * @param message EnumReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.EnumDescriptorProto.IEnumReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an EnumReservedRange message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns EnumReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Decodes an EnumReservedRange message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns EnumReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Verifies an EnumReservedRange message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an EnumReservedRange message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns EnumReservedRange
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Creates a plain object from an EnumReservedRange message. Also converts values to other types if specified.
                 * @param message EnumReservedRange
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.EnumDescriptorProto.EnumReservedRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this EnumReservedRange to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for EnumReservedRange
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of an EnumValueDescriptorProto. */
        interface IEnumValueDescriptorProto {

            /** EnumValueDescriptorProto name */
            name?: (string|null);

            /** EnumValueDescriptorProto number */
            number?: (number|null);

            /** EnumValueDescriptorProto options */
            options?: (google.protobuf.IEnumValueOptions|null);
        }

        /** Represents an EnumValueDescriptorProto. */
        class EnumValueDescriptorProto implements IEnumValueDescriptorProto {

            /**
             * Constructs a new EnumValueDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumValueDescriptorProto);

            /** EnumValueDescriptorProto name. */
            public name: string;

            /** EnumValueDescriptorProto number. */
            public number: number;

            /** EnumValueDescriptorProto options. */
            public options?: (google.protobuf.IEnumValueOptions|null);

            /**
             * Creates a new EnumValueDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumValueDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IEnumValueDescriptorProto): google.protobuf.EnumValueDescriptorProto;

            /**
             * Encodes the specified EnumValueDescriptorProto message. Does not implicitly {@link google.protobuf.EnumValueDescriptorProto.verify|verify} messages.
             * @param message EnumValueDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumValueDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumValueDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.EnumValueDescriptorProto.verify|verify} messages.
             * @param message EnumValueDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumValueDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumValueDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumValueDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumValueDescriptorProto;

            /**
             * Decodes an EnumValueDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumValueDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumValueDescriptorProto;

            /**
             * Verifies an EnumValueDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumValueDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumValueDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumValueDescriptorProto;

            /**
             * Creates a plain object from an EnumValueDescriptorProto message. Also converts values to other types if specified.
             * @param message EnumValueDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumValueDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumValueDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumValueDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ServiceDescriptorProto. */
        interface IServiceDescriptorProto {

            /** ServiceDescriptorProto name */
            name?: (string|null);

            /** ServiceDescriptorProto method */
            method?: (google.protobuf.IMethodDescriptorProto[]|null);

            /** ServiceDescriptorProto options */
            options?: (google.protobuf.IServiceOptions|null);
        }

        /** Represents a ServiceDescriptorProto. */
        class ServiceDescriptorProto implements IServiceDescriptorProto {

            /**
             * Constructs a new ServiceDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IServiceDescriptorProto);

            /** ServiceDescriptorProto name. */
            public name: string;

            /** ServiceDescriptorProto method. */
            public method: google.protobuf.IMethodDescriptorProto[];

            /** ServiceDescriptorProto options. */
            public options?: (google.protobuf.IServiceOptions|null);

            /**
             * Creates a new ServiceDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ServiceDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IServiceDescriptorProto): google.protobuf.ServiceDescriptorProto;

            /**
             * Encodes the specified ServiceDescriptorProto message. Does not implicitly {@link google.protobuf.ServiceDescriptorProto.verify|verify} messages.
             * @param message ServiceDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IServiceDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ServiceDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.ServiceDescriptorProto.verify|verify} messages.
             * @param message ServiceDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IServiceDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ServiceDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ServiceDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ServiceDescriptorProto;

            /**
             * Decodes a ServiceDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ServiceDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ServiceDescriptorProto;

            /**
             * Verifies a ServiceDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ServiceDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ServiceDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.ServiceDescriptorProto;

            /**
             * Creates a plain object from a ServiceDescriptorProto message. Also converts values to other types if specified.
             * @param message ServiceDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.ServiceDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ServiceDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ServiceDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a MethodDescriptorProto. */
        interface IMethodDescriptorProto {

            /** MethodDescriptorProto name */
            name?: (string|null);

            /** MethodDescriptorProto inputType */
            inputType?: (string|null);

            /** MethodDescriptorProto outputType */
            outputType?: (string|null);

            /** MethodDescriptorProto options */
            options?: (google.protobuf.IMethodOptions|null);

            /** MethodDescriptorProto clientStreaming */
            clientStreaming?: (boolean|null);

            /** MethodDescriptorProto serverStreaming */
            serverStreaming?: (boolean|null);
        }

        /** Represents a MethodDescriptorProto. */
        class MethodDescriptorProto implements IMethodDescriptorProto {

            /**
             * Constructs a new MethodDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IMethodDescriptorProto);

            /** MethodDescriptorProto name. */
            public name: string;

            /** MethodDescriptorProto inputType. */
            public inputType: string;

            /** MethodDescriptorProto outputType. */
            public outputType: string;

            /** MethodDescriptorProto options. */
            public options?: (google.protobuf.IMethodOptions|null);

            /** MethodDescriptorProto clientStreaming. */
            public clientStreaming: boolean;

            /** MethodDescriptorProto serverStreaming. */
            public serverStreaming: boolean;

            /**
             * Creates a new MethodDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MethodDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IMethodDescriptorProto): google.protobuf.MethodDescriptorProto;

            /**
             * Encodes the specified MethodDescriptorProto message. Does not implicitly {@link google.protobuf.MethodDescriptorProto.verify|verify} messages.
             * @param message MethodDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IMethodDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MethodDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.MethodDescriptorProto.verify|verify} messages.
             * @param message MethodDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IMethodDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MethodDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MethodDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.MethodDescriptorProto;

            /**
             * Decodes a MethodDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MethodDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.MethodDescriptorProto;

            /**
             * Verifies a MethodDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MethodDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MethodDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.MethodDescriptorProto;

            /**
             * Creates a plain object from a MethodDescriptorProto message. Also converts values to other types if specified.
             * @param message MethodDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.MethodDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MethodDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MethodDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FileOptions. */
        interface IFileOptions {

            /** FileOptions javaPackage */
            javaPackage?: (string|null);

            /** FileOptions javaOuterClassname */
            javaOuterClassname?: (string|null);

            /** FileOptions javaMultipleFiles */
            javaMultipleFiles?: (boolean|null);

            /** FileOptions javaGenerateEqualsAndHash */
            javaGenerateEqualsAndHash?: (boolean|null);

            /** FileOptions javaStringCheckUtf8 */
            javaStringCheckUtf8?: (boolean|null);

            /** FileOptions optimizeFor */
            optimizeFor?: (google.protobuf.FileOptions.OptimizeMode|keyof typeof google.protobuf.FileOptions.OptimizeMode|null);

            /** FileOptions goPackage */
            goPackage?: (string|null);

            /** FileOptions ccGenericServices */
            ccGenericServices?: (boolean|null);

            /** FileOptions javaGenericServices */
            javaGenericServices?: (boolean|null);

            /** FileOptions pyGenericServices */
            pyGenericServices?: (boolean|null);

            /** FileOptions phpGenericServices */
            phpGenericServices?: (boolean|null);

            /** FileOptions deprecated */
            deprecated?: (boolean|null);

            /** FileOptions ccEnableArenas */
            ccEnableArenas?: (boolean|null);

            /** FileOptions objcClassPrefix */
            objcClassPrefix?: (string|null);

            /** FileOptions csharpNamespace */
            csharpNamespace?: (string|null);

            /** FileOptions swiftPrefix */
            swiftPrefix?: (string|null);

            /** FileOptions phpClassPrefix */
            phpClassPrefix?: (string|null);

            /** FileOptions phpNamespace */
            phpNamespace?: (string|null);

            /** FileOptions phpMetadataNamespace */
            phpMetadataNamespace?: (string|null);

            /** FileOptions rubyPackage */
            rubyPackage?: (string|null);

            /** FileOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** FileOptions .google.api.resourceDefinition */
            ".google.api.resourceDefinition"?: (google.api.IResourceDescriptor[]|null);
        }

        /** Represents a FileOptions. */
        class FileOptions implements IFileOptions {

            /**
             * Constructs a new FileOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFileOptions);

            /** FileOptions javaPackage. */
            public javaPackage: string;

            /** FileOptions javaOuterClassname. */
            public javaOuterClassname: string;

            /** FileOptions javaMultipleFiles. */
            public javaMultipleFiles: boolean;

            /** FileOptions javaGenerateEqualsAndHash. */
            public javaGenerateEqualsAndHash: boolean;

            /** FileOptions javaStringCheckUtf8. */
            public javaStringCheckUtf8: boolean;

            /** FileOptions optimizeFor. */
            public optimizeFor: (google.protobuf.FileOptions.OptimizeMode|keyof typeof google.protobuf.FileOptions.OptimizeMode);

            /** FileOptions goPackage. */
            public goPackage: string;

            /** FileOptions ccGenericServices. */
            public ccGenericServices: boolean;

            /** FileOptions javaGenericServices. */
            public javaGenericServices: boolean;

            /** FileOptions pyGenericServices. */
            public pyGenericServices: boolean;

            /** FileOptions phpGenericServices. */
            public phpGenericServices: boolean;

            /** FileOptions deprecated. */
            public deprecated: boolean;

            /** FileOptions ccEnableArenas. */
            public ccEnableArenas: boolean;

            /** FileOptions objcClassPrefix. */
            public objcClassPrefix: string;

            /** FileOptions csharpNamespace. */
            public csharpNamespace: string;

            /** FileOptions swiftPrefix. */
            public swiftPrefix: string;

            /** FileOptions phpClassPrefix. */
            public phpClassPrefix: string;

            /** FileOptions phpNamespace. */
            public phpNamespace: string;

            /** FileOptions phpMetadataNamespace. */
            public phpMetadataNamespace: string;

            /** FileOptions rubyPackage. */
            public rubyPackage: string;

            /** FileOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new FileOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FileOptions instance
             */
            public static create(properties?: google.protobuf.IFileOptions): google.protobuf.FileOptions;

            /**
             * Encodes the specified FileOptions message. Does not implicitly {@link google.protobuf.FileOptions.verify|verify} messages.
             * @param message FileOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFileOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FileOptions message, length delimited. Does not implicitly {@link google.protobuf.FileOptions.verify|verify} messages.
             * @param message FileOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFileOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FileOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FileOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FileOptions;

            /**
             * Decodes a FileOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FileOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FileOptions;

            /**
             * Verifies a FileOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FileOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FileOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FileOptions;

            /**
             * Creates a plain object from a FileOptions message. Also converts values to other types if specified.
             * @param message FileOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FileOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FileOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FileOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FileOptions {

            /** OptimizeMode enum. */
            enum OptimizeMode {
                SPEED = 1,
                CODE_SIZE = 2,
                LITE_RUNTIME = 3
            }
        }

        /** Properties of a MessageOptions. */
        interface IMessageOptions {

            /** MessageOptions messageSetWireFormat */
            messageSetWireFormat?: (boolean|null);

            /** MessageOptions noStandardDescriptorAccessor */
            noStandardDescriptorAccessor?: (boolean|null);

            /** MessageOptions deprecated */
            deprecated?: (boolean|null);

            /** MessageOptions mapEntry */
            mapEntry?: (boolean|null);

            /** MessageOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** MessageOptions .google.api.resource */
            ".google.api.resource"?: (google.api.IResourceDescriptor|null);
        }

        /** Represents a MessageOptions. */
        class MessageOptions implements IMessageOptions {

            /**
             * Constructs a new MessageOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IMessageOptions);

            /** MessageOptions messageSetWireFormat. */
            public messageSetWireFormat: boolean;

            /** MessageOptions noStandardDescriptorAccessor. */
            public noStandardDescriptorAccessor: boolean;

            /** MessageOptions deprecated. */
            public deprecated: boolean;

            /** MessageOptions mapEntry. */
            public mapEntry: boolean;

            /** MessageOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new MessageOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MessageOptions instance
             */
            public static create(properties?: google.protobuf.IMessageOptions): google.protobuf.MessageOptions;

            /**
             * Encodes the specified MessageOptions message. Does not implicitly {@link google.protobuf.MessageOptions.verify|verify} messages.
             * @param message MessageOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IMessageOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MessageOptions message, length delimited. Does not implicitly {@link google.protobuf.MessageOptions.verify|verify} messages.
             * @param message MessageOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IMessageOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MessageOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MessageOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.MessageOptions;

            /**
             * Decodes a MessageOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MessageOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.MessageOptions;

            /**
             * Verifies a MessageOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MessageOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MessageOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.MessageOptions;

            /**
             * Creates a plain object from a MessageOptions message. Also converts values to other types if specified.
             * @param message MessageOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.MessageOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MessageOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MessageOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FieldOptions. */
        interface IFieldOptions {

            /** FieldOptions ctype */
            ctype?: (google.protobuf.FieldOptions.CType|keyof typeof google.protobuf.FieldOptions.CType|null);

            /** FieldOptions packed */
            packed?: (boolean|null);

            /** FieldOptions jstype */
            jstype?: (google.protobuf.FieldOptions.JSType|keyof typeof google.protobuf.FieldOptions.JSType|null);

            /** FieldOptions lazy */
            lazy?: (boolean|null);

            /** FieldOptions unverifiedLazy */
            unverifiedLazy?: (boolean|null);

            /** FieldOptions deprecated */
            deprecated?: (boolean|null);

            /** FieldOptions weak */
            weak?: (boolean|null);

            /** FieldOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** FieldOptions .google.api.fieldBehavior */
            ".google.api.fieldBehavior"?: (google.api.FieldBehavior[]|null);

            /** FieldOptions .google.api.resourceReference */
            ".google.api.resourceReference"?: (google.api.IResourceReference|null);
        }

        /** Represents a FieldOptions. */
        class FieldOptions implements IFieldOptions {

            /**
             * Constructs a new FieldOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFieldOptions);

            /** FieldOptions ctype. */
            public ctype: (google.protobuf.FieldOptions.CType|keyof typeof google.protobuf.FieldOptions.CType);

            /** FieldOptions packed. */
            public packed: boolean;

            /** FieldOptions jstype. */
            public jstype: (google.protobuf.FieldOptions.JSType|keyof typeof google.protobuf.FieldOptions.JSType);

            /** FieldOptions lazy. */
            public lazy: boolean;

            /** FieldOptions unverifiedLazy. */
            public unverifiedLazy: boolean;

            /** FieldOptions deprecated. */
            public deprecated: boolean;

            /** FieldOptions weak. */
            public weak: boolean;

            /** FieldOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new FieldOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FieldOptions instance
             */
            public static create(properties?: google.protobuf.IFieldOptions): google.protobuf.FieldOptions;

            /**
             * Encodes the specified FieldOptions message. Does not implicitly {@link google.protobuf.FieldOptions.verify|verify} messages.
             * @param message FieldOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFieldOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FieldOptions message, length delimited. Does not implicitly {@link google.protobuf.FieldOptions.verify|verify} messages.
             * @param message FieldOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFieldOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FieldOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FieldOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FieldOptions;

            /**
             * Decodes a FieldOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FieldOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FieldOptions;

            /**
             * Verifies a FieldOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FieldOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FieldOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FieldOptions;

            /**
             * Creates a plain object from a FieldOptions message. Also converts values to other types if specified.
             * @param message FieldOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FieldOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FieldOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FieldOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FieldOptions {

            /** CType enum. */
            enum CType {
                STRING = 0,
                CORD = 1,
                STRING_PIECE = 2
            }

            /** JSType enum. */
            enum JSType {
                JS_NORMAL = 0,
                JS_STRING = 1,
                JS_NUMBER = 2
            }
        }

        /** Properties of an OneofOptions. */
        interface IOneofOptions {

            /** OneofOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an OneofOptions. */
        class OneofOptions implements IOneofOptions {

            /**
             * Constructs a new OneofOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IOneofOptions);

            /** OneofOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new OneofOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns OneofOptions instance
             */
            public static create(properties?: google.protobuf.IOneofOptions): google.protobuf.OneofOptions;

            /**
             * Encodes the specified OneofOptions message. Does not implicitly {@link google.protobuf.OneofOptions.verify|verify} messages.
             * @param message OneofOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IOneofOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified OneofOptions message, length delimited. Does not implicitly {@link google.protobuf.OneofOptions.verify|verify} messages.
             * @param message OneofOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IOneofOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an OneofOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns OneofOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.OneofOptions;

            /**
             * Decodes an OneofOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns OneofOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.OneofOptions;

            /**
             * Verifies an OneofOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an OneofOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns OneofOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.OneofOptions;

            /**
             * Creates a plain object from an OneofOptions message. Also converts values to other types if specified.
             * @param message OneofOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.OneofOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this OneofOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for OneofOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an EnumOptions. */
        interface IEnumOptions {

            /** EnumOptions allowAlias */
            allowAlias?: (boolean|null);

            /** EnumOptions deprecated */
            deprecated?: (boolean|null);

            /** EnumOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an EnumOptions. */
        class EnumOptions implements IEnumOptions {

            /**
             * Constructs a new EnumOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumOptions);

            /** EnumOptions allowAlias. */
            public allowAlias: boolean;

            /** EnumOptions deprecated. */
            public deprecated: boolean;

            /** EnumOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new EnumOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumOptions instance
             */
            public static create(properties?: google.protobuf.IEnumOptions): google.protobuf.EnumOptions;

            /**
             * Encodes the specified EnumOptions message. Does not implicitly {@link google.protobuf.EnumOptions.verify|verify} messages.
             * @param message EnumOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumOptions message, length delimited. Does not implicitly {@link google.protobuf.EnumOptions.verify|verify} messages.
             * @param message EnumOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumOptions;

            /**
             * Decodes an EnumOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumOptions;

            /**
             * Verifies an EnumOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumOptions;

            /**
             * Creates a plain object from an EnumOptions message. Also converts values to other types if specified.
             * @param message EnumOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an EnumValueOptions. */
        interface IEnumValueOptions {

            /** EnumValueOptions deprecated */
            deprecated?: (boolean|null);

            /** EnumValueOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an EnumValueOptions. */
        class EnumValueOptions implements IEnumValueOptions {

            /**
             * Constructs a new EnumValueOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumValueOptions);

            /** EnumValueOptions deprecated. */
            public deprecated: boolean;

            /** EnumValueOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new EnumValueOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumValueOptions instance
             */
            public static create(properties?: google.protobuf.IEnumValueOptions): google.protobuf.EnumValueOptions;

            /**
             * Encodes the specified EnumValueOptions message. Does not implicitly {@link google.protobuf.EnumValueOptions.verify|verify} messages.
             * @param message EnumValueOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumValueOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumValueOptions message, length delimited. Does not implicitly {@link google.protobuf.EnumValueOptions.verify|verify} messages.
             * @param message EnumValueOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumValueOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumValueOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumValueOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumValueOptions;

            /**
             * Decodes an EnumValueOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumValueOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumValueOptions;

            /**
             * Verifies an EnumValueOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumValueOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumValueOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumValueOptions;

            /**
             * Creates a plain object from an EnumValueOptions message. Also converts values to other types if specified.
             * @param message EnumValueOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumValueOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumValueOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumValueOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ServiceOptions. */
        interface IServiceOptions {

            /** ServiceOptions deprecated */
            deprecated?: (boolean|null);

            /** ServiceOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** ServiceOptions .google.api.defaultHost */
            ".google.api.defaultHost"?: (string|null);

            /** ServiceOptions .google.api.oauthScopes */
            ".google.api.oauthScopes"?: (string|null);
        }

        /** Represents a ServiceOptions. */
        class ServiceOptions implements IServiceOptions {

            /**
             * Constructs a new ServiceOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IServiceOptions);

            /** ServiceOptions deprecated. */
            public deprecated: boolean;

            /** ServiceOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new ServiceOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ServiceOptions instance
             */
            public static create(properties?: google.protobuf.IServiceOptions): google.protobuf.ServiceOptions;

            /**
             * Encodes the specified ServiceOptions message. Does not implicitly {@link google.protobuf.ServiceOptions.verify|verify} messages.
             * @param message ServiceOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IServiceOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ServiceOptions message, length delimited. Does not implicitly {@link google.protobuf.ServiceOptions.verify|verify} messages.
             * @param message ServiceOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IServiceOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ServiceOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ServiceOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ServiceOptions;

            /**
             * Decodes a ServiceOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ServiceOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ServiceOptions;

            /**
             * Verifies a ServiceOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ServiceOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ServiceOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.ServiceOptions;

            /**
             * Creates a plain object from a ServiceOptions message. Also converts values to other types if specified.
             * @param message ServiceOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.ServiceOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ServiceOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ServiceOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a MethodOptions. */
        interface IMethodOptions {

            /** MethodOptions deprecated */
            deprecated?: (boolean|null);

            /** MethodOptions idempotencyLevel */
            idempotencyLevel?: (google.protobuf.MethodOptions.IdempotencyLevel|keyof typeof google.protobuf.MethodOptions.IdempotencyLevel|null);

            /** MethodOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** MethodOptions .google.api.http */
            ".google.api.http"?: (google.api.IHttpRule|null);

            /** MethodOptions .google.api.methodSignature */
            ".google.api.methodSignature"?: (string[]|null);
        }

        /** Represents a MethodOptions. */
        class MethodOptions implements IMethodOptions {

            /**
             * Constructs a new MethodOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IMethodOptions);

            /** MethodOptions deprecated. */
            public deprecated: boolean;

            /** MethodOptions idempotencyLevel. */
            public idempotencyLevel: (google.protobuf.MethodOptions.IdempotencyLevel|keyof typeof google.protobuf.MethodOptions.IdempotencyLevel);

            /** MethodOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new MethodOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MethodOptions instance
             */
            public static create(properties?: google.protobuf.IMethodOptions): google.protobuf.MethodOptions;

            /**
             * Encodes the specified MethodOptions message. Does not implicitly {@link google.protobuf.MethodOptions.verify|verify} messages.
             * @param message MethodOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IMethodOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MethodOptions message, length delimited. Does not implicitly {@link google.protobuf.MethodOptions.verify|verify} messages.
             * @param message MethodOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IMethodOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MethodOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MethodOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.MethodOptions;

            /**
             * Decodes a MethodOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MethodOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.MethodOptions;

            /**
             * Verifies a MethodOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MethodOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MethodOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.MethodOptions;

            /**
             * Creates a plain object from a MethodOptions message. Also converts values to other types if specified.
             * @param message MethodOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.MethodOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MethodOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MethodOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace MethodOptions {

            /** IdempotencyLevel enum. */
            enum IdempotencyLevel {
                IDEMPOTENCY_UNKNOWN = 0,
                NO_SIDE_EFFECTS = 1,
                IDEMPOTENT = 2
            }
        }

        /** Properties of an UninterpretedOption. */
        interface IUninterpretedOption {

            /** UninterpretedOption name */
            name?: (google.protobuf.UninterpretedOption.INamePart[]|null);

            /** UninterpretedOption identifierValue */
            identifierValue?: (string|null);

            /** UninterpretedOption positiveIntValue */
            positiveIntValue?: (number|Long|string|null);

            /** UninterpretedOption negativeIntValue */
            negativeIntValue?: (number|Long|string|null);

            /** UninterpretedOption doubleValue */
            doubleValue?: (number|null);

            /** UninterpretedOption stringValue */
            stringValue?: (Uint8Array|string|null);

            /** UninterpretedOption aggregateValue */
            aggregateValue?: (string|null);
        }

        /** Represents an UninterpretedOption. */
        class UninterpretedOption implements IUninterpretedOption {

            /**
             * Constructs a new UninterpretedOption.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IUninterpretedOption);

            /** UninterpretedOption name. */
            public name: google.protobuf.UninterpretedOption.INamePart[];

            /** UninterpretedOption identifierValue. */
            public identifierValue: string;

            /** UninterpretedOption positiveIntValue. */
            public positiveIntValue: (number|Long|string);

            /** UninterpretedOption negativeIntValue. */
            public negativeIntValue: (number|Long|string);

            /** UninterpretedOption doubleValue. */
            public doubleValue: number;

            /** UninterpretedOption stringValue. */
            public stringValue: (Uint8Array|string);

            /** UninterpretedOption aggregateValue. */
            public aggregateValue: string;

            /**
             * Creates a new UninterpretedOption instance using the specified properties.
             * @param [properties] Properties to set
             * @returns UninterpretedOption instance
             */
            public static create(properties?: google.protobuf.IUninterpretedOption): google.protobuf.UninterpretedOption;

            /**
             * Encodes the specified UninterpretedOption message. Does not implicitly {@link google.protobuf.UninterpretedOption.verify|verify} messages.
             * @param message UninterpretedOption message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IUninterpretedOption, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified UninterpretedOption message, length delimited. Does not implicitly {@link google.protobuf.UninterpretedOption.verify|verify} messages.
             * @param message UninterpretedOption message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IUninterpretedOption, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an UninterpretedOption message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns UninterpretedOption
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.UninterpretedOption;

            /**
             * Decodes an UninterpretedOption message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns UninterpretedOption
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.UninterpretedOption;

            /**
             * Verifies an UninterpretedOption message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an UninterpretedOption message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns UninterpretedOption
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.UninterpretedOption;

            /**
             * Creates a plain object from an UninterpretedOption message. Also converts values to other types if specified.
             * @param message UninterpretedOption
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.UninterpretedOption, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this UninterpretedOption to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for UninterpretedOption
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace UninterpretedOption {

            /** Properties of a NamePart. */
            interface INamePart {

                /** NamePart namePart */
                namePart: string;

                /** NamePart isExtension */
                isExtension: boolean;
            }

            /** Represents a NamePart. */
            class NamePart implements INamePart {

                /**
                 * Constructs a new NamePart.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.UninterpretedOption.INamePart);

                /** NamePart namePart. */
                public namePart: string;

                /** NamePart isExtension. */
                public isExtension: boolean;

                /**
                 * Creates a new NamePart instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns NamePart instance
                 */
                public static create(properties?: google.protobuf.UninterpretedOption.INamePart): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Encodes the specified NamePart message. Does not implicitly {@link google.protobuf.UninterpretedOption.NamePart.verify|verify} messages.
                 * @param message NamePart message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.UninterpretedOption.INamePart, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified NamePart message, length delimited. Does not implicitly {@link google.protobuf.UninterpretedOption.NamePart.verify|verify} messages.
                 * @param message NamePart message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.UninterpretedOption.INamePart, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a NamePart message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns NamePart
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Decodes a NamePart message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns NamePart
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Verifies a NamePart message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a NamePart message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns NamePart
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Creates a plain object from a NamePart message. Also converts values to other types if specified.
                 * @param message NamePart
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.UninterpretedOption.NamePart, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this NamePart to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for NamePart
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of a SourceCodeInfo. */
        interface ISourceCodeInfo {

            /** SourceCodeInfo location */
            location?: (google.protobuf.SourceCodeInfo.ILocation[]|null);
        }

        /** Represents a SourceCodeInfo. */
        class SourceCodeInfo implements ISourceCodeInfo {

            /**
             * Constructs a new SourceCodeInfo.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.ISourceCodeInfo);

            /** SourceCodeInfo location. */
            public location: google.protobuf.SourceCodeInfo.ILocation[];

            /**
             * Creates a new SourceCodeInfo instance using the specified properties.
             * @param [properties] Properties to set
             * @returns SourceCodeInfo instance
             */
            public static create(properties?: google.protobuf.ISourceCodeInfo): google.protobuf.SourceCodeInfo;

            /**
             * Encodes the specified SourceCodeInfo message. Does not implicitly {@link google.protobuf.SourceCodeInfo.verify|verify} messages.
             * @param message SourceCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.ISourceCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified SourceCodeInfo message, length delimited. Does not implicitly {@link google.protobuf.SourceCodeInfo.verify|verify} messages.
             * @param message SourceCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.ISourceCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a SourceCodeInfo message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns SourceCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.SourceCodeInfo;

            /**
             * Decodes a SourceCodeInfo message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns SourceCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.SourceCodeInfo;

            /**
             * Verifies a SourceCodeInfo message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a SourceCodeInfo message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns SourceCodeInfo
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.SourceCodeInfo;

            /**
             * Creates a plain object from a SourceCodeInfo message. Also converts values to other types if specified.
             * @param message SourceCodeInfo
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.SourceCodeInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this SourceCodeInfo to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for SourceCodeInfo
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace SourceCodeInfo {

            /** Properties of a Location. */
            interface ILocation {

                /** Location path */
                path?: (number[]|null);

                /** Location span */
                span?: (number[]|null);

                /** Location leadingComments */
                leadingComments?: (string|null);

                /** Location trailingComments */
                trailingComments?: (string|null);

                /** Location leadingDetachedComments */
                leadingDetachedComments?: (string[]|null);
            }

            /** Represents a Location. */
            class Location implements ILocation {

                /**
                 * Constructs a new Location.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.SourceCodeInfo.ILocation);

                /** Location path. */
                public path: number[];

                /** Location span. */
                public span: number[];

                /** Location leadingComments. */
                public leadingComments: string;

                /** Location trailingComments. */
                public trailingComments: string;

                /** Location leadingDetachedComments. */
                public leadingDetachedComments: string[];

                /**
                 * Creates a new Location instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns Location instance
                 */
                public static create(properties?: google.protobuf.SourceCodeInfo.ILocation): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Encodes the specified Location message. Does not implicitly {@link google.protobuf.SourceCodeInfo.Location.verify|verify} messages.
                 * @param message Location message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.SourceCodeInfo.ILocation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified Location message, length delimited. Does not implicitly {@link google.protobuf.SourceCodeInfo.Location.verify|verify} messages.
                 * @param message Location message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.SourceCodeInfo.ILocation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a Location message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns Location
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Decodes a Location message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns Location
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Verifies a Location message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a Location message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns Location
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Creates a plain object from a Location message. Also converts values to other types if specified.
                 * @param message Location
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.SourceCodeInfo.Location, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this Location to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for Location
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of a GeneratedCodeInfo. */
        interface IGeneratedCodeInfo {

            /** GeneratedCodeInfo annotation */
            annotation?: (google.protobuf.GeneratedCodeInfo.IAnnotation[]|null);
        }

        /** Represents a GeneratedCodeInfo. */
        class GeneratedCodeInfo implements IGeneratedCodeInfo {

            /**
             * Constructs a new GeneratedCodeInfo.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IGeneratedCodeInfo);

            /** GeneratedCodeInfo annotation. */
            public annotation: google.protobuf.GeneratedCodeInfo.IAnnotation[];

            /**
             * Creates a new GeneratedCodeInfo instance using the specified properties.
             * @param [properties] Properties to set
             * @returns GeneratedCodeInfo instance
             */
            public static create(properties?: google.protobuf.IGeneratedCodeInfo): google.protobuf.GeneratedCodeInfo;

            /**
             * Encodes the specified GeneratedCodeInfo message. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.verify|verify} messages.
             * @param message GeneratedCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IGeneratedCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified GeneratedCodeInfo message, length delimited. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.verify|verify} messages.
             * @param message GeneratedCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IGeneratedCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a GeneratedCodeInfo message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns GeneratedCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.GeneratedCodeInfo;

            /**
             * Decodes a GeneratedCodeInfo message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns GeneratedCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.GeneratedCodeInfo;

            /**
             * Verifies a GeneratedCodeInfo message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a GeneratedCodeInfo message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns GeneratedCodeInfo
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.GeneratedCodeInfo;

            /**
             * Creates a plain object from a GeneratedCodeInfo message. Also converts values to other types if specified.
             * @param message GeneratedCodeInfo
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.GeneratedCodeInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this GeneratedCodeInfo to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for GeneratedCodeInfo
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace GeneratedCodeInfo {

            /** Properties of an Annotation. */
            interface IAnnotation {

                /** Annotation path */
                path?: (number[]|null);

                /** Annotation sourceFile */
                sourceFile?: (string|null);

                /** Annotation begin */
                begin?: (number|null);

                /** Annotation end */
                end?: (number|null);

                /** Annotation semantic */
                semantic?: (google.protobuf.GeneratedCodeInfo.Annotation.Semantic|keyof typeof google.protobuf.GeneratedCodeInfo.Annotation.Semantic|null);
            }

            /** Represents an Annotation. */
            class Annotation implements IAnnotation {

                /**
                 * Constructs a new Annotation.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.GeneratedCodeInfo.IAnnotation);

                /** Annotation path. */
                public path: number[];

                /** Annotation sourceFile. */
                public sourceFile: string;

                /** Annotation begin. */
                public begin: number;

                /** Annotation end. */
                public end: number;

                /** Annotation semantic. */
                public semantic: (google.protobuf.GeneratedCodeInfo.Annotation.Semantic|keyof typeof google.protobuf.GeneratedCodeInfo.Annotation.Semantic);

                /**
                 * Creates a new Annotation instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns Annotation instance
                 */
                public static create(properties?: google.protobuf.GeneratedCodeInfo.IAnnotation): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Encodes the specified Annotation message. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.Annotation.verify|verify} messages.
                 * @param message Annotation message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.GeneratedCodeInfo.IAnnotation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified Annotation message, length delimited. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.Annotation.verify|verify} messages.
                 * @param message Annotation message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.GeneratedCodeInfo.IAnnotation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an Annotation message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns Annotation
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Decodes an Annotation message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns Annotation
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Verifies an Annotation message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an Annotation message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns Annotation
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Creates a plain object from an Annotation message. Also converts values to other types if specified.
                 * @param message Annotation
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.GeneratedCodeInfo.Annotation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this Annotation to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for Annotation
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }

            namespace Annotation {

                /** Semantic enum. */
                enum Semantic {
                    NONE = 0,
                    SET = 1,
                    ALIAS = 2
                }
            }
        }
    }
}
